// ================================================================
// Copyright (c) Meta Platforms, Inc. and affiliates.
// ================================================================

#include <pdq/cpp/common/pdqbasetypes.h>
#include <pdq/cpp/common/pdqhamming.h>

namespace facebook {
namespace pdq {
namespace hashing {

// ================================================================
// These are for regression/portability testing

// https://en.wikipedia.org/wiki/Hamming_weight
static const Hash8 hash8_m1 = 0x55;
static const Hash8 hash8_m2 = 0x33;
static const Hash8 hash8_m4 = 0x0f;

static const Hash16 hash16_m1 = 0x5555;
static const Hash16 hash16_m2 = 0x3333;
static const Hash16 hash16_m4 = 0x0f0f;
static const Hash16 hash16_m8 = 0x00ff;

// ----------------------------------------------------------------
int hammingNorm8Uncached(Hash8 h) {
  h = (h & hash8_m1) + ((h >> 1) & hash8_m1);
  h = (h & hash8_m2) + ((h >> 2) & hash8_m2);
  h = (h & hash8_m4) + ((h >> 4) & hash8_m4);
  return h;
}

// ----------------------------------------------------------------
int hammingNorm16Uncached(Hash16 h) {
  h = (h & hash16_m1) + ((h >> 1) & hash16_m1);
  h = (h & hash16_m2) + ((h >> 2) & hash16_m2);
  h = (h & hash16_m4) + ((h >> 4) & hash16_m4);
  h = (h & hash16_m8) + ((h >> 8) & hash16_m8);
  return h;
}

// ----------------------------------------------------------------
int hammingNorm8Slow(Hash8 a) {
  int rv = 0;
  for (int i = 0; i < 8; i++) {
    if (a & (1 << i)) {
      rv++;
    }
  }
  return rv;
}

// ----------------------------------------------------------------
int hammingNorm16Slow(Hash16 a) {
  int rv = 0;
  for (int i = 0; i < 16; i++) {
    if (a & (1 << i)) {
      rv++;
    }
  }
  return rv;
}

// ================================================================
// These are the fast production versions

#ifndef USE_BUILTIN_POPCOUNT

// ----------------------------------------------------------------
// Created by ./hamming-tabulate.cpp
static Hash8 hash8_norm_lookup_table[] = {
    0 /*00*/, 1 /*01*/, 1 /*02*/, 2 /*03*/, 1 /*04*/, 2 /*05*/, 2 /*06*/,
    3 /*07*/, 1 /*08*/, 2 /*09*/, 2 /*0a*/, 3 /*0b*/, 2 /*0c*/, 3 /*0d*/,
    3 /*0e*/, 4 /*0f*/, 1 /*10*/, 2 /*11*/, 2 /*12*/, 3 /*13*/, 2 /*14*/,
    3 /*15*/, 3 /*16*/, 4 /*17*/, 2 /*18*/, 3 /*19*/, 3 /*1a*/, 4 /*1b*/,
    3 /*1c*/, 4 /*1d*/, 4 /*1e*/, 5 /*1f*/, 1 /*20*/, 2 /*21*/, 2 /*22*/,
    3 /*23*/, 2 /*24*/, 3 /*25*/, 3 /*26*/, 4 /*27*/, 2 /*28*/, 3 /*29*/,
    3 /*2a*/, 4 /*2b*/, 3 /*2c*/, 4 /*2d*/, 4 /*2e*/, 5 /*2f*/, 2 /*30*/,
    3 /*31*/, 3 /*32*/, 4 /*33*/, 3 /*34*/, 4 /*35*/, 4 /*36*/, 5 /*37*/,
    3 /*38*/, 4 /*39*/, 4 /*3a*/, 5 /*3b*/, 4 /*3c*/, 5 /*3d*/, 5 /*3e*/,
    6 /*3f*/, 1 /*40*/, 2 /*41*/, 2 /*42*/, 3 /*43*/, 2 /*44*/, 3 /*45*/,
    3 /*46*/, 4 /*47*/, 2 /*48*/, 3 /*49*/, 3 /*4a*/, 4 /*4b*/, 3 /*4c*/,
    4 /*4d*/, 4 /*4e*/, 5 /*4f*/, 2 /*50*/, 3 /*51*/, 3 /*52*/, 4 /*53*/,
    3 /*54*/, 4 /*55*/, 4 /*56*/, 5 /*57*/, 3 /*58*/, 4 /*59*/, 4 /*5a*/,
    5 /*5b*/, 4 /*5c*/, 5 /*5d*/, 5 /*5e*/, 6 /*5f*/, 2 /*60*/, 3 /*61*/,
    3 /*62*/, 4 /*63*/, 3 /*64*/, 4 /*65*/, 4 /*66*/, 5 /*67*/, 3 /*68*/,
    4 /*69*/, 4 /*6a*/, 5 /*6b*/, 4 /*6c*/, 5 /*6d*/, 5 /*6e*/, 6 /*6f*/,
    3 /*70*/, 4 /*71*/, 4 /*72*/, 5 /*73*/, 4 /*74*/, 5 /*75*/, 5 /*76*/,
    6 /*77*/, 4 /*78*/, 5 /*79*/, 5 /*7a*/, 6 /*7b*/, 5 /*7c*/, 6 /*7d*/,
    6 /*7e*/, 7 /*7f*/, 1 /*80*/, 2 /*81*/, 2 /*82*/, 3 /*83*/, 2 /*84*/,
    3 /*85*/, 3 /*86*/, 4 /*87*/, 2 /*88*/, 3 /*89*/, 3 /*8a*/, 4 /*8b*/,
    3 /*8c*/, 4 /*8d*/, 4 /*8e*/, 5 /*8f*/, 2 /*90*/, 3 /*91*/, 3 /*92*/,
    4 /*93*/, 3 /*94*/, 4 /*95*/, 4 /*96*/, 5 /*97*/, 3 /*98*/, 4 /*99*/,
    4 /*9a*/, 5 /*9b*/, 4 /*9c*/, 5 /*9d*/, 5 /*9e*/, 6 /*9f*/, 2 /*a0*/,
    3 /*a1*/, 3 /*a2*/, 4 /*a3*/, 3 /*a4*/, 4 /*a5*/, 4 /*a6*/, 5 /*a7*/,
    3 /*a8*/, 4 /*a9*/, 4 /*aa*/, 5 /*ab*/, 4 /*ac*/, 5 /*ad*/, 5 /*ae*/,
    6 /*af*/, 3 /*b0*/, 4 /*b1*/, 4 /*b2*/, 5 /*b3*/, 4 /*b4*/, 5 /*b5*/,
    5 /*b6*/, 6 /*b7*/, 4 /*b8*/, 5 /*b9*/, 5 /*ba*/, 6 /*bb*/, 5 /*bc*/,
    6 /*bd*/, 6 /*be*/, 7 /*bf*/, 2 /*c0*/, 3 /*c1*/, 3 /*c2*/, 4 /*c3*/,
    3 /*c4*/, 4 /*c5*/, 4 /*c6*/, 5 /*c7*/, 3 /*c8*/, 4 /*c9*/, 4 /*ca*/,
    5 /*cb*/, 4 /*cc*/, 5 /*cd*/, 5 /*ce*/, 6 /*cf*/, 3 /*d0*/, 4 /*d1*/,
    4 /*d2*/, 5 /*d3*/, 4 /*d4*/, 5 /*d5*/, 5 /*d6*/, 6 /*d7*/, 4 /*d8*/,
    5 /*d9*/, 5 /*da*/, 6 /*db*/, 5 /*dc*/, 6 /*dd*/, 6 /*de*/, 7 /*df*/,
    3 /*e0*/, 4 /*e1*/, 4 /*e2*/, 5 /*e3*/, 4 /*e4*/, 5 /*e5*/, 5 /*e6*/,
    6 /*e7*/, 4 /*e8*/, 5 /*e9*/, 5 /*ea*/, 6 /*eb*/, 5 /*ec*/, 6 /*ed*/,
    6 /*ee*/, 7 /*ef*/, 4 /*f0*/, 5 /*f1*/, 5 /*f2*/, 6 /*f3*/, 5 /*f4*/,
    6 /*f5*/, 6 /*f6*/, 7 /*f7*/, 5 /*f8*/, 6 /*f9*/, 6 /*fa*/, 7 /*fb*/,
    6 /*fc*/, 7 /*fd*/, 7 /*fe*/, 8 /*ff*/
};

static Hash16 hash16_norm_lookup_table[] = {
    0 /*00*/,    1 /*01*/,    1 /*02*/,    2 /*03*/,    1 /*04*/,
    2 /*05*/,    2 /*06*/,    3 /*07*/,    1 /*08*/,    2 /*09*/,
    2 /*0a*/,    3 /*0b*/,    2 /*0c*/,    3 /*0d*/,    3 /*0e*/,
    4 /*0f*/,    1 /*10*/,    2 /*11*/,    2 /*12*/,    3 /*13*/,
    2 /*14*/,    3 /*15*/,    3 /*16*/,    4 /*17*/,    2 /*18*/,
    3 /*19*/,    3 /*1a*/,    4 /*1b*/,    3 /*1c*/,    4 /*1d*/,
    4 /*1e*/,    5 /*1f*/,    1 /*20*/,    2 /*21*/,    2 /*22*/,
    3 /*23*/,    2 /*24*/,    3 /*25*/,    3 /*26*/,    4 /*27*/,
    2 /*28*/,    3 /*29*/,    3 /*2a*/,    4 /*2b*/,    3 /*2c*/,
    4 /*2d*/,    4 /*2e*/,    5 /*2f*/,    2 /*30*/,    3 /*31*/,
    3 /*32*/,    4 /*33*/,    3 /*34*/,    4 /*35*/,    4 /*36*/,
    5 /*37*/,    3 /*38*/,    4 /*39*/,    4 /*3a*/,    5 /*3b*/,
    4 /*3c*/,    5 /*3d*/,    5 /*3e*/,    6 /*3f*/,    1 /*40*/,
    2 /*41*/,    2 /*42*/,    3 /*43*/,    2 /*44*/,    3 /*45*/,
    3 /*46*/,    4 /*47*/,    2 /*48*/,    3 /*49*/,    3 /*4a*/,
    4 /*4b*/,    3 /*4c*/,    4 /*4d*/,    4 /*4e*/,    5 /*4f*/,
    2 /*50*/,    3 /*51*/,    3 /*52*/,    4 /*53*/,    3 /*54*/,
    4 /*55*/,    4 /*56*/,    5 /*57*/,    3 /*58*/,    4 /*59*/,
    4 /*5a*/,    5 /*5b*/,    4 /*5c*/,    5 /*5d*/,    5 /*5e*/,
    6 /*5f*/,    2 /*60*/,    3 /*61*/,    3 /*62*/,    4 /*63*/,
    3 /*64*/,    4 /*65*/,    4 /*66*/,    5 /*67*/,    3 /*68*/,
    4 /*69*/,    4 /*6a*/,    5 /*6b*/,    4 /*6c*/,    5 /*6d*/,
    5 /*6e*/,    6 /*6f*/,    3 /*70*/,    4 /*71*/,    4 /*72*/,
    5 /*73*/,    4 /*74*/,    5 /*75*/,    5 /*76*/,    6 /*77*/,
    4 /*78*/,    5 /*79*/,    5 /*7a*/,    6 /*7b*/,    5 /*7c*/,
    6 /*7d*/,    6 /*7e*/,    7 /*7f*/,    1 /*80*/,    2 /*81*/,
    2 /*82*/,    3 /*83*/,    2 /*84*/,    3 /*85*/,    3 /*86*/,
    4 /*87*/,    2 /*88*/,    3 /*89*/,    3 /*8a*/,    4 /*8b*/,
    3 /*8c*/,    4 /*8d*/,    4 /*8e*/,    5 /*8f*/,    2 /*90*/,
    3 /*91*/,    3 /*92*/,    4 /*93*/,    3 /*94*/,    4 /*95*/,
    4 /*96*/,    5 /*97*/,    3 /*98*/,    4 /*99*/,    4 /*9a*/,
    5 /*9b*/,    4 /*9c*/,    5 /*9d*/,    5 /*9e*/,    6 /*9f*/,
    2 /*a0*/,    3 /*a1*/,    3 /*a2*/,    4 /*a3*/,    3 /*a4*/,
    4 /*a5*/,    4 /*a6*/,    5 /*a7*/,    3 /*a8*/,    4 /*a9*/,
    4 /*aa*/,    5 /*ab*/,    4 /*ac*/,    5 /*ad*/,    5 /*ae*/,
    6 /*af*/,    3 /*b0*/,    4 /*b1*/,    4 /*b2*/,    5 /*b3*/,
    4 /*b4*/,    5 /*b5*/,    5 /*b6*/,    6 /*b7*/,    4 /*b8*/,
    5 /*b9*/,    5 /*ba*/,    6 /*bb*/,    5 /*bc*/,    6 /*bd*/,
    6 /*be*/,    7 /*bf*/,    2 /*c0*/,    3 /*c1*/,    3 /*c2*/,
    4 /*c3*/,    3 /*c4*/,    4 /*c5*/,    4 /*c6*/,    5 /*c7*/,
    3 /*c8*/,    4 /*c9*/,    4 /*ca*/,    5 /*cb*/,    4 /*cc*/,
    5 /*cd*/,    5 /*ce*/,    6 /*cf*/,    3 /*d0*/,    4 /*d1*/,
    4 /*d2*/,    5 /*d3*/,    4 /*d4*/,    5 /*d5*/,    5 /*d6*/,
    6 /*d7*/,    4 /*d8*/,    5 /*d9*/,    5 /*da*/,    6 /*db*/,
    5 /*dc*/,    6 /*dd*/,    6 /*de*/,    7 /*df*/,    3 /*e0*/,
    4 /*e1*/,    4 /*e2*/,    5 /*e3*/,    4 /*e4*/,    5 /*e5*/,
    5 /*e6*/,    6 /*e7*/,    4 /*e8*/,    5 /*e9*/,    5 /*ea*/,
    6 /*eb*/,    5 /*ec*/,    6 /*ed*/,    6 /*ee*/,    7 /*ef*/,
    4 /*f0*/,    5 /*f1*/,    5 /*f2*/,    6 /*f3*/,    5 /*f4*/,
    6 /*f5*/,    6 /*f6*/,    7 /*f7*/,    5 /*f8*/,    6 /*f9*/,
    6 /*fa*/,    7 /*fb*/,    6 /*fc*/,    7 /*fd*/,    7 /*fe*/,
    8 /*ff*/,    1 /*100*/,   2 /*101*/,   2 /*102*/,   3 /*103*/,
    2 /*104*/,   3 /*105*/,   3 /*106*/,   4 /*107*/,   2 /*108*/,
    3 /*109*/,   3 /*10a*/,   4 /*10b*/,   3 /*10c*/,   4 /*10d*/,
    4 /*10e*/,   5 /*10f*/,   2 /*110*/,   3 /*111*/,   3 /*112*/,
    4 /*113*/,   3 /*114*/,   4 /*115*/,   4 /*116*/,   5 /*117*/,
    3 /*118*/,   4 /*119*/,   4 /*11a*/,   5 /*11b*/,   4 /*11c*/,
    5 /*11d*/,   5 /*11e*/,   6 /*11f*/,   2 /*120*/,   3 /*121*/,
    3 /*122*/,   4 /*123*/,   3 /*124*/,   4 /*125*/,   4 /*126*/,
    5 /*127*/,   3 /*128*/,   4 /*129*/,   4 /*12a*/,   5 /*12b*/,
    4 /*12c*/,   5 /*12d*/,   5 /*12e*/,   6 /*12f*/,   3 /*130*/,
    4 /*131*/,   4 /*132*/,   5 /*133*/,   4 /*134*/,   5 /*135*/,
    5 /*136*/,   6 /*137*/,   4 /*138*/,   5 /*139*/,   5 /*13a*/,
    6 /*13b*/,   5 /*13c*/,   6 /*13d*/,   6 /*13e*/,   7 /*13f*/,
    2 /*140*/,   3 /*141*/,   3 /*142*/,   4 /*143*/,   3 /*144*/,
    4 /*145*/,   4 /*146*/,   5 /*147*/,   3 /*148*/,   4 /*149*/,
    4 /*14a*/,   5 /*14b*/,   4 /*14c*/,   5 /*14d*/,   5 /*14e*/,
    6 /*14f*/,   3 /*150*/,   4 /*151*/,   4 /*152*/,   5 /*153*/,
    4 /*154*/,   5 /*155*/,   5 /*156*/,   6 /*157*/,   4 /*158*/,
    5 /*159*/,   5 /*15a*/,   6 /*15b*/,   5 /*15c*/,   6 /*15d*/,
    6 /*15e*/,   7 /*15f*/,   3 /*160*/,   4 /*161*/,   4 /*162*/,
    5 /*163*/,   4 /*164*/,   5 /*165*/,   5 /*166*/,   6 /*167*/,
    4 /*168*/,   5 /*169*/,   5 /*16a*/,   6 /*16b*/,   5 /*16c*/,
    6 /*16d*/,   6 /*16e*/,   7 /*16f*/,   4 /*170*/,   5 /*171*/,
    5 /*172*/,   6 /*173*/,   5 /*174*/,   6 /*175*/,   6 /*176*/,
    7 /*177*/,   5 /*178*/,   6 /*179*/,   6 /*17a*/,   7 /*17b*/,
    6 /*17c*/,   7 /*17d*/,   7 /*17e*/,   8 /*17f*/,   2 /*180*/,
    3 /*181*/,   3 /*182*/,   4 /*183*/,   3 /*184*/,   4 /*185*/,
    4 /*186*/,   5 /*187*/,   3 /*188*/,   4 /*189*/,   4 /*18a*/,
    5 /*18b*/,   4 /*18c*/,   5 /*18d*/,   5 /*18e*/,   6 /*18f*/,
    3 /*190*/,   4 /*191*/,   4 /*192*/,   5 /*193*/,   4 /*194*/,
    5 /*195*/,   5 /*196*/,   6 /*197*/,   4 /*198*/,   5 /*199*/,
    5 /*19a*/,   6 /*19b*/,   5 /*19c*/,   6 /*19d*/,   6 /*19e*/,
    7 /*19f*/,   3 /*1a0*/,   4 /*1a1*/,   4 /*1a2*/,   5 /*1a3*/,
    4 /*1a4*/,   5 /*1a5*/,   5 /*1a6*/,   6 /*1a7*/,   4 /*1a8*/,
    5 /*1a9*/,   5 /*1aa*/,   6 /*1ab*/,   5 /*1ac*/,   6 /*1ad*/,
    6 /*1ae*/,   7 /*1af*/,   4 /*1b0*/,   5 /*1b1*/,   5 /*1b2*/,
    6 /*1b3*/,   5 /*1b4*/,   6 /*1b5*/,   6 /*1b6*/,   7 /*1b7*/,
    5 /*1b8*/,   6 /*1b9*/,   6 /*1ba*/,   7 /*1bb*/,   6 /*1bc*/,
    7 /*1bd*/,   7 /*1be*/,   8 /*1bf*/,   3 /*1c0*/,   4 /*1c1*/,
    4 /*1c2*/,   5 /*1c3*/,   4 /*1c4*/,   5 /*1c5*/,   5 /*1c6*/,
    6 /*1c7*/,   4 /*1c8*/,   5 /*1c9*/,   5 /*1ca*/,   6 /*1cb*/,
    5 /*1cc*/,   6 /*1cd*/,   6 /*1ce*/,   7 /*1cf*/,   4 /*1d0*/,
    5 /*1d1*/,   5 /*1d2*/,   6 /*1d3*/,   5 /*1d4*/,   6 /*1d5*/,
    6 /*1d6*/,   7 /*1d7*/,   5 /*1d8*/,   6 /*1d9*/,   6 /*1da*/,
    7 /*1db*/,   6 /*1dc*/,   7 /*1dd*/,   7 /*1de*/,   8 /*1df*/,
    4 /*1e0*/,   5 /*1e1*/,   5 /*1e2*/,   6 /*1e3*/,   5 /*1e4*/,
    6 /*1e5*/,   6 /*1e6*/,   7 /*1e7*/,   5 /*1e8*/,   6 /*1e9*/,
    6 /*1ea*/,   7 /*1eb*/,   6 /*1ec*/,   7 /*1ed*/,   7 /*1ee*/,
    8 /*1ef*/,   5 /*1f0*/,   6 /*1f1*/,   6 /*1f2*/,   7 /*1f3*/,
    6 /*1f4*/,   7 /*1f5*/,   7 /*1f6*/,   8 /*1f7*/,   6 /*1f8*/,
    7 /*1f9*/,   7 /*1fa*/,   8 /*1fb*/,   7 /*1fc*/,   8 /*1fd*/,
    8 /*1fe*/,   9 /*1ff*/,   1 /*200*/,   2 /*201*/,   2 /*202*/,
    3 /*203*/,   2 /*204*/,   3 /*205*/,   3 /*206*/,   4 /*207*/,
    2 /*208*/,   3 /*209*/,   3 /*20a*/,   4 /*20b*/,   3 /*20c*/,
    4 /*20d*/,   4 /*20e*/,   5 /*20f*/,   2 /*210*/,   3 /*211*/,
    3 /*212*/,   4 /*213*/,   3 /*214*/,   4 /*215*/,   4 /*216*/,
    5 /*217*/,   3 /*218*/,   4 /*219*/,   4 /*21a*/,   5 /*21b*/,
    4 /*21c*/,   5 /*21d*/,   5 /*21e*/,   6 /*21f*/,   2 /*220*/,
    3 /*221*/,   3 /*222*/,   4 /*223*/,   3 /*224*/,   4 /*225*/,
    4 /*226*/,   5 /*227*/,   3 /*228*/,   4 /*229*/,   4 /*22a*/,
    5 /*22b*/,   4 /*22c*/,   5 /*22d*/,   5 /*22e*/,   6 /*22f*/,
    3 /*230*/,   4 /*231*/,   4 /*232*/,   5 /*233*/,   4 /*234*/,
    5 /*235*/,   5 /*236*/,   6 /*237*/,   4 /*238*/,   5 /*239*/,
    5 /*23a*/,   6 /*23b*/,   5 /*23c*/,   6 /*23d*/,   6 /*23e*/,
    7 /*23f*/,   2 /*240*/,   3 /*241*/,   3 /*242*/,   4 /*243*/,
    3 /*244*/,   4 /*245*/,   4 /*246*/,   5 /*247*/,   3 /*248*/,
    4 /*249*/,   4 /*24a*/,   5 /*24b*/,   4 /*24c*/,   5 /*24d*/,
    5 /*24e*/,   6 /*24f*/,   3 /*250*/,   4 /*251*/,   4 /*252*/,
    5 /*253*/,   4 /*254*/,   5 /*255*/,   5 /*256*/,   6 /*257*/,
    4 /*258*/,   5 /*259*/,   5 /*25a*/,   6 /*25b*/,   5 /*25c*/,
    6 /*25d*/,   6 /*25e*/,   7 /*25f*/,   3 /*260*/,   4 /*261*/,
    4 /*262*/,   5 /*263*/,   4 /*264*/,   5 /*265*/,   5 /*266*/,
    6 /*267*/,   4 /*268*/,   5 /*269*/,   5 /*26a*/,   6 /*26b*/,
    5 /*26c*/,   6 /*26d*/,   6 /*26e*/,   7 /*26f*/,   4 /*270*/,
    5 /*271*/,   5 /*272*/,   6 /*273*/,   5 /*274*/,   6 /*275*/,
    6 /*276*/,   7 /*277*/,   5 /*278*/,   6 /*279*/,   6 /*27a*/,
    7 /*27b*/,   6 /*27c*/,   7 /*27d*/,   7 /*27e*/,   8 /*27f*/,
    2 /*280*/,   3 /*281*/,   3 /*282*/,   4 /*283*/,   3 /*284*/,
    4 /*285*/,   4 /*286*/,   5 /*287*/,   3 /*288*/,   4 /*289*/,
    4 /*28a*/,   5 /*28b*/,   4 /*28c*/,   5 /*28d*/,   5 /*28e*/,
    6 /*28f*/,   3 /*290*/,   4 /*291*/,   4 /*292*/,   5 /*293*/,
    4 /*294*/,   5 /*295*/,   5 /*296*/,   6 /*297*/,   4 /*298*/,
    5 /*299*/,   5 /*29a*/,   6 /*29b*/,   5 /*29c*/,   6 /*29d*/,
    6 /*29e*/,   7 /*29f*/,   3 /*2a0*/,   4 /*2a1*/,   4 /*2a2*/,
    5 /*2a3*/,   4 /*2a4*/,   5 /*2a5*/,   5 /*2a6*/,   6 /*2a7*/,
    4 /*2a8*/,   5 /*2a9*/,   5 /*2aa*/,   6 /*2ab*/,   5 /*2ac*/,
    6 /*2ad*/,   6 /*2ae*/,   7 /*2af*/,   4 /*2b0*/,   5 /*2b1*/,
    5 /*2b2*/,   6 /*2b3*/,   5 /*2b4*/,   6 /*2b5*/,   6 /*2b6*/,
    7 /*2b7*/,   5 /*2b8*/,   6 /*2b9*/,   6 /*2ba*/,   7 /*2bb*/,
    6 /*2bc*/,   7 /*2bd*/,   7 /*2be*/,   8 /*2bf*/,   3 /*2c0*/,
    4 /*2c1*/,   4 /*2c2*/,   5 /*2c3*/,   4 /*2c4*/,   5 /*2c5*/,
    5 /*2c6*/,   6 /*2c7*/,   4 /*2c8*/,   5 /*2c9*/,   5 /*2ca*/,
    6 /*2cb*/,   5 /*2cc*/,   6 /*2cd*/,   6 /*2ce*/,   7 /*2cf*/,
    4 /*2d0*/,   5 /*2d1*/,   5 /*2d2*/,   6 /*2d3*/,   5 /*2d4*/,
    6 /*2d5*/,   6 /*2d6*/,   7 /*2d7*/,   5 /*2d8*/,   6 /*2d9*/,
    6 /*2da*/,   7 /*2db*/,   6 /*2dc*/,   7 /*2dd*/,   7 /*2de*/,
    8 /*2df*/,   4 /*2e0*/,   5 /*2e1*/,   5 /*2e2*/,   6 /*2e3*/,
    5 /*2e4*/,   6 /*2e5*/,   6 /*2e6*/,   7 /*2e7*/,   5 /*2e8*/,
    6 /*2e9*/,   6 /*2ea*/,   7 /*2eb*/,   6 /*2ec*/,   7 /*2ed*/,
    7 /*2ee*/,   8 /*2ef*/,   5 /*2f0*/,   6 /*2f1*/,   6 /*2f2*/,
    7 /*2f3*/,   6 /*2f4*/,   7 /*2f5*/,   7 /*2f6*/,   8 /*2f7*/,
    6 /*2f8*/,   7 /*2f9*/,   7 /*2fa*/,   8 /*2fb*/,   7 /*2fc*/,
    8 /*2fd*/,   8 /*2fe*/,   9 /*2ff*/,   2 /*300*/,   3 /*301*/,
    3 /*302*/,   4 /*303*/,   3 /*304*/,   4 /*305*/,   4 /*306*/,
    5 /*307*/,   3 /*308*/,   4 /*309*/,   4 /*30a*/,   5 /*30b*/,
    4 /*30c*/,   5 /*30d*/,   5 /*30e*/,   6 /*30f*/,   3 /*310*/,
    4 /*311*/,   4 /*312*/,   5 /*313*/,   4 /*314*/,   5 /*315*/,
    5 /*316*/,   6 /*317*/,   4 /*318*/,   5 /*319*/,   5 /*31a*/,
    6 /*31b*/,   5 /*31c*/,   6 /*31d*/,   6 /*31e*/,   7 /*31f*/,
    3 /*320*/,   4 /*321*/,   4 /*322*/,   5 /*323*/,   4 /*324*/,
    5 /*325*/,   5 /*326*/,   6 /*327*/,   4 /*328*/,   5 /*329*/,
    5 /*32a*/,   6 /*32b*/,   5 /*32c*/,   6 /*32d*/,   6 /*32e*/,
    7 /*32f*/,   4 /*330*/,   5 /*331*/,   5 /*332*/,   6 /*333*/,
    5 /*334*/,   6 /*335*/,   6 /*336*/,   7 /*337*/,   5 /*338*/,
    6 /*339*/,   6 /*33a*/,   7 /*33b*/,   6 /*33c*/,   7 /*33d*/,
    7 /*33e*/,   8 /*33f*/,   3 /*340*/,   4 /*341*/,   4 /*342*/,
    5 /*343*/,   4 /*344*/,   5 /*345*/,   5 /*346*/,   6 /*347*/,
    4 /*348*/,   5 /*349*/,   5 /*34a*/,   6 /*34b*/,   5 /*34c*/,
    6 /*34d*/,   6 /*34e*/,   7 /*34f*/,   4 /*350*/,   5 /*351*/,
    5 /*352*/,   6 /*353*/,   5 /*354*/,   6 /*355*/,   6 /*356*/,
    7 /*357*/,   5 /*358*/,   6 /*359*/,   6 /*35a*/,   7 /*35b*/,
    6 /*35c*/,   7 /*35d*/,   7 /*35e*/,   8 /*35f*/,   4 /*360*/,
    5 /*361*/,   5 /*362*/,   6 /*363*/,   5 /*364*/,   6 /*365*/,
    6 /*366*/,   7 /*367*/,   5 /*368*/,   6 /*369*/,   6 /*36a*/,
    7 /*36b*/,   6 /*36c*/,   7 /*36d*/,   7 /*36e*/,   8 /*36f*/,
    5 /*370*/,   6 /*371*/,   6 /*372*/,   7 /*373*/,   6 /*374*/,
    7 /*375*/,   7 /*376*/,   8 /*377*/,   6 /*378*/,   7 /*379*/,
    7 /*37a*/,   8 /*37b*/,   7 /*37c*/,   8 /*37d*/,   8 /*37e*/,
    9 /*37f*/,   3 /*380*/,   4 /*381*/,   4 /*382*/,   5 /*383*/,
    4 /*384*/,   5 /*385*/,   5 /*386*/,   6 /*387*/,   4 /*388*/,
    5 /*389*/,   5 /*38a*/,   6 /*38b*/,   5 /*38c*/,   6 /*38d*/,
    6 /*38e*/,   7 /*38f*/,   4 /*390*/,   5 /*391*/,   5 /*392*/,
    6 /*393*/,   5 /*394*/,   6 /*395*/,   6 /*396*/,   7 /*397*/,
    5 /*398*/,   6 /*399*/,   6 /*39a*/,   7 /*39b*/,   6 /*39c*/,
    7 /*39d*/,   7 /*39e*/,   8 /*39f*/,   4 /*3a0*/,   5 /*3a1*/,
    5 /*3a2*/,   6 /*3a3*/,   5 /*3a4*/,   6 /*3a5*/,   6 /*3a6*/,
    7 /*3a7*/,   5 /*3a8*/,   6 /*3a9*/,   6 /*3aa*/,   7 /*3ab*/,
    6 /*3ac*/,   7 /*3ad*/,   7 /*3ae*/,   8 /*3af*/,   5 /*3b0*/,
    6 /*3b1*/,   6 /*3b2*/,   7 /*3b3*/,   6 /*3b4*/,   7 /*3b5*/,
    7 /*3b6*/,   8 /*3b7*/,   6 /*3b8*/,   7 /*3b9*/,   7 /*3ba*/,
    8 /*3bb*/,   7 /*3bc*/,   8 /*3bd*/,   8 /*3be*/,   9 /*3bf*/,
    4 /*3c0*/,   5 /*3c1*/,   5 /*3c2*/,   6 /*3c3*/,   5 /*3c4*/,
    6 /*3c5*/,   6 /*3c6*/,   7 /*3c7*/,   5 /*3c8*/,   6 /*3c9*/,
    6 /*3ca*/,   7 /*3cb*/,   6 /*3cc*/,   7 /*3cd*/,   7 /*3ce*/,
    8 /*3cf*/,   5 /*3d0*/,   6 /*3d1*/,   6 /*3d2*/,   7 /*3d3*/,
    6 /*3d4*/,   7 /*3d5*/,   7 /*3d6*/,   8 /*3d7*/,   6 /*3d8*/,
    7 /*3d9*/,   7 /*3da*/,   8 /*3db*/,   7 /*3dc*/,   8 /*3dd*/,
    8 /*3de*/,   9 /*3df*/,   5 /*3e0*/,   6 /*3e1*/,   6 /*3e2*/,
    7 /*3e3*/,   6 /*3e4*/,   7 /*3e5*/,   7 /*3e6*/,   8 /*3e7*/,
    6 /*3e8*/,   7 /*3e9*/,   7 /*3ea*/,   8 /*3eb*/,   7 /*3ec*/,
    8 /*3ed*/,   8 /*3ee*/,   9 /*3ef*/,   6 /*3f0*/,   7 /*3f1*/,
    7 /*3f2*/,   8 /*3f3*/,   7 /*3f4*/,   8 /*3f5*/,   8 /*3f6*/,
    9 /*3f7*/,   7 /*3f8*/,   8 /*3f9*/,   8 /*3fa*/,   9 /*3fb*/,
    8 /*3fc*/,   9 /*3fd*/,   9 /*3fe*/,   10 /*3ff*/,  1 /*400*/,
    2 /*401*/,   2 /*402*/,   3 /*403*/,   2 /*404*/,   3 /*405*/,
    3 /*406*/,   4 /*407*/,   2 /*408*/,   3 /*409*/,   3 /*40a*/,
    4 /*40b*/,   3 /*40c*/,   4 /*40d*/,   4 /*40e*/,   5 /*40f*/,
    2 /*410*/,   3 /*411*/,   3 /*412*/,   4 /*413*/,   3 /*414*/,
    4 /*415*/,   4 /*416*/,   5 /*417*/,   3 /*418*/,   4 /*419*/,
    4 /*41a*/,   5 /*41b*/,   4 /*41c*/,   5 /*41d*/,   5 /*41e*/,
    6 /*41f*/,   2 /*420*/,   3 /*421*/,   3 /*422*/,   4 /*423*/,
    3 /*424*/,   4 /*425*/,   4 /*426*/,   5 /*427*/,   3 /*428*/,
    4 /*429*/,   4 /*42a*/,   5 /*42b*/,   4 /*42c*/,   5 /*42d*/,
    5 /*42e*/,   6 /*42f*/,   3 /*430*/,   4 /*431*/,   4 /*432*/,
    5 /*433*/,   4 /*434*/,   5 /*435*/,   5 /*436*/,   6 /*437*/,
    4 /*438*/,   5 /*439*/,   5 /*43a*/,   6 /*43b*/,   5 /*43c*/,
    6 /*43d*/,   6 /*43e*/,   7 /*43f*/,   2 /*440*/,   3 /*441*/,
    3 /*442*/,   4 /*443*/,   3 /*444*/,   4 /*445*/,   4 /*446*/,
    5 /*447*/,   3 /*448*/,   4 /*449*/,   4 /*44a*/,   5 /*44b*/,
    4 /*44c*/,   5 /*44d*/,   5 /*44e*/,   6 /*44f*/,   3 /*450*/,
    4 /*451*/,   4 /*452*/,   5 /*453*/,   4 /*454*/,   5 /*455*/,
    5 /*456*/,   6 /*457*/,   4 /*458*/,   5 /*459*/,   5 /*45a*/,
    6 /*45b*/,   5 /*45c*/,   6 /*45d*/,   6 /*45e*/,   7 /*45f*/,
    3 /*460*/,   4 /*461*/,   4 /*462*/,   5 /*463*/,   4 /*464*/,
    5 /*465*/,   5 /*466*/,   6 /*467*/,   4 /*468*/,   5 /*469*/,
    5 /*46a*/,   6 /*46b*/,   5 /*46c*/,   6 /*46d*/,   6 /*46e*/,
    7 /*46f*/,   4 /*470*/,   5 /*471*/,   5 /*472*/,   6 /*473*/,
    5 /*474*/,   6 /*475*/,   6 /*476*/,   7 /*477*/,   5 /*478*/,
    6 /*479*/,   6 /*47a*/,   7 /*47b*/,   6 /*47c*/,   7 /*47d*/,
    7 /*47e*/,   8 /*47f*/,   2 /*480*/,   3 /*481*/,   3 /*482*/,
    4 /*483*/,   3 /*484*/,   4 /*485*/,   4 /*486*/,   5 /*487*/,
    3 /*488*/,   4 /*489*/,   4 /*48a*/,   5 /*48b*/,   4 /*48c*/,
    5 /*48d*/,   5 /*48e*/,   6 /*48f*/,   3 /*490*/,   4 /*491*/,
    4 /*492*/,   5 /*493*/,   4 /*494*/,   5 /*495*/,   5 /*496*/,
    6 /*497*/,   4 /*498*/,   5 /*499*/,   5 /*49a*/,   6 /*49b*/,
    5 /*49c*/,   6 /*49d*/,   6 /*49e*/,   7 /*49f*/,   3 /*4a0*/,
    4 /*4a1*/,   4 /*4a2*/,   5 /*4a3*/,   4 /*4a4*/,   5 /*4a5*/,
    5 /*4a6*/,   6 /*4a7*/,   4 /*4a8*/,   5 /*4a9*/,   5 /*4aa*/,
    6 /*4ab*/,   5 /*4ac*/,   6 /*4ad*/,   6 /*4ae*/,   7 /*4af*/,
    4 /*4b0*/,   5 /*4b1*/,   5 /*4b2*/,   6 /*4b3*/,   5 /*4b4*/,
    6 /*4b5*/,   6 /*4b6*/,   7 /*4b7*/,   5 /*4b8*/,   6 /*4b9*/,
    6 /*4ba*/,   7 /*4bb*/,   6 /*4bc*/,   7 /*4bd*/,   7 /*4be*/,
    8 /*4bf*/,   3 /*4c0*/,   4 /*4c1*/,   4 /*4c2*/,   5 /*4c3*/,
    4 /*4c4*/,   5 /*4c5*/,   5 /*4c6*/,   6 /*4c7*/,   4 /*4c8*/,
    5 /*4c9*/,   5 /*4ca*/,   6 /*4cb*/,   5 /*4cc*/,   6 /*4cd*/,
    6 /*4ce*/,   7 /*4cf*/,   4 /*4d0*/,   5 /*4d1*/,   5 /*4d2*/,
    6 /*4d3*/,   5 /*4d4*/,   6 /*4d5*/,   6 /*4d6*/,   7 /*4d7*/,
    5 /*4d8*/,   6 /*4d9*/,   6 /*4da*/,   7 /*4db*/,   6 /*4dc*/,
    7 /*4dd*/,   7 /*4de*/,   8 /*4df*/,   4 /*4e0*/,   5 /*4e1*/,
    5 /*4e2*/,   6 /*4e3*/,   5 /*4e4*/,   6 /*4e5*/,   6 /*4e6*/,
    7 /*4e7*/,   5 /*4e8*/,   6 /*4e9*/,   6 /*4ea*/,   7 /*4eb*/,
    6 /*4ec*/,   7 /*4ed*/,   7 /*4ee*/,   8 /*4ef*/,   5 /*4f0*/,
    6 /*4f1*/,   6 /*4f2*/,   7 /*4f3*/,   6 /*4f4*/,   7 /*4f5*/,
    7 /*4f6*/,   8 /*4f7*/,   6 /*4f8*/,   7 /*4f9*/,   7 /*4fa*/,
    8 /*4fb*/,   7 /*4fc*/,   8 /*4fd*/,   8 /*4fe*/,   9 /*4ff*/,
    2 /*500*/,   3 /*501*/,   3 /*502*/,   4 /*503*/,   3 /*504*/,
    4 /*505*/,   4 /*506*/,   5 /*507*/,   3 /*508*/,   4 /*509*/,
    4 /*50a*/,   5 /*50b*/,   4 /*50c*/,   5 /*50d*/,   5 /*50e*/,
    6 /*50f*/,   3 /*510*/,   4 /*511*/,   4 /*512*/,   5 /*513*/,
    4 /*514*/,   5 /*515*/,   5 /*516*/,   6 /*517*/,   4 /*518*/,
    5 /*519*/,   5 /*51a*/,   6 /*51b*/,   5 /*51c*/,   6 /*51d*/,
    6 /*51e*/,   7 /*51f*/,   3 /*520*/,   4 /*521*/,   4 /*522*/,
    5 /*523*/,   4 /*524*/,   5 /*525*/,   5 /*526*/,   6 /*527*/,
    4 /*528*/,   5 /*529*/,   5 /*52a*/,   6 /*52b*/,   5 /*52c*/,
    6 /*52d*/,   6 /*52e*/,   7 /*52f*/,   4 /*530*/,   5 /*531*/,
    5 /*532*/,   6 /*533*/,   5 /*534*/,   6 /*535*/,   6 /*536*/,
    7 /*537*/,   5 /*538*/,   6 /*539*/,   6 /*53a*/,   7 /*53b*/,
    6 /*53c*/,   7 /*53d*/,   7 /*53e*/,   8 /*53f*/,   3 /*540*/,
    4 /*541*/,   4 /*542*/,   5 /*543*/,   4 /*544*/,   5 /*545*/,
    5 /*546*/,   6 /*547*/,   4 /*548*/,   5 /*549*/,   5 /*54a*/,
    6 /*54b*/,   5 /*54c*/,   6 /*54d*/,   6 /*54e*/,   7 /*54f*/,
    4 /*550*/,   5 /*551*/,   5 /*552*/,   6 /*553*/,   5 /*554*/,
    6 /*555*/,   6 /*556*/,   7 /*557*/,   5 /*558*/,   6 /*559*/,
    6 /*55a*/,   7 /*55b*/,   6 /*55c*/,   7 /*55d*/,   7 /*55e*/,
    8 /*55f*/,   4 /*560*/,   5 /*561*/,   5 /*562*/,   6 /*563*/,
    5 /*564*/,   6 /*565*/,   6 /*566*/,   7 /*567*/,   5 /*568*/,
    6 /*569*/,   6 /*56a*/,   7 /*56b*/,   6 /*56c*/,   7 /*56d*/,
    7 /*56e*/,   8 /*56f*/,   5 /*570*/,   6 /*571*/,   6 /*572*/,
    7 /*573*/,   6 /*574*/,   7 /*575*/,   7 /*576*/,   8 /*577*/,
    6 /*578*/,   7 /*579*/,   7 /*57a*/,   8 /*57b*/,   7 /*57c*/,
    8 /*57d*/,   8 /*57e*/,   9 /*57f*/,   3 /*580*/,   4 /*581*/,
    4 /*582*/,   5 /*583*/,   4 /*584*/,   5 /*585*/,   5 /*586*/,
    6 /*587*/,   4 /*588*/,   5 /*589*/,   5 /*58a*/,   6 /*58b*/,
    5 /*58c*/,   6 /*58d*/,   6 /*58e*/,   7 /*58f*/,   4 /*590*/,
    5 /*591*/,   5 /*592*/,   6 /*593*/,   5 /*594*/,   6 /*595*/,
    6 /*596*/,   7 /*597*/,   5 /*598*/,   6 /*599*/,   6 /*59a*/,
    7 /*59b*/,   6 /*59c*/,   7 /*59d*/,   7 /*59e*/,   8 /*59f*/,
    4 /*5a0*/,   5 /*5a1*/,   5 /*5a2*/,   6 /*5a3*/,   5 /*5a4*/,
    6 /*5a5*/,   6 /*5a6*/,   7 /*5a7*/,   5 /*5a8*/,   6 /*5a9*/,
    6 /*5aa*/,   7 /*5ab*/,   6 /*5ac*/,   7 /*5ad*/,   7 /*5ae*/,
    8 /*5af*/,   5 /*5b0*/,   6 /*5b1*/,   6 /*5b2*/,   7 /*5b3*/,
    6 /*5b4*/,   7 /*5b5*/,   7 /*5b6*/,   8 /*5b7*/,   6 /*5b8*/,
    7 /*5b9*/,   7 /*5ba*/,   8 /*5bb*/,   7 /*5bc*/,   8 /*5bd*/,
    8 /*5be*/,   9 /*5bf*/,   4 /*5c0*/,   5 /*5c1*/,   5 /*5c2*/,
    6 /*5c3*/,   5 /*5c4*/,   6 /*5c5*/,   6 /*5c6*/,   7 /*5c7*/,
    5 /*5c8*/,   6 /*5c9*/,   6 /*5ca*/,   7 /*5cb*/,   6 /*5cc*/,
    7 /*5cd*/,   7 /*5ce*/,   8 /*5cf*/,   5 /*5d0*/,   6 /*5d1*/,
    6 /*5d2*/,   7 /*5d3*/,   6 /*5d4*/,   7 /*5d5*/,   7 /*5d6*/,
    8 /*5d7*/,   6 /*5d8*/,   7 /*5d9*/,   7 /*5da*/,   8 /*5db*/,
    7 /*5dc*/,   8 /*5dd*/,   8 /*5de*/,   9 /*5df*/,   5 /*5e0*/,
    6 /*5e1*/,   6 /*5e2*/,   7 /*5e3*/,   6 /*5e4*/,   7 /*5e5*/,
    7 /*5e6*/,   8 /*5e7*/,   6 /*5e8*/,   7 /*5e9*/,   7 /*5ea*/,
    8 /*5eb*/,   7 /*5ec*/,   8 /*5ed*/,   8 /*5ee*/,   9 /*5ef*/,
    6 /*5f0*/,   7 /*5f1*/,   7 /*5f2*/,   8 /*5f3*/,   7 /*5f4*/,
    8 /*5f5*/,   8 /*5f6*/,   9 /*5f7*/,   7 /*5f8*/,   8 /*5f9*/,
    8 /*5fa*/,   9 /*5fb*/,   8 /*5fc*/,   9 /*5fd*/,   9 /*5fe*/,
    10 /*5ff*/,  2 /*600*/,   3 /*601*/,   3 /*602*/,   4 /*603*/,
    3 /*604*/,   4 /*605*/,   4 /*606*/,   5 /*607*/,   3 /*608*/,
    4 /*609*/,   4 /*60a*/,   5 /*60b*/,   4 /*60c*/,   5 /*60d*/,
    5 /*60e*/,   6 /*60f*/,   3 /*610*/,   4 /*611*/,   4 /*612*/,
    5 /*613*/,   4 /*614*/,   5 /*615*/,   5 /*616*/,   6 /*617*/,
    4 /*618*/,   5 /*619*/,   5 /*61a*/,   6 /*61b*/,   5 /*61c*/,
    6 /*61d*/,   6 /*61e*/,   7 /*61f*/,   3 /*620*/,   4 /*621*/,
    4 /*622*/,   5 /*623*/,   4 /*624*/,   5 /*625*/,   5 /*626*/,
    6 /*627*/,   4 /*628*/,   5 /*629*/,   5 /*62a*/,   6 /*62b*/,
    5 /*62c*/,   6 /*62d*/,   6 /*62e*/,   7 /*62f*/,   4 /*630*/,
    5 /*631*/,   5 /*632*/,   6 /*633*/,   5 /*634*/,   6 /*635*/,
    6 /*636*/,   7 /*637*/,   5 /*638*/,   6 /*639*/,   6 /*63a*/,
    7 /*63b*/,   6 /*63c*/,   7 /*63d*/,   7 /*63e*/,   8 /*63f*/,
    3 /*640*/,   4 /*641*/,   4 /*642*/,   5 /*643*/,   4 /*644*/,
    5 /*645*/,   5 /*646*/,   6 /*647*/,   4 /*648*/,   5 /*649*/,
    5 /*64a*/,   6 /*64b*/,   5 /*64c*/,   6 /*64d*/,   6 /*64e*/,
    7 /*64f*/,   4 /*650*/,   5 /*651*/,   5 /*652*/,   6 /*653*/,
    5 /*654*/,   6 /*655*/,   6 /*656*/,   7 /*657*/,   5 /*658*/,
    6 /*659*/,   6 /*65a*/,   7 /*65b*/,   6 /*65c*/,   7 /*65d*/,
    7 /*65e*/,   8 /*65f*/,   4 /*660*/,   5 /*661*/,   5 /*662*/,
    6 /*663*/,   5 /*664*/,   6 /*665*/,   6 /*666*/,   7 /*667*/,
    5 /*668*/,   6 /*669*/,   6 /*66a*/,   7 /*66b*/,   6 /*66c*/,
    7 /*66d*/,   7 /*66e*/,   8 /*66f*/,   5 /*670*/,   6 /*671*/,
    6 /*672*/,   7 /*673*/,   6 /*674*/,   7 /*675*/,   7 /*676*/,
    8 /*677*/,   6 /*678*/,   7 /*679*/,   7 /*67a*/,   8 /*67b*/,
    7 /*67c*/,   8 /*67d*/,   8 /*67e*/,   9 /*67f*/,   3 /*680*/,
    4 /*681*/,   4 /*682*/,   5 /*683*/,   4 /*684*/,   5 /*685*/,
    5 /*686*/,   6 /*687*/,   4 /*688*/,   5 /*689*/,   5 /*68a*/,
    6 /*68b*/,   5 /*68c*/,   6 /*68d*/,   6 /*68e*/,   7 /*68f*/,
    4 /*690*/,   5 /*691*/,   5 /*692*/,   6 /*693*/,   5 /*694*/,
    6 /*695*/,   6 /*696*/,   7 /*697*/,   5 /*698*/,   6 /*699*/,
    6 /*69a*/,   7 /*69b*/,   6 /*69c*/,   7 /*69d*/,   7 /*69e*/,
    8 /*69f*/,   4 /*6a0*/,   5 /*6a1*/,   5 /*6a2*/,   6 /*6a3*/,
    5 /*6a4*/,   6 /*6a5*/,   6 /*6a6*/,   7 /*6a7*/,   5 /*6a8*/,
    6 /*6a9*/,   6 /*6aa*/,   7 /*6ab*/,   6 /*6ac*/,   7 /*6ad*/,
    7 /*6ae*/,   8 /*6af*/,   5 /*6b0*/,   6 /*6b1*/,   6 /*6b2*/,
    7 /*6b3*/,   6 /*6b4*/,   7 /*6b5*/,   7 /*6b6*/,   8 /*6b7*/,
    6 /*6b8*/,   7 /*6b9*/,   7 /*6ba*/,   8 /*6bb*/,   7 /*6bc*/,
    8 /*6bd*/,   8 /*6be*/,   9 /*6bf*/,   4 /*6c0*/,   5 /*6c1*/,
    5 /*6c2*/,   6 /*6c3*/,   5 /*6c4*/,   6 /*6c5*/,   6 /*6c6*/,
    7 /*6c7*/,   5 /*6c8*/,   6 /*6c9*/,   6 /*6ca*/,   7 /*6cb*/,
    6 /*6cc*/,   7 /*6cd*/,   7 /*6ce*/,   8 /*6cf*/,   5 /*6d0*/,
    6 /*6d1*/,   6 /*6d2*/,   7 /*6d3*/,   6 /*6d4*/,   7 /*6d5*/,
    7 /*6d6*/,   8 /*6d7*/,   6 /*6d8*/,   7 /*6d9*/,   7 /*6da*/,
    8 /*6db*/,   7 /*6dc*/,   8 /*6dd*/,   8 /*6de*/,   9 /*6df*/,
    5 /*6e0*/,   6 /*6e1*/,   6 /*6e2*/,   7 /*6e3*/,   6 /*6e4*/,
    7 /*6e5*/,   7 /*6e6*/,   8 /*6e7*/,   6 /*6e8*/,   7 /*6e9*/,
    7 /*6ea*/,   8 /*6eb*/,   7 /*6ec*/,   8 /*6ed*/,   8 /*6ee*/,
    9 /*6ef*/,   6 /*6f0*/,   7 /*6f1*/,   7 /*6f2*/,   8 /*6f3*/,
    7 /*6f4*/,   8 /*6f5*/,   8 /*6f6*/,   9 /*6f7*/,   7 /*6f8*/,
    8 /*6f9*/,   8 /*6fa*/,   9 /*6fb*/,   8 /*6fc*/,   9 /*6fd*/,
    9 /*6fe*/,   10 /*6ff*/,  3 /*700*/,   4 /*701*/,   4 /*702*/,
    5 /*703*/,   4 /*704*/,   5 /*705*/,   5 /*706*/,   6 /*707*/,
    4 /*708*/,   5 /*709*/,   5 /*70a*/,   6 /*70b*/,   5 /*70c*/,
    6 /*70d*/,   6 /*70e*/,   7 /*70f*/,   4 /*710*/,   5 /*711*/,
    5 /*712*/,   6 /*713*/,   5 /*714*/,   6 /*715*/,   6 /*716*/,
    7 /*717*/,   5 /*718*/,   6 /*719*/,   6 /*71a*/,   7 /*71b*/,
    6 /*71c*/,   7 /*71d*/,   7 /*71e*/,   8 /*71f*/,   4 /*720*/,
    5 /*721*/,   5 /*722*/,   6 /*723*/,   5 /*724*/,   6 /*725*/,
    6 /*726*/,   7 /*727*/,   5 /*728*/,   6 /*729*/,   6 /*72a*/,
    7 /*72b*/,   6 /*72c*/,   7 /*72d*/,   7 /*72e*/,   8 /*72f*/,
    5 /*730*/,   6 /*731*/,   6 /*732*/,   7 /*733*/,   6 /*734*/,
    7 /*735*/,   7 /*736*/,   8 /*737*/,   6 /*738*/,   7 /*739*/,
    7 /*73a*/,   8 /*73b*/,   7 /*73c*/,   8 /*73d*/,   8 /*73e*/,
    9 /*73f*/,   4 /*740*/,   5 /*741*/,   5 /*742*/,   6 /*743*/,
    5 /*744*/,   6 /*745*/,   6 /*746*/,   7 /*747*/,   5 /*748*/,
    6 /*749*/,   6 /*74a*/,   7 /*74b*/,   6 /*74c*/,   7 /*74d*/,
    7 /*74e*/,   8 /*74f*/,   5 /*750*/,   6 /*751*/,   6 /*752*/,
    7 /*753*/,   6 /*754*/,   7 /*755*/,   7 /*756*/,   8 /*757*/,
    6 /*758*/,   7 /*759*/,   7 /*75a*/,   8 /*75b*/,   7 /*75c*/,
    8 /*75d*/,   8 /*75e*/,   9 /*75f*/,   5 /*760*/,   6 /*761*/,
    6 /*762*/,   7 /*763*/,   6 /*764*/,   7 /*765*/,   7 /*766*/,
    8 /*767*/,   6 /*768*/,   7 /*769*/,   7 /*76a*/,   8 /*76b*/,
    7 /*76c*/,   8 /*76d*/,   8 /*76e*/,   9 /*76f*/,   6 /*770*/,
    7 /*771*/,   7 /*772*/,   8 /*773*/,   7 /*774*/,   8 /*775*/,
    8 /*776*/,   9 /*777*/,   7 /*778*/,   8 /*779*/,   8 /*77a*/,
    9 /*77b*/,   8 /*77c*/,   9 /*77d*/,   9 /*77e*/,   10 /*77f*/,
    4 /*780*/,   5 /*781*/,   5 /*782*/,   6 /*783*/,   5 /*784*/,
    6 /*785*/,   6 /*786*/,   7 /*787*/,   5 /*788*/,   6 /*789*/,
    6 /*78a*/,   7 /*78b*/,   6 /*78c*/,   7 /*78d*/,   7 /*78e*/,
    8 /*78f*/,   5 /*790*/,   6 /*791*/,   6 /*792*/,   7 /*793*/,
    6 /*794*/,   7 /*795*/,   7 /*796*/,   8 /*797*/,   6 /*798*/,
    7 /*799*/,   7 /*79a*/,   8 /*79b*/,   7 /*79c*/,   8 /*79d*/,
    8 /*79e*/,   9 /*79f*/,   5 /*7a0*/,   6 /*7a1*/,   6 /*7a2*/,
    7 /*7a3*/,   6 /*7a4*/,   7 /*7a5*/,   7 /*7a6*/,   8 /*7a7*/,
    6 /*7a8*/,   7 /*7a9*/,   7 /*7aa*/,   8 /*7ab*/,   7 /*7ac*/,
    8 /*7ad*/,   8 /*7ae*/,   9 /*7af*/,   6 /*7b0*/,   7 /*7b1*/,
    7 /*7b2*/,   8 /*7b3*/,   7 /*7b4*/,   8 /*7b5*/,   8 /*7b6*/,
    9 /*7b7*/,   7 /*7b8*/,   8 /*7b9*/,   8 /*7ba*/,   9 /*7bb*/,
    8 /*7bc*/,   9 /*7bd*/,   9 /*7be*/,   10 /*7bf*/,  5 /*7c0*/,
    6 /*7c1*/,   6 /*7c2*/,   7 /*7c3*/,   6 /*7c4*/,   7 /*7c5*/,
    7 /*7c6*/,   8 /*7c7*/,   6 /*7c8*/,   7 /*7c9*/,   7 /*7ca*/,
    8 /*7cb*/,   7 /*7cc*/,   8 /*7cd*/,   8 /*7ce*/,   9 /*7cf*/,
    6 /*7d0*/,   7 /*7d1*/,   7 /*7d2*/,   8 /*7d3*/,   7 /*7d4*/,
    8 /*7d5*/,   8 /*7d6*/,   9 /*7d7*/,   7 /*7d8*/,   8 /*7d9*/,
    8 /*7da*/,   9 /*7db*/,   8 /*7dc*/,   9 /*7dd*/,   9 /*7de*/,
    10 /*7df*/,  6 /*7e0*/,   7 /*7e1*/,   7 /*7e2*/,   8 /*7e3*/,
    7 /*7e4*/,   8 /*7e5*/,   8 /*7e6*/,   9 /*7e7*/,   7 /*7e8*/,
    8 /*7e9*/,   8 /*7ea*/,   9 /*7eb*/,   8 /*7ec*/,   9 /*7ed*/,
    9 /*7ee*/,   10 /*7ef*/,  7 /*7f0*/,   8 /*7f1*/,   8 /*7f2*/,
    9 /*7f3*/,   8 /*7f4*/,   9 /*7f5*/,   9 /*7f6*/,   10 /*7f7*/,
    8 /*7f8*/,   9 /*7f9*/,   9 /*7fa*/,   10 /*7fb*/,  9 /*7fc*/,
    10 /*7fd*/,  10 /*7fe*/,  11 /*7ff*/,  1 /*800*/,   2 /*801*/,
    2 /*802*/,   3 /*803*/,   2 /*804*/,   3 /*805*/,   3 /*806*/,
    4 /*807*/,   2 /*808*/,   3 /*809*/,   3 /*80a*/,   4 /*80b*/,
    3 /*80c*/,   4 /*80d*/,   4 /*80e*/,   5 /*80f*/,   2 /*810*/,
    3 /*811*/,   3 /*812*/,   4 /*813*/,   3 /*814*/,   4 /*815*/,
    4 /*816*/,   5 /*817*/,   3 /*818*/,   4 /*819*/,   4 /*81a*/,
    5 /*81b*/,   4 /*81c*/,   5 /*81d*/,   5 /*81e*/,   6 /*81f*/,
    2 /*820*/,   3 /*821*/,   3 /*822*/,   4 /*823*/,   3 /*824*/,
    4 /*825*/,   4 /*826*/,   5 /*827*/,   3 /*828*/,   4 /*829*/,
    4 /*82a*/,   5 /*82b*/,   4 /*82c*/,   5 /*82d*/,   5 /*82e*/,
    6 /*82f*/,   3 /*830*/,   4 /*831*/,   4 /*832*/,   5 /*833*/,
    4 /*834*/,   5 /*835*/,   5 /*836*/,   6 /*837*/,   4 /*838*/,
    5 /*839*/,   5 /*83a*/,   6 /*83b*/,   5 /*83c*/,   6 /*83d*/,
    6 /*83e*/,   7 /*83f*/,   2 /*840*/,   3 /*841*/,   3 /*842*/,
    4 /*843*/,   3 /*844*/,   4 /*845*/,   4 /*846*/,   5 /*847*/,
    3 /*848*/,   4 /*849*/,   4 /*84a*/,   5 /*84b*/,   4 /*84c*/,
    5 /*84d*/,   5 /*84e*/,   6 /*84f*/,   3 /*850*/,   4 /*851*/,
    4 /*852*/,   5 /*853*/,   4 /*854*/,   5 /*855*/,   5 /*856*/,
    6 /*857*/,   4 /*858*/,   5 /*859*/,   5 /*85a*/,   6 /*85b*/,
    5 /*85c*/,   6 /*85d*/,   6 /*85e*/,   7 /*85f*/,   3 /*860*/,
    4 /*861*/,   4 /*862*/,   5 /*863*/,   4 /*864*/,   5 /*865*/,
    5 /*866*/,   6 /*867*/,   4 /*868*/,   5 /*869*/,   5 /*86a*/,
    6 /*86b*/,   5 /*86c*/,   6 /*86d*/,   6 /*86e*/,   7 /*86f*/,
    4 /*870*/,   5 /*871*/,   5 /*872*/,   6 /*873*/,   5 /*874*/,
    6 /*875*/,   6 /*876*/,   7 /*877*/,   5 /*878*/,   6 /*879*/,
    6 /*87a*/,   7 /*87b*/,   6 /*87c*/,   7 /*87d*/,   7 /*87e*/,
    8 /*87f*/,   2 /*880*/,   3 /*881*/,   3 /*882*/,   4 /*883*/,
    3 /*884*/,   4 /*885*/,   4 /*886*/,   5 /*887*/,   3 /*888*/,
    4 /*889*/,   4 /*88a*/,   5 /*88b*/,   4 /*88c*/,   5 /*88d*/,
    5 /*88e*/,   6 /*88f*/,   3 /*890*/,   4 /*891*/,   4 /*892*/,
    5 /*893*/,   4 /*894*/,   5 /*895*/,   5 /*896*/,   6 /*897*/,
    4 /*898*/,   5 /*899*/,   5 /*89a*/,   6 /*89b*/,   5 /*89c*/,
    6 /*89d*/,   6 /*89e*/,   7 /*89f*/,   3 /*8a0*/,   4 /*8a1*/,
    4 /*8a2*/,   5 /*8a3*/,   4 /*8a4*/,   5 /*8a5*/,   5 /*8a6*/,
    6 /*8a7*/,   4 /*8a8*/,   5 /*8a9*/,   5 /*8aa*/,   6 /*8ab*/,
    5 /*8ac*/,   6 /*8ad*/,   6 /*8ae*/,   7 /*8af*/,   4 /*8b0*/,
    5 /*8b1*/,   5 /*8b2*/,   6 /*8b3*/,   5 /*8b4*/,   6 /*8b5*/,
    6 /*8b6*/,   7 /*8b7*/,   5 /*8b8*/,   6 /*8b9*/,   6 /*8ba*/,
    7 /*8bb*/,   6 /*8bc*/,   7 /*8bd*/,   7 /*8be*/,   8 /*8bf*/,
    3 /*8c0*/,   4 /*8c1*/,   4 /*8c2*/,   5 /*8c3*/,   4 /*8c4*/,
    5 /*8c5*/,   5 /*8c6*/,   6 /*8c7*/,   4 /*8c8*/,   5 /*8c9*/,
    5 /*8ca*/,   6 /*8cb*/,   5 /*8cc*/,   6 /*8cd*/,   6 /*8ce*/,
    7 /*8cf*/,   4 /*8d0*/,   5 /*8d1*/,   5 /*8d2*/,   6 /*8d3*/,
    5 /*8d4*/,   6 /*8d5*/,   6 /*8d6*/,   7 /*8d7*/,   5 /*8d8*/,
    6 /*8d9*/,   6 /*8da*/,   7 /*8db*/,   6 /*8dc*/,   7 /*8dd*/,
    7 /*8de*/,   8 /*8df*/,   4 /*8e0*/,   5 /*8e1*/,   5 /*8e2*/,
    6 /*8e3*/,   5 /*8e4*/,   6 /*8e5*/,   6 /*8e6*/,   7 /*8e7*/,
    5 /*8e8*/,   6 /*8e9*/,   6 /*8ea*/,   7 /*8eb*/,   6 /*8ec*/,
    7 /*8ed*/,   7 /*8ee*/,   8 /*8ef*/,   5 /*8f0*/,   6 /*8f1*/,
    6 /*8f2*/,   7 /*8f3*/,   6 /*8f4*/,   7 /*8f5*/,   7 /*8f6*/,
    8 /*8f7*/,   6 /*8f8*/,   7 /*8f9*/,   7 /*8fa*/,   8 /*8fb*/,
    7 /*8fc*/,   8 /*8fd*/,   8 /*8fe*/,   9 /*8ff*/,   2 /*900*/,
    3 /*901*/,   3 /*902*/,   4 /*903*/,   3 /*904*/,   4 /*905*/,
    4 /*906*/,   5 /*907*/,   3 /*908*/,   4 /*909*/,   4 /*90a*/,
    5 /*90b*/,   4 /*90c*/,   5 /*90d*/,   5 /*90e*/,   6 /*90f*/,
    3 /*910*/,   4 /*911*/,   4 /*912*/,   5 /*913*/,   4 /*914*/,
    5 /*915*/,   5 /*916*/,   6 /*917*/,   4 /*918*/,   5 /*919*/,
    5 /*91a*/,   6 /*91b*/,   5 /*91c*/,   6 /*91d*/,   6 /*91e*/,
    7 /*91f*/,   3 /*920*/,   4 /*921*/,   4 /*922*/,   5 /*923*/,
    4 /*924*/,   5 /*925*/,   5 /*926*/,   6 /*927*/,   4 /*928*/,
    5 /*929*/,   5 /*92a*/,   6 /*92b*/,   5 /*92c*/,   6 /*92d*/,
    6 /*92e*/,   7 /*92f*/,   4 /*930*/,   5 /*931*/,   5 /*932*/,
    6 /*933*/,   5 /*934*/,   6 /*935*/,   6 /*936*/,   7 /*937*/,
    5 /*938*/,   6 /*939*/,   6 /*93a*/,   7 /*93b*/,   6 /*93c*/,
    7 /*93d*/,   7 /*93e*/,   8 /*93f*/,   3 /*940*/,   4 /*941*/,
    4 /*942*/,   5 /*943*/,   4 /*944*/,   5 /*945*/,   5 /*946*/,
    6 /*947*/,   4 /*948*/,   5 /*949*/,   5 /*94a*/,   6 /*94b*/,
    5 /*94c*/,   6 /*94d*/,   6 /*94e*/,   7 /*94f*/,   4 /*950*/,
    5 /*951*/,   5 /*952*/,   6 /*953*/,   5 /*954*/,   6 /*955*/,
    6 /*956*/,   7 /*957*/,   5 /*958*/,   6 /*959*/,   6 /*95a*/,
    7 /*95b*/,   6 /*95c*/,   7 /*95d*/,   7 /*95e*/,   8 /*95f*/,
    4 /*960*/,   5 /*961*/,   5 /*962*/,   6 /*963*/,   5 /*964*/,
    6 /*965*/,   6 /*966*/,   7 /*967*/,   5 /*968*/,   6 /*969*/,
    6 /*96a*/,   7 /*96b*/,   6 /*96c*/,   7 /*96d*/,   7 /*96e*/,
    8 /*96f*/,   5 /*970*/,   6 /*971*/,   6 /*972*/,   7 /*973*/,
    6 /*974*/,   7 /*975*/,   7 /*976*/,   8 /*977*/,   6 /*978*/,
    7 /*979*/,   7 /*97a*/,   8 /*97b*/,   7 /*97c*/,   8 /*97d*/,
    8 /*97e*/,   9 /*97f*/,   3 /*980*/,   4 /*981*/,   4 /*982*/,
    5 /*983*/,   4 /*984*/,   5 /*985*/,   5 /*986*/,   6 /*987*/,
    4 /*988*/,   5 /*989*/,   5 /*98a*/,   6 /*98b*/,   5 /*98c*/,
    6 /*98d*/,   6 /*98e*/,   7 /*98f*/,   4 /*990*/,   5 /*991*/,
    5 /*992*/,   6 /*993*/,   5 /*994*/,   6 /*995*/,   6 /*996*/,
    7 /*997*/,   5 /*998*/,   6 /*999*/,   6 /*99a*/,   7 /*99b*/,
    6 /*99c*/,   7 /*99d*/,   7 /*99e*/,   8 /*99f*/,   4 /*9a0*/,
    5 /*9a1*/,   5 /*9a2*/,   6 /*9a3*/,   5 /*9a4*/,   6 /*9a5*/,
    6 /*9a6*/,   7 /*9a7*/,   5 /*9a8*/,   6 /*9a9*/,   6 /*9aa*/,
    7 /*9ab*/,   6 /*9ac*/,   7 /*9ad*/,   7 /*9ae*/,   8 /*9af*/,
    5 /*9b0*/,   6 /*9b1*/,   6 /*9b2*/,   7 /*9b3*/,   6 /*9b4*/,
    7 /*9b5*/,   7 /*9b6*/,   8 /*9b7*/,   6 /*9b8*/,   7 /*9b9*/,
    7 /*9ba*/,   8 /*9bb*/,   7 /*9bc*/,   8 /*9bd*/,   8 /*9be*/,
    9 /*9bf*/,   4 /*9c0*/,   5 /*9c1*/,   5 /*9c2*/,   6 /*9c3*/,
    5 /*9c4*/,   6 /*9c5*/,   6 /*9c6*/,   7 /*9c7*/,   5 /*9c8*/,
    6 /*9c9*/,   6 /*9ca*/,   7 /*9cb*/,   6 /*9cc*/,   7 /*9cd*/,
    7 /*9ce*/,   8 /*9cf*/,   5 /*9d0*/,   6 /*9d1*/,   6 /*9d2*/,
    7 /*9d3*/,   6 /*9d4*/,   7 /*9d5*/,   7 /*9d6*/,   8 /*9d7*/,
    6 /*9d8*/,   7 /*9d9*/,   7 /*9da*/,   8 /*9db*/,   7 /*9dc*/,
    8 /*9dd*/,   8 /*9de*/,   9 /*9df*/,   5 /*9e0*/,   6 /*9e1*/,
    6 /*9e2*/,   7 /*9e3*/,   6 /*9e4*/,   7 /*9e5*/,   7 /*9e6*/,
    8 /*9e7*/,   6 /*9e8*/,   7 /*9e9*/,   7 /*9ea*/,   8 /*9eb*/,
    7 /*9ec*/,   8 /*9ed*/,   8 /*9ee*/,   9 /*9ef*/,   6 /*9f0*/,
    7 /*9f1*/,   7 /*9f2*/,   8 /*9f3*/,   7 /*9f4*/,   8 /*9f5*/,
    8 /*9f6*/,   9 /*9f7*/,   7 /*9f8*/,   8 /*9f9*/,   8 /*9fa*/,
    9 /*9fb*/,   8 /*9fc*/,   9 /*9fd*/,   9 /*9fe*/,   10 /*9ff*/,
    2 /*a00*/,   3 /*a01*/,   3 /*a02*/,   4 /*a03*/,   3 /*a04*/,
    4 /*a05*/,   4 /*a06*/,   5 /*a07*/,   3 /*a08*/,   4 /*a09*/,
    4 /*a0a*/,   5 /*a0b*/,   4 /*a0c*/,   5 /*a0d*/,   5 /*a0e*/,
    6 /*a0f*/,   3 /*a10*/,   4 /*a11*/,   4 /*a12*/,   5 /*a13*/,
    4 /*a14*/,   5 /*a15*/,   5 /*a16*/,   6 /*a17*/,   4 /*a18*/,
    5 /*a19*/,   5 /*a1a*/,   6 /*a1b*/,   5 /*a1c*/,   6 /*a1d*/,
    6 /*a1e*/,   7 /*a1f*/,   3 /*a20*/,   4 /*a21*/,   4 /*a22*/,
    5 /*a23*/,   4 /*a24*/,   5 /*a25*/,   5 /*a26*/,   6 /*a27*/,
    4 /*a28*/,   5 /*a29*/,   5 /*a2a*/,   6 /*a2b*/,   5 /*a2c*/,
    6 /*a2d*/,   6 /*a2e*/,   7 /*a2f*/,   4 /*a30*/,   5 /*a31*/,
    5 /*a32*/,   6 /*a33*/,   5 /*a34*/,   6 /*a35*/,   6 /*a36*/,
    7 /*a37*/,   5 /*a38*/,   6 /*a39*/,   6 /*a3a*/,   7 /*a3b*/,
    6 /*a3c*/,   7 /*a3d*/,   7 /*a3e*/,   8 /*a3f*/,   3 /*a40*/,
    4 /*a41*/,   4 /*a42*/,   5 /*a43*/,   4 /*a44*/,   5 /*a45*/,
    5 /*a46*/,   6 /*a47*/,   4 /*a48*/,   5 /*a49*/,   5 /*a4a*/,
    6 /*a4b*/,   5 /*a4c*/,   6 /*a4d*/,   6 /*a4e*/,   7 /*a4f*/,
    4 /*a50*/,   5 /*a51*/,   5 /*a52*/,   6 /*a53*/,   5 /*a54*/,
    6 /*a55*/,   6 /*a56*/,   7 /*a57*/,   5 /*a58*/,   6 /*a59*/,
    6 /*a5a*/,   7 /*a5b*/,   6 /*a5c*/,   7 /*a5d*/,   7 /*a5e*/,
    8 /*a5f*/,   4 /*a60*/,   5 /*a61*/,   5 /*a62*/,   6 /*a63*/,
    5 /*a64*/,   6 /*a65*/,   6 /*a66*/,   7 /*a67*/,   5 /*a68*/,
    6 /*a69*/,   6 /*a6a*/,   7 /*a6b*/,   6 /*a6c*/,   7 /*a6d*/,
    7 /*a6e*/,   8 /*a6f*/,   5 /*a70*/,   6 /*a71*/,   6 /*a72*/,
    7 /*a73*/,   6 /*a74*/,   7 /*a75*/,   7 /*a76*/,   8 /*a77*/,
    6 /*a78*/,   7 /*a79*/,   7 /*a7a*/,   8 /*a7b*/,   7 /*a7c*/,
    8 /*a7d*/,   8 /*a7e*/,   9 /*a7f*/,   3 /*a80*/,   4 /*a81*/,
    4 /*a82*/,   5 /*a83*/,   4 /*a84*/,   5 /*a85*/,   5 /*a86*/,
    6 /*a87*/,   4 /*a88*/,   5 /*a89*/,   5 /*a8a*/,   6 /*a8b*/,
    5 /*a8c*/,   6 /*a8d*/,   6 /*a8e*/,   7 /*a8f*/,   4 /*a90*/,
    5 /*a91*/,   5 /*a92*/,   6 /*a93*/,   5 /*a94*/,   6 /*a95*/,
    6 /*a96*/,   7 /*a97*/,   5 /*a98*/,   6 /*a99*/,   6 /*a9a*/,
    7 /*a9b*/,   6 /*a9c*/,   7 /*a9d*/,   7 /*a9e*/,   8 /*a9f*/,
    4 /*aa0*/,   5 /*aa1*/,   5 /*aa2*/,   6 /*aa3*/,   5 /*aa4*/,
    6 /*aa5*/,   6 /*aa6*/,   7 /*aa7*/,   5 /*aa8*/,   6 /*aa9*/,
    6 /*aaa*/,   7 /*aab*/,   6 /*aac*/,   7 /*aad*/,   7 /*aae*/,
    8 /*aaf*/,   5 /*ab0*/,   6 /*ab1*/,   6 /*ab2*/,   7 /*ab3*/,
    6 /*ab4*/,   7 /*ab5*/,   7 /*ab6*/,   8 /*ab7*/,   6 /*ab8*/,
    7 /*ab9*/,   7 /*aba*/,   8 /*abb*/,   7 /*abc*/,   8 /*abd*/,
    8 /*abe*/,   9 /*abf*/,   4 /*ac0*/,   5 /*ac1*/,   5 /*ac2*/,
    6 /*ac3*/,   5 /*ac4*/,   6 /*ac5*/,   6 /*ac6*/,   7 /*ac7*/,
    5 /*ac8*/,   6 /*ac9*/,   6 /*aca*/,   7 /*acb*/,   6 /*acc*/,
    7 /*acd*/,   7 /*ace*/,   8 /*acf*/,   5 /*ad0*/,   6 /*ad1*/,
    6 /*ad2*/,   7 /*ad3*/,   6 /*ad4*/,   7 /*ad5*/,   7 /*ad6*/,
    8 /*ad7*/,   6 /*ad8*/,   7 /*ad9*/,   7 /*ada*/,   8 /*adb*/,
    7 /*adc*/,   8 /*add*/,   8 /*ade*/,   9 /*adf*/,   5 /*ae0*/,
    6 /*ae1*/,   6 /*ae2*/,   7 /*ae3*/,   6 /*ae4*/,   7 /*ae5*/,
    7 /*ae6*/,   8 /*ae7*/,   6 /*ae8*/,   7 /*ae9*/,   7 /*aea*/,
    8 /*aeb*/,   7 /*aec*/,   8 /*aed*/,   8 /*aee*/,   9 /*aef*/,
    6 /*af0*/,   7 /*af1*/,   7 /*af2*/,   8 /*af3*/,   7 /*af4*/,
    8 /*af5*/,   8 /*af6*/,   9 /*af7*/,   7 /*af8*/,   8 /*af9*/,
    8 /*afa*/,   9 /*afb*/,   8 /*afc*/,   9 /*afd*/,   9 /*afe*/,
    10 /*aff*/,  3 /*b00*/,   4 /*b01*/,   4 /*b02*/,   5 /*b03*/,
    4 /*b04*/,   5 /*b05*/,   5 /*b06*/,   6 /*b07*/,   4 /*b08*/,
    5 /*b09*/,   5 /*b0a*/,   6 /*b0b*/,   5 /*b0c*/,   6 /*b0d*/,
    6 /*b0e*/,   7 /*b0f*/,   4 /*b10*/,   5 /*b11*/,   5 /*b12*/,
    6 /*b13*/,   5 /*b14*/,   6 /*b15*/,   6 /*b16*/,   7 /*b17*/,
    5 /*b18*/,   6 /*b19*/,   6 /*b1a*/,   7 /*b1b*/,   6 /*b1c*/,
    7 /*b1d*/,   7 /*b1e*/,   8 /*b1f*/,   4 /*b20*/,   5 /*b21*/,
    5 /*b22*/,   6 /*b23*/,   5 /*b24*/,   6 /*b25*/,   6 /*b26*/,
    7 /*b27*/,   5 /*b28*/,   6 /*b29*/,   6 /*b2a*/,   7 /*b2b*/,
    6 /*b2c*/,   7 /*b2d*/,   7 /*b2e*/,   8 /*b2f*/,   5 /*b30*/,
    6 /*b31*/,   6 /*b32*/,   7 /*b33*/,   6 /*b34*/,   7 /*b35*/,
    7 /*b36*/,   8 /*b37*/,   6 /*b38*/,   7 /*b39*/,   7 /*b3a*/,
    8 /*b3b*/,   7 /*b3c*/,   8 /*b3d*/,   8 /*b3e*/,   9 /*b3f*/,
    4 /*b40*/,   5 /*b41*/,   5 /*b42*/,   6 /*b43*/,   5 /*b44*/,
    6 /*b45*/,   6 /*b46*/,   7 /*b47*/,   5 /*b48*/,   6 /*b49*/,
    6 /*b4a*/,   7 /*b4b*/,   6 /*b4c*/,   7 /*b4d*/,   7 /*b4e*/,
    8 /*b4f*/,   5 /*b50*/,   6 /*b51*/,   6 /*b52*/,   7 /*b53*/,
    6 /*b54*/,   7 /*b55*/,   7 /*b56*/,   8 /*b57*/,   6 /*b58*/,
    7 /*b59*/,   7 /*b5a*/,   8 /*b5b*/,   7 /*b5c*/,   8 /*b5d*/,
    8 /*b5e*/,   9 /*b5f*/,   5 /*b60*/,   6 /*b61*/,   6 /*b62*/,
    7 /*b63*/,   6 /*b64*/,   7 /*b65*/,   7 /*b66*/,   8 /*b67*/,
    6 /*b68*/,   7 /*b69*/,   7 /*b6a*/,   8 /*b6b*/,   7 /*b6c*/,
    8 /*b6d*/,   8 /*b6e*/,   9 /*b6f*/,   6 /*b70*/,   7 /*b71*/,
    7 /*b72*/,   8 /*b73*/,   7 /*b74*/,   8 /*b75*/,   8 /*b76*/,
    9 /*b77*/,   7 /*b78*/,   8 /*b79*/,   8 /*b7a*/,   9 /*b7b*/,
    8 /*b7c*/,   9 /*b7d*/,   9 /*b7e*/,   10 /*b7f*/,  4 /*b80*/,
    5 /*b81*/,   5 /*b82*/,   6 /*b83*/,   5 /*b84*/,   6 /*b85*/,
    6 /*b86*/,   7 /*b87*/,   5 /*b88*/,   6 /*b89*/,   6 /*b8a*/,
    7 /*b8b*/,   6 /*b8c*/,   7 /*b8d*/,   7 /*b8e*/,   8 /*b8f*/,
    5 /*b90*/,   6 /*b91*/,   6 /*b92*/,   7 /*b93*/,   6 /*b94*/,
    7 /*b95*/,   7 /*b96*/,   8 /*b97*/,   6 /*b98*/,   7 /*b99*/,
    7 /*b9a*/,   8 /*b9b*/,   7 /*b9c*/,   8 /*b9d*/,   8 /*b9e*/,
    9 /*b9f*/,   5 /*ba0*/,   6 /*ba1*/,   6 /*ba2*/,   7 /*ba3*/,
    6 /*ba4*/,   7 /*ba5*/,   7 /*ba6*/,   8 /*ba7*/,   6 /*ba8*/,
    7 /*ba9*/,   7 /*baa*/,   8 /*bab*/,   7 /*bac*/,   8 /*bad*/,
    8 /*bae*/,   9 /*baf*/,   6 /*bb0*/,   7 /*bb1*/,   7 /*bb2*/,
    8 /*bb3*/,   7 /*bb4*/,   8 /*bb5*/,   8 /*bb6*/,   9 /*bb7*/,
    7 /*bb8*/,   8 /*bb9*/,   8 /*bba*/,   9 /*bbb*/,   8 /*bbc*/,
    9 /*bbd*/,   9 /*bbe*/,   10 /*bbf*/,  5 /*bc0*/,   6 /*bc1*/,
    6 /*bc2*/,   7 /*bc3*/,   6 /*bc4*/,   7 /*bc5*/,   7 /*bc6*/,
    8 /*bc7*/,   6 /*bc8*/,   7 /*bc9*/,   7 /*bca*/,   8 /*bcb*/,
    7 /*bcc*/,   8 /*bcd*/,   8 /*bce*/,   9 /*bcf*/,   6 /*bd0*/,
    7 /*bd1*/,   7 /*bd2*/,   8 /*bd3*/,   7 /*bd4*/,   8 /*bd5*/,
    8 /*bd6*/,   9 /*bd7*/,   7 /*bd8*/,   8 /*bd9*/,   8 /*bda*/,
    9 /*bdb*/,   8 /*bdc*/,   9 /*bdd*/,   9 /*bde*/,   10 /*bdf*/,
    6 /*be0*/,   7 /*be1*/,   7 /*be2*/,   8 /*be3*/,   7 /*be4*/,
    8 /*be5*/,   8 /*be6*/,   9 /*be7*/,   7 /*be8*/,   8 /*be9*/,
    8 /*bea*/,   9 /*beb*/,   8 /*bec*/,   9 /*bed*/,   9 /*bee*/,
    10 /*bef*/,  7 /*bf0*/,   8 /*bf1*/,   8 /*bf2*/,   9 /*bf3*/,
    8 /*bf4*/,   9 /*bf5*/,   9 /*bf6*/,   10 /*bf7*/,  8 /*bf8*/,
    9 /*bf9*/,   9 /*bfa*/,   10 /*bfb*/,  9 /*bfc*/,   10 /*bfd*/,
    10 /*bfe*/,  11 /*bff*/,  2 /*c00*/,   3 /*c01*/,   3 /*c02*/,
    4 /*c03*/,   3 /*c04*/,   4 /*c05*/,   4 /*c06*/,   5 /*c07*/,
    3 /*c08*/,   4 /*c09*/,   4 /*c0a*/,   5 /*c0b*/,   4 /*c0c*/,
    5 /*c0d*/,   5 /*c0e*/,   6 /*c0f*/,   3 /*c10*/,   4 /*c11*/,
    4 /*c12*/,   5 /*c13*/,   4 /*c14*/,   5 /*c15*/,   5 /*c16*/,
    6 /*c17*/,   4 /*c18*/,   5 /*c19*/,   5 /*c1a*/,   6 /*c1b*/,
    5 /*c1c*/,   6 /*c1d*/,   6 /*c1e*/,   7 /*c1f*/,   3 /*c20*/,
    4 /*c21*/,   4 /*c22*/,   5 /*c23*/,   4 /*c24*/,   5 /*c25*/,
    5 /*c26*/,   6 /*c27*/,   4 /*c28*/,   5 /*c29*/,   5 /*c2a*/,
    6 /*c2b*/,   5 /*c2c*/,   6 /*c2d*/,   6 /*c2e*/,   7 /*c2f*/,
    4 /*c30*/,   5 /*c31*/,   5 /*c32*/,   6 /*c33*/,   5 /*c34*/,
    6 /*c35*/,   6 /*c36*/,   7 /*c37*/,   5 /*c38*/,   6 /*c39*/,
    6 /*c3a*/,   7 /*c3b*/,   6 /*c3c*/,   7 /*c3d*/,   7 /*c3e*/,
    8 /*c3f*/,   3 /*c40*/,   4 /*c41*/,   4 /*c42*/,   5 /*c43*/,
    4 /*c44*/,   5 /*c45*/,   5 /*c46*/,   6 /*c47*/,   4 /*c48*/,
    5 /*c49*/,   5 /*c4a*/,   6 /*c4b*/,   5 /*c4c*/,   6 /*c4d*/,
    6 /*c4e*/,   7 /*c4f*/,   4 /*c50*/,   5 /*c51*/,   5 /*c52*/,
    6 /*c53*/,   5 /*c54*/,   6 /*c55*/,   6 /*c56*/,   7 /*c57*/,
    5 /*c58*/,   6 /*c59*/,   6 /*c5a*/,   7 /*c5b*/,   6 /*c5c*/,
    7 /*c5d*/,   7 /*c5e*/,   8 /*c5f*/,   4 /*c60*/,   5 /*c61*/,
    5 /*c62*/,   6 /*c63*/,   5 /*c64*/,   6 /*c65*/,   6 /*c66*/,
    7 /*c67*/,   5 /*c68*/,   6 /*c69*/,   6 /*c6a*/,   7 /*c6b*/,
    6 /*c6c*/,   7 /*c6d*/,   7 /*c6e*/,   8 /*c6f*/,   5 /*c70*/,
    6 /*c71*/,   6 /*c72*/,   7 /*c73*/,   6 /*c74*/,   7 /*c75*/,
    7 /*c76*/,   8 /*c77*/,   6 /*c78*/,   7 /*c79*/,   7 /*c7a*/,
    8 /*c7b*/,   7 /*c7c*/,   8 /*c7d*/,   8 /*c7e*/,   9 /*c7f*/,
    3 /*c80*/,   4 /*c81*/,   4 /*c82*/,   5 /*c83*/,   4 /*c84*/,
    5 /*c85*/,   5 /*c86*/,   6 /*c87*/,   4 /*c88*/,   5 /*c89*/,
    5 /*c8a*/,   6 /*c8b*/,   5 /*c8c*/,   6 /*c8d*/,   6 /*c8e*/,
    7 /*c8f*/,   4 /*c90*/,   5 /*c91*/,   5 /*c92*/,   6 /*c93*/,
    5 /*c94*/,   6 /*c95*/,   6 /*c96*/,   7 /*c97*/,   5 /*c98*/,
    6 /*c99*/,   6 /*c9a*/,   7 /*c9b*/,   6 /*c9c*/,   7 /*c9d*/,
    7 /*c9e*/,   8 /*c9f*/,   4 /*ca0*/,   5 /*ca1*/,   5 /*ca2*/,
    6 /*ca3*/,   5 /*ca4*/,   6 /*ca5*/,   6 /*ca6*/,   7 /*ca7*/,
    5 /*ca8*/,   6 /*ca9*/,   6 /*caa*/,   7 /*cab*/,   6 /*cac*/,
    7 /*cad*/,   7 /*cae*/,   8 /*caf*/,   5 /*cb0*/,   6 /*cb1*/,
    6 /*cb2*/,   7 /*cb3*/,   6 /*cb4*/,   7 /*cb5*/,   7 /*cb6*/,
    8 /*cb7*/,   6 /*cb8*/,   7 /*cb9*/,   7 /*cba*/,   8 /*cbb*/,
    7 /*cbc*/,   8 /*cbd*/,   8 /*cbe*/,   9 /*cbf*/,   4 /*cc0*/,
    5 /*cc1*/,   5 /*cc2*/,   6 /*cc3*/,   5 /*cc4*/,   6 /*cc5*/,
    6 /*cc6*/,   7 /*cc7*/,   5 /*cc8*/,   6 /*cc9*/,   6 /*cca*/,
    7 /*ccb*/,   6 /*ccc*/,   7 /*ccd*/,   7 /*cce*/,   8 /*ccf*/,
    5 /*cd0*/,   6 /*cd1*/,   6 /*cd2*/,   7 /*cd3*/,   6 /*cd4*/,
    7 /*cd5*/,   7 /*cd6*/,   8 /*cd7*/,   6 /*cd8*/,   7 /*cd9*/,
    7 /*cda*/,   8 /*cdb*/,   7 /*cdc*/,   8 /*cdd*/,   8 /*cde*/,
    9 /*cdf*/,   5 /*ce0*/,   6 /*ce1*/,   6 /*ce2*/,   7 /*ce3*/,
    6 /*ce4*/,   7 /*ce5*/,   7 /*ce6*/,   8 /*ce7*/,   6 /*ce8*/,
    7 /*ce9*/,   7 /*cea*/,   8 /*ceb*/,   7 /*cec*/,   8 /*ced*/,
    8 /*cee*/,   9 /*cef*/,   6 /*cf0*/,   7 /*cf1*/,   7 /*cf2*/,
    8 /*cf3*/,   7 /*cf4*/,   8 /*cf5*/,   8 /*cf6*/,   9 /*cf7*/,
    7 /*cf8*/,   8 /*cf9*/,   8 /*cfa*/,   9 /*cfb*/,   8 /*cfc*/,
    9 /*cfd*/,   9 /*cfe*/,   10 /*cff*/,  3 /*d00*/,   4 /*d01*/,
    4 /*d02*/,   5 /*d03*/,   4 /*d04*/,   5 /*d05*/,   5 /*d06*/,
    6 /*d07*/,   4 /*d08*/,   5 /*d09*/,   5 /*d0a*/,   6 /*d0b*/,
    5 /*d0c*/,   6 /*d0d*/,   6 /*d0e*/,   7 /*d0f*/,   4 /*d10*/,
    5 /*d11*/,   5 /*d12*/,   6 /*d13*/,   5 /*d14*/,   6 /*d15*/,
    6 /*d16*/,   7 /*d17*/,   5 /*d18*/,   6 /*d19*/,   6 /*d1a*/,
    7 /*d1b*/,   6 /*d1c*/,   7 /*d1d*/,   7 /*d1e*/,   8 /*d1f*/,
    4 /*d20*/,   5 /*d21*/,   5 /*d22*/,   6 /*d23*/,   5 /*d24*/,
    6 /*d25*/,   6 /*d26*/,   7 /*d27*/,   5 /*d28*/,   6 /*d29*/,
    6 /*d2a*/,   7 /*d2b*/,   6 /*d2c*/,   7 /*d2d*/,   7 /*d2e*/,
    8 /*d2f*/,   5 /*d30*/,   6 /*d31*/,   6 /*d32*/,   7 /*d33*/,
    6 /*d34*/,   7 /*d35*/,   7 /*d36*/,   8 /*d37*/,   6 /*d38*/,
    7 /*d39*/,   7 /*d3a*/,   8 /*d3b*/,   7 /*d3c*/,   8 /*d3d*/,
    8 /*d3e*/,   9 /*d3f*/,   4 /*d40*/,   5 /*d41*/,   5 /*d42*/,
    6 /*d43*/,   5 /*d44*/,   6 /*d45*/,   6 /*d46*/,   7 /*d47*/,
    5 /*d48*/,   6 /*d49*/,   6 /*d4a*/,   7 /*d4b*/,   6 /*d4c*/,
    7 /*d4d*/,   7 /*d4e*/,   8 /*d4f*/,   5 /*d50*/,   6 /*d51*/,
    6 /*d52*/,   7 /*d53*/,   6 /*d54*/,   7 /*d55*/,   7 /*d56*/,
    8 /*d57*/,   6 /*d58*/,   7 /*d59*/,   7 /*d5a*/,   8 /*d5b*/,
    7 /*d5c*/,   8 /*d5d*/,   8 /*d5e*/,   9 /*d5f*/,   5 /*d60*/,
    6 /*d61*/,   6 /*d62*/,   7 /*d63*/,   6 /*d64*/,   7 /*d65*/,
    7 /*d66*/,   8 /*d67*/,   6 /*d68*/,   7 /*d69*/,   7 /*d6a*/,
    8 /*d6b*/,   7 /*d6c*/,   8 /*d6d*/,   8 /*d6e*/,   9 /*d6f*/,
    6 /*d70*/,   7 /*d71*/,   7 /*d72*/,   8 /*d73*/,   7 /*d74*/,
    8 /*d75*/,   8 /*d76*/,   9 /*d77*/,   7 /*d78*/,   8 /*d79*/,
    8 /*d7a*/,   9 /*d7b*/,   8 /*d7c*/,   9 /*d7d*/,   9 /*d7e*/,
    10 /*d7f*/,  4 /*d80*/,   5 /*d81*/,   5 /*d82*/,   6 /*d83*/,
    5 /*d84*/,   6 /*d85*/,   6 /*d86*/,   7 /*d87*/,   5 /*d88*/,
    6 /*d89*/,   6 /*d8a*/,   7 /*d8b*/,   6 /*d8c*/,   7 /*d8d*/,
    7 /*d8e*/,   8 /*d8f*/,   5 /*d90*/,   6 /*d91*/,   6 /*d92*/,
    7 /*d93*/,   6 /*d94*/,   7 /*d95*/,   7 /*d96*/,   8 /*d97*/,
    6 /*d98*/,   7 /*d99*/,   7 /*d9a*/,   8 /*d9b*/,   7 /*d9c*/,
    8 /*d9d*/,   8 /*d9e*/,   9 /*d9f*/,   5 /*da0*/,   6 /*da1*/,
    6 /*da2*/,   7 /*da3*/,   6 /*da4*/,   7 /*da5*/,   7 /*da6*/,
    8 /*da7*/,   6 /*da8*/,   7 /*da9*/,   7 /*daa*/,   8 /*dab*/,
    7 /*dac*/,   8 /*dad*/,   8 /*dae*/,   9 /*daf*/,   6 /*db0*/,
    7 /*db1*/,   7 /*db2*/,   8 /*db3*/,   7 /*db4*/,   8 /*db5*/,
    8 /*db6*/,   9 /*db7*/,   7 /*db8*/,   8 /*db9*/,   8 /*dba*/,
    9 /*dbb*/,   8 /*dbc*/,   9 /*dbd*/,   9 /*dbe*/,   10 /*dbf*/,
    5 /*dc0*/,   6 /*dc1*/,   6 /*dc2*/,   7 /*dc3*/,   6 /*dc4*/,
    7 /*dc5*/,   7 /*dc6*/,   8 /*dc7*/,   6 /*dc8*/,   7 /*dc9*/,
    7 /*dca*/,   8 /*dcb*/,   7 /*dcc*/,   8 /*dcd*/,   8 /*dce*/,
    9 /*dcf*/,   6 /*dd0*/,   7 /*dd1*/,   7 /*dd2*/,   8 /*dd3*/,
    7 /*dd4*/,   8 /*dd5*/,   8 /*dd6*/,   9 /*dd7*/,   7 /*dd8*/,
    8 /*dd9*/,   8 /*dda*/,   9 /*ddb*/,   8 /*ddc*/,   9 /*ddd*/,
    9 /*dde*/,   10 /*ddf*/,  6 /*de0*/,   7 /*de1*/,   7 /*de2*/,
    8 /*de3*/,   7 /*de4*/,   8 /*de5*/,   8 /*de6*/,   9 /*de7*/,
    7 /*de8*/,   8 /*de9*/,   8 /*dea*/,   9 /*deb*/,   8 /*dec*/,
    9 /*ded*/,   9 /*dee*/,   10 /*def*/,  7 /*df0*/,   8 /*df1*/,
    8 /*df2*/,   9 /*df3*/,   8 /*df4*/,   9 /*df5*/,   9 /*df6*/,
    10 /*df7*/,  8 /*df8*/,   9 /*df9*/,   9 /*dfa*/,   10 /*dfb*/,
    9 /*dfc*/,   10 /*dfd*/,  10 /*dfe*/,  11 /*dff*/,  3 /*e00*/,
    4 /*e01*/,   4 /*e02*/,   5 /*e03*/,   4 /*e04*/,   5 /*e05*/,
    5 /*e06*/,   6 /*e07*/,   4 /*e08*/,   5 /*e09*/,   5 /*e0a*/,
    6 /*e0b*/,   5 /*e0c*/,   6 /*e0d*/,   6 /*e0e*/,   7 /*e0f*/,
    4 /*e10*/,   5 /*e11*/,   5 /*e12*/,   6 /*e13*/,   5 /*e14*/,
    6 /*e15*/,   6 /*e16*/,   7 /*e17*/,   5 /*e18*/,   6 /*e19*/,
    6 /*e1a*/,   7 /*e1b*/,   6 /*e1c*/,   7 /*e1d*/,   7 /*e1e*/,
    8 /*e1f*/,   4 /*e20*/,   5 /*e21*/,   5 /*e22*/,   6 /*e23*/,
    5 /*e24*/,   6 /*e25*/,   6 /*e26*/,   7 /*e27*/,   5 /*e28*/,
    6 /*e29*/,   6 /*e2a*/,   7 /*e2b*/,   6 /*e2c*/,   7 /*e2d*/,
    7 /*e2e*/,   8 /*e2f*/,   5 /*e30*/,   6 /*e31*/,   6 /*e32*/,
    7 /*e33*/,   6 /*e34*/,   7 /*e35*/,   7 /*e36*/,   8 /*e37*/,
    6 /*e38*/,   7 /*e39*/,   7 /*e3a*/,   8 /*e3b*/,   7 /*e3c*/,
    8 /*e3d*/,   8 /*e3e*/,   9 /*e3f*/,   4 /*e40*/,   5 /*e41*/,
    5 /*e42*/,   6 /*e43*/,   5 /*e44*/,   6 /*e45*/,   6 /*e46*/,
    7 /*e47*/,   5 /*e48*/,   6 /*e49*/,   6 /*e4a*/,   7 /*e4b*/,
    6 /*e4c*/,   7 /*e4d*/,   7 /*e4e*/,   8 /*e4f*/,   5 /*e50*/,
    6 /*e51*/,   6 /*e52*/,   7 /*e53*/,   6 /*e54*/,   7 /*e55*/,
    7 /*e56*/,   8 /*e57*/,   6 /*e58*/,   7 /*e59*/,   7 /*e5a*/,
    8 /*e5b*/,   7 /*e5c*/,   8 /*e5d*/,   8 /*e5e*/,   9 /*e5f*/,
    5 /*e60*/,   6 /*e61*/,   6 /*e62*/,   7 /*e63*/,   6 /*e64*/,
    7 /*e65*/,   7 /*e66*/,   8 /*e67*/,   6 /*e68*/,   7 /*e69*/,
    7 /*e6a*/,   8 /*e6b*/,   7 /*e6c*/,   8 /*e6d*/,   8 /*e6e*/,
    9 /*e6f*/,   6 /*e70*/,   7 /*e71*/,   7 /*e72*/,   8 /*e73*/,
    7 /*e74*/,   8 /*e75*/,   8 /*e76*/,   9 /*e77*/,   7 /*e78*/,
    8 /*e79*/,   8 /*e7a*/,   9 /*e7b*/,   8 /*e7c*/,   9 /*e7d*/,
    9 /*e7e*/,   10 /*e7f*/,  4 /*e80*/,   5 /*e81*/,   5 /*e82*/,
    6 /*e83*/,   5 /*e84*/,   6 /*e85*/,   6 /*e86*/,   7 /*e87*/,
    5 /*e88*/,   6 /*e89*/,   6 /*e8a*/,   7 /*e8b*/,   6 /*e8c*/,
    7 /*e8d*/,   7 /*e8e*/,   8 /*e8f*/,   5 /*e90*/,   6 /*e91*/,
    6 /*e92*/,   7 /*e93*/,   6 /*e94*/,   7 /*e95*/,   7 /*e96*/,
    8 /*e97*/,   6 /*e98*/,   7 /*e99*/,   7 /*e9a*/,   8 /*e9b*/,
    7 /*e9c*/,   8 /*e9d*/,   8 /*e9e*/,   9 /*e9f*/,   5 /*ea0*/,
    6 /*ea1*/,   6 /*ea2*/,   7 /*ea3*/,   6 /*ea4*/,   7 /*ea5*/,
    7 /*ea6*/,   8 /*ea7*/,   6 /*ea8*/,   7 /*ea9*/,   7 /*eaa*/,
    8 /*eab*/,   7 /*eac*/,   8 /*ead*/,   8 /*eae*/,   9 /*eaf*/,
    6 /*eb0*/,   7 /*eb1*/,   7 /*eb2*/,   8 /*eb3*/,   7 /*eb4*/,
    8 /*eb5*/,   8 /*eb6*/,   9 /*eb7*/,   7 /*eb8*/,   8 /*eb9*/,
    8 /*eba*/,   9 /*ebb*/,   8 /*ebc*/,   9 /*ebd*/,   9 /*ebe*/,
    10 /*ebf*/,  5 /*ec0*/,   6 /*ec1*/,   6 /*ec2*/,   7 /*ec3*/,
    6 /*ec4*/,   7 /*ec5*/,   7 /*ec6*/,   8 /*ec7*/,   6 /*ec8*/,
    7 /*ec9*/,   7 /*eca*/,   8 /*ecb*/,   7 /*ecc*/,   8 /*ecd*/,
    8 /*ece*/,   9 /*ecf*/,   6 /*ed0*/,   7 /*ed1*/,   7 /*ed2*/,
    8 /*ed3*/,   7 /*ed4*/,   8 /*ed5*/,   8 /*ed6*/,   9 /*ed7*/,
    7 /*ed8*/,   8 /*ed9*/,   8 /*eda*/,   9 /*edb*/,   8 /*edc*/,
    9 /*edd*/,   9 /*ede*/,   10 /*edf*/,  6 /*ee0*/,   7 /*ee1*/,
    7 /*ee2*/,   8 /*ee3*/,   7 /*ee4*/,   8 /*ee5*/,   8 /*ee6*/,
    9 /*ee7*/,   7 /*ee8*/,   8 /*ee9*/,   8 /*eea*/,   9 /*eeb*/,
    8 /*eec*/,   9 /*eed*/,   9 /*eee*/,   10 /*eef*/,  7 /*ef0*/,
    8 /*ef1*/,   8 /*ef2*/,   9 /*ef3*/,   8 /*ef4*/,   9 /*ef5*/,
    9 /*ef6*/,   10 /*ef7*/,  8 /*ef8*/,   9 /*ef9*/,   9 /*efa*/,
    10 /*efb*/,  9 /*efc*/,   10 /*efd*/,  10 /*efe*/,  11 /*eff*/,
    4 /*f00*/,   5 /*f01*/,   5 /*f02*/,   6 /*f03*/,   5 /*f04*/,
    6 /*f05*/,   6 /*f06*/,   7 /*f07*/,   5 /*f08*/,   6 /*f09*/,
    6 /*f0a*/,   7 /*f0b*/,   6 /*f0c*/,   7 /*f0d*/,   7 /*f0e*/,
    8 /*f0f*/,   5 /*f10*/,   6 /*f11*/,   6 /*f12*/,   7 /*f13*/,
    6 /*f14*/,   7 /*f15*/,   7 /*f16*/,   8 /*f17*/,   6 /*f18*/,
    7 /*f19*/,   7 /*f1a*/,   8 /*f1b*/,   7 /*f1c*/,   8 /*f1d*/,
    8 /*f1e*/,   9 /*f1f*/,   5 /*f20*/,   6 /*f21*/,   6 /*f22*/,
    7 /*f23*/,   6 /*f24*/,   7 /*f25*/,   7 /*f26*/,   8 /*f27*/,
    6 /*f28*/,   7 /*f29*/,   7 /*f2a*/,   8 /*f2b*/,   7 /*f2c*/,
    8 /*f2d*/,   8 /*f2e*/,   9 /*f2f*/,   6 /*f30*/,   7 /*f31*/,
    7 /*f32*/,   8 /*f33*/,   7 /*f34*/,   8 /*f35*/,   8 /*f36*/,
    9 /*f37*/,   7 /*f38*/,   8 /*f39*/,   8 /*f3a*/,   9 /*f3b*/,
    8 /*f3c*/,   9 /*f3d*/,   9 /*f3e*/,   10 /*f3f*/,  5 /*f40*/,
    6 /*f41*/,   6 /*f42*/,   7 /*f43*/,   6 /*f44*/,   7 /*f45*/,
    7 /*f46*/,   8 /*f47*/,   6 /*f48*/,   7 /*f49*/,   7 /*f4a*/,
    8 /*f4b*/,   7 /*f4c*/,   8 /*f4d*/,   8 /*f4e*/,   9 /*f4f*/,
    6 /*f50*/,   7 /*f51*/,   7 /*f52*/,   8 /*f53*/,   7 /*f54*/,
    8 /*f55*/,   8 /*f56*/,   9 /*f57*/,   7 /*f58*/,   8 /*f59*/,
    8 /*f5a*/,   9 /*f5b*/,   8 /*f5c*/,   9 /*f5d*/,   9 /*f5e*/,
    10 /*f5f*/,  6 /*f60*/,   7 /*f61*/,   7 /*f62*/,   8 /*f63*/,
    7 /*f64*/,   8 /*f65*/,   8 /*f66*/,   9 /*f67*/,   7 /*f68*/,
    8 /*f69*/,   8 /*f6a*/,   9 /*f6b*/,   8 /*f6c*/,   9 /*f6d*/,
    9 /*f6e*/,   10 /*f6f*/,  7 /*f70*/,   8 /*f71*/,   8 /*f72*/,
    9 /*f73*/,   8 /*f74*/,   9 /*f75*/,   9 /*f76*/,   10 /*f77*/,
    8 /*f78*/,   9 /*f79*/,   9 /*f7a*/,   10 /*f7b*/,  9 /*f7c*/,
    10 /*f7d*/,  10 /*f7e*/,  11 /*f7f*/,  5 /*f80*/,   6 /*f81*/,
    6 /*f82*/,   7 /*f83*/,   6 /*f84*/,   7 /*f85*/,   7 /*f86*/,
    8 /*f87*/,   6 /*f88*/,   7 /*f89*/,   7 /*f8a*/,   8 /*f8b*/,
    7 /*f8c*/,   8 /*f8d*/,   8 /*f8e*/,   9 /*f8f*/,   6 /*f90*/,
    7 /*f91*/,   7 /*f92*/,   8 /*f93*/,   7 /*f94*/,   8 /*f95*/,
    8 /*f96*/,   9 /*f97*/,   7 /*f98*/,   8 /*f99*/,   8 /*f9a*/,
    9 /*f9b*/,   8 /*f9c*/,   9 /*f9d*/,   9 /*f9e*/,   10 /*f9f*/,
    6 /*fa0*/,   7 /*fa1*/,   7 /*fa2*/,   8 /*fa3*/,   7 /*fa4*/,
    8 /*fa5*/,   8 /*fa6*/,   9 /*fa7*/,   7 /*fa8*/,   8 /*fa9*/,
    8 /*faa*/,   9 /*fab*/,   8 /*fac*/,   9 /*fad*/,   9 /*fae*/,
    10 /*faf*/,  7 /*fb0*/,   8 /*fb1*/,   8 /*fb2*/,   9 /*fb3*/,
    8 /*fb4*/,   9 /*fb5*/,   9 /*fb6*/,   10 /*fb7*/,  8 /*fb8*/,
    9 /*fb9*/,   9 /*fba*/,   10 /*fbb*/,  9 /*fbc*/,   10 /*fbd*/,
    10 /*fbe*/,  11 /*fbf*/,  6 /*fc0*/,   7 /*fc1*/,   7 /*fc2*/,
    8 /*fc3*/,   7 /*fc4*/,   8 /*fc5*/,   8 /*fc6*/,   9 /*fc7*/,
    7 /*fc8*/,   8 /*fc9*/,   8 /*fca*/,   9 /*fcb*/,   8 /*fcc*/,
    9 /*fcd*/,   9 /*fce*/,   10 /*fcf*/,  7 /*fd0*/,   8 /*fd1*/,
    8 /*fd2*/,   9 /*fd3*/,   8 /*fd4*/,   9 /*fd5*/,   9 /*fd6*/,
    10 /*fd7*/,  8 /*fd8*/,   9 /*fd9*/,   9 /*fda*/,   10 /*fdb*/,
    9 /*fdc*/,   10 /*fdd*/,  10 /*fde*/,  11 /*fdf*/,  7 /*fe0*/,
    8 /*fe1*/,   8 /*fe2*/,   9 /*fe3*/,   8 /*fe4*/,   9 /*fe5*/,
    9 /*fe6*/,   10 /*fe7*/,  8 /*fe8*/,   9 /*fe9*/,   9 /*fea*/,
    10 /*feb*/,  9 /*fec*/,   10 /*fed*/,  10 /*fee*/,  11 /*fef*/,
    8 /*ff0*/,   9 /*ff1*/,   9 /*ff2*/,   10 /*ff3*/,  9 /*ff4*/,
    10 /*ff5*/,  10 /*ff6*/,  11 /*ff7*/,  9 /*ff8*/,   10 /*ff9*/,
    10 /*ffa*/,  11 /*ffb*/,  10 /*ffc*/,  11 /*ffd*/,  11 /*ffe*/,
    12 /*fff*/,  1 /*1000*/,  2 /*1001*/,  2 /*1002*/,  3 /*1003*/,
    2 /*1004*/,  3 /*1005*/,  3 /*1006*/,  4 /*1007*/,  2 /*1008*/,
    3 /*1009*/,  3 /*100a*/,  4 /*100b*/,  3 /*100c*/,  4 /*100d*/,
    4 /*100e*/,  5 /*100f*/,  2 /*1010*/,  3 /*1011*/,  3 /*1012*/,
    4 /*1013*/,  3 /*1014*/,  4 /*1015*/,  4 /*1016*/,  5 /*1017*/,
    3 /*1018*/,  4 /*1019*/,  4 /*101a*/,  5 /*101b*/,  4 /*101c*/,
    5 /*101d*/,  5 /*101e*/,  6 /*101f*/,  2 /*1020*/,  3 /*1021*/,
    3 /*1022*/,  4 /*1023*/,  3 /*1024*/,  4 /*1025*/,  4 /*1026*/,
    5 /*1027*/,  3 /*1028*/,  4 /*1029*/,  4 /*102a*/,  5 /*102b*/,
    4 /*102c*/,  5 /*102d*/,  5 /*102e*/,  6 /*102f*/,  3 /*1030*/,
    4 /*1031*/,  4 /*1032*/,  5 /*1033*/,  4 /*1034*/,  5 /*1035*/,
    5 /*1036*/,  6 /*1037*/,  4 /*1038*/,  5 /*1039*/,  5 /*103a*/,
    6 /*103b*/,  5 /*103c*/,  6 /*103d*/,  6 /*103e*/,  7 /*103f*/,
    2 /*1040*/,  3 /*1041*/,  3 /*1042*/,  4 /*1043*/,  3 /*1044*/,
    4 /*1045*/,  4 /*1046*/,  5 /*1047*/,  3 /*1048*/,  4 /*1049*/,
    4 /*104a*/,  5 /*104b*/,  4 /*104c*/,  5 /*104d*/,  5 /*104e*/,
    6 /*104f*/,  3 /*1050*/,  4 /*1051*/,  4 /*1052*/,  5 /*1053*/,
    4 /*1054*/,  5 /*1055*/,  5 /*1056*/,  6 /*1057*/,  4 /*1058*/,
    5 /*1059*/,  5 /*105a*/,  6 /*105b*/,  5 /*105c*/,  6 /*105d*/,
    6 /*105e*/,  7 /*105f*/,  3 /*1060*/,  4 /*1061*/,  4 /*1062*/,
    5 /*1063*/,  4 /*1064*/,  5 /*1065*/,  5 /*1066*/,  6 /*1067*/,
    4 /*1068*/,  5 /*1069*/,  5 /*106a*/,  6 /*106b*/,  5 /*106c*/,
    6 /*106d*/,  6 /*106e*/,  7 /*106f*/,  4 /*1070*/,  5 /*1071*/,
    5 /*1072*/,  6 /*1073*/,  5 /*1074*/,  6 /*1075*/,  6 /*1076*/,
    7 /*1077*/,  5 /*1078*/,  6 /*1079*/,  6 /*107a*/,  7 /*107b*/,
    6 /*107c*/,  7 /*107d*/,  7 /*107e*/,  8 /*107f*/,  2 /*1080*/,
    3 /*1081*/,  3 /*1082*/,  4 /*1083*/,  3 /*1084*/,  4 /*1085*/,
    4 /*1086*/,  5 /*1087*/,  3 /*1088*/,  4 /*1089*/,  4 /*108a*/,
    5 /*108b*/,  4 /*108c*/,  5 /*108d*/,  5 /*108e*/,  6 /*108f*/,
    3 /*1090*/,  4 /*1091*/,  4 /*1092*/,  5 /*1093*/,  4 /*1094*/,
    5 /*1095*/,  5 /*1096*/,  6 /*1097*/,  4 /*1098*/,  5 /*1099*/,
    5 /*109a*/,  6 /*109b*/,  5 /*109c*/,  6 /*109d*/,  6 /*109e*/,
    7 /*109f*/,  3 /*10a0*/,  4 /*10a1*/,  4 /*10a2*/,  5 /*10a3*/,
    4 /*10a4*/,  5 /*10a5*/,  5 /*10a6*/,  6 /*10a7*/,  4 /*10a8*/,
    5 /*10a9*/,  5 /*10aa*/,  6 /*10ab*/,  5 /*10ac*/,  6 /*10ad*/,
    6 /*10ae*/,  7 /*10af*/,  4 /*10b0*/,  5 /*10b1*/,  5 /*10b2*/,
    6 /*10b3*/,  5 /*10b4*/,  6 /*10b5*/,  6 /*10b6*/,  7 /*10b7*/,
    5 /*10b8*/,  6 /*10b9*/,  6 /*10ba*/,  7 /*10bb*/,  6 /*10bc*/,
    7 /*10bd*/,  7 /*10be*/,  8 /*10bf*/,  3 /*10c0*/,  4 /*10c1*/,
    4 /*10c2*/,  5 /*10c3*/,  4 /*10c4*/,  5 /*10c5*/,  5 /*10c6*/,
    6 /*10c7*/,  4 /*10c8*/,  5 /*10c9*/,  5 /*10ca*/,  6 /*10cb*/,
    5 /*10cc*/,  6 /*10cd*/,  6 /*10ce*/,  7 /*10cf*/,  4 /*10d0*/,
    5 /*10d1*/,  5 /*10d2*/,  6 /*10d3*/,  5 /*10d4*/,  6 /*10d5*/,
    6 /*10d6*/,  7 /*10d7*/,  5 /*10d8*/,  6 /*10d9*/,  6 /*10da*/,
    7 /*10db*/,  6 /*10dc*/,  7 /*10dd*/,  7 /*10de*/,  8 /*10df*/,
    4 /*10e0*/,  5 /*10e1*/,  5 /*10e2*/,  6 /*10e3*/,  5 /*10e4*/,
    6 /*10e5*/,  6 /*10e6*/,  7 /*10e7*/,  5 /*10e8*/,  6 /*10e9*/,
    6 /*10ea*/,  7 /*10eb*/,  6 /*10ec*/,  7 /*10ed*/,  7 /*10ee*/,
    8 /*10ef*/,  5 /*10f0*/,  6 /*10f1*/,  6 /*10f2*/,  7 /*10f3*/,
    6 /*10f4*/,  7 /*10f5*/,  7 /*10f6*/,  8 /*10f7*/,  6 /*10f8*/,
    7 /*10f9*/,  7 /*10fa*/,  8 /*10fb*/,  7 /*10fc*/,  8 /*10fd*/,
    8 /*10fe*/,  9 /*10ff*/,  2 /*1100*/,  3 /*1101*/,  3 /*1102*/,
    4 /*1103*/,  3 /*1104*/,  4 /*1105*/,  4 /*1106*/,  5 /*1107*/,
    3 /*1108*/,  4 /*1109*/,  4 /*110a*/,  5 /*110b*/,  4 /*110c*/,
    5 /*110d*/,  5 /*110e*/,  6 /*110f*/,  3 /*1110*/,  4 /*1111*/,
    4 /*1112*/,  5 /*1113*/,  4 /*1114*/,  5 /*1115*/,  5 /*1116*/,
    6 /*1117*/,  4 /*1118*/,  5 /*1119*/,  5 /*111a*/,  6 /*111b*/,
    5 /*111c*/,  6 /*111d*/,  6 /*111e*/,  7 /*111f*/,  3 /*1120*/,
    4 /*1121*/,  4 /*1122*/,  5 /*1123*/,  4 /*1124*/,  5 /*1125*/,
    5 /*1126*/,  6 /*1127*/,  4 /*1128*/,  5 /*1129*/,  5 /*112a*/,
    6 /*112b*/,  5 /*112c*/,  6 /*112d*/,  6 /*112e*/,  7 /*112f*/,
    4 /*1130*/,  5 /*1131*/,  5 /*1132*/,  6 /*1133*/,  5 /*1134*/,
    6 /*1135*/,  6 /*1136*/,  7 /*1137*/,  5 /*1138*/,  6 /*1139*/,
    6 /*113a*/,  7 /*113b*/,  6 /*113c*/,  7 /*113d*/,  7 /*113e*/,
    8 /*113f*/,  3 /*1140*/,  4 /*1141*/,  4 /*1142*/,  5 /*1143*/,
    4 /*1144*/,  5 /*1145*/,  5 /*1146*/,  6 /*1147*/,  4 /*1148*/,
    5 /*1149*/,  5 /*114a*/,  6 /*114b*/,  5 /*114c*/,  6 /*114d*/,
    6 /*114e*/,  7 /*114f*/,  4 /*1150*/,  5 /*1151*/,  5 /*1152*/,
    6 /*1153*/,  5 /*1154*/,  6 /*1155*/,  6 /*1156*/,  7 /*1157*/,
    5 /*1158*/,  6 /*1159*/,  6 /*115a*/,  7 /*115b*/,  6 /*115c*/,
    7 /*115d*/,  7 /*115e*/,  8 /*115f*/,  4 /*1160*/,  5 /*1161*/,
    5 /*1162*/,  6 /*1163*/,  5 /*1164*/,  6 /*1165*/,  6 /*1166*/,
    7 /*1167*/,  5 /*1168*/,  6 /*1169*/,  6 /*116a*/,  7 /*116b*/,
    6 /*116c*/,  7 /*116d*/,  7 /*116e*/,  8 /*116f*/,  5 /*1170*/,
    6 /*1171*/,  6 /*1172*/,  7 /*1173*/,  6 /*1174*/,  7 /*1175*/,
    7 /*1176*/,  8 /*1177*/,  6 /*1178*/,  7 /*1179*/,  7 /*117a*/,
    8 /*117b*/,  7 /*117c*/,  8 /*117d*/,  8 /*117e*/,  9 /*117f*/,
    3 /*1180*/,  4 /*1181*/,  4 /*1182*/,  5 /*1183*/,  4 /*1184*/,
    5 /*1185*/,  5 /*1186*/,  6 /*1187*/,  4 /*1188*/,  5 /*1189*/,
    5 /*118a*/,  6 /*118b*/,  5 /*118c*/,  6 /*118d*/,  6 /*118e*/,
    7 /*118f*/,  4 /*1190*/,  5 /*1191*/,  5 /*1192*/,  6 /*1193*/,
    5 /*1194*/,  6 /*1195*/,  6 /*1196*/,  7 /*1197*/,  5 /*1198*/,
    6 /*1199*/,  6 /*119a*/,  7 /*119b*/,  6 /*119c*/,  7 /*119d*/,
    7 /*119e*/,  8 /*119f*/,  4 /*11a0*/,  5 /*11a1*/,  5 /*11a2*/,
    6 /*11a3*/,  5 /*11a4*/,  6 /*11a5*/,  6 /*11a6*/,  7 /*11a7*/,
    5 /*11a8*/,  6 /*11a9*/,  6 /*11aa*/,  7 /*11ab*/,  6 /*11ac*/,
    7 /*11ad*/,  7 /*11ae*/,  8 /*11af*/,  5 /*11b0*/,  6 /*11b1*/,
    6 /*11b2*/,  7 /*11b3*/,  6 /*11b4*/,  7 /*11b5*/,  7 /*11b6*/,
    8 /*11b7*/,  6 /*11b8*/,  7 /*11b9*/,  7 /*11ba*/,  8 /*11bb*/,
    7 /*11bc*/,  8 /*11bd*/,  8 /*11be*/,  9 /*11bf*/,  4 /*11c0*/,
    5 /*11c1*/,  5 /*11c2*/,  6 /*11c3*/,  5 /*11c4*/,  6 /*11c5*/,
    6 /*11c6*/,  7 /*11c7*/,  5 /*11c8*/,  6 /*11c9*/,  6 /*11ca*/,
    7 /*11cb*/,  6 /*11cc*/,  7 /*11cd*/,  7 /*11ce*/,  8 /*11cf*/,
    5 /*11d0*/,  6 /*11d1*/,  6 /*11d2*/,  7 /*11d3*/,  6 /*11d4*/,
    7 /*11d5*/,  7 /*11d6*/,  8 /*11d7*/,  6 /*11d8*/,  7 /*11d9*/,
    7 /*11da*/,  8 /*11db*/,  7 /*11dc*/,  8 /*11dd*/,  8 /*11de*/,
    9 /*11df*/,  5 /*11e0*/,  6 /*11e1*/,  6 /*11e2*/,  7 /*11e3*/,
    6 /*11e4*/,  7 /*11e5*/,  7 /*11e6*/,  8 /*11e7*/,  6 /*11e8*/,
    7 /*11e9*/,  7 /*11ea*/,  8 /*11eb*/,  7 /*11ec*/,  8 /*11ed*/,
    8 /*11ee*/,  9 /*11ef*/,  6 /*11f0*/,  7 /*11f1*/,  7 /*11f2*/,
    8 /*11f3*/,  7 /*11f4*/,  8 /*11f5*/,  8 /*11f6*/,  9 /*11f7*/,
    7 /*11f8*/,  8 /*11f9*/,  8 /*11fa*/,  9 /*11fb*/,  8 /*11fc*/,
    9 /*11fd*/,  9 /*11fe*/,  10 /*11ff*/, 2 /*1200*/,  3 /*1201*/,
    3 /*1202*/,  4 /*1203*/,  3 /*1204*/,  4 /*1205*/,  4 /*1206*/,
    5 /*1207*/,  3 /*1208*/,  4 /*1209*/,  4 /*120a*/,  5 /*120b*/,
    4 /*120c*/,  5 /*120d*/,  5 /*120e*/,  6 /*120f*/,  3 /*1210*/,
    4 /*1211*/,  4 /*1212*/,  5 /*1213*/,  4 /*1214*/,  5 /*1215*/,
    5 /*1216*/,  6 /*1217*/,  4 /*1218*/,  5 /*1219*/,  5 /*121a*/,
    6 /*121b*/,  5 /*121c*/,  6 /*121d*/,  6 /*121e*/,  7 /*121f*/,
    3 /*1220*/,  4 /*1221*/,  4 /*1222*/,  5 /*1223*/,  4 /*1224*/,
    5 /*1225*/,  5 /*1226*/,  6 /*1227*/,  4 /*1228*/,  5 /*1229*/,
    5 /*122a*/,  6 /*122b*/,  5 /*122c*/,  6 /*122d*/,  6 /*122e*/,
    7 /*122f*/,  4 /*1230*/,  5 /*1231*/,  5 /*1232*/,  6 /*1233*/,
    5 /*1234*/,  6 /*1235*/,  6 /*1236*/,  7 /*1237*/,  5 /*1238*/,
    6 /*1239*/,  6 /*123a*/,  7 /*123b*/,  6 /*123c*/,  7 /*123d*/,
    7 /*123e*/,  8 /*123f*/,  3 /*1240*/,  4 /*1241*/,  4 /*1242*/,
    5 /*1243*/,  4 /*1244*/,  5 /*1245*/,  5 /*1246*/,  6 /*1247*/,
    4 /*1248*/,  5 /*1249*/,  5 /*124a*/,  6 /*124b*/,  5 /*124c*/,
    6 /*124d*/,  6 /*124e*/,  7 /*124f*/,  4 /*1250*/,  5 /*1251*/,
    5 /*1252*/,  6 /*1253*/,  5 /*1254*/,  6 /*1255*/,  6 /*1256*/,
    7 /*1257*/,  5 /*1258*/,  6 /*1259*/,  6 /*125a*/,  7 /*125b*/,
    6 /*125c*/,  7 /*125d*/,  7 /*125e*/,  8 /*125f*/,  4 /*1260*/,
    5 /*1261*/,  5 /*1262*/,  6 /*1263*/,  5 /*1264*/,  6 /*1265*/,
    6 /*1266*/,  7 /*1267*/,  5 /*1268*/,  6 /*1269*/,  6 /*126a*/,
    7 /*126b*/,  6 /*126c*/,  7 /*126d*/,  7 /*126e*/,  8 /*126f*/,
    5 /*1270*/,  6 /*1271*/,  6 /*1272*/,  7 /*1273*/,  6 /*1274*/,
    7 /*1275*/,  7 /*1276*/,  8 /*1277*/,  6 /*1278*/,  7 /*1279*/,
    7 /*127a*/,  8 /*127b*/,  7 /*127c*/,  8 /*127d*/,  8 /*127e*/,
    9 /*127f*/,  3 /*1280*/,  4 /*1281*/,  4 /*1282*/,  5 /*1283*/,
    4 /*1284*/,  5 /*1285*/,  5 /*1286*/,  6 /*1287*/,  4 /*1288*/,
    5 /*1289*/,  5 /*128a*/,  6 /*128b*/,  5 /*128c*/,  6 /*128d*/,
    6 /*128e*/,  7 /*128f*/,  4 /*1290*/,  5 /*1291*/,  5 /*1292*/,
    6 /*1293*/,  5 /*1294*/,  6 /*1295*/,  6 /*1296*/,  7 /*1297*/,
    5 /*1298*/,  6 /*1299*/,  6 /*129a*/,  7 /*129b*/,  6 /*129c*/,
    7 /*129d*/,  7 /*129e*/,  8 /*129f*/,  4 /*12a0*/,  5 /*12a1*/,
    5 /*12a2*/,  6 /*12a3*/,  5 /*12a4*/,  6 /*12a5*/,  6 /*12a6*/,
    7 /*12a7*/,  5 /*12a8*/,  6 /*12a9*/,  6 /*12aa*/,  7 /*12ab*/,
    6 /*12ac*/,  7 /*12ad*/,  7 /*12ae*/,  8 /*12af*/,  5 /*12b0*/,
    6 /*12b1*/,  6 /*12b2*/,  7 /*12b3*/,  6 /*12b4*/,  7 /*12b5*/,
    7 /*12b6*/,  8 /*12b7*/,  6 /*12b8*/,  7 /*12b9*/,  7 /*12ba*/,
    8 /*12bb*/,  7 /*12bc*/,  8 /*12bd*/,  8 /*12be*/,  9 /*12bf*/,
    4 /*12c0*/,  5 /*12c1*/,  5 /*12c2*/,  6 /*12c3*/,  5 /*12c4*/,
    6 /*12c5*/,  6 /*12c6*/,  7 /*12c7*/,  5 /*12c8*/,  6 /*12c9*/,
    6 /*12ca*/,  7 /*12cb*/,  6 /*12cc*/,  7 /*12cd*/,  7 /*12ce*/,
    8 /*12cf*/,  5 /*12d0*/,  6 /*12d1*/,  6 /*12d2*/,  7 /*12d3*/,
    6 /*12d4*/,  7 /*12d5*/,  7 /*12d6*/,  8 /*12d7*/,  6 /*12d8*/,
    7 /*12d9*/,  7 /*12da*/,  8 /*12db*/,  7 /*12dc*/,  8 /*12dd*/,
    8 /*12de*/,  9 /*12df*/,  5 /*12e0*/,  6 /*12e1*/,  6 /*12e2*/,
    7 /*12e3*/,  6 /*12e4*/,  7 /*12e5*/,  7 /*12e6*/,  8 /*12e7*/,
    6 /*12e8*/,  7 /*12e9*/,  7 /*12ea*/,  8 /*12eb*/,  7 /*12ec*/,
    8 /*12ed*/,  8 /*12ee*/,  9 /*12ef*/,  6 /*12f0*/,  7 /*12f1*/,
    7 /*12f2*/,  8 /*12f3*/,  7 /*12f4*/,  8 /*12f5*/,  8 /*12f6*/,
    9 /*12f7*/,  7 /*12f8*/,  8 /*12f9*/,  8 /*12fa*/,  9 /*12fb*/,
    8 /*12fc*/,  9 /*12fd*/,  9 /*12fe*/,  10 /*12ff*/, 3 /*1300*/,
    4 /*1301*/,  4 /*1302*/,  5 /*1303*/,  4 /*1304*/,  5 /*1305*/,
    5 /*1306*/,  6 /*1307*/,  4 /*1308*/,  5 /*1309*/,  5 /*130a*/,
    6 /*130b*/,  5 /*130c*/,  6 /*130d*/,  6 /*130e*/,  7 /*130f*/,
    4 /*1310*/,  5 /*1311*/,  5 /*1312*/,  6 /*1313*/,  5 /*1314*/,
    6 /*1315*/,  6 /*1316*/,  7 /*1317*/,  5 /*1318*/,  6 /*1319*/,
    6 /*131a*/,  7 /*131b*/,  6 /*131c*/,  7 /*131d*/,  7 /*131e*/,
    8 /*131f*/,  4 /*1320*/,  5 /*1321*/,  5 /*1322*/,  6 /*1323*/,
    5 /*1324*/,  6 /*1325*/,  6 /*1326*/,  7 /*1327*/,  5 /*1328*/,
    6 /*1329*/,  6 /*132a*/,  7 /*132b*/,  6 /*132c*/,  7 /*132d*/,
    7 /*132e*/,  8 /*132f*/,  5 /*1330*/,  6 /*1331*/,  6 /*1332*/,
    7 /*1333*/,  6 /*1334*/,  7 /*1335*/,  7 /*1336*/,  8 /*1337*/,
    6 /*1338*/,  7 /*1339*/,  7 /*133a*/,  8 /*133b*/,  7 /*133c*/,
    8 /*133d*/,  8 /*133e*/,  9 /*133f*/,  4 /*1340*/,  5 /*1341*/,
    5 /*1342*/,  6 /*1343*/,  5 /*1344*/,  6 /*1345*/,  6 /*1346*/,
    7 /*1347*/,  5 /*1348*/,  6 /*1349*/,  6 /*134a*/,  7 /*134b*/,
    6 /*134c*/,  7 /*134d*/,  7 /*134e*/,  8 /*134f*/,  5 /*1350*/,
    6 /*1351*/,  6 /*1352*/,  7 /*1353*/,  6 /*1354*/,  7 /*1355*/,
    7 /*1356*/,  8 /*1357*/,  6 /*1358*/,  7 /*1359*/,  7 /*135a*/,
    8 /*135b*/,  7 /*135c*/,  8 /*135d*/,  8 /*135e*/,  9 /*135f*/,
    5 /*1360*/,  6 /*1361*/,  6 /*1362*/,  7 /*1363*/,  6 /*1364*/,
    7 /*1365*/,  7 /*1366*/,  8 /*1367*/,  6 /*1368*/,  7 /*1369*/,
    7 /*136a*/,  8 /*136b*/,  7 /*136c*/,  8 /*136d*/,  8 /*136e*/,
    9 /*136f*/,  6 /*1370*/,  7 /*1371*/,  7 /*1372*/,  8 /*1373*/,
    7 /*1374*/,  8 /*1375*/,  8 /*1376*/,  9 /*1377*/,  7 /*1378*/,
    8 /*1379*/,  8 /*137a*/,  9 /*137b*/,  8 /*137c*/,  9 /*137d*/,
    9 /*137e*/,  10 /*137f*/, 4 /*1380*/,  5 /*1381*/,  5 /*1382*/,
    6 /*1383*/,  5 /*1384*/,  6 /*1385*/,  6 /*1386*/,  7 /*1387*/,
    5 /*1388*/,  6 /*1389*/,  6 /*138a*/,  7 /*138b*/,  6 /*138c*/,
    7 /*138d*/,  7 /*138e*/,  8 /*138f*/,  5 /*1390*/,  6 /*1391*/,
    6 /*1392*/,  7 /*1393*/,  6 /*1394*/,  7 /*1395*/,  7 /*1396*/,
    8 /*1397*/,  6 /*1398*/,  7 /*1399*/,  7 /*139a*/,  8 /*139b*/,
    7 /*139c*/,  8 /*139d*/,  8 /*139e*/,  9 /*139f*/,  5 /*13a0*/,
    6 /*13a1*/,  6 /*13a2*/,  7 /*13a3*/,  6 /*13a4*/,  7 /*13a5*/,
    7 /*13a6*/,  8 /*13a7*/,  6 /*13a8*/,  7 /*13a9*/,  7 /*13aa*/,
    8 /*13ab*/,  7 /*13ac*/,  8 /*13ad*/,  8 /*13ae*/,  9 /*13af*/,
    6 /*13b0*/,  7 /*13b1*/,  7 /*13b2*/,  8 /*13b3*/,  7 /*13b4*/,
    8 /*13b5*/,  8 /*13b6*/,  9 /*13b7*/,  7 /*13b8*/,  8 /*13b9*/,
    8 /*13ba*/,  9 /*13bb*/,  8 /*13bc*/,  9 /*13bd*/,  9 /*13be*/,
    10 /*13bf*/, 5 /*13c0*/,  6 /*13c1*/,  6 /*13c2*/,  7 /*13c3*/,
    6 /*13c4*/,  7 /*13c5*/,  7 /*13c6*/,  8 /*13c7*/,  6 /*13c8*/,
    7 /*13c9*/,  7 /*13ca*/,  8 /*13cb*/,  7 /*13cc*/,  8 /*13cd*/,
    8 /*13ce*/,  9 /*13cf*/,  6 /*13d0*/,  7 /*13d1*/,  7 /*13d2*/,
    8 /*13d3*/,  7 /*13d4*/,  8 /*13d5*/,  8 /*13d6*/,  9 /*13d7*/,
    7 /*13d8*/,  8 /*13d9*/,  8 /*13da*/,  9 /*13db*/,  8 /*13dc*/,
    9 /*13dd*/,  9 /*13de*/,  10 /*13df*/, 6 /*13e0*/,  7 /*13e1*/,
    7 /*13e2*/,  8 /*13e3*/,  7 /*13e4*/,  8 /*13e5*/,  8 /*13e6*/,
    9 /*13e7*/,  7 /*13e8*/,  8 /*13e9*/,  8 /*13ea*/,  9 /*13eb*/,
    8 /*13ec*/,  9 /*13ed*/,  9 /*13ee*/,  10 /*13ef*/, 7 /*13f0*/,
    8 /*13f1*/,  8 /*13f2*/,  9 /*13f3*/,  8 /*13f4*/,  9 /*13f5*/,
    9 /*13f6*/,  10 /*13f7*/, 8 /*13f8*/,  9 /*13f9*/,  9 /*13fa*/,
    10 /*13fb*/, 9 /*13fc*/,  10 /*13fd*/, 10 /*13fe*/, 11 /*13ff*/,
    2 /*1400*/,  3 /*1401*/,  3 /*1402*/,  4 /*1403*/,  3 /*1404*/,
    4 /*1405*/,  4 /*1406*/,  5 /*1407*/,  3 /*1408*/,  4 /*1409*/,
    4 /*140a*/,  5 /*140b*/,  4 /*140c*/,  5 /*140d*/,  5 /*140e*/,
    6 /*140f*/,  3 /*1410*/,  4 /*1411*/,  4 /*1412*/,  5 /*1413*/,
    4 /*1414*/,  5 /*1415*/,  5 /*1416*/,  6 /*1417*/,  4 /*1418*/,
    5 /*1419*/,  5 /*141a*/,  6 /*141b*/,  5 /*141c*/,  6 /*141d*/,
    6 /*141e*/,  7 /*141f*/,  3 /*1420*/,  4 /*1421*/,  4 /*1422*/,
    5 /*1423*/,  4 /*1424*/,  5 /*1425*/,  5 /*1426*/,  6 /*1427*/,
    4 /*1428*/,  5 /*1429*/,  5 /*142a*/,  6 /*142b*/,  5 /*142c*/,
    6 /*142d*/,  6 /*142e*/,  7 /*142f*/,  4 /*1430*/,  5 /*1431*/,
    5 /*1432*/,  6 /*1433*/,  5 /*1434*/,  6 /*1435*/,  6 /*1436*/,
    7 /*1437*/,  5 /*1438*/,  6 /*1439*/,  6 /*143a*/,  7 /*143b*/,
    6 /*143c*/,  7 /*143d*/,  7 /*143e*/,  8 /*143f*/,  3 /*1440*/,
    4 /*1441*/,  4 /*1442*/,  5 /*1443*/,  4 /*1444*/,  5 /*1445*/,
    5 /*1446*/,  6 /*1447*/,  4 /*1448*/,  5 /*1449*/,  5 /*144a*/,
    6 /*144b*/,  5 /*144c*/,  6 /*144d*/,  6 /*144e*/,  7 /*144f*/,
    4 /*1450*/,  5 /*1451*/,  5 /*1452*/,  6 /*1453*/,  5 /*1454*/,
    6 /*1455*/,  6 /*1456*/,  7 /*1457*/,  5 /*1458*/,  6 /*1459*/,
    6 /*145a*/,  7 /*145b*/,  6 /*145c*/,  7 /*145d*/,  7 /*145e*/,
    8 /*145f*/,  4 /*1460*/,  5 /*1461*/,  5 /*1462*/,  6 /*1463*/,
    5 /*1464*/,  6 /*1465*/,  6 /*1466*/,  7 /*1467*/,  5 /*1468*/,
    6 /*1469*/,  6 /*146a*/,  7 /*146b*/,  6 /*146c*/,  7 /*146d*/,
    7 /*146e*/,  8 /*146f*/,  5 /*1470*/,  6 /*1471*/,  6 /*1472*/,
    7 /*1473*/,  6 /*1474*/,  7 /*1475*/,  7 /*1476*/,  8 /*1477*/,
    6 /*1478*/,  7 /*1479*/,  7 /*147a*/,  8 /*147b*/,  7 /*147c*/,
    8 /*147d*/,  8 /*147e*/,  9 /*147f*/,  3 /*1480*/,  4 /*1481*/,
    4 /*1482*/,  5 /*1483*/,  4 /*1484*/,  5 /*1485*/,  5 /*1486*/,
    6 /*1487*/,  4 /*1488*/,  5 /*1489*/,  5 /*148a*/,  6 /*148b*/,
    5 /*148c*/,  6 /*148d*/,  6 /*148e*/,  7 /*148f*/,  4 /*1490*/,
    5 /*1491*/,  5 /*1492*/,  6 /*1493*/,  5 /*1494*/,  6 /*1495*/,
    6 /*1496*/,  7 /*1497*/,  5 /*1498*/,  6 /*1499*/,  6 /*149a*/,
    7 /*149b*/,  6 /*149c*/,  7 /*149d*/,  7 /*149e*/,  8 /*149f*/,
    4 /*14a0*/,  5 /*14a1*/,  5 /*14a2*/,  6 /*14a3*/,  5 /*14a4*/,
    6 /*14a5*/,  6 /*14a6*/,  7 /*14a7*/,  5 /*14a8*/,  6 /*14a9*/,
    6 /*14aa*/,  7 /*14ab*/,  6 /*14ac*/,  7 /*14ad*/,  7 /*14ae*/,
    8 /*14af*/,  5 /*14b0*/,  6 /*14b1*/,  6 /*14b2*/,  7 /*14b3*/,
    6 /*14b4*/,  7 /*14b5*/,  7 /*14b6*/,  8 /*14b7*/,  6 /*14b8*/,
    7 /*14b9*/,  7 /*14ba*/,  8 /*14bb*/,  7 /*14bc*/,  8 /*14bd*/,
    8 /*14be*/,  9 /*14bf*/,  4 /*14c0*/,  5 /*14c1*/,  5 /*14c2*/,
    6 /*14c3*/,  5 /*14c4*/,  6 /*14c5*/,  6 /*14c6*/,  7 /*14c7*/,
    5 /*14c8*/,  6 /*14c9*/,  6 /*14ca*/,  7 /*14cb*/,  6 /*14cc*/,
    7 /*14cd*/,  7 /*14ce*/,  8 /*14cf*/,  5 /*14d0*/,  6 /*14d1*/,
    6 /*14d2*/,  7 /*14d3*/,  6 /*14d4*/,  7 /*14d5*/,  7 /*14d6*/,
    8 /*14d7*/,  6 /*14d8*/,  7 /*14d9*/,  7 /*14da*/,  8 /*14db*/,
    7 /*14dc*/,  8 /*14dd*/,  8 /*14de*/,  9 /*14df*/,  5 /*14e0*/,
    6 /*14e1*/,  6 /*14e2*/,  7 /*14e3*/,  6 /*14e4*/,  7 /*14e5*/,
    7 /*14e6*/,  8 /*14e7*/,  6 /*14e8*/,  7 /*14e9*/,  7 /*14ea*/,
    8 /*14eb*/,  7 /*14ec*/,  8 /*14ed*/,  8 /*14ee*/,  9 /*14ef*/,
    6 /*14f0*/,  7 /*14f1*/,  7 /*14f2*/,  8 /*14f3*/,  7 /*14f4*/,
    8 /*14f5*/,  8 /*14f6*/,  9 /*14f7*/,  7 /*14f8*/,  8 /*14f9*/,
    8 /*14fa*/,  9 /*14fb*/,  8 /*14fc*/,  9 /*14fd*/,  9 /*14fe*/,
    10 /*14ff*/, 3 /*1500*/,  4 /*1501*/,  4 /*1502*/,  5 /*1503*/,
    4 /*1504*/,  5 /*1505*/,  5 /*1506*/,  6 /*1507*/,  4 /*1508*/,
    5 /*1509*/,  5 /*150a*/,  6 /*150b*/,  5 /*150c*/,  6 /*150d*/,
    6 /*150e*/,  7 /*150f*/,  4 /*1510*/,  5 /*1511*/,  5 /*1512*/,
    6 /*1513*/,  5 /*1514*/,  6 /*1515*/,  6 /*1516*/,  7 /*1517*/,
    5 /*1518*/,  6 /*1519*/,  6 /*151a*/,  7 /*151b*/,  6 /*151c*/,
    7 /*151d*/,  7 /*151e*/,  8 /*151f*/,  4 /*1520*/,  5 /*1521*/,
    5 /*1522*/,  6 /*1523*/,  5 /*1524*/,  6 /*1525*/,  6 /*1526*/,
    7 /*1527*/,  5 /*1528*/,  6 /*1529*/,  6 /*152a*/,  7 /*152b*/,
    6 /*152c*/,  7 /*152d*/,  7 /*152e*/,  8 /*152f*/,  5 /*1530*/,
    6 /*1531*/,  6 /*1532*/,  7 /*1533*/,  6 /*1534*/,  7 /*1535*/,
    7 /*1536*/,  8 /*1537*/,  6 /*1538*/,  7 /*1539*/,  7 /*153a*/,
    8 /*153b*/,  7 /*153c*/,  8 /*153d*/,  8 /*153e*/,  9 /*153f*/,
    4 /*1540*/,  5 /*1541*/,  5 /*1542*/,  6 /*1543*/,  5 /*1544*/,
    6 /*1545*/,  6 /*1546*/,  7 /*1547*/,  5 /*1548*/,  6 /*1549*/,
    6 /*154a*/,  7 /*154b*/,  6 /*154c*/,  7 /*154d*/,  7 /*154e*/,
    8 /*154f*/,  5 /*1550*/,  6 /*1551*/,  6 /*1552*/,  7 /*1553*/,
    6 /*1554*/,  7 /*1555*/,  7 /*1556*/,  8 /*1557*/,  6 /*1558*/,
    7 /*1559*/,  7 /*155a*/,  8 /*155b*/,  7 /*155c*/,  8 /*155d*/,
    8 /*155e*/,  9 /*155f*/,  5 /*1560*/,  6 /*1561*/,  6 /*1562*/,
    7 /*1563*/,  6 /*1564*/,  7 /*1565*/,  7 /*1566*/,  8 /*1567*/,
    6 /*1568*/,  7 /*1569*/,  7 /*156a*/,  8 /*156b*/,  7 /*156c*/,
    8 /*156d*/,  8 /*156e*/,  9 /*156f*/,  6 /*1570*/,  7 /*1571*/,
    7 /*1572*/,  8 /*1573*/,  7 /*1574*/,  8 /*1575*/,  8 /*1576*/,
    9 /*1577*/,  7 /*1578*/,  8 /*1579*/,  8 /*157a*/,  9 /*157b*/,
    8 /*157c*/,  9 /*157d*/,  9 /*157e*/,  10 /*157f*/, 4 /*1580*/,
    5 /*1581*/,  5 /*1582*/,  6 /*1583*/,  5 /*1584*/,  6 /*1585*/,
    6 /*1586*/,  7 /*1587*/,  5 /*1588*/,  6 /*1589*/,  6 /*158a*/,
    7 /*158b*/,  6 /*158c*/,  7 /*158d*/,  7 /*158e*/,  8 /*158f*/,
    5 /*1590*/,  6 /*1591*/,  6 /*1592*/,  7 /*1593*/,  6 /*1594*/,
    7 /*1595*/,  7 /*1596*/,  8 /*1597*/,  6 /*1598*/,  7 /*1599*/,
    7 /*159a*/,  8 /*159b*/,  7 /*159c*/,  8 /*159d*/,  8 /*159e*/,
    9 /*159f*/,  5 /*15a0*/,  6 /*15a1*/,  6 /*15a2*/,  7 /*15a3*/,
    6 /*15a4*/,  7 /*15a5*/,  7 /*15a6*/,  8 /*15a7*/,  6 /*15a8*/,
    7 /*15a9*/,  7 /*15aa*/,  8 /*15ab*/,  7 /*15ac*/,  8 /*15ad*/,
    8 /*15ae*/,  9 /*15af*/,  6 /*15b0*/,  7 /*15b1*/,  7 /*15b2*/,
    8 /*15b3*/,  7 /*15b4*/,  8 /*15b5*/,  8 /*15b6*/,  9 /*15b7*/,
    7 /*15b8*/,  8 /*15b9*/,  8 /*15ba*/,  9 /*15bb*/,  8 /*15bc*/,
    9 /*15bd*/,  9 /*15be*/,  10 /*15bf*/, 5 /*15c0*/,  6 /*15c1*/,
    6 /*15c2*/,  7 /*15c3*/,  6 /*15c4*/,  7 /*15c5*/,  7 /*15c6*/,
    8 /*15c7*/,  6 /*15c8*/,  7 /*15c9*/,  7 /*15ca*/,  8 /*15cb*/,
    7 /*15cc*/,  8 /*15cd*/,  8 /*15ce*/,  9 /*15cf*/,  6 /*15d0*/,
    7 /*15d1*/,  7 /*15d2*/,  8 /*15d3*/,  7 /*15d4*/,  8 /*15d5*/,
    8 /*15d6*/,  9 /*15d7*/,  7 /*15d8*/,  8 /*15d9*/,  8 /*15da*/,
    9 /*15db*/,  8 /*15dc*/,  9 /*15dd*/,  9 /*15de*/,  10 /*15df*/,
    6 /*15e0*/,  7 /*15e1*/,  7 /*15e2*/,  8 /*15e3*/,  7 /*15e4*/,
    8 /*15e5*/,  8 /*15e6*/,  9 /*15e7*/,  7 /*15e8*/,  8 /*15e9*/,
    8 /*15ea*/,  9 /*15eb*/,  8 /*15ec*/,  9 /*15ed*/,  9 /*15ee*/,
    10 /*15ef*/, 7 /*15f0*/,  8 /*15f1*/,  8 /*15f2*/,  9 /*15f3*/,
    8 /*15f4*/,  9 /*15f5*/,  9 /*15f6*/,  10 /*15f7*/, 8 /*15f8*/,
    9 /*15f9*/,  9 /*15fa*/,  10 /*15fb*/, 9 /*15fc*/,  10 /*15fd*/,
    10 /*15fe*/, 11 /*15ff*/, 3 /*1600*/,  4 /*1601*/,  4 /*1602*/,
    5 /*1603*/,  4 /*1604*/,  5 /*1605*/,  5 /*1606*/,  6 /*1607*/,
    4 /*1608*/,  5 /*1609*/,  5 /*160a*/,  6 /*160b*/,  5 /*160c*/,
    6 /*160d*/,  6 /*160e*/,  7 /*160f*/,  4 /*1610*/,  5 /*1611*/,
    5 /*1612*/,  6 /*1613*/,  5 /*1614*/,  6 /*1615*/,  6 /*1616*/,
    7 /*1617*/,  5 /*1618*/,  6 /*1619*/,  6 /*161a*/,  7 /*161b*/,
    6 /*161c*/,  7 /*161d*/,  7 /*161e*/,  8 /*161f*/,  4 /*1620*/,
    5 /*1621*/,  5 /*1622*/,  6 /*1623*/,  5 /*1624*/,  6 /*1625*/,
    6 /*1626*/,  7 /*1627*/,  5 /*1628*/,  6 /*1629*/,  6 /*162a*/,
    7 /*162b*/,  6 /*162c*/,  7 /*162d*/,  7 /*162e*/,  8 /*162f*/,
    5 /*1630*/,  6 /*1631*/,  6 /*1632*/,  7 /*1633*/,  6 /*1634*/,
    7 /*1635*/,  7 /*1636*/,  8 /*1637*/,  6 /*1638*/,  7 /*1639*/,
    7 /*163a*/,  8 /*163b*/,  7 /*163c*/,  8 /*163d*/,  8 /*163e*/,
    9 /*163f*/,  4 /*1640*/,  5 /*1641*/,  5 /*1642*/,  6 /*1643*/,
    5 /*1644*/,  6 /*1645*/,  6 /*1646*/,  7 /*1647*/,  5 /*1648*/,
    6 /*1649*/,  6 /*164a*/,  7 /*164b*/,  6 /*164c*/,  7 /*164d*/,
    7 /*164e*/,  8 /*164f*/,  5 /*1650*/,  6 /*1651*/,  6 /*1652*/,
    7 /*1653*/,  6 /*1654*/,  7 /*1655*/,  7 /*1656*/,  8 /*1657*/,
    6 /*1658*/,  7 /*1659*/,  7 /*165a*/,  8 /*165b*/,  7 /*165c*/,
    8 /*165d*/,  8 /*165e*/,  9 /*165f*/,  5 /*1660*/,  6 /*1661*/,
    6 /*1662*/,  7 /*1663*/,  6 /*1664*/,  7 /*1665*/,  7 /*1666*/,
    8 /*1667*/,  6 /*1668*/,  7 /*1669*/,  7 /*166a*/,  8 /*166b*/,
    7 /*166c*/,  8 /*166d*/,  8 /*166e*/,  9 /*166f*/,  6 /*1670*/,
    7 /*1671*/,  7 /*1672*/,  8 /*1673*/,  7 /*1674*/,  8 /*1675*/,
    8 /*1676*/,  9 /*1677*/,  7 /*1678*/,  8 /*1679*/,  8 /*167a*/,
    9 /*167b*/,  8 /*167c*/,  9 /*167d*/,  9 /*167e*/,  10 /*167f*/,
    4 /*1680*/,  5 /*1681*/,  5 /*1682*/,  6 /*1683*/,  5 /*1684*/,
    6 /*1685*/,  6 /*1686*/,  7 /*1687*/,  5 /*1688*/,  6 /*1689*/,
    6 /*168a*/,  7 /*168b*/,  6 /*168c*/,  7 /*168d*/,  7 /*168e*/,
    8 /*168f*/,  5 /*1690*/,  6 /*1691*/,  6 /*1692*/,  7 /*1693*/,
    6 /*1694*/,  7 /*1695*/,  7 /*1696*/,  8 /*1697*/,  6 /*1698*/,
    7 /*1699*/,  7 /*169a*/,  8 /*169b*/,  7 /*169c*/,  8 /*169d*/,
    8 /*169e*/,  9 /*169f*/,  5 /*16a0*/,  6 /*16a1*/,  6 /*16a2*/,
    7 /*16a3*/,  6 /*16a4*/,  7 /*16a5*/,  7 /*16a6*/,  8 /*16a7*/,
    6 /*16a8*/,  7 /*16a9*/,  7 /*16aa*/,  8 /*16ab*/,  7 /*16ac*/,
    8 /*16ad*/,  8 /*16ae*/,  9 /*16af*/,  6 /*16b0*/,  7 /*16b1*/,
    7 /*16b2*/,  8 /*16b3*/,  7 /*16b4*/,  8 /*16b5*/,  8 /*16b6*/,
    9 /*16b7*/,  7 /*16b8*/,  8 /*16b9*/,  8 /*16ba*/,  9 /*16bb*/,
    8 /*16bc*/,  9 /*16bd*/,  9 /*16be*/,  10 /*16bf*/, 5 /*16c0*/,
    6 /*16c1*/,  6 /*16c2*/,  7 /*16c3*/,  6 /*16c4*/,  7 /*16c5*/,
    7 /*16c6*/,  8 /*16c7*/,  6 /*16c8*/,  7 /*16c9*/,  7 /*16ca*/,
    8 /*16cb*/,  7 /*16cc*/,  8 /*16cd*/,  8 /*16ce*/,  9 /*16cf*/,
    6 /*16d0*/,  7 /*16d1*/,  7 /*16d2*/,  8 /*16d3*/,  7 /*16d4*/,
    8 /*16d5*/,  8 /*16d6*/,  9 /*16d7*/,  7 /*16d8*/,  8 /*16d9*/,
    8 /*16da*/,  9 /*16db*/,  8 /*16dc*/,  9 /*16dd*/,  9 /*16de*/,
    10 /*16df*/, 6 /*16e0*/,  7 /*16e1*/,  7 /*16e2*/,  8 /*16e3*/,
    7 /*16e4*/,  8 /*16e5*/,  8 /*16e6*/,  9 /*16e7*/,  7 /*16e8*/,
    8 /*16e9*/,  8 /*16ea*/,  9 /*16eb*/,  8 /*16ec*/,  9 /*16ed*/,
    9 /*16ee*/,  10 /*16ef*/, 7 /*16f0*/,  8 /*16f1*/,  8 /*16f2*/,
    9 /*16f3*/,  8 /*16f4*/,  9 /*16f5*/,  9 /*16f6*/,  10 /*16f7*/,
    8 /*16f8*/,  9 /*16f9*/,  9 /*16fa*/,  10 /*16fb*/, 9 /*16fc*/,
    10 /*16fd*/, 10 /*16fe*/, 11 /*16ff*/, 4 /*1700*/,  5 /*1701*/,
    5 /*1702*/,  6 /*1703*/,  5 /*1704*/,  6 /*1705*/,  6 /*1706*/,
    7 /*1707*/,  5 /*1708*/,  6 /*1709*/,  6 /*170a*/,  7 /*170b*/,
    6 /*170c*/,  7 /*170d*/,  7 /*170e*/,  8 /*170f*/,  5 /*1710*/,
    6 /*1711*/,  6 /*1712*/,  7 /*1713*/,  6 /*1714*/,  7 /*1715*/,
    7 /*1716*/,  8 /*1717*/,  6 /*1718*/,  7 /*1719*/,  7 /*171a*/,
    8 /*171b*/,  7 /*171c*/,  8 /*171d*/,  8 /*171e*/,  9 /*171f*/,
    5 /*1720*/,  6 /*1721*/,  6 /*1722*/,  7 /*1723*/,  6 /*1724*/,
    7 /*1725*/,  7 /*1726*/,  8 /*1727*/,  6 /*1728*/,  7 /*1729*/,
    7 /*172a*/,  8 /*172b*/,  7 /*172c*/,  8 /*172d*/,  8 /*172e*/,
    9 /*172f*/,  6 /*1730*/,  7 /*1731*/,  7 /*1732*/,  8 /*1733*/,
    7 /*1734*/,  8 /*1735*/,  8 /*1736*/,  9 /*1737*/,  7 /*1738*/,
    8 /*1739*/,  8 /*173a*/,  9 /*173b*/,  8 /*173c*/,  9 /*173d*/,
    9 /*173e*/,  10 /*173f*/, 5 /*1740*/,  6 /*1741*/,  6 /*1742*/,
    7 /*1743*/,  6 /*1744*/,  7 /*1745*/,  7 /*1746*/,  8 /*1747*/,
    6 /*1748*/,  7 /*1749*/,  7 /*174a*/,  8 /*174b*/,  7 /*174c*/,
    8 /*174d*/,  8 /*174e*/,  9 /*174f*/,  6 /*1750*/,  7 /*1751*/,
    7 /*1752*/,  8 /*1753*/,  7 /*1754*/,  8 /*1755*/,  8 /*1756*/,
    9 /*1757*/,  7 /*1758*/,  8 /*1759*/,  8 /*175a*/,  9 /*175b*/,
    8 /*175c*/,  9 /*175d*/,  9 /*175e*/,  10 /*175f*/, 6 /*1760*/,
    7 /*1761*/,  7 /*1762*/,  8 /*1763*/,  7 /*1764*/,  8 /*1765*/,
    8 /*1766*/,  9 /*1767*/,  7 /*1768*/,  8 /*1769*/,  8 /*176a*/,
    9 /*176b*/,  8 /*176c*/,  9 /*176d*/,  9 /*176e*/,  10 /*176f*/,
    7 /*1770*/,  8 /*1771*/,  8 /*1772*/,  9 /*1773*/,  8 /*1774*/,
    9 /*1775*/,  9 /*1776*/,  10 /*1777*/, 8 /*1778*/,  9 /*1779*/,
    9 /*177a*/,  10 /*177b*/, 9 /*177c*/,  10 /*177d*/, 10 /*177e*/,
    11 /*177f*/, 5 /*1780*/,  6 /*1781*/,  6 /*1782*/,  7 /*1783*/,
    6 /*1784*/,  7 /*1785*/,  7 /*1786*/,  8 /*1787*/,  6 /*1788*/,
    7 /*1789*/,  7 /*178a*/,  8 /*178b*/,  7 /*178c*/,  8 /*178d*/,
    8 /*178e*/,  9 /*178f*/,  6 /*1790*/,  7 /*1791*/,  7 /*1792*/,
    8 /*1793*/,  7 /*1794*/,  8 /*1795*/,  8 /*1796*/,  9 /*1797*/,
    7 /*1798*/,  8 /*1799*/,  8 /*179a*/,  9 /*179b*/,  8 /*179c*/,
    9 /*179d*/,  9 /*179e*/,  10 /*179f*/, 6 /*17a0*/,  7 /*17a1*/,
    7 /*17a2*/,  8 /*17a3*/,  7 /*17a4*/,  8 /*17a5*/,  8 /*17a6*/,
    9 /*17a7*/,  7 /*17a8*/,  8 /*17a9*/,  8 /*17aa*/,  9 /*17ab*/,
    8 /*17ac*/,  9 /*17ad*/,  9 /*17ae*/,  10 /*17af*/, 7 /*17b0*/,
    8 /*17b1*/,  8 /*17b2*/,  9 /*17b3*/,  8 /*17b4*/,  9 /*17b5*/,
    9 /*17b6*/,  10 /*17b7*/, 8 /*17b8*/,  9 /*17b9*/,  9 /*17ba*/,
    10 /*17bb*/, 9 /*17bc*/,  10 /*17bd*/, 10 /*17be*/, 11 /*17bf*/,
    6 /*17c0*/,  7 /*17c1*/,  7 /*17c2*/,  8 /*17c3*/,  7 /*17c4*/,
    8 /*17c5*/,  8 /*17c6*/,  9 /*17c7*/,  7 /*17c8*/,  8 /*17c9*/,
    8 /*17ca*/,  9 /*17cb*/,  8 /*17cc*/,  9 /*17cd*/,  9 /*17ce*/,
    10 /*17cf*/, 7 /*17d0*/,  8 /*17d1*/,  8 /*17d2*/,  9 /*17d3*/,
    8 /*17d4*/,  9 /*17d5*/,  9 /*17d6*/,  10 /*17d7*/, 8 /*17d8*/,
    9 /*17d9*/,  9 /*17da*/,  10 /*17db*/, 9 /*17dc*/,  10 /*17dd*/,
    10 /*17de*/, 11 /*17df*/, 7 /*17e0*/,  8 /*17e1*/,  8 /*17e2*/,
    9 /*17e3*/,  8 /*17e4*/,  9 /*17e5*/,  9 /*17e6*/,  10 /*17e7*/,
    8 /*17e8*/,  9 /*17e9*/,  9 /*17ea*/,  10 /*17eb*/, 9 /*17ec*/,
    10 /*17ed*/, 10 /*17ee*/, 11 /*17ef*/, 8 /*17f0*/,  9 /*17f1*/,
    9 /*17f2*/,  10 /*17f3*/, 9 /*17f4*/,  10 /*17f5*/, 10 /*17f6*/,
    11 /*17f7*/, 9 /*17f8*/,  10 /*17f9*/, 10 /*17fa*/, 11 /*17fb*/,
    10 /*17fc*/, 11 /*17fd*/, 11 /*17fe*/, 12 /*17ff*/, 2 /*1800*/,
    3 /*1801*/,  3 /*1802*/,  4 /*1803*/,  3 /*1804*/,  4 /*1805*/,
    4 /*1806*/,  5 /*1807*/,  3 /*1808*/,  4 /*1809*/,  4 /*180a*/,
    5 /*180b*/,  4 /*180c*/,  5 /*180d*/,  5 /*180e*/,  6 /*180f*/,
    3 /*1810*/,  4 /*1811*/,  4 /*1812*/,  5 /*1813*/,  4 /*1814*/,
    5 /*1815*/,  5 /*1816*/,  6 /*1817*/,  4 /*1818*/,  5 /*1819*/,
    5 /*181a*/,  6 /*181b*/,  5 /*181c*/,  6 /*181d*/,  6 /*181e*/,
    7 /*181f*/,  3 /*1820*/,  4 /*1821*/,  4 /*1822*/,  5 /*1823*/,
    4 /*1824*/,  5 /*1825*/,  5 /*1826*/,  6 /*1827*/,  4 /*1828*/,
    5 /*1829*/,  5 /*182a*/,  6 /*182b*/,  5 /*182c*/,  6 /*182d*/,
    6 /*182e*/,  7 /*182f*/,  4 /*1830*/,  5 /*1831*/,  5 /*1832*/,
    6 /*1833*/,  5 /*1834*/,  6 /*1835*/,  6 /*1836*/,  7 /*1837*/,
    5 /*1838*/,  6 /*1839*/,  6 /*183a*/,  7 /*183b*/,  6 /*183c*/,
    7 /*183d*/,  7 /*183e*/,  8 /*183f*/,  3 /*1840*/,  4 /*1841*/,
    4 /*1842*/,  5 /*1843*/,  4 /*1844*/,  5 /*1845*/,  5 /*1846*/,
    6 /*1847*/,  4 /*1848*/,  5 /*1849*/,  5 /*184a*/,  6 /*184b*/,
    5 /*184c*/,  6 /*184d*/,  6 /*184e*/,  7 /*184f*/,  4 /*1850*/,
    5 /*1851*/,  5 /*1852*/,  6 /*1853*/,  5 /*1854*/,  6 /*1855*/,
    6 /*1856*/,  7 /*1857*/,  5 /*1858*/,  6 /*1859*/,  6 /*185a*/,
    7 /*185b*/,  6 /*185c*/,  7 /*185d*/,  7 /*185e*/,  8 /*185f*/,
    4 /*1860*/,  5 /*1861*/,  5 /*1862*/,  6 /*1863*/,  5 /*1864*/,
    6 /*1865*/,  6 /*1866*/,  7 /*1867*/,  5 /*1868*/,  6 /*1869*/,
    6 /*186a*/,  7 /*186b*/,  6 /*186c*/,  7 /*186d*/,  7 /*186e*/,
    8 /*186f*/,  5 /*1870*/,  6 /*1871*/,  6 /*1872*/,  7 /*1873*/,
    6 /*1874*/,  7 /*1875*/,  7 /*1876*/,  8 /*1877*/,  6 /*1878*/,
    7 /*1879*/,  7 /*187a*/,  8 /*187b*/,  7 /*187c*/,  8 /*187d*/,
    8 /*187e*/,  9 /*187f*/,  3 /*1880*/,  4 /*1881*/,  4 /*1882*/,
    5 /*1883*/,  4 /*1884*/,  5 /*1885*/,  5 /*1886*/,  6 /*1887*/,
    4 /*1888*/,  5 /*1889*/,  5 /*188a*/,  6 /*188b*/,  5 /*188c*/,
    6 /*188d*/,  6 /*188e*/,  7 /*188f*/,  4 /*1890*/,  5 /*1891*/,
    5 /*1892*/,  6 /*1893*/,  5 /*1894*/,  6 /*1895*/,  6 /*1896*/,
    7 /*1897*/,  5 /*1898*/,  6 /*1899*/,  6 /*189a*/,  7 /*189b*/,
    6 /*189c*/,  7 /*189d*/,  7 /*189e*/,  8 /*189f*/,  4 /*18a0*/,
    5 /*18a1*/,  5 /*18a2*/,  6 /*18a3*/,  5 /*18a4*/,  6 /*18a5*/,
    6 /*18a6*/,  7 /*18a7*/,  5 /*18a8*/,  6 /*18a9*/,  6 /*18aa*/,
    7 /*18ab*/,  6 /*18ac*/,  7 /*18ad*/,  7 /*18ae*/,  8 /*18af*/,
    5 /*18b0*/,  6 /*18b1*/,  6 /*18b2*/,  7 /*18b3*/,  6 /*18b4*/,
    7 /*18b5*/,  7 /*18b6*/,  8 /*18b7*/,  6 /*18b8*/,  7 /*18b9*/,
    7 /*18ba*/,  8 /*18bb*/,  7 /*18bc*/,  8 /*18bd*/,  8 /*18be*/,
    9 /*18bf*/,  4 /*18c0*/,  5 /*18c1*/,  5 /*18c2*/,  6 /*18c3*/,
    5 /*18c4*/,  6 /*18c5*/,  6 /*18c6*/,  7 /*18c7*/,  5 /*18c8*/,
    6 /*18c9*/,  6 /*18ca*/,  7 /*18cb*/,  6 /*18cc*/,  7 /*18cd*/,
    7 /*18ce*/,  8 /*18cf*/,  5 /*18d0*/,  6 /*18d1*/,  6 /*18d2*/,
    7 /*18d3*/,  6 /*18d4*/,  7 /*18d5*/,  7 /*18d6*/,  8 /*18d7*/,
    6 /*18d8*/,  7 /*18d9*/,  7 /*18da*/,  8 /*18db*/,  7 /*18dc*/,
    8 /*18dd*/,  8 /*18de*/,  9 /*18df*/,  5 /*18e0*/,  6 /*18e1*/,
    6 /*18e2*/,  7 /*18e3*/,  6 /*18e4*/,  7 /*18e5*/,  7 /*18e6*/,
    8 /*18e7*/,  6 /*18e8*/,  7 /*18e9*/,  7 /*18ea*/,  8 /*18eb*/,
    7 /*18ec*/,  8 /*18ed*/,  8 /*18ee*/,  9 /*18ef*/,  6 /*18f0*/,
    7 /*18f1*/,  7 /*18f2*/,  8 /*18f3*/,  7 /*18f4*/,  8 /*18f5*/,
    8 /*18f6*/,  9 /*18f7*/,  7 /*18f8*/,  8 /*18f9*/,  8 /*18fa*/,
    9 /*18fb*/,  8 /*18fc*/,  9 /*18fd*/,  9 /*18fe*/,  10 /*18ff*/,
    3 /*1900*/,  4 /*1901*/,  4 /*1902*/,  5 /*1903*/,  4 /*1904*/,
    5 /*1905*/,  5 /*1906*/,  6 /*1907*/,  4 /*1908*/,  5 /*1909*/,
    5 /*190a*/,  6 /*190b*/,  5 /*190c*/,  6 /*190d*/,  6 /*190e*/,
    7 /*190f*/,  4 /*1910*/,  5 /*1911*/,  5 /*1912*/,  6 /*1913*/,
    5 /*1914*/,  6 /*1915*/,  6 /*1916*/,  7 /*1917*/,  5 /*1918*/,
    6 /*1919*/,  6 /*191a*/,  7 /*191b*/,  6 /*191c*/,  7 /*191d*/,
    7 /*191e*/,  8 /*191f*/,  4 /*1920*/,  5 /*1921*/,  5 /*1922*/,
    6 /*1923*/,  5 /*1924*/,  6 /*1925*/,  6 /*1926*/,  7 /*1927*/,
    5 /*1928*/,  6 /*1929*/,  6 /*192a*/,  7 /*192b*/,  6 /*192c*/,
    7 /*192d*/,  7 /*192e*/,  8 /*192f*/,  5 /*1930*/,  6 /*1931*/,
    6 /*1932*/,  7 /*1933*/,  6 /*1934*/,  7 /*1935*/,  7 /*1936*/,
    8 /*1937*/,  6 /*1938*/,  7 /*1939*/,  7 /*193a*/,  8 /*193b*/,
    7 /*193c*/,  8 /*193d*/,  8 /*193e*/,  9 /*193f*/,  4 /*1940*/,
    5 /*1941*/,  5 /*1942*/,  6 /*1943*/,  5 /*1944*/,  6 /*1945*/,
    6 /*1946*/,  7 /*1947*/,  5 /*1948*/,  6 /*1949*/,  6 /*194a*/,
    7 /*194b*/,  6 /*194c*/,  7 /*194d*/,  7 /*194e*/,  8 /*194f*/,
    5 /*1950*/,  6 /*1951*/,  6 /*1952*/,  7 /*1953*/,  6 /*1954*/,
    7 /*1955*/,  7 /*1956*/,  8 /*1957*/,  6 /*1958*/,  7 /*1959*/,
    7 /*195a*/,  8 /*195b*/,  7 /*195c*/,  8 /*195d*/,  8 /*195e*/,
    9 /*195f*/,  5 /*1960*/,  6 /*1961*/,  6 /*1962*/,  7 /*1963*/,
    6 /*1964*/,  7 /*1965*/,  7 /*1966*/,  8 /*1967*/,  6 /*1968*/,
    7 /*1969*/,  7 /*196a*/,  8 /*196b*/,  7 /*196c*/,  8 /*196d*/,
    8 /*196e*/,  9 /*196f*/,  6 /*1970*/,  7 /*1971*/,  7 /*1972*/,
    8 /*1973*/,  7 /*1974*/,  8 /*1975*/,  8 /*1976*/,  9 /*1977*/,
    7 /*1978*/,  8 /*1979*/,  8 /*197a*/,  9 /*197b*/,  8 /*197c*/,
    9 /*197d*/,  9 /*197e*/,  10 /*197f*/, 4 /*1980*/,  5 /*1981*/,
    5 /*1982*/,  6 /*1983*/,  5 /*1984*/,  6 /*1985*/,  6 /*1986*/,
    7 /*1987*/,  5 /*1988*/,  6 /*1989*/,  6 /*198a*/,  7 /*198b*/,
    6 /*198c*/,  7 /*198d*/,  7 /*198e*/,  8 /*198f*/,  5 /*1990*/,
    6 /*1991*/,  6 /*1992*/,  7 /*1993*/,  6 /*1994*/,  7 /*1995*/,
    7 /*1996*/,  8 /*1997*/,  6 /*1998*/,  7 /*1999*/,  7 /*199a*/,
    8 /*199b*/,  7 /*199c*/,  8 /*199d*/,  8 /*199e*/,  9 /*199f*/,
    5 /*19a0*/,  6 /*19a1*/,  6 /*19a2*/,  7 /*19a3*/,  6 /*19a4*/,
    7 /*19a5*/,  7 /*19a6*/,  8 /*19a7*/,  6 /*19a8*/,  7 /*19a9*/,
    7 /*19aa*/,  8 /*19ab*/,  7 /*19ac*/,  8 /*19ad*/,  8 /*19ae*/,
    9 /*19af*/,  6 /*19b0*/,  7 /*19b1*/,  7 /*19b2*/,  8 /*19b3*/,
    7 /*19b4*/,  8 /*19b5*/,  8 /*19b6*/,  9 /*19b7*/,  7 /*19b8*/,
    8 /*19b9*/,  8 /*19ba*/,  9 /*19bb*/,  8 /*19bc*/,  9 /*19bd*/,
    9 /*19be*/,  10 /*19bf*/, 5 /*19c0*/,  6 /*19c1*/,  6 /*19c2*/,
    7 /*19c3*/,  6 /*19c4*/,  7 /*19c5*/,  7 /*19c6*/,  8 /*19c7*/,
    6 /*19c8*/,  7 /*19c9*/,  7 /*19ca*/,  8 /*19cb*/,  7 /*19cc*/,
    8 /*19cd*/,  8 /*19ce*/,  9 /*19cf*/,  6 /*19d0*/,  7 /*19d1*/,
    7 /*19d2*/,  8 /*19d3*/,  7 /*19d4*/,  8 /*19d5*/,  8 /*19d6*/,
    9 /*19d7*/,  7 /*19d8*/,  8 /*19d9*/,  8 /*19da*/,  9 /*19db*/,
    8 /*19dc*/,  9 /*19dd*/,  9 /*19de*/,  10 /*19df*/, 6 /*19e0*/,
    7 /*19e1*/,  7 /*19e2*/,  8 /*19e3*/,  7 /*19e4*/,  8 /*19e5*/,
    8 /*19e6*/,  9 /*19e7*/,  7 /*19e8*/,  8 /*19e9*/,  8 /*19ea*/,
    9 /*19eb*/,  8 /*19ec*/,  9 /*19ed*/,  9 /*19ee*/,  10 /*19ef*/,
    7 /*19f0*/,  8 /*19f1*/,  8 /*19f2*/,  9 /*19f3*/,  8 /*19f4*/,
    9 /*19f5*/,  9 /*19f6*/,  10 /*19f7*/, 8 /*19f8*/,  9 /*19f9*/,
    9 /*19fa*/,  10 /*19fb*/, 9 /*19fc*/,  10 /*19fd*/, 10 /*19fe*/,
    11 /*19ff*/, 3 /*1a00*/,  4 /*1a01*/,  4 /*1a02*/,  5 /*1a03*/,
    4 /*1a04*/,  5 /*1a05*/,  5 /*1a06*/,  6 /*1a07*/,  4 /*1a08*/,
    5 /*1a09*/,  5 /*1a0a*/,  6 /*1a0b*/,  5 /*1a0c*/,  6 /*1a0d*/,
    6 /*1a0e*/,  7 /*1a0f*/,  4 /*1a10*/,  5 /*1a11*/,  5 /*1a12*/,
    6 /*1a13*/,  5 /*1a14*/,  6 /*1a15*/,  6 /*1a16*/,  7 /*1a17*/,
    5 /*1a18*/,  6 /*1a19*/,  6 /*1a1a*/,  7 /*1a1b*/,  6 /*1a1c*/,
    7 /*1a1d*/,  7 /*1a1e*/,  8 /*1a1f*/,  4 /*1a20*/,  5 /*1a21*/,
    5 /*1a22*/,  6 /*1a23*/,  5 /*1a24*/,  6 /*1a25*/,  6 /*1a26*/,
    7 /*1a27*/,  5 /*1a28*/,  6 /*1a29*/,  6 /*1a2a*/,  7 /*1a2b*/,
    6 /*1a2c*/,  7 /*1a2d*/,  7 /*1a2e*/,  8 /*1a2f*/,  5 /*1a30*/,
    6 /*1a31*/,  6 /*1a32*/,  7 /*1a33*/,  6 /*1a34*/,  7 /*1a35*/,
    7 /*1a36*/,  8 /*1a37*/,  6 /*1a38*/,  7 /*1a39*/,  7 /*1a3a*/,
    8 /*1a3b*/,  7 /*1a3c*/,  8 /*1a3d*/,  8 /*1a3e*/,  9 /*1a3f*/,
    4 /*1a40*/,  5 /*1a41*/,  5 /*1a42*/,  6 /*1a43*/,  5 /*1a44*/,
    6 /*1a45*/,  6 /*1a46*/,  7 /*1a47*/,  5 /*1a48*/,  6 /*1a49*/,
    6 /*1a4a*/,  7 /*1a4b*/,  6 /*1a4c*/,  7 /*1a4d*/,  7 /*1a4e*/,
    8 /*1a4f*/,  5 /*1a50*/,  6 /*1a51*/,  6 /*1a52*/,  7 /*1a53*/,
    6 /*1a54*/,  7 /*1a55*/,  7 /*1a56*/,  8 /*1a57*/,  6 /*1a58*/,
    7 /*1a59*/,  7 /*1a5a*/,  8 /*1a5b*/,  7 /*1a5c*/,  8 /*1a5d*/,
    8 /*1a5e*/,  9 /*1a5f*/,  5 /*1a60*/,  6 /*1a61*/,  6 /*1a62*/,
    7 /*1a63*/,  6 /*1a64*/,  7 /*1a65*/,  7 /*1a66*/,  8 /*1a67*/,
    6 /*1a68*/,  7 /*1a69*/,  7 /*1a6a*/,  8 /*1a6b*/,  7 /*1a6c*/,
    8 /*1a6d*/,  8 /*1a6e*/,  9 /*1a6f*/,  6 /*1a70*/,  7 /*1a71*/,
    7 /*1a72*/,  8 /*1a73*/,  7 /*1a74*/,  8 /*1a75*/,  8 /*1a76*/,
    9 /*1a77*/,  7 /*1a78*/,  8 /*1a79*/,  8 /*1a7a*/,  9 /*1a7b*/,
    8 /*1a7c*/,  9 /*1a7d*/,  9 /*1a7e*/,  10 /*1a7f*/, 4 /*1a80*/,
    5 /*1a81*/,  5 /*1a82*/,  6 /*1a83*/,  5 /*1a84*/,  6 /*1a85*/,
    6 /*1a86*/,  7 /*1a87*/,  5 /*1a88*/,  6 /*1a89*/,  6 /*1a8a*/,
    7 /*1a8b*/,  6 /*1a8c*/,  7 /*1a8d*/,  7 /*1a8e*/,  8 /*1a8f*/,
    5 /*1a90*/,  6 /*1a91*/,  6 /*1a92*/,  7 /*1a93*/,  6 /*1a94*/,
    7 /*1a95*/,  7 /*1a96*/,  8 /*1a97*/,  6 /*1a98*/,  7 /*1a99*/,
    7 /*1a9a*/,  8 /*1a9b*/,  7 /*1a9c*/,  8 /*1a9d*/,  8 /*1a9e*/,
    9 /*1a9f*/,  5 /*1aa0*/,  6 /*1aa1*/,  6 /*1aa2*/,  7 /*1aa3*/,
    6 /*1aa4*/,  7 /*1aa5*/,  7 /*1aa6*/,  8 /*1aa7*/,  6 /*1aa8*/,
    7 /*1aa9*/,  7 /*1aaa*/,  8 /*1aab*/,  7 /*1aac*/,  8 /*1aad*/,
    8 /*1aae*/,  9 /*1aaf*/,  6 /*1ab0*/,  7 /*1ab1*/,  7 /*1ab2*/,
    8 /*1ab3*/,  7 /*1ab4*/,  8 /*1ab5*/,  8 /*1ab6*/,  9 /*1ab7*/,
    7 /*1ab8*/,  8 /*1ab9*/,  8 /*1aba*/,  9 /*1abb*/,  8 /*1abc*/,
    9 /*1abd*/,  9 /*1abe*/,  10 /*1abf*/, 5 /*1ac0*/,  6 /*1ac1*/,
    6 /*1ac2*/,  7 /*1ac3*/,  6 /*1ac4*/,  7 /*1ac5*/,  7 /*1ac6*/,
    8 /*1ac7*/,  6 /*1ac8*/,  7 /*1ac9*/,  7 /*1aca*/,  8 /*1acb*/,
    7 /*1acc*/,  8 /*1acd*/,  8 /*1ace*/,  9 /*1acf*/,  6 /*1ad0*/,
    7 /*1ad1*/,  7 /*1ad2*/,  8 /*1ad3*/,  7 /*1ad4*/,  8 /*1ad5*/,
    8 /*1ad6*/,  9 /*1ad7*/,  7 /*1ad8*/,  8 /*1ad9*/,  8 /*1ada*/,
    9 /*1adb*/,  8 /*1adc*/,  9 /*1add*/,  9 /*1ade*/,  10 /*1adf*/,
    6 /*1ae0*/,  7 /*1ae1*/,  7 /*1ae2*/,  8 /*1ae3*/,  7 /*1ae4*/,
    8 /*1ae5*/,  8 /*1ae6*/,  9 /*1ae7*/,  7 /*1ae8*/,  8 /*1ae9*/,
    8 /*1aea*/,  9 /*1aeb*/,  8 /*1aec*/,  9 /*1aed*/,  9 /*1aee*/,
    10 /*1aef*/, 7 /*1af0*/,  8 /*1af1*/,  8 /*1af2*/,  9 /*1af3*/,
    8 /*1af4*/,  9 /*1af5*/,  9 /*1af6*/,  10 /*1af7*/, 8 /*1af8*/,
    9 /*1af9*/,  9 /*1afa*/,  10 /*1afb*/, 9 /*1afc*/,  10 /*1afd*/,
    10 /*1afe*/, 11 /*1aff*/, 4 /*1b00*/,  5 /*1b01*/,  5 /*1b02*/,
    6 /*1b03*/,  5 /*1b04*/,  6 /*1b05*/,  6 /*1b06*/,  7 /*1b07*/,
    5 /*1b08*/,  6 /*1b09*/,  6 /*1b0a*/,  7 /*1b0b*/,  6 /*1b0c*/,
    7 /*1b0d*/,  7 /*1b0e*/,  8 /*1b0f*/,  5 /*1b10*/,  6 /*1b11*/,
    6 /*1b12*/,  7 /*1b13*/,  6 /*1b14*/,  7 /*1b15*/,  7 /*1b16*/,
    8 /*1b17*/,  6 /*1b18*/,  7 /*1b19*/,  7 /*1b1a*/,  8 /*1b1b*/,
    7 /*1b1c*/,  8 /*1b1d*/,  8 /*1b1e*/,  9 /*1b1f*/,  5 /*1b20*/,
    6 /*1b21*/,  6 /*1b22*/,  7 /*1b23*/,  6 /*1b24*/,  7 /*1b25*/,
    7 /*1b26*/,  8 /*1b27*/,  6 /*1b28*/,  7 /*1b29*/,  7 /*1b2a*/,
    8 /*1b2b*/,  7 /*1b2c*/,  8 /*1b2d*/,  8 /*1b2e*/,  9 /*1b2f*/,
    6 /*1b30*/,  7 /*1b31*/,  7 /*1b32*/,  8 /*1b33*/,  7 /*1b34*/,
    8 /*1b35*/,  8 /*1b36*/,  9 /*1b37*/,  7 /*1b38*/,  8 /*1b39*/,
    8 /*1b3a*/,  9 /*1b3b*/,  8 /*1b3c*/,  9 /*1b3d*/,  9 /*1b3e*/,
    10 /*1b3f*/, 5 /*1b40*/,  6 /*1b41*/,  6 /*1b42*/,  7 /*1b43*/,
    6 /*1b44*/,  7 /*1b45*/,  7 /*1b46*/,  8 /*1b47*/,  6 /*1b48*/,
    7 /*1b49*/,  7 /*1b4a*/,  8 /*1b4b*/,  7 /*1b4c*/,  8 /*1b4d*/,
    8 /*1b4e*/,  9 /*1b4f*/,  6 /*1b50*/,  7 /*1b51*/,  7 /*1b52*/,
    8 /*1b53*/,  7 /*1b54*/,  8 /*1b55*/,  8 /*1b56*/,  9 /*1b57*/,
    7 /*1b58*/,  8 /*1b59*/,  8 /*1b5a*/,  9 /*1b5b*/,  8 /*1b5c*/,
    9 /*1b5d*/,  9 /*1b5e*/,  10 /*1b5f*/, 6 /*1b60*/,  7 /*1b61*/,
    7 /*1b62*/,  8 /*1b63*/,  7 /*1b64*/,  8 /*1b65*/,  8 /*1b66*/,
    9 /*1b67*/,  7 /*1b68*/,  8 /*1b69*/,  8 /*1b6a*/,  9 /*1b6b*/,
    8 /*1b6c*/,  9 /*1b6d*/,  9 /*1b6e*/,  10 /*1b6f*/, 7 /*1b70*/,
    8 /*1b71*/,  8 /*1b72*/,  9 /*1b73*/,  8 /*1b74*/,  9 /*1b75*/,
    9 /*1b76*/,  10 /*1b77*/, 8 /*1b78*/,  9 /*1b79*/,  9 /*1b7a*/,
    10 /*1b7b*/, 9 /*1b7c*/,  10 /*1b7d*/, 10 /*1b7e*/, 11 /*1b7f*/,
    5 /*1b80*/,  6 /*1b81*/,  6 /*1b82*/,  7 /*1b83*/,  6 /*1b84*/,
    7 /*1b85*/,  7 /*1b86*/,  8 /*1b87*/,  6 /*1b88*/,  7 /*1b89*/,
    7 /*1b8a*/,  8 /*1b8b*/,  7 /*1b8c*/,  8 /*1b8d*/,  8 /*1b8e*/,
    9 /*1b8f*/,  6 /*1b90*/,  7 /*1b91*/,  7 /*1b92*/,  8 /*1b93*/,
    7 /*1b94*/,  8 /*1b95*/,  8 /*1b96*/,  9 /*1b97*/,  7 /*1b98*/,
    8 /*1b99*/,  8 /*1b9a*/,  9 /*1b9b*/,  8 /*1b9c*/,  9 /*1b9d*/,
    9 /*1b9e*/,  10 /*1b9f*/, 6 /*1ba0*/,  7 /*1ba1*/,  7 /*1ba2*/,
    8 /*1ba3*/,  7 /*1ba4*/,  8 /*1ba5*/,  8 /*1ba6*/,  9 /*1ba7*/,
    7 /*1ba8*/,  8 /*1ba9*/,  8 /*1baa*/,  9 /*1bab*/,  8 /*1bac*/,
    9 /*1bad*/,  9 /*1bae*/,  10 /*1baf*/, 7 /*1bb0*/,  8 /*1bb1*/,
    8 /*1bb2*/,  9 /*1bb3*/,  8 /*1bb4*/,  9 /*1bb5*/,  9 /*1bb6*/,
    10 /*1bb7*/, 8 /*1bb8*/,  9 /*1bb9*/,  9 /*1bba*/,  10 /*1bbb*/,
    9 /*1bbc*/,  10 /*1bbd*/, 10 /*1bbe*/, 11 /*1bbf*/, 6 /*1bc0*/,
    7 /*1bc1*/,  7 /*1bc2*/,  8 /*1bc3*/,  7 /*1bc4*/,  8 /*1bc5*/,
    8 /*1bc6*/,  9 /*1bc7*/,  7 /*1bc8*/,  8 /*1bc9*/,  8 /*1bca*/,
    9 /*1bcb*/,  8 /*1bcc*/,  9 /*1bcd*/,  9 /*1bce*/,  10 /*1bcf*/,
    7 /*1bd0*/,  8 /*1bd1*/,  8 /*1bd2*/,  9 /*1bd3*/,  8 /*1bd4*/,
    9 /*1bd5*/,  9 /*1bd6*/,  10 /*1bd7*/, 8 /*1bd8*/,  9 /*1bd9*/,
    9 /*1bda*/,  10 /*1bdb*/, 9 /*1bdc*/,  10 /*1bdd*/, 10 /*1bde*/,
    11 /*1bdf*/, 7 /*1be0*/,  8 /*1be1*/,  8 /*1be2*/,  9 /*1be3*/,
    8 /*1be4*/,  9 /*1be5*/,  9 /*1be6*/,  10 /*1be7*/, 8 /*1be8*/,
    9 /*1be9*/,  9 /*1bea*/,  10 /*1beb*/, 9 /*1bec*/,  10 /*1bed*/,
    10 /*1bee*/, 11 /*1bef*/, 8 /*1bf0*/,  9 /*1bf1*/,  9 /*1bf2*/,
    10 /*1bf3*/, 9 /*1bf4*/,  10 /*1bf5*/, 10 /*1bf6*/, 11 /*1bf7*/,
    9 /*1bf8*/,  10 /*1bf9*/, 10 /*1bfa*/, 11 /*1bfb*/, 10 /*1bfc*/,
    11 /*1bfd*/, 11 /*1bfe*/, 12 /*1bff*/, 3 /*1c00*/,  4 /*1c01*/,
    4 /*1c02*/,  5 /*1c03*/,  4 /*1c04*/,  5 /*1c05*/,  5 /*1c06*/,
    6 /*1c07*/,  4 /*1c08*/,  5 /*1c09*/,  5 /*1c0a*/,  6 /*1c0b*/,
    5 /*1c0c*/,  6 /*1c0d*/,  6 /*1c0e*/,  7 /*1c0f*/,  4 /*1c10*/,
    5 /*1c11*/,  5 /*1c12*/,  6 /*1c13*/,  5 /*1c14*/,  6 /*1c15*/,
    6 /*1c16*/,  7 /*1c17*/,  5 /*1c18*/,  6 /*1c19*/,  6 /*1c1a*/,
    7 /*1c1b*/,  6 /*1c1c*/,  7 /*1c1d*/,  7 /*1c1e*/,  8 /*1c1f*/,
    4 /*1c20*/,  5 /*1c21*/,  5 /*1c22*/,  6 /*1c23*/,  5 /*1c24*/,
    6 /*1c25*/,  6 /*1c26*/,  7 /*1c27*/,  5 /*1c28*/,  6 /*1c29*/,
    6 /*1c2a*/,  7 /*1c2b*/,  6 /*1c2c*/,  7 /*1c2d*/,  7 /*1c2e*/,
    8 /*1c2f*/,  5 /*1c30*/,  6 /*1c31*/,  6 /*1c32*/,  7 /*1c33*/,
    6 /*1c34*/,  7 /*1c35*/,  7 /*1c36*/,  8 /*1c37*/,  6 /*1c38*/,
    7 /*1c39*/,  7 /*1c3a*/,  8 /*1c3b*/,  7 /*1c3c*/,  8 /*1c3d*/,
    8 /*1c3e*/,  9 /*1c3f*/,  4 /*1c40*/,  5 /*1c41*/,  5 /*1c42*/,
    6 /*1c43*/,  5 /*1c44*/,  6 /*1c45*/,  6 /*1c46*/,  7 /*1c47*/,
    5 /*1c48*/,  6 /*1c49*/,  6 /*1c4a*/,  7 /*1c4b*/,  6 /*1c4c*/,
    7 /*1c4d*/,  7 /*1c4e*/,  8 /*1c4f*/,  5 /*1c50*/,  6 /*1c51*/,
    6 /*1c52*/,  7 /*1c53*/,  6 /*1c54*/,  7 /*1c55*/,  7 /*1c56*/,
    8 /*1c57*/,  6 /*1c58*/,  7 /*1c59*/,  7 /*1c5a*/,  8 /*1c5b*/,
    7 /*1c5c*/,  8 /*1c5d*/,  8 /*1c5e*/,  9 /*1c5f*/,  5 /*1c60*/,
    6 /*1c61*/,  6 /*1c62*/,  7 /*1c63*/,  6 /*1c64*/,  7 /*1c65*/,
    7 /*1c66*/,  8 /*1c67*/,  6 /*1c68*/,  7 /*1c69*/,  7 /*1c6a*/,
    8 /*1c6b*/,  7 /*1c6c*/,  8 /*1c6d*/,  8 /*1c6e*/,  9 /*1c6f*/,
    6 /*1c70*/,  7 /*1c71*/,  7 /*1c72*/,  8 /*1c73*/,  7 /*1c74*/,
    8 /*1c75*/,  8 /*1c76*/,  9 /*1c77*/,  7 /*1c78*/,  8 /*1c79*/,
    8 /*1c7a*/,  9 /*1c7b*/,  8 /*1c7c*/,  9 /*1c7d*/,  9 /*1c7e*/,
    10 /*1c7f*/, 4 /*1c80*/,  5 /*1c81*/,  5 /*1c82*/,  6 /*1c83*/,
    5 /*1c84*/,  6 /*1c85*/,  6 /*1c86*/,  7 /*1c87*/,  5 /*1c88*/,
    6 /*1c89*/,  6 /*1c8a*/,  7 /*1c8b*/,  6 /*1c8c*/,  7 /*1c8d*/,
    7 /*1c8e*/,  8 /*1c8f*/,  5 /*1c90*/,  6 /*1c91*/,  6 /*1c92*/,
    7 /*1c93*/,  6 /*1c94*/,  7 /*1c95*/,  7 /*1c96*/,  8 /*1c97*/,
    6 /*1c98*/,  7 /*1c99*/,  7 /*1c9a*/,  8 /*1c9b*/,  7 /*1c9c*/,
    8 /*1c9d*/,  8 /*1c9e*/,  9 /*1c9f*/,  5 /*1ca0*/,  6 /*1ca1*/,
    6 /*1ca2*/,  7 /*1ca3*/,  6 /*1ca4*/,  7 /*1ca5*/,  7 /*1ca6*/,
    8 /*1ca7*/,  6 /*1ca8*/,  7 /*1ca9*/,  7 /*1caa*/,  8 /*1cab*/,
    7 /*1cac*/,  8 /*1cad*/,  8 /*1cae*/,  9 /*1caf*/,  6 /*1cb0*/,
    7 /*1cb1*/,  7 /*1cb2*/,  8 /*1cb3*/,  7 /*1cb4*/,  8 /*1cb5*/,
    8 /*1cb6*/,  9 /*1cb7*/,  7 /*1cb8*/,  8 /*1cb9*/,  8 /*1cba*/,
    9 /*1cbb*/,  8 /*1cbc*/,  9 /*1cbd*/,  9 /*1cbe*/,  10 /*1cbf*/,
    5 /*1cc0*/,  6 /*1cc1*/,  6 /*1cc2*/,  7 /*1cc3*/,  6 /*1cc4*/,
    7 /*1cc5*/,  7 /*1cc6*/,  8 /*1cc7*/,  6 /*1cc8*/,  7 /*1cc9*/,
    7 /*1cca*/,  8 /*1ccb*/,  7 /*1ccc*/,  8 /*1ccd*/,  8 /*1cce*/,
    9 /*1ccf*/,  6 /*1cd0*/,  7 /*1cd1*/,  7 /*1cd2*/,  8 /*1cd3*/,
    7 /*1cd4*/,  8 /*1cd5*/,  8 /*1cd6*/,  9 /*1cd7*/,  7 /*1cd8*/,
    8 /*1cd9*/,  8 /*1cda*/,  9 /*1cdb*/,  8 /*1cdc*/,  9 /*1cdd*/,
    9 /*1cde*/,  10 /*1cdf*/, 6 /*1ce0*/,  7 /*1ce1*/,  7 /*1ce2*/,
    8 /*1ce3*/,  7 /*1ce4*/,  8 /*1ce5*/,  8 /*1ce6*/,  9 /*1ce7*/,
    7 /*1ce8*/,  8 /*1ce9*/,  8 /*1cea*/,  9 /*1ceb*/,  8 /*1cec*/,
    9 /*1ced*/,  9 /*1cee*/,  10 /*1cef*/, 7 /*1cf0*/,  8 /*1cf1*/,
    8 /*1cf2*/,  9 /*1cf3*/,  8 /*1cf4*/,  9 /*1cf5*/,  9 /*1cf6*/,
    10 /*1cf7*/, 8 /*1cf8*/,  9 /*1cf9*/,  9 /*1cfa*/,  10 /*1cfb*/,
    9 /*1cfc*/,  10 /*1cfd*/, 10 /*1cfe*/, 11 /*1cff*/, 4 /*1d00*/,
    5 /*1d01*/,  5 /*1d02*/,  6 /*1d03*/,  5 /*1d04*/,  6 /*1d05*/,
    6 /*1d06*/,  7 /*1d07*/,  5 /*1d08*/,  6 /*1d09*/,  6 /*1d0a*/,
    7 /*1d0b*/,  6 /*1d0c*/,  7 /*1d0d*/,  7 /*1d0e*/,  8 /*1d0f*/,
    5 /*1d10*/,  6 /*1d11*/,  6 /*1d12*/,  7 /*1d13*/,  6 /*1d14*/,
    7 /*1d15*/,  7 /*1d16*/,  8 /*1d17*/,  6 /*1d18*/,  7 /*1d19*/,
    7 /*1d1a*/,  8 /*1d1b*/,  7 /*1d1c*/,  8 /*1d1d*/,  8 /*1d1e*/,
    9 /*1d1f*/,  5 /*1d20*/,  6 /*1d21*/,  6 /*1d22*/,  7 /*1d23*/,
    6 /*1d24*/,  7 /*1d25*/,  7 /*1d26*/,  8 /*1d27*/,  6 /*1d28*/,
    7 /*1d29*/,  7 /*1d2a*/,  8 /*1d2b*/,  7 /*1d2c*/,  8 /*1d2d*/,
    8 /*1d2e*/,  9 /*1d2f*/,  6 /*1d30*/,  7 /*1d31*/,  7 /*1d32*/,
    8 /*1d33*/,  7 /*1d34*/,  8 /*1d35*/,  8 /*1d36*/,  9 /*1d37*/,
    7 /*1d38*/,  8 /*1d39*/,  8 /*1d3a*/,  9 /*1d3b*/,  8 /*1d3c*/,
    9 /*1d3d*/,  9 /*1d3e*/,  10 /*1d3f*/, 5 /*1d40*/,  6 /*1d41*/,
    6 /*1d42*/,  7 /*1d43*/,  6 /*1d44*/,  7 /*1d45*/,  7 /*1d46*/,
    8 /*1d47*/,  6 /*1d48*/,  7 /*1d49*/,  7 /*1d4a*/,  8 /*1d4b*/,
    7 /*1d4c*/,  8 /*1d4d*/,  8 /*1d4e*/,  9 /*1d4f*/,  6 /*1d50*/,
    7 /*1d51*/,  7 /*1d52*/,  8 /*1d53*/,  7 /*1d54*/,  8 /*1d55*/,
    8 /*1d56*/,  9 /*1d57*/,  7 /*1d58*/,  8 /*1d59*/,  8 /*1d5a*/,
    9 /*1d5b*/,  8 /*1d5c*/,  9 /*1d5d*/,  9 /*1d5e*/,  10 /*1d5f*/,
    6 /*1d60*/,  7 /*1d61*/,  7 /*1d62*/,  8 /*1d63*/,  7 /*1d64*/,
    8 /*1d65*/,  8 /*1d66*/,  9 /*1d67*/,  7 /*1d68*/,  8 /*1d69*/,
    8 /*1d6a*/,  9 /*1d6b*/,  8 /*1d6c*/,  9 /*1d6d*/,  9 /*1d6e*/,
    10 /*1d6f*/, 7 /*1d70*/,  8 /*1d71*/,  8 /*1d72*/,  9 /*1d73*/,
    8 /*1d74*/,  9 /*1d75*/,  9 /*1d76*/,  10 /*1d77*/, 8 /*1d78*/,
    9 /*1d79*/,  9 /*1d7a*/,  10 /*1d7b*/, 9 /*1d7c*/,  10 /*1d7d*/,
    10 /*1d7e*/, 11 /*1d7f*/, 5 /*1d80*/,  6 /*1d81*/,  6 /*1d82*/,
    7 /*1d83*/,  6 /*1d84*/,  7 /*1d85*/,  7 /*1d86*/,  8 /*1d87*/,
    6 /*1d88*/,  7 /*1d89*/,  7 /*1d8a*/,  8 /*1d8b*/,  7 /*1d8c*/,
    8 /*1d8d*/,  8 /*1d8e*/,  9 /*1d8f*/,  6 /*1d90*/,  7 /*1d91*/,
    7 /*1d92*/,  8 /*1d93*/,  7 /*1d94*/,  8 /*1d95*/,  8 /*1d96*/,
    9 /*1d97*/,  7 /*1d98*/,  8 /*1d99*/,  8 /*1d9a*/,  9 /*1d9b*/,
    8 /*1d9c*/,  9 /*1d9d*/,  9 /*1d9e*/,  10 /*1d9f*/, 6 /*1da0*/,
    7 /*1da1*/,  7 /*1da2*/,  8 /*1da3*/,  7 /*1da4*/,  8 /*1da5*/,
    8 /*1da6*/,  9 /*1da7*/,  7 /*1da8*/,  8 /*1da9*/,  8 /*1daa*/,
    9 /*1dab*/,  8 /*1dac*/,  9 /*1dad*/,  9 /*1dae*/,  10 /*1daf*/,
    7 /*1db0*/,  8 /*1db1*/,  8 /*1db2*/,  9 /*1db3*/,  8 /*1db4*/,
    9 /*1db5*/,  9 /*1db6*/,  10 /*1db7*/, 8 /*1db8*/,  9 /*1db9*/,
    9 /*1dba*/,  10 /*1dbb*/, 9 /*1dbc*/,  10 /*1dbd*/, 10 /*1dbe*/,
    11 /*1dbf*/, 6 /*1dc0*/,  7 /*1dc1*/,  7 /*1dc2*/,  8 /*1dc3*/,
    7 /*1dc4*/,  8 /*1dc5*/,  8 /*1dc6*/,  9 /*1dc7*/,  7 /*1dc8*/,
    8 /*1dc9*/,  8 /*1dca*/,  9 /*1dcb*/,  8 /*1dcc*/,  9 /*1dcd*/,
    9 /*1dce*/,  10 /*1dcf*/, 7 /*1dd0*/,  8 /*1dd1*/,  8 /*1dd2*/,
    9 /*1dd3*/,  8 /*1dd4*/,  9 /*1dd5*/,  9 /*1dd6*/,  10 /*1dd7*/,
    8 /*1dd8*/,  9 /*1dd9*/,  9 /*1dda*/,  10 /*1ddb*/, 9 /*1ddc*/,
    10 /*1ddd*/, 10 /*1dde*/, 11 /*1ddf*/, 7 /*1de0*/,  8 /*1de1*/,
    8 /*1de2*/,  9 /*1de3*/,  8 /*1de4*/,  9 /*1de5*/,  9 /*1de6*/,
    10 /*1de7*/, 8 /*1de8*/,  9 /*1de9*/,  9 /*1dea*/,  10 /*1deb*/,
    9 /*1dec*/,  10 /*1ded*/, 10 /*1dee*/, 11 /*1def*/, 8 /*1df0*/,
    9 /*1df1*/,  9 /*1df2*/,  10 /*1df3*/, 9 /*1df4*/,  10 /*1df5*/,
    10 /*1df6*/, 11 /*1df7*/, 9 /*1df8*/,  10 /*1df9*/, 10 /*1dfa*/,
    11 /*1dfb*/, 10 /*1dfc*/, 11 /*1dfd*/, 11 /*1dfe*/, 12 /*1dff*/,
    4 /*1e00*/,  5 /*1e01*/,  5 /*1e02*/,  6 /*1e03*/,  5 /*1e04*/,
    6 /*1e05*/,  6 /*1e06*/,  7 /*1e07*/,  5 /*1e08*/,  6 /*1e09*/,
    6 /*1e0a*/,  7 /*1e0b*/,  6 /*1e0c*/,  7 /*1e0d*/,  7 /*1e0e*/,
    8 /*1e0f*/,  5 /*1e10*/,  6 /*1e11*/,  6 /*1e12*/,  7 /*1e13*/,
    6 /*1e14*/,  7 /*1e15*/,  7 /*1e16*/,  8 /*1e17*/,  6 /*1e18*/,
    7 /*1e19*/,  7 /*1e1a*/,  8 /*1e1b*/,  7 /*1e1c*/,  8 /*1e1d*/,
    8 /*1e1e*/,  9 /*1e1f*/,  5 /*1e20*/,  6 /*1e21*/,  6 /*1e22*/,
    7 /*1e23*/,  6 /*1e24*/,  7 /*1e25*/,  7 /*1e26*/,  8 /*1e27*/,
    6 /*1e28*/,  7 /*1e29*/,  7 /*1e2a*/,  8 /*1e2b*/,  7 /*1e2c*/,
    8 /*1e2d*/,  8 /*1e2e*/,  9 /*1e2f*/,  6 /*1e30*/,  7 /*1e31*/,
    7 /*1e32*/,  8 /*1e33*/,  7 /*1e34*/,  8 /*1e35*/,  8 /*1e36*/,
    9 /*1e37*/,  7 /*1e38*/,  8 /*1e39*/,  8 /*1e3a*/,  9 /*1e3b*/,
    8 /*1e3c*/,  9 /*1e3d*/,  9 /*1e3e*/,  10 /*1e3f*/, 5 /*1e40*/,
    6 /*1e41*/,  6 /*1e42*/,  7 /*1e43*/,  6 /*1e44*/,  7 /*1e45*/,
    7 /*1e46*/,  8 /*1e47*/,  6 /*1e48*/,  7 /*1e49*/,  7 /*1e4a*/,
    8 /*1e4b*/,  7 /*1e4c*/,  8 /*1e4d*/,  8 /*1e4e*/,  9 /*1e4f*/,
    6 /*1e50*/,  7 /*1e51*/,  7 /*1e52*/,  8 /*1e53*/,  7 /*1e54*/,
    8 /*1e55*/,  8 /*1e56*/,  9 /*1e57*/,  7 /*1e58*/,  8 /*1e59*/,
    8 /*1e5a*/,  9 /*1e5b*/,  8 /*1e5c*/,  9 /*1e5d*/,  9 /*1e5e*/,
    10 /*1e5f*/, 6 /*1e60*/,  7 /*1e61*/,  7 /*1e62*/,  8 /*1e63*/,
    7 /*1e64*/,  8 /*1e65*/,  8 /*1e66*/,  9 /*1e67*/,  7 /*1e68*/,
    8 /*1e69*/,  8 /*1e6a*/,  9 /*1e6b*/,  8 /*1e6c*/,  9 /*1e6d*/,
    9 /*1e6e*/,  10 /*1e6f*/, 7 /*1e70*/,  8 /*1e71*/,  8 /*1e72*/,
    9 /*1e73*/,  8 /*1e74*/,  9 /*1e75*/,  9 /*1e76*/,  10 /*1e77*/,
    8 /*1e78*/,  9 /*1e79*/,  9 /*1e7a*/,  10 /*1e7b*/, 9 /*1e7c*/,
    10 /*1e7d*/, 10 /*1e7e*/, 11 /*1e7f*/, 5 /*1e80*/,  6 /*1e81*/,
    6 /*1e82*/,  7 /*1e83*/,  6 /*1e84*/,  7 /*1e85*/,  7 /*1e86*/,
    8 /*1e87*/,  6 /*1e88*/,  7 /*1e89*/,  7 /*1e8a*/,  8 /*1e8b*/,
    7 /*1e8c*/,  8 /*1e8d*/,  8 /*1e8e*/,  9 /*1e8f*/,  6 /*1e90*/,
    7 /*1e91*/,  7 /*1e92*/,  8 /*1e93*/,  7 /*1e94*/,  8 /*1e95*/,
    8 /*1e96*/,  9 /*1e97*/,  7 /*1e98*/,  8 /*1e99*/,  8 /*1e9a*/,
    9 /*1e9b*/,  8 /*1e9c*/,  9 /*1e9d*/,  9 /*1e9e*/,  10 /*1e9f*/,
    6 /*1ea0*/,  7 /*1ea1*/,  7 /*1ea2*/,  8 /*1ea3*/,  7 /*1ea4*/,
    8 /*1ea5*/,  8 /*1ea6*/,  9 /*1ea7*/,  7 /*1ea8*/,  8 /*1ea9*/,
    8 /*1eaa*/,  9 /*1eab*/,  8 /*1eac*/,  9 /*1ead*/,  9 /*1eae*/,
    10 /*1eaf*/, 7 /*1eb0*/,  8 /*1eb1*/,  8 /*1eb2*/,  9 /*1eb3*/,
    8 /*1eb4*/,  9 /*1eb5*/,  9 /*1eb6*/,  10 /*1eb7*/, 8 /*1eb8*/,
    9 /*1eb9*/,  9 /*1eba*/,  10 /*1ebb*/, 9 /*1ebc*/,  10 /*1ebd*/,
    10 /*1ebe*/, 11 /*1ebf*/, 6 /*1ec0*/,  7 /*1ec1*/,  7 /*1ec2*/,
    8 /*1ec3*/,  7 /*1ec4*/,  8 /*1ec5*/,  8 /*1ec6*/,  9 /*1ec7*/,
    7 /*1ec8*/,  8 /*1ec9*/,  8 /*1eca*/,  9 /*1ecb*/,  8 /*1ecc*/,
    9 /*1ecd*/,  9 /*1ece*/,  10 /*1ecf*/, 7 /*1ed0*/,  8 /*1ed1*/,
    8 /*1ed2*/,  9 /*1ed3*/,  8 /*1ed4*/,  9 /*1ed5*/,  9 /*1ed6*/,
    10 /*1ed7*/, 8 /*1ed8*/,  9 /*1ed9*/,  9 /*1eda*/,  10 /*1edb*/,
    9 /*1edc*/,  10 /*1edd*/, 10 /*1ede*/, 11 /*1edf*/, 7 /*1ee0*/,
    8 /*1ee1*/,  8 /*1ee2*/,  9 /*1ee3*/,  8 /*1ee4*/,  9 /*1ee5*/,
    9 /*1ee6*/,  10 /*1ee7*/, 8 /*1ee8*/,  9 /*1ee9*/,  9 /*1eea*/,
    10 /*1eeb*/, 9 /*1eec*/,  10 /*1eed*/, 10 /*1eee*/, 11 /*1eef*/,
    8 /*1ef0*/,  9 /*1ef1*/,  9 /*1ef2*/,  10 /*1ef3*/, 9 /*1ef4*/,
    10 /*1ef5*/, 10 /*1ef6*/, 11 /*1ef7*/, 9 /*1ef8*/,  10 /*1ef9*/,
    10 /*1efa*/, 11 /*1efb*/, 10 /*1efc*/, 11 /*1efd*/, 11 /*1efe*/,
    12 /*1eff*/, 5 /*1f00*/,  6 /*1f01*/,  6 /*1f02*/,  7 /*1f03*/,
    6 /*1f04*/,  7 /*1f05*/,  7 /*1f06*/,  8 /*1f07*/,  6 /*1f08*/,
    7 /*1f09*/,  7 /*1f0a*/,  8 /*1f0b*/,  7 /*1f0c*/,  8 /*1f0d*/,
    8 /*1f0e*/,  9 /*1f0f*/,  6 /*1f10*/,  7 /*1f11*/,  7 /*1f12*/,
    8 /*1f13*/,  7 /*1f14*/,  8 /*1f15*/,  8 /*1f16*/,  9 /*1f17*/,
    7 /*1f18*/,  8 /*1f19*/,  8 /*1f1a*/,  9 /*1f1b*/,  8 /*1f1c*/,
    9 /*1f1d*/,  9 /*1f1e*/,  10 /*1f1f*/, 6 /*1f20*/,  7 /*1f21*/,
    7 /*1f22*/,  8 /*1f23*/,  7 /*1f24*/,  8 /*1f25*/,  8 /*1f26*/,
    9 /*1f27*/,  7 /*1f28*/,  8 /*1f29*/,  8 /*1f2a*/,  9 /*1f2b*/,
    8 /*1f2c*/,  9 /*1f2d*/,  9 /*1f2e*/,  10 /*1f2f*/, 7 /*1f30*/,
    8 /*1f31*/,  8 /*1f32*/,  9 /*1f33*/,  8 /*1f34*/,  9 /*1f35*/,
    9 /*1f36*/,  10 /*1f37*/, 8 /*1f38*/,  9 /*1f39*/,  9 /*1f3a*/,
    10 /*1f3b*/, 9 /*1f3c*/,  10 /*1f3d*/, 10 /*1f3e*/, 11 /*1f3f*/,
    6 /*1f40*/,  7 /*1f41*/,  7 /*1f42*/,  8 /*1f43*/,  7 /*1f44*/,
    8 /*1f45*/,  8 /*1f46*/,  9 /*1f47*/,  7 /*1f48*/,  8 /*1f49*/,
    8 /*1f4a*/,  9 /*1f4b*/,  8 /*1f4c*/,  9 /*1f4d*/,  9 /*1f4e*/,
    10 /*1f4f*/, 7 /*1f50*/,  8 /*1f51*/,  8 /*1f52*/,  9 /*1f53*/,
    8 /*1f54*/,  9 /*1f55*/,  9 /*1f56*/,  10 /*1f57*/, 8 /*1f58*/,
    9 /*1f59*/,  9 /*1f5a*/,  10 /*1f5b*/, 9 /*1f5c*/,  10 /*1f5d*/,
    10 /*1f5e*/, 11 /*1f5f*/, 7 /*1f60*/,  8 /*1f61*/,  8 /*1f62*/,
    9 /*1f63*/,  8 /*1f64*/,  9 /*1f65*/,  9 /*1f66*/,  10 /*1f67*/,
    8 /*1f68*/,  9 /*1f69*/,  9 /*1f6a*/,  10 /*1f6b*/, 9 /*1f6c*/,
    10 /*1f6d*/, 10 /*1f6e*/, 11 /*1f6f*/, 8 /*1f70*/,  9 /*1f71*/,
    9 /*1f72*/,  10 /*1f73*/, 9 /*1f74*/,  10 /*1f75*/, 10 /*1f76*/,
    11 /*1f77*/, 9 /*1f78*/,  10 /*1f79*/, 10 /*1f7a*/, 11 /*1f7b*/,
    10 /*1f7c*/, 11 /*1f7d*/, 11 /*1f7e*/, 12 /*1f7f*/, 6 /*1f80*/,
    7 /*1f81*/,  7 /*1f82*/,  8 /*1f83*/,  7 /*1f84*/,  8 /*1f85*/,
    8 /*1f86*/,  9 /*1f87*/,  7 /*1f88*/,  8 /*1f89*/,  8 /*1f8a*/,
    9 /*1f8b*/,  8 /*1f8c*/,  9 /*1f8d*/,  9 /*1f8e*/,  10 /*1f8f*/,
    7 /*1f90*/,  8 /*1f91*/,  8 /*1f92*/,  9 /*1f93*/,  8 /*1f94*/,
    9 /*1f95*/,  9 /*1f96*/,  10 /*1f97*/, 8 /*1f98*/,  9 /*1f99*/,
    9 /*1f9a*/,  10 /*1f9b*/, 9 /*1f9c*/,  10 /*1f9d*/, 10 /*1f9e*/,
    11 /*1f9f*/, 7 /*1fa0*/,  8 /*1fa1*/,  8 /*1fa2*/,  9 /*1fa3*/,
    8 /*1fa4*/,  9 /*1fa5*/,  9 /*1fa6*/,  10 /*1fa7*/, 8 /*1fa8*/,
    9 /*1fa9*/,  9 /*1faa*/,  10 /*1fab*/, 9 /*1fac*/,  10 /*1fad*/,
    10 /*1fae*/, 11 /*1faf*/, 8 /*1fb0*/,  9 /*1fb1*/,  9 /*1fb2*/,
    10 /*1fb3*/, 9 /*1fb4*/,  10 /*1fb5*/, 10 /*1fb6*/, 11 /*1fb7*/,
    9 /*1fb8*/,  10 /*1fb9*/, 10 /*1fba*/, 11 /*1fbb*/, 10 /*1fbc*/,
    11 /*1fbd*/, 11 /*1fbe*/, 12 /*1fbf*/, 7 /*1fc0*/,  8 /*1fc1*/,
    8 /*1fc2*/,  9 /*1fc3*/,  8 /*1fc4*/,  9 /*1fc5*/,  9 /*1fc6*/,
    10 /*1fc7*/, 8 /*1fc8*/,  9 /*1fc9*/,  9 /*1fca*/,  10 /*1fcb*/,
    9 /*1fcc*/,  10 /*1fcd*/, 10 /*1fce*/, 11 /*1fcf*/, 8 /*1fd0*/,
    9 /*1fd1*/,  9 /*1fd2*/,  10 /*1fd3*/, 9 /*1fd4*/,  10 /*1fd5*/,
    10 /*1fd6*/, 11 /*1fd7*/, 9 /*1fd8*/,  10 /*1fd9*/, 10 /*1fda*/,
    11 /*1fdb*/, 10 /*1fdc*/, 11 /*1fdd*/, 11 /*1fde*/, 12 /*1fdf*/,
    8 /*1fe0*/,  9 /*1fe1*/,  9 /*1fe2*/,  10 /*1fe3*/, 9 /*1fe4*/,
    10 /*1fe5*/, 10 /*1fe6*/, 11 /*1fe7*/, 9 /*1fe8*/,  10 /*1fe9*/,
    10 /*1fea*/, 11 /*1feb*/, 10 /*1fec*/, 11 /*1fed*/, 11 /*1fee*/,
    12 /*1fef*/, 9 /*1ff0*/,  10 /*1ff1*/, 10 /*1ff2*/, 11 /*1ff3*/,
    10 /*1ff4*/, 11 /*1ff5*/, 11 /*1ff6*/, 12 /*1ff7*/, 10 /*1ff8*/,
    11 /*1ff9*/, 11 /*1ffa*/, 12 /*1ffb*/, 11 /*1ffc*/, 12 /*1ffd*/,
    12 /*1ffe*/, 13 /*1fff*/, 1 /*2000*/,  2 /*2001*/,  2 /*2002*/,
    3 /*2003*/,  2 /*2004*/,  3 /*2005*/,  3 /*2006*/,  4 /*2007*/,
    2 /*2008*/,  3 /*2009*/,  3 /*200a*/,  4 /*200b*/,  3 /*200c*/,
    4 /*200d*/,  4 /*200e*/,  5 /*200f*/,  2 /*2010*/,  3 /*2011*/,
    3 /*2012*/,  4 /*2013*/,  3 /*2014*/,  4 /*2015*/,  4 /*2016*/,
    5 /*2017*/,  3 /*2018*/,  4 /*2019*/,  4 /*201a*/,  5 /*201b*/,
    4 /*201c*/,  5 /*201d*/,  5 /*201e*/,  6 /*201f*/,  2 /*2020*/,
    3 /*2021*/,  3 /*2022*/,  4 /*2023*/,  3 /*2024*/,  4 /*2025*/,
    4 /*2026*/,  5 /*2027*/,  3 /*2028*/,  4 /*2029*/,  4 /*202a*/,
    5 /*202b*/,  4 /*202c*/,  5 /*202d*/,  5 /*202e*/,  6 /*202f*/,
    3 /*2030*/,  4 /*2031*/,  4 /*2032*/,  5 /*2033*/,  4 /*2034*/,
    5 /*2035*/,  5 /*2036*/,  6 /*2037*/,  4 /*2038*/,  5 /*2039*/,
    5 /*203a*/,  6 /*203b*/,  5 /*203c*/,  6 /*203d*/,  6 /*203e*/,
    7 /*203f*/,  2 /*2040*/,  3 /*2041*/,  3 /*2042*/,  4 /*2043*/,
    3 /*2044*/,  4 /*2045*/,  4 /*2046*/,  5 /*2047*/,  3 /*2048*/,
    4 /*2049*/,  4 /*204a*/,  5 /*204b*/,  4 /*204c*/,  5 /*204d*/,
    5 /*204e*/,  6 /*204f*/,  3 /*2050*/,  4 /*2051*/,  4 /*2052*/,
    5 /*2053*/,  4 /*2054*/,  5 /*2055*/,  5 /*2056*/,  6 /*2057*/,
    4 /*2058*/,  5 /*2059*/,  5 /*205a*/,  6 /*205b*/,  5 /*205c*/,
    6 /*205d*/,  6 /*205e*/,  7 /*205f*/,  3 /*2060*/,  4 /*2061*/,
    4 /*2062*/,  5 /*2063*/,  4 /*2064*/,  5 /*2065*/,  5 /*2066*/,
    6 /*2067*/,  4 /*2068*/,  5 /*2069*/,  5 /*206a*/,  6 /*206b*/,
    5 /*206c*/,  6 /*206d*/,  6 /*206e*/,  7 /*206f*/,  4 /*2070*/,
    5 /*2071*/,  5 /*2072*/,  6 /*2073*/,  5 /*2074*/,  6 /*2075*/,
    6 /*2076*/,  7 /*2077*/,  5 /*2078*/,  6 /*2079*/,  6 /*207a*/,
    7 /*207b*/,  6 /*207c*/,  7 /*207d*/,  7 /*207e*/,  8 /*207f*/,
    2 /*2080*/,  3 /*2081*/,  3 /*2082*/,  4 /*2083*/,  3 /*2084*/,
    4 /*2085*/,  4 /*2086*/,  5 /*2087*/,  3 /*2088*/,  4 /*2089*/,
    4 /*208a*/,  5 /*208b*/,  4 /*208c*/,  5 /*208d*/,  5 /*208e*/,
    6 /*208f*/,  3 /*2090*/,  4 /*2091*/,  4 /*2092*/,  5 /*2093*/,
    4 /*2094*/,  5 /*2095*/,  5 /*2096*/,  6 /*2097*/,  4 /*2098*/,
    5 /*2099*/,  5 /*209a*/,  6 /*209b*/,  5 /*209c*/,  6 /*209d*/,
    6 /*209e*/,  7 /*209f*/,  3 /*20a0*/,  4 /*20a1*/,  4 /*20a2*/,
    5 /*20a3*/,  4 /*20a4*/,  5 /*20a5*/,  5 /*20a6*/,  6 /*20a7*/,
    4 /*20a8*/,  5 /*20a9*/,  5 /*20aa*/,  6 /*20ab*/,  5 /*20ac*/,
    6 /*20ad*/,  6 /*20ae*/,  7 /*20af*/,  4 /*20b0*/,  5 /*20b1*/,
    5 /*20b2*/,  6 /*20b3*/,  5 /*20b4*/,  6 /*20b5*/,  6 /*20b6*/,
    7 /*20b7*/,  5 /*20b8*/,  6 /*20b9*/,  6 /*20ba*/,  7 /*20bb*/,
    6 /*20bc*/,  7 /*20bd*/,  7 /*20be*/,  8 /*20bf*/,  3 /*20c0*/,
    4 /*20c1*/,  4 /*20c2*/,  5 /*20c3*/,  4 /*20c4*/,  5 /*20c5*/,
    5 /*20c6*/,  6 /*20c7*/,  4 /*20c8*/,  5 /*20c9*/,  5 /*20ca*/,
    6 /*20cb*/,  5 /*20cc*/,  6 /*20cd*/,  6 /*20ce*/,  7 /*20cf*/,
    4 /*20d0*/,  5 /*20d1*/,  5 /*20d2*/,  6 /*20d3*/,  5 /*20d4*/,
    6 /*20d5*/,  6 /*20d6*/,  7 /*20d7*/,  5 /*20d8*/,  6 /*20d9*/,
    6 /*20da*/,  7 /*20db*/,  6 /*20dc*/,  7 /*20dd*/,  7 /*20de*/,
    8 /*20df*/,  4 /*20e0*/,  5 /*20e1*/,  5 /*20e2*/,  6 /*20e3*/,
    5 /*20e4*/,  6 /*20e5*/,  6 /*20e6*/,  7 /*20e7*/,  5 /*20e8*/,
    6 /*20e9*/,  6 /*20ea*/,  7 /*20eb*/,  6 /*20ec*/,  7 /*20ed*/,
    7 /*20ee*/,  8 /*20ef*/,  5 /*20f0*/,  6 /*20f1*/,  6 /*20f2*/,
    7 /*20f3*/,  6 /*20f4*/,  7 /*20f5*/,  7 /*20f6*/,  8 /*20f7*/,
    6 /*20f8*/,  7 /*20f9*/,  7 /*20fa*/,  8 /*20fb*/,  7 /*20fc*/,
    8 /*20fd*/,  8 /*20fe*/,  9 /*20ff*/,  2 /*2100*/,  3 /*2101*/,
    3 /*2102*/,  4 /*2103*/,  3 /*2104*/,  4 /*2105*/,  4 /*2106*/,
    5 /*2107*/,  3 /*2108*/,  4 /*2109*/,  4 /*210a*/,  5 /*210b*/,
    4 /*210c*/,  5 /*210d*/,  5 /*210e*/,  6 /*210f*/,  3 /*2110*/,
    4 /*2111*/,  4 /*2112*/,  5 /*2113*/,  4 /*2114*/,  5 /*2115*/,
    5 /*2116*/,  6 /*2117*/,  4 /*2118*/,  5 /*2119*/,  5 /*211a*/,
    6 /*211b*/,  5 /*211c*/,  6 /*211d*/,  6 /*211e*/,  7 /*211f*/,
    3 /*2120*/,  4 /*2121*/,  4 /*2122*/,  5 /*2123*/,  4 /*2124*/,
    5 /*2125*/,  5 /*2126*/,  6 /*2127*/,  4 /*2128*/,  5 /*2129*/,
    5 /*212a*/,  6 /*212b*/,  5 /*212c*/,  6 /*212d*/,  6 /*212e*/,
    7 /*212f*/,  4 /*2130*/,  5 /*2131*/,  5 /*2132*/,  6 /*2133*/,
    5 /*2134*/,  6 /*2135*/,  6 /*2136*/,  7 /*2137*/,  5 /*2138*/,
    6 /*2139*/,  6 /*213a*/,  7 /*213b*/,  6 /*213c*/,  7 /*213d*/,
    7 /*213e*/,  8 /*213f*/,  3 /*2140*/,  4 /*2141*/,  4 /*2142*/,
    5 /*2143*/,  4 /*2144*/,  5 /*2145*/,  5 /*2146*/,  6 /*2147*/,
    4 /*2148*/,  5 /*2149*/,  5 /*214a*/,  6 /*214b*/,  5 /*214c*/,
    6 /*214d*/,  6 /*214e*/,  7 /*214f*/,  4 /*2150*/,  5 /*2151*/,
    5 /*2152*/,  6 /*2153*/,  5 /*2154*/,  6 /*2155*/,  6 /*2156*/,
    7 /*2157*/,  5 /*2158*/,  6 /*2159*/,  6 /*215a*/,  7 /*215b*/,
    6 /*215c*/,  7 /*215d*/,  7 /*215e*/,  8 /*215f*/,  4 /*2160*/,
    5 /*2161*/,  5 /*2162*/,  6 /*2163*/,  5 /*2164*/,  6 /*2165*/,
    6 /*2166*/,  7 /*2167*/,  5 /*2168*/,  6 /*2169*/,  6 /*216a*/,
    7 /*216b*/,  6 /*216c*/,  7 /*216d*/,  7 /*216e*/,  8 /*216f*/,
    5 /*2170*/,  6 /*2171*/,  6 /*2172*/,  7 /*2173*/,  6 /*2174*/,
    7 /*2175*/,  7 /*2176*/,  8 /*2177*/,  6 /*2178*/,  7 /*2179*/,
    7 /*217a*/,  8 /*217b*/,  7 /*217c*/,  8 /*217d*/,  8 /*217e*/,
    9 /*217f*/,  3 /*2180*/,  4 /*2181*/,  4 /*2182*/,  5 /*2183*/,
    4 /*2184*/,  5 /*2185*/,  5 /*2186*/,  6 /*2187*/,  4 /*2188*/,
    5 /*2189*/,  5 /*218a*/,  6 /*218b*/,  5 /*218c*/,  6 /*218d*/,
    6 /*218e*/,  7 /*218f*/,  4 /*2190*/,  5 /*2191*/,  5 /*2192*/,
    6 /*2193*/,  5 /*2194*/,  6 /*2195*/,  6 /*2196*/,  7 /*2197*/,
    5 /*2198*/,  6 /*2199*/,  6 /*219a*/,  7 /*219b*/,  6 /*219c*/,
    7 /*219d*/,  7 /*219e*/,  8 /*219f*/,  4 /*21a0*/,  5 /*21a1*/,
    5 /*21a2*/,  6 /*21a3*/,  5 /*21a4*/,  6 /*21a5*/,  6 /*21a6*/,
    7 /*21a7*/,  5 /*21a8*/,  6 /*21a9*/,  6 /*21aa*/,  7 /*21ab*/,
    6 /*21ac*/,  7 /*21ad*/,  7 /*21ae*/,  8 /*21af*/,  5 /*21b0*/,
    6 /*21b1*/,  6 /*21b2*/,  7 /*21b3*/,  6 /*21b4*/,  7 /*21b5*/,
    7 /*21b6*/,  8 /*21b7*/,  6 /*21b8*/,  7 /*21b9*/,  7 /*21ba*/,
    8 /*21bb*/,  7 /*21bc*/,  8 /*21bd*/,  8 /*21be*/,  9 /*21bf*/,
    4 /*21c0*/,  5 /*21c1*/,  5 /*21c2*/,  6 /*21c3*/,  5 /*21c4*/,
    6 /*21c5*/,  6 /*21c6*/,  7 /*21c7*/,  5 /*21c8*/,  6 /*21c9*/,
    6 /*21ca*/,  7 /*21cb*/,  6 /*21cc*/,  7 /*21cd*/,  7 /*21ce*/,
    8 /*21cf*/,  5 /*21d0*/,  6 /*21d1*/,  6 /*21d2*/,  7 /*21d3*/,
    6 /*21d4*/,  7 /*21d5*/,  7 /*21d6*/,  8 /*21d7*/,  6 /*21d8*/,
    7 /*21d9*/,  7 /*21da*/,  8 /*21db*/,  7 /*21dc*/,  8 /*21dd*/,
    8 /*21de*/,  9 /*21df*/,  5 /*21e0*/,  6 /*21e1*/,  6 /*21e2*/,
    7 /*21e3*/,  6 /*21e4*/,  7 /*21e5*/,  7 /*21e6*/,  8 /*21e7*/,
    6 /*21e8*/,  7 /*21e9*/,  7 /*21ea*/,  8 /*21eb*/,  7 /*21ec*/,
    8 /*21ed*/,  8 /*21ee*/,  9 /*21ef*/,  6 /*21f0*/,  7 /*21f1*/,
    7 /*21f2*/,  8 /*21f3*/,  7 /*21f4*/,  8 /*21f5*/,  8 /*21f6*/,
    9 /*21f7*/,  7 /*21f8*/,  8 /*21f9*/,  8 /*21fa*/,  9 /*21fb*/,
    8 /*21fc*/,  9 /*21fd*/,  9 /*21fe*/,  10 /*21ff*/, 2 /*2200*/,
    3 /*2201*/,  3 /*2202*/,  4 /*2203*/,  3 /*2204*/,  4 /*2205*/,
    4 /*2206*/,  5 /*2207*/,  3 /*2208*/,  4 /*2209*/,  4 /*220a*/,
    5 /*220b*/,  4 /*220c*/,  5 /*220d*/,  5 /*220e*/,  6 /*220f*/,
    3 /*2210*/,  4 /*2211*/,  4 /*2212*/,  5 /*2213*/,  4 /*2214*/,
    5 /*2215*/,  5 /*2216*/,  6 /*2217*/,  4 /*2218*/,  5 /*2219*/,
    5 /*221a*/,  6 /*221b*/,  5 /*221c*/,  6 /*221d*/,  6 /*221e*/,
    7 /*221f*/,  3 /*2220*/,  4 /*2221*/,  4 /*2222*/,  5 /*2223*/,
    4 /*2224*/,  5 /*2225*/,  5 /*2226*/,  6 /*2227*/,  4 /*2228*/,
    5 /*2229*/,  5 /*222a*/,  6 /*222b*/,  5 /*222c*/,  6 /*222d*/,
    6 /*222e*/,  7 /*222f*/,  4 /*2230*/,  5 /*2231*/,  5 /*2232*/,
    6 /*2233*/,  5 /*2234*/,  6 /*2235*/,  6 /*2236*/,  7 /*2237*/,
    5 /*2238*/,  6 /*2239*/,  6 /*223a*/,  7 /*223b*/,  6 /*223c*/,
    7 /*223d*/,  7 /*223e*/,  8 /*223f*/,  3 /*2240*/,  4 /*2241*/,
    4 /*2242*/,  5 /*2243*/,  4 /*2244*/,  5 /*2245*/,  5 /*2246*/,
    6 /*2247*/,  4 /*2248*/,  5 /*2249*/,  5 /*224a*/,  6 /*224b*/,
    5 /*224c*/,  6 /*224d*/,  6 /*224e*/,  7 /*224f*/,  4 /*2250*/,
    5 /*2251*/,  5 /*2252*/,  6 /*2253*/,  5 /*2254*/,  6 /*2255*/,
    6 /*2256*/,  7 /*2257*/,  5 /*2258*/,  6 /*2259*/,  6 /*225a*/,
    7 /*225b*/,  6 /*225c*/,  7 /*225d*/,  7 /*225e*/,  8 /*225f*/,
    4 /*2260*/,  5 /*2261*/,  5 /*2262*/,  6 /*2263*/,  5 /*2264*/,
    6 /*2265*/,  6 /*2266*/,  7 /*2267*/,  5 /*2268*/,  6 /*2269*/,
    6 /*226a*/,  7 /*226b*/,  6 /*226c*/,  7 /*226d*/,  7 /*226e*/,
    8 /*226f*/,  5 /*2270*/,  6 /*2271*/,  6 /*2272*/,  7 /*2273*/,
    6 /*2274*/,  7 /*2275*/,  7 /*2276*/,  8 /*2277*/,  6 /*2278*/,
    7 /*2279*/,  7 /*227a*/,  8 /*227b*/,  7 /*227c*/,  8 /*227d*/,
    8 /*227e*/,  9 /*227f*/,  3 /*2280*/,  4 /*2281*/,  4 /*2282*/,
    5 /*2283*/,  4 /*2284*/,  5 /*2285*/,  5 /*2286*/,  6 /*2287*/,
    4 /*2288*/,  5 /*2289*/,  5 /*228a*/,  6 /*228b*/,  5 /*228c*/,
    6 /*228d*/,  6 /*228e*/,  7 /*228f*/,  4 /*2290*/,  5 /*2291*/,
    5 /*2292*/,  6 /*2293*/,  5 /*2294*/,  6 /*2295*/,  6 /*2296*/,
    7 /*2297*/,  5 /*2298*/,  6 /*2299*/,  6 /*229a*/,  7 /*229b*/,
    6 /*229c*/,  7 /*229d*/,  7 /*229e*/,  8 /*229f*/,  4 /*22a0*/,
    5 /*22a1*/,  5 /*22a2*/,  6 /*22a3*/,  5 /*22a4*/,  6 /*22a5*/,
    6 /*22a6*/,  7 /*22a7*/,  5 /*22a8*/,  6 /*22a9*/,  6 /*22aa*/,
    7 /*22ab*/,  6 /*22ac*/,  7 /*22ad*/,  7 /*22ae*/,  8 /*22af*/,
    5 /*22b0*/,  6 /*22b1*/,  6 /*22b2*/,  7 /*22b3*/,  6 /*22b4*/,
    7 /*22b5*/,  7 /*22b6*/,  8 /*22b7*/,  6 /*22b8*/,  7 /*22b9*/,
    7 /*22ba*/,  8 /*22bb*/,  7 /*22bc*/,  8 /*22bd*/,  8 /*22be*/,
    9 /*22bf*/,  4 /*22c0*/,  5 /*22c1*/,  5 /*22c2*/,  6 /*22c3*/,
    5 /*22c4*/,  6 /*22c5*/,  6 /*22c6*/,  7 /*22c7*/,  5 /*22c8*/,
    6 /*22c9*/,  6 /*22ca*/,  7 /*22cb*/,  6 /*22cc*/,  7 /*22cd*/,
    7 /*22ce*/,  8 /*22cf*/,  5 /*22d0*/,  6 /*22d1*/,  6 /*22d2*/,
    7 /*22d3*/,  6 /*22d4*/,  7 /*22d5*/,  7 /*22d6*/,  8 /*22d7*/,
    6 /*22d8*/,  7 /*22d9*/,  7 /*22da*/,  8 /*22db*/,  7 /*22dc*/,
    8 /*22dd*/,  8 /*22de*/,  9 /*22df*/,  5 /*22e0*/,  6 /*22e1*/,
    6 /*22e2*/,  7 /*22e3*/,  6 /*22e4*/,  7 /*22e5*/,  7 /*22e6*/,
    8 /*22e7*/,  6 /*22e8*/,  7 /*22e9*/,  7 /*22ea*/,  8 /*22eb*/,
    7 /*22ec*/,  8 /*22ed*/,  8 /*22ee*/,  9 /*22ef*/,  6 /*22f0*/,
    7 /*22f1*/,  7 /*22f2*/,  8 /*22f3*/,  7 /*22f4*/,  8 /*22f5*/,
    8 /*22f6*/,  9 /*22f7*/,  7 /*22f8*/,  8 /*22f9*/,  8 /*22fa*/,
    9 /*22fb*/,  8 /*22fc*/,  9 /*22fd*/,  9 /*22fe*/,  10 /*22ff*/,
    3 /*2300*/,  4 /*2301*/,  4 /*2302*/,  5 /*2303*/,  4 /*2304*/,
    5 /*2305*/,  5 /*2306*/,  6 /*2307*/,  4 /*2308*/,  5 /*2309*/,
    5 /*230a*/,  6 /*230b*/,  5 /*230c*/,  6 /*230d*/,  6 /*230e*/,
    7 /*230f*/,  4 /*2310*/,  5 /*2311*/,  5 /*2312*/,  6 /*2313*/,
    5 /*2314*/,  6 /*2315*/,  6 /*2316*/,  7 /*2317*/,  5 /*2318*/,
    6 /*2319*/,  6 /*231a*/,  7 /*231b*/,  6 /*231c*/,  7 /*231d*/,
    7 /*231e*/,  8 /*231f*/,  4 /*2320*/,  5 /*2321*/,  5 /*2322*/,
    6 /*2323*/,  5 /*2324*/,  6 /*2325*/,  6 /*2326*/,  7 /*2327*/,
    5 /*2328*/,  6 /*2329*/,  6 /*232a*/,  7 /*232b*/,  6 /*232c*/,
    7 /*232d*/,  7 /*232e*/,  8 /*232f*/,  5 /*2330*/,  6 /*2331*/,
    6 /*2332*/,  7 /*2333*/,  6 /*2334*/,  7 /*2335*/,  7 /*2336*/,
    8 /*2337*/,  6 /*2338*/,  7 /*2339*/,  7 /*233a*/,  8 /*233b*/,
    7 /*233c*/,  8 /*233d*/,  8 /*233e*/,  9 /*233f*/,  4 /*2340*/,
    5 /*2341*/,  5 /*2342*/,  6 /*2343*/,  5 /*2344*/,  6 /*2345*/,
    6 /*2346*/,  7 /*2347*/,  5 /*2348*/,  6 /*2349*/,  6 /*234a*/,
    7 /*234b*/,  6 /*234c*/,  7 /*234d*/,  7 /*234e*/,  8 /*234f*/,
    5 /*2350*/,  6 /*2351*/,  6 /*2352*/,  7 /*2353*/,  6 /*2354*/,
    7 /*2355*/,  7 /*2356*/,  8 /*2357*/,  6 /*2358*/,  7 /*2359*/,
    7 /*235a*/,  8 /*235b*/,  7 /*235c*/,  8 /*235d*/,  8 /*235e*/,
    9 /*235f*/,  5 /*2360*/,  6 /*2361*/,  6 /*2362*/,  7 /*2363*/,
    6 /*2364*/,  7 /*2365*/,  7 /*2366*/,  8 /*2367*/,  6 /*2368*/,
    7 /*2369*/,  7 /*236a*/,  8 /*236b*/,  7 /*236c*/,  8 /*236d*/,
    8 /*236e*/,  9 /*236f*/,  6 /*2370*/,  7 /*2371*/,  7 /*2372*/,
    8 /*2373*/,  7 /*2374*/,  8 /*2375*/,  8 /*2376*/,  9 /*2377*/,
    7 /*2378*/,  8 /*2379*/,  8 /*237a*/,  9 /*237b*/,  8 /*237c*/,
    9 /*237d*/,  9 /*237e*/,  10 /*237f*/, 4 /*2380*/,  5 /*2381*/,
    5 /*2382*/,  6 /*2383*/,  5 /*2384*/,  6 /*2385*/,  6 /*2386*/,
    7 /*2387*/,  5 /*2388*/,  6 /*2389*/,  6 /*238a*/,  7 /*238b*/,
    6 /*238c*/,  7 /*238d*/,  7 /*238e*/,  8 /*238f*/,  5 /*2390*/,
    6 /*2391*/,  6 /*2392*/,  7 /*2393*/,  6 /*2394*/,  7 /*2395*/,
    7 /*2396*/,  8 /*2397*/,  6 /*2398*/,  7 /*2399*/,  7 /*239a*/,
    8 /*239b*/,  7 /*239c*/,  8 /*239d*/,  8 /*239e*/,  9 /*239f*/,
    5 /*23a0*/,  6 /*23a1*/,  6 /*23a2*/,  7 /*23a3*/,  6 /*23a4*/,
    7 /*23a5*/,  7 /*23a6*/,  8 /*23a7*/,  6 /*23a8*/,  7 /*23a9*/,
    7 /*23aa*/,  8 /*23ab*/,  7 /*23ac*/,  8 /*23ad*/,  8 /*23ae*/,
    9 /*23af*/,  6 /*23b0*/,  7 /*23b1*/,  7 /*23b2*/,  8 /*23b3*/,
    7 /*23b4*/,  8 /*23b5*/,  8 /*23b6*/,  9 /*23b7*/,  7 /*23b8*/,
    8 /*23b9*/,  8 /*23ba*/,  9 /*23bb*/,  8 /*23bc*/,  9 /*23bd*/,
    9 /*23be*/,  10 /*23bf*/, 5 /*23c0*/,  6 /*23c1*/,  6 /*23c2*/,
    7 /*23c3*/,  6 /*23c4*/,  7 /*23c5*/,  7 /*23c6*/,  8 /*23c7*/,
    6 /*23c8*/,  7 /*23c9*/,  7 /*23ca*/,  8 /*23cb*/,  7 /*23cc*/,
    8 /*23cd*/,  8 /*23ce*/,  9 /*23cf*/,  6 /*23d0*/,  7 /*23d1*/,
    7 /*23d2*/,  8 /*23d3*/,  7 /*23d4*/,  8 /*23d5*/,  8 /*23d6*/,
    9 /*23d7*/,  7 /*23d8*/,  8 /*23d9*/,  8 /*23da*/,  9 /*23db*/,
    8 /*23dc*/,  9 /*23dd*/,  9 /*23de*/,  10 /*23df*/, 6 /*23e0*/,
    7 /*23e1*/,  7 /*23e2*/,  8 /*23e3*/,  7 /*23e4*/,  8 /*23e5*/,
    8 /*23e6*/,  9 /*23e7*/,  7 /*23e8*/,  8 /*23e9*/,  8 /*23ea*/,
    9 /*23eb*/,  8 /*23ec*/,  9 /*23ed*/,  9 /*23ee*/,  10 /*23ef*/,
    7 /*23f0*/,  8 /*23f1*/,  8 /*23f2*/,  9 /*23f3*/,  8 /*23f4*/,
    9 /*23f5*/,  9 /*23f6*/,  10 /*23f7*/, 8 /*23f8*/,  9 /*23f9*/,
    9 /*23fa*/,  10 /*23fb*/, 9 /*23fc*/,  10 /*23fd*/, 10 /*23fe*/,
    11 /*23ff*/, 2 /*2400*/,  3 /*2401*/,  3 /*2402*/,  4 /*2403*/,
    3 /*2404*/,  4 /*2405*/,  4 /*2406*/,  5 /*2407*/,  3 /*2408*/,
    4 /*2409*/,  4 /*240a*/,  5 /*240b*/,  4 /*240c*/,  5 /*240d*/,
    5 /*240e*/,  6 /*240f*/,  3 /*2410*/,  4 /*2411*/,  4 /*2412*/,
    5 /*2413*/,  4 /*2414*/,  5 /*2415*/,  5 /*2416*/,  6 /*2417*/,
    4 /*2418*/,  5 /*2419*/,  5 /*241a*/,  6 /*241b*/,  5 /*241c*/,
    6 /*241d*/,  6 /*241e*/,  7 /*241f*/,  3 /*2420*/,  4 /*2421*/,
    4 /*2422*/,  5 /*2423*/,  4 /*2424*/,  5 /*2425*/,  5 /*2426*/,
    6 /*2427*/,  4 /*2428*/,  5 /*2429*/,  5 /*242a*/,  6 /*242b*/,
    5 /*242c*/,  6 /*242d*/,  6 /*242e*/,  7 /*242f*/,  4 /*2430*/,
    5 /*2431*/,  5 /*2432*/,  6 /*2433*/,  5 /*2434*/,  6 /*2435*/,
    6 /*2436*/,  7 /*2437*/,  5 /*2438*/,  6 /*2439*/,  6 /*243a*/,
    7 /*243b*/,  6 /*243c*/,  7 /*243d*/,  7 /*243e*/,  8 /*243f*/,
    3 /*2440*/,  4 /*2441*/,  4 /*2442*/,  5 /*2443*/,  4 /*2444*/,
    5 /*2445*/,  5 /*2446*/,  6 /*2447*/,  4 /*2448*/,  5 /*2449*/,
    5 /*244a*/,  6 /*244b*/,  5 /*244c*/,  6 /*244d*/,  6 /*244e*/,
    7 /*244f*/,  4 /*2450*/,  5 /*2451*/,  5 /*2452*/,  6 /*2453*/,
    5 /*2454*/,  6 /*2455*/,  6 /*2456*/,  7 /*2457*/,  5 /*2458*/,
    6 /*2459*/,  6 /*245a*/,  7 /*245b*/,  6 /*245c*/,  7 /*245d*/,
    7 /*245e*/,  8 /*245f*/,  4 /*2460*/,  5 /*2461*/,  5 /*2462*/,
    6 /*2463*/,  5 /*2464*/,  6 /*2465*/,  6 /*2466*/,  7 /*2467*/,
    5 /*2468*/,  6 /*2469*/,  6 /*246a*/,  7 /*246b*/,  6 /*246c*/,
    7 /*246d*/,  7 /*246e*/,  8 /*246f*/,  5 /*2470*/,  6 /*2471*/,
    6 /*2472*/,  7 /*2473*/,  6 /*2474*/,  7 /*2475*/,  7 /*2476*/,
    8 /*2477*/,  6 /*2478*/,  7 /*2479*/,  7 /*247a*/,  8 /*247b*/,
    7 /*247c*/,  8 /*247d*/,  8 /*247e*/,  9 /*247f*/,  3 /*2480*/,
    4 /*2481*/,  4 /*2482*/,  5 /*2483*/,  4 /*2484*/,  5 /*2485*/,
    5 /*2486*/,  6 /*2487*/,  4 /*2488*/,  5 /*2489*/,  5 /*248a*/,
    6 /*248b*/,  5 /*248c*/,  6 /*248d*/,  6 /*248e*/,  7 /*248f*/,
    4 /*2490*/,  5 /*2491*/,  5 /*2492*/,  6 /*2493*/,  5 /*2494*/,
    6 /*2495*/,  6 /*2496*/,  7 /*2497*/,  5 /*2498*/,  6 /*2499*/,
    6 /*249a*/,  7 /*249b*/,  6 /*249c*/,  7 /*249d*/,  7 /*249e*/,
    8 /*249f*/,  4 /*24a0*/,  5 /*24a1*/,  5 /*24a2*/,  6 /*24a3*/,
    5 /*24a4*/,  6 /*24a5*/,  6 /*24a6*/,  7 /*24a7*/,  5 /*24a8*/,
    6 /*24a9*/,  6 /*24aa*/,  7 /*24ab*/,  6 /*24ac*/,  7 /*24ad*/,
    7 /*24ae*/,  8 /*24af*/,  5 /*24b0*/,  6 /*24b1*/,  6 /*24b2*/,
    7 /*24b3*/,  6 /*24b4*/,  7 /*24b5*/,  7 /*24b6*/,  8 /*24b7*/,
    6 /*24b8*/,  7 /*24b9*/,  7 /*24ba*/,  8 /*24bb*/,  7 /*24bc*/,
    8 /*24bd*/,  8 /*24be*/,  9 /*24bf*/,  4 /*24c0*/,  5 /*24c1*/,
    5 /*24c2*/,  6 /*24c3*/,  5 /*24c4*/,  6 /*24c5*/,  6 /*24c6*/,
    7 /*24c7*/,  5 /*24c8*/,  6 /*24c9*/,  6 /*24ca*/,  7 /*24cb*/,
    6 /*24cc*/,  7 /*24cd*/,  7 /*24ce*/,  8 /*24cf*/,  5 /*24d0*/,
    6 /*24d1*/,  6 /*24d2*/,  7 /*24d3*/,  6 /*24d4*/,  7 /*24d5*/,
    7 /*24d6*/,  8 /*24d7*/,  6 /*24d8*/,  7 /*24d9*/,  7 /*24da*/,
    8 /*24db*/,  7 /*24dc*/,  8 /*24dd*/,  8 /*24de*/,  9 /*24df*/,
    5 /*24e0*/,  6 /*24e1*/,  6 /*24e2*/,  7 /*24e3*/,  6 /*24e4*/,
    7 /*24e5*/,  7 /*24e6*/,  8 /*24e7*/,  6 /*24e8*/,  7 /*24e9*/,
    7 /*24ea*/,  8 /*24eb*/,  7 /*24ec*/,  8 /*24ed*/,  8 /*24ee*/,
    9 /*24ef*/,  6 /*24f0*/,  7 /*24f1*/,  7 /*24f2*/,  8 /*24f3*/,
    7 /*24f4*/,  8 /*24f5*/,  8 /*24f6*/,  9 /*24f7*/,  7 /*24f8*/,
    8 /*24f9*/,  8 /*24fa*/,  9 /*24fb*/,  8 /*24fc*/,  9 /*24fd*/,
    9 /*24fe*/,  10 /*24ff*/, 3 /*2500*/,  4 /*2501*/,  4 /*2502*/,
    5 /*2503*/,  4 /*2504*/,  5 /*2505*/,  5 /*2506*/,  6 /*2507*/,
    4 /*2508*/,  5 /*2509*/,  5 /*250a*/,  6 /*250b*/,  5 /*250c*/,
    6 /*250d*/,  6 /*250e*/,  7 /*250f*/,  4 /*2510*/,  5 /*2511*/,
    5 /*2512*/,  6 /*2513*/,  5 /*2514*/,  6 /*2515*/,  6 /*2516*/,
    7 /*2517*/,  5 /*2518*/,  6 /*2519*/,  6 /*251a*/,  7 /*251b*/,
    6 /*251c*/,  7 /*251d*/,  7 /*251e*/,  8 /*251f*/,  4 /*2520*/,
    5 /*2521*/,  5 /*2522*/,  6 /*2523*/,  5 /*2524*/,  6 /*2525*/,
    6 /*2526*/,  7 /*2527*/,  5 /*2528*/,  6 /*2529*/,  6 /*252a*/,
    7 /*252b*/,  6 /*252c*/,  7 /*252d*/,  7 /*252e*/,  8 /*252f*/,
    5 /*2530*/,  6 /*2531*/,  6 /*2532*/,  7 /*2533*/,  6 /*2534*/,
    7 /*2535*/,  7 /*2536*/,  8 /*2537*/,  6 /*2538*/,  7 /*2539*/,
    7 /*253a*/,  8 /*253b*/,  7 /*253c*/,  8 /*253d*/,  8 /*253e*/,
    9 /*253f*/,  4 /*2540*/,  5 /*2541*/,  5 /*2542*/,  6 /*2543*/,
    5 /*2544*/,  6 /*2545*/,  6 /*2546*/,  7 /*2547*/,  5 /*2548*/,
    6 /*2549*/,  6 /*254a*/,  7 /*254b*/,  6 /*254c*/,  7 /*254d*/,
    7 /*254e*/,  8 /*254f*/,  5 /*2550*/,  6 /*2551*/,  6 /*2552*/,
    7 /*2553*/,  6 /*2554*/,  7 /*2555*/,  7 /*2556*/,  8 /*2557*/,
    6 /*2558*/,  7 /*2559*/,  7 /*255a*/,  8 /*255b*/,  7 /*255c*/,
    8 /*255d*/,  8 /*255e*/,  9 /*255f*/,  5 /*2560*/,  6 /*2561*/,
    6 /*2562*/,  7 /*2563*/,  6 /*2564*/,  7 /*2565*/,  7 /*2566*/,
    8 /*2567*/,  6 /*2568*/,  7 /*2569*/,  7 /*256a*/,  8 /*256b*/,
    7 /*256c*/,  8 /*256d*/,  8 /*256e*/,  9 /*256f*/,  6 /*2570*/,
    7 /*2571*/,  7 /*2572*/,  8 /*2573*/,  7 /*2574*/,  8 /*2575*/,
    8 /*2576*/,  9 /*2577*/,  7 /*2578*/,  8 /*2579*/,  8 /*257a*/,
    9 /*257b*/,  8 /*257c*/,  9 /*257d*/,  9 /*257e*/,  10 /*257f*/,
    4 /*2580*/,  5 /*2581*/,  5 /*2582*/,  6 /*2583*/,  5 /*2584*/,
    6 /*2585*/,  6 /*2586*/,  7 /*2587*/,  5 /*2588*/,  6 /*2589*/,
    6 /*258a*/,  7 /*258b*/,  6 /*258c*/,  7 /*258d*/,  7 /*258e*/,
    8 /*258f*/,  5 /*2590*/,  6 /*2591*/,  6 /*2592*/,  7 /*2593*/,
    6 /*2594*/,  7 /*2595*/,  7 /*2596*/,  8 /*2597*/,  6 /*2598*/,
    7 /*2599*/,  7 /*259a*/,  8 /*259b*/,  7 /*259c*/,  8 /*259d*/,
    8 /*259e*/,  9 /*259f*/,  5 /*25a0*/,  6 /*25a1*/,  6 /*25a2*/,
    7 /*25a3*/,  6 /*25a4*/,  7 /*25a5*/,  7 /*25a6*/,  8 /*25a7*/,
    6 /*25a8*/,  7 /*25a9*/,  7 /*25aa*/,  8 /*25ab*/,  7 /*25ac*/,
    8 /*25ad*/,  8 /*25ae*/,  9 /*25af*/,  6 /*25b0*/,  7 /*25b1*/,
    7 /*25b2*/,  8 /*25b3*/,  7 /*25b4*/,  8 /*25b5*/,  8 /*25b6*/,
    9 /*25b7*/,  7 /*25b8*/,  8 /*25b9*/,  8 /*25ba*/,  9 /*25bb*/,
    8 /*25bc*/,  9 /*25bd*/,  9 /*25be*/,  10 /*25bf*/, 5 /*25c0*/,
    6 /*25c1*/,  6 /*25c2*/,  7 /*25c3*/,  6 /*25c4*/,  7 /*25c5*/,
    7 /*25c6*/,  8 /*25c7*/,  6 /*25c8*/,  7 /*25c9*/,  7 /*25ca*/,
    8 /*25cb*/,  7 /*25cc*/,  8 /*25cd*/,  8 /*25ce*/,  9 /*25cf*/,
    6 /*25d0*/,  7 /*25d1*/,  7 /*25d2*/,  8 /*25d3*/,  7 /*25d4*/,
    8 /*25d5*/,  8 /*25d6*/,  9 /*25d7*/,  7 /*25d8*/,  8 /*25d9*/,
    8 /*25da*/,  9 /*25db*/,  8 /*25dc*/,  9 /*25dd*/,  9 /*25de*/,
    10 /*25df*/, 6 /*25e0*/,  7 /*25e1*/,  7 /*25e2*/,  8 /*25e3*/,
    7 /*25e4*/,  8 /*25e5*/,  8 /*25e6*/,  9 /*25e7*/,  7 /*25e8*/,
    8 /*25e9*/,  8 /*25ea*/,  9 /*25eb*/,  8 /*25ec*/,  9 /*25ed*/,
    9 /*25ee*/,  10 /*25ef*/, 7 /*25f0*/,  8 /*25f1*/,  8 /*25f2*/,
    9 /*25f3*/,  8 /*25f4*/,  9 /*25f5*/,  9 /*25f6*/,  10 /*25f7*/,
    8 /*25f8*/,  9 /*25f9*/,  9 /*25fa*/,  10 /*25fb*/, 9 /*25fc*/,
    10 /*25fd*/, 10 /*25fe*/, 11 /*25ff*/, 3 /*2600*/,  4 /*2601*/,
    4 /*2602*/,  5 /*2603*/,  4 /*2604*/,  5 /*2605*/,  5 /*2606*/,
    6 /*2607*/,  4 /*2608*/,  5 /*2609*/,  5 /*260a*/,  6 /*260b*/,
    5 /*260c*/,  6 /*260d*/,  6 /*260e*/,  7 /*260f*/,  4 /*2610*/,
    5 /*2611*/,  5 /*2612*/,  6 /*2613*/,  5 /*2614*/,  6 /*2615*/,
    6 /*2616*/,  7 /*2617*/,  5 /*2618*/,  6 /*2619*/,  6 /*261a*/,
    7 /*261b*/,  6 /*261c*/,  7 /*261d*/,  7 /*261e*/,  8 /*261f*/,
    4 /*2620*/,  5 /*2621*/,  5 /*2622*/,  6 /*2623*/,  5 /*2624*/,
    6 /*2625*/,  6 /*2626*/,  7 /*2627*/,  5 /*2628*/,  6 /*2629*/,
    6 /*262a*/,  7 /*262b*/,  6 /*262c*/,  7 /*262d*/,  7 /*262e*/,
    8 /*262f*/,  5 /*2630*/,  6 /*2631*/,  6 /*2632*/,  7 /*2633*/,
    6 /*2634*/,  7 /*2635*/,  7 /*2636*/,  8 /*2637*/,  6 /*2638*/,
    7 /*2639*/,  7 /*263a*/,  8 /*263b*/,  7 /*263c*/,  8 /*263d*/,
    8 /*263e*/,  9 /*263f*/,  4 /*2640*/,  5 /*2641*/,  5 /*2642*/,
    6 /*2643*/,  5 /*2644*/,  6 /*2645*/,  6 /*2646*/,  7 /*2647*/,
    5 /*2648*/,  6 /*2649*/,  6 /*264a*/,  7 /*264b*/,  6 /*264c*/,
    7 /*264d*/,  7 /*264e*/,  8 /*264f*/,  5 /*2650*/,  6 /*2651*/,
    6 /*2652*/,  7 /*2653*/,  6 /*2654*/,  7 /*2655*/,  7 /*2656*/,
    8 /*2657*/,  6 /*2658*/,  7 /*2659*/,  7 /*265a*/,  8 /*265b*/,
    7 /*265c*/,  8 /*265d*/,  8 /*265e*/,  9 /*265f*/,  5 /*2660*/,
    6 /*2661*/,  6 /*2662*/,  7 /*2663*/,  6 /*2664*/,  7 /*2665*/,
    7 /*2666*/,  8 /*2667*/,  6 /*2668*/,  7 /*2669*/,  7 /*266a*/,
    8 /*266b*/,  7 /*266c*/,  8 /*266d*/,  8 /*266e*/,  9 /*266f*/,
    6 /*2670*/,  7 /*2671*/,  7 /*2672*/,  8 /*2673*/,  7 /*2674*/,
    8 /*2675*/,  8 /*2676*/,  9 /*2677*/,  7 /*2678*/,  8 /*2679*/,
    8 /*267a*/,  9 /*267b*/,  8 /*267c*/,  9 /*267d*/,  9 /*267e*/,
    10 /*267f*/, 4 /*2680*/,  5 /*2681*/,  5 /*2682*/,  6 /*2683*/,
    5 /*2684*/,  6 /*2685*/,  6 /*2686*/,  7 /*2687*/,  5 /*2688*/,
    6 /*2689*/,  6 /*268a*/,  7 /*268b*/,  6 /*268c*/,  7 /*268d*/,
    7 /*268e*/,  8 /*268f*/,  5 /*2690*/,  6 /*2691*/,  6 /*2692*/,
    7 /*2693*/,  6 /*2694*/,  7 /*2695*/,  7 /*2696*/,  8 /*2697*/,
    6 /*2698*/,  7 /*2699*/,  7 /*269a*/,  8 /*269b*/,  7 /*269c*/,
    8 /*269d*/,  8 /*269e*/,  9 /*269f*/,  5 /*26a0*/,  6 /*26a1*/,
    6 /*26a2*/,  7 /*26a3*/,  6 /*26a4*/,  7 /*26a5*/,  7 /*26a6*/,
    8 /*26a7*/,  6 /*26a8*/,  7 /*26a9*/,  7 /*26aa*/,  8 /*26ab*/,
    7 /*26ac*/,  8 /*26ad*/,  8 /*26ae*/,  9 /*26af*/,  6 /*26b0*/,
    7 /*26b1*/,  7 /*26b2*/,  8 /*26b3*/,  7 /*26b4*/,  8 /*26b5*/,
    8 /*26b6*/,  9 /*26b7*/,  7 /*26b8*/,  8 /*26b9*/,  8 /*26ba*/,
    9 /*26bb*/,  8 /*26bc*/,  9 /*26bd*/,  9 /*26be*/,  10 /*26bf*/,
    5 /*26c0*/,  6 /*26c1*/,  6 /*26c2*/,  7 /*26c3*/,  6 /*26c4*/,
    7 /*26c5*/,  7 /*26c6*/,  8 /*26c7*/,  6 /*26c8*/,  7 /*26c9*/,
    7 /*26ca*/,  8 /*26cb*/,  7 /*26cc*/,  8 /*26cd*/,  8 /*26ce*/,
    9 /*26cf*/,  6 /*26d0*/,  7 /*26d1*/,  7 /*26d2*/,  8 /*26d3*/,
    7 /*26d4*/,  8 /*26d5*/,  8 /*26d6*/,  9 /*26d7*/,  7 /*26d8*/,
    8 /*26d9*/,  8 /*26da*/,  9 /*26db*/,  8 /*26dc*/,  9 /*26dd*/,
    9 /*26de*/,  10 /*26df*/, 6 /*26e0*/,  7 /*26e1*/,  7 /*26e2*/,
    8 /*26e3*/,  7 /*26e4*/,  8 /*26e5*/,  8 /*26e6*/,  9 /*26e7*/,
    7 /*26e8*/,  8 /*26e9*/,  8 /*26ea*/,  9 /*26eb*/,  8 /*26ec*/,
    9 /*26ed*/,  9 /*26ee*/,  10 /*26ef*/, 7 /*26f0*/,  8 /*26f1*/,
    8 /*26f2*/,  9 /*26f3*/,  8 /*26f4*/,  9 /*26f5*/,  9 /*26f6*/,
    10 /*26f7*/, 8 /*26f8*/,  9 /*26f9*/,  9 /*26fa*/,  10 /*26fb*/,
    9 /*26fc*/,  10 /*26fd*/, 10 /*26fe*/, 11 /*26ff*/, 4 /*2700*/,
    5 /*2701*/,  5 /*2702*/,  6 /*2703*/,  5 /*2704*/,  6 /*2705*/,
    6 /*2706*/,  7 /*2707*/,  5 /*2708*/,  6 /*2709*/,  6 /*270a*/,
    7 /*270b*/,  6 /*270c*/,  7 /*270d*/,  7 /*270e*/,  8 /*270f*/,
    5 /*2710*/,  6 /*2711*/,  6 /*2712*/,  7 /*2713*/,  6 /*2714*/,
    7 /*2715*/,  7 /*2716*/,  8 /*2717*/,  6 /*2718*/,  7 /*2719*/,
    7 /*271a*/,  8 /*271b*/,  7 /*271c*/,  8 /*271d*/,  8 /*271e*/,
    9 /*271f*/,  5 /*2720*/,  6 /*2721*/,  6 /*2722*/,  7 /*2723*/,
    6 /*2724*/,  7 /*2725*/,  7 /*2726*/,  8 /*2727*/,  6 /*2728*/,
    7 /*2729*/,  7 /*272a*/,  8 /*272b*/,  7 /*272c*/,  8 /*272d*/,
    8 /*272e*/,  9 /*272f*/,  6 /*2730*/,  7 /*2731*/,  7 /*2732*/,
    8 /*2733*/,  7 /*2734*/,  8 /*2735*/,  8 /*2736*/,  9 /*2737*/,
    7 /*2738*/,  8 /*2739*/,  8 /*273a*/,  9 /*273b*/,  8 /*273c*/,
    9 /*273d*/,  9 /*273e*/,  10 /*273f*/, 5 /*2740*/,  6 /*2741*/,
    6 /*2742*/,  7 /*2743*/,  6 /*2744*/,  7 /*2745*/,  7 /*2746*/,
    8 /*2747*/,  6 /*2748*/,  7 /*2749*/,  7 /*274a*/,  8 /*274b*/,
    7 /*274c*/,  8 /*274d*/,  8 /*274e*/,  9 /*274f*/,  6 /*2750*/,
    7 /*2751*/,  7 /*2752*/,  8 /*2753*/,  7 /*2754*/,  8 /*2755*/,
    8 /*2756*/,  9 /*2757*/,  7 /*2758*/,  8 /*2759*/,  8 /*275a*/,
    9 /*275b*/,  8 /*275c*/,  9 /*275d*/,  9 /*275e*/,  10 /*275f*/,
    6 /*2760*/,  7 /*2761*/,  7 /*2762*/,  8 /*2763*/,  7 /*2764*/,
    8 /*2765*/,  8 /*2766*/,  9 /*2767*/,  7 /*2768*/,  8 /*2769*/,
    8 /*276a*/,  9 /*276b*/,  8 /*276c*/,  9 /*276d*/,  9 /*276e*/,
    10 /*276f*/, 7 /*2770*/,  8 /*2771*/,  8 /*2772*/,  9 /*2773*/,
    8 /*2774*/,  9 /*2775*/,  9 /*2776*/,  10 /*2777*/, 8 /*2778*/,
    9 /*2779*/,  9 /*277a*/,  10 /*277b*/, 9 /*277c*/,  10 /*277d*/,
    10 /*277e*/, 11 /*277f*/, 5 /*2780*/,  6 /*2781*/,  6 /*2782*/,
    7 /*2783*/,  6 /*2784*/,  7 /*2785*/,  7 /*2786*/,  8 /*2787*/,
    6 /*2788*/,  7 /*2789*/,  7 /*278a*/,  8 /*278b*/,  7 /*278c*/,
    8 /*278d*/,  8 /*278e*/,  9 /*278f*/,  6 /*2790*/,  7 /*2791*/,
    7 /*2792*/,  8 /*2793*/,  7 /*2794*/,  8 /*2795*/,  8 /*2796*/,
    9 /*2797*/,  7 /*2798*/,  8 /*2799*/,  8 /*279a*/,  9 /*279b*/,
    8 /*279c*/,  9 /*279d*/,  9 /*279e*/,  10 /*279f*/, 6 /*27a0*/,
    7 /*27a1*/,  7 /*27a2*/,  8 /*27a3*/,  7 /*27a4*/,  8 /*27a5*/,
    8 /*27a6*/,  9 /*27a7*/,  7 /*27a8*/,  8 /*27a9*/,  8 /*27aa*/,
    9 /*27ab*/,  8 /*27ac*/,  9 /*27ad*/,  9 /*27ae*/,  10 /*27af*/,
    7 /*27b0*/,  8 /*27b1*/,  8 /*27b2*/,  9 /*27b3*/,  8 /*27b4*/,
    9 /*27b5*/,  9 /*27b6*/,  10 /*27b7*/, 8 /*27b8*/,  9 /*27b9*/,
    9 /*27ba*/,  10 /*27bb*/, 9 /*27bc*/,  10 /*27bd*/, 10 /*27be*/,
    11 /*27bf*/, 6 /*27c0*/,  7 /*27c1*/,  7 /*27c2*/,  8 /*27c3*/,
    7 /*27c4*/,  8 /*27c5*/,  8 /*27c6*/,  9 /*27c7*/,  7 /*27c8*/,
    8 /*27c9*/,  8 /*27ca*/,  9 /*27cb*/,  8 /*27cc*/,  9 /*27cd*/,
    9 /*27ce*/,  10 /*27cf*/, 7 /*27d0*/,  8 /*27d1*/,  8 /*27d2*/,
    9 /*27d3*/,  8 /*27d4*/,  9 /*27d5*/,  9 /*27d6*/,  10 /*27d7*/,
    8 /*27d8*/,  9 /*27d9*/,  9 /*27da*/,  10 /*27db*/, 9 /*27dc*/,
    10 /*27dd*/, 10 /*27de*/, 11 /*27df*/, 7 /*27e0*/,  8 /*27e1*/,
    8 /*27e2*/,  9 /*27e3*/,  8 /*27e4*/,  9 /*27e5*/,  9 /*27e6*/,
    10 /*27e7*/, 8 /*27e8*/,  9 /*27e9*/,  9 /*27ea*/,  10 /*27eb*/,
    9 /*27ec*/,  10 /*27ed*/, 10 /*27ee*/, 11 /*27ef*/, 8 /*27f0*/,
    9 /*27f1*/,  9 /*27f2*/,  10 /*27f3*/, 9 /*27f4*/,  10 /*27f5*/,
    10 /*27f6*/, 11 /*27f7*/, 9 /*27f8*/,  10 /*27f9*/, 10 /*27fa*/,
    11 /*27fb*/, 10 /*27fc*/, 11 /*27fd*/, 11 /*27fe*/, 12 /*27ff*/,
    2 /*2800*/,  3 /*2801*/,  3 /*2802*/,  4 /*2803*/,  3 /*2804*/,
    4 /*2805*/,  4 /*2806*/,  5 /*2807*/,  3 /*2808*/,  4 /*2809*/,
    4 /*280a*/,  5 /*280b*/,  4 /*280c*/,  5 /*280d*/,  5 /*280e*/,
    6 /*280f*/,  3 /*2810*/,  4 /*2811*/,  4 /*2812*/,  5 /*2813*/,
    4 /*2814*/,  5 /*2815*/,  5 /*2816*/,  6 /*2817*/,  4 /*2818*/,
    5 /*2819*/,  5 /*281a*/,  6 /*281b*/,  5 /*281c*/,  6 /*281d*/,
    6 /*281e*/,  7 /*281f*/,  3 /*2820*/,  4 /*2821*/,  4 /*2822*/,
    5 /*2823*/,  4 /*2824*/,  5 /*2825*/,  5 /*2826*/,  6 /*2827*/,
    4 /*2828*/,  5 /*2829*/,  5 /*282a*/,  6 /*282b*/,  5 /*282c*/,
    6 /*282d*/,  6 /*282e*/,  7 /*282f*/,  4 /*2830*/,  5 /*2831*/,
    5 /*2832*/,  6 /*2833*/,  5 /*2834*/,  6 /*2835*/,  6 /*2836*/,
    7 /*2837*/,  5 /*2838*/,  6 /*2839*/,  6 /*283a*/,  7 /*283b*/,
    6 /*283c*/,  7 /*283d*/,  7 /*283e*/,  8 /*283f*/,  3 /*2840*/,
    4 /*2841*/,  4 /*2842*/,  5 /*2843*/,  4 /*2844*/,  5 /*2845*/,
    5 /*2846*/,  6 /*2847*/,  4 /*2848*/,  5 /*2849*/,  5 /*284a*/,
    6 /*284b*/,  5 /*284c*/,  6 /*284d*/,  6 /*284e*/,  7 /*284f*/,
    4 /*2850*/,  5 /*2851*/,  5 /*2852*/,  6 /*2853*/,  5 /*2854*/,
    6 /*2855*/,  6 /*2856*/,  7 /*2857*/,  5 /*2858*/,  6 /*2859*/,
    6 /*285a*/,  7 /*285b*/,  6 /*285c*/,  7 /*285d*/,  7 /*285e*/,
    8 /*285f*/,  4 /*2860*/,  5 /*2861*/,  5 /*2862*/,  6 /*2863*/,
    5 /*2864*/,  6 /*2865*/,  6 /*2866*/,  7 /*2867*/,  5 /*2868*/,
    6 /*2869*/,  6 /*286a*/,  7 /*286b*/,  6 /*286c*/,  7 /*286d*/,
    7 /*286e*/,  8 /*286f*/,  5 /*2870*/,  6 /*2871*/,  6 /*2872*/,
    7 /*2873*/,  6 /*2874*/,  7 /*2875*/,  7 /*2876*/,  8 /*2877*/,
    6 /*2878*/,  7 /*2879*/,  7 /*287a*/,  8 /*287b*/,  7 /*287c*/,
    8 /*287d*/,  8 /*287e*/,  9 /*287f*/,  3 /*2880*/,  4 /*2881*/,
    4 /*2882*/,  5 /*2883*/,  4 /*2884*/,  5 /*2885*/,  5 /*2886*/,
    6 /*2887*/,  4 /*2888*/,  5 /*2889*/,  5 /*288a*/,  6 /*288b*/,
    5 /*288c*/,  6 /*288d*/,  6 /*288e*/,  7 /*288f*/,  4 /*2890*/,
    5 /*2891*/,  5 /*2892*/,  6 /*2893*/,  5 /*2894*/,  6 /*2895*/,
    6 /*2896*/,  7 /*2897*/,  5 /*2898*/,  6 /*2899*/,  6 /*289a*/,
    7 /*289b*/,  6 /*289c*/,  7 /*289d*/,  7 /*289e*/,  8 /*289f*/,
    4 /*28a0*/,  5 /*28a1*/,  5 /*28a2*/,  6 /*28a3*/,  5 /*28a4*/,
    6 /*28a5*/,  6 /*28a6*/,  7 /*28a7*/,  5 /*28a8*/,  6 /*28a9*/,
    6 /*28aa*/,  7 /*28ab*/,  6 /*28ac*/,  7 /*28ad*/,  7 /*28ae*/,
    8 /*28af*/,  5 /*28b0*/,  6 /*28b1*/,  6 /*28b2*/,  7 /*28b3*/,
    6 /*28b4*/,  7 /*28b5*/,  7 /*28b6*/,  8 /*28b7*/,  6 /*28b8*/,
    7 /*28b9*/,  7 /*28ba*/,  8 /*28bb*/,  7 /*28bc*/,  8 /*28bd*/,
    8 /*28be*/,  9 /*28bf*/,  4 /*28c0*/,  5 /*28c1*/,  5 /*28c2*/,
    6 /*28c3*/,  5 /*28c4*/,  6 /*28c5*/,  6 /*28c6*/,  7 /*28c7*/,
    5 /*28c8*/,  6 /*28c9*/,  6 /*28ca*/,  7 /*28cb*/,  6 /*28cc*/,
    7 /*28cd*/,  7 /*28ce*/,  8 /*28cf*/,  5 /*28d0*/,  6 /*28d1*/,
    6 /*28d2*/,  7 /*28d3*/,  6 /*28d4*/,  7 /*28d5*/,  7 /*28d6*/,
    8 /*28d7*/,  6 /*28d8*/,  7 /*28d9*/,  7 /*28da*/,  8 /*28db*/,
    7 /*28dc*/,  8 /*28dd*/,  8 /*28de*/,  9 /*28df*/,  5 /*28e0*/,
    6 /*28e1*/,  6 /*28e2*/,  7 /*28e3*/,  6 /*28e4*/,  7 /*28e5*/,
    7 /*28e6*/,  8 /*28e7*/,  6 /*28e8*/,  7 /*28e9*/,  7 /*28ea*/,
    8 /*28eb*/,  7 /*28ec*/,  8 /*28ed*/,  8 /*28ee*/,  9 /*28ef*/,
    6 /*28f0*/,  7 /*28f1*/,  7 /*28f2*/,  8 /*28f3*/,  7 /*28f4*/,
    8 /*28f5*/,  8 /*28f6*/,  9 /*28f7*/,  7 /*28f8*/,  8 /*28f9*/,
    8 /*28fa*/,  9 /*28fb*/,  8 /*28fc*/,  9 /*28fd*/,  9 /*28fe*/,
    10 /*28ff*/, 3 /*2900*/,  4 /*2901*/,  4 /*2902*/,  5 /*2903*/,
    4 /*2904*/,  5 /*2905*/,  5 /*2906*/,  6 /*2907*/,  4 /*2908*/,
    5 /*2909*/,  5 /*290a*/,  6 /*290b*/,  5 /*290c*/,  6 /*290d*/,
    6 /*290e*/,  7 /*290f*/,  4 /*2910*/,  5 /*2911*/,  5 /*2912*/,
    6 /*2913*/,  5 /*2914*/,  6 /*2915*/,  6 /*2916*/,  7 /*2917*/,
    5 /*2918*/,  6 /*2919*/,  6 /*291a*/,  7 /*291b*/,  6 /*291c*/,
    7 /*291d*/,  7 /*291e*/,  8 /*291f*/,  4 /*2920*/,  5 /*2921*/,
    5 /*2922*/,  6 /*2923*/,  5 /*2924*/,  6 /*2925*/,  6 /*2926*/,
    7 /*2927*/,  5 /*2928*/,  6 /*2929*/,  6 /*292a*/,  7 /*292b*/,
    6 /*292c*/,  7 /*292d*/,  7 /*292e*/,  8 /*292f*/,  5 /*2930*/,
    6 /*2931*/,  6 /*2932*/,  7 /*2933*/,  6 /*2934*/,  7 /*2935*/,
    7 /*2936*/,  8 /*2937*/,  6 /*2938*/,  7 /*2939*/,  7 /*293a*/,
    8 /*293b*/,  7 /*293c*/,  8 /*293d*/,  8 /*293e*/,  9 /*293f*/,
    4 /*2940*/,  5 /*2941*/,  5 /*2942*/,  6 /*2943*/,  5 /*2944*/,
    6 /*2945*/,  6 /*2946*/,  7 /*2947*/,  5 /*2948*/,  6 /*2949*/,
    6 /*294a*/,  7 /*294b*/,  6 /*294c*/,  7 /*294d*/,  7 /*294e*/,
    8 /*294f*/,  5 /*2950*/,  6 /*2951*/,  6 /*2952*/,  7 /*2953*/,
    6 /*2954*/,  7 /*2955*/,  7 /*2956*/,  8 /*2957*/,  6 /*2958*/,
    7 /*2959*/,  7 /*295a*/,  8 /*295b*/,  7 /*295c*/,  8 /*295d*/,
    8 /*295e*/,  9 /*295f*/,  5 /*2960*/,  6 /*2961*/,  6 /*2962*/,
    7 /*2963*/,  6 /*2964*/,  7 /*2965*/,  7 /*2966*/,  8 /*2967*/,
    6 /*2968*/,  7 /*2969*/,  7 /*296a*/,  8 /*296b*/,  7 /*296c*/,
    8 /*296d*/,  8 /*296e*/,  9 /*296f*/,  6 /*2970*/,  7 /*2971*/,
    7 /*2972*/,  8 /*2973*/,  7 /*2974*/,  8 /*2975*/,  8 /*2976*/,
    9 /*2977*/,  7 /*2978*/,  8 /*2979*/,  8 /*297a*/,  9 /*297b*/,
    8 /*297c*/,  9 /*297d*/,  9 /*297e*/,  10 /*297f*/, 4 /*2980*/,
    5 /*2981*/,  5 /*2982*/,  6 /*2983*/,  5 /*2984*/,  6 /*2985*/,
    6 /*2986*/,  7 /*2987*/,  5 /*2988*/,  6 /*2989*/,  6 /*298a*/,
    7 /*298b*/,  6 /*298c*/,  7 /*298d*/,  7 /*298e*/,  8 /*298f*/,
    5 /*2990*/,  6 /*2991*/,  6 /*2992*/,  7 /*2993*/,  6 /*2994*/,
    7 /*2995*/,  7 /*2996*/,  8 /*2997*/,  6 /*2998*/,  7 /*2999*/,
    7 /*299a*/,  8 /*299b*/,  7 /*299c*/,  8 /*299d*/,  8 /*299e*/,
    9 /*299f*/,  5 /*29a0*/,  6 /*29a1*/,  6 /*29a2*/,  7 /*29a3*/,
    6 /*29a4*/,  7 /*29a5*/,  7 /*29a6*/,  8 /*29a7*/,  6 /*29a8*/,
    7 /*29a9*/,  7 /*29aa*/,  8 /*29ab*/,  7 /*29ac*/,  8 /*29ad*/,
    8 /*29ae*/,  9 /*29af*/,  6 /*29b0*/,  7 /*29b1*/,  7 /*29b2*/,
    8 /*29b3*/,  7 /*29b4*/,  8 /*29b5*/,  8 /*29b6*/,  9 /*29b7*/,
    7 /*29b8*/,  8 /*29b9*/,  8 /*29ba*/,  9 /*29bb*/,  8 /*29bc*/,
    9 /*29bd*/,  9 /*29be*/,  10 /*29bf*/, 5 /*29c0*/,  6 /*29c1*/,
    6 /*29c2*/,  7 /*29c3*/,  6 /*29c4*/,  7 /*29c5*/,  7 /*29c6*/,
    8 /*29c7*/,  6 /*29c8*/,  7 /*29c9*/,  7 /*29ca*/,  8 /*29cb*/,
    7 /*29cc*/,  8 /*29cd*/,  8 /*29ce*/,  9 /*29cf*/,  6 /*29d0*/,
    7 /*29d1*/,  7 /*29d2*/,  8 /*29d3*/,  7 /*29d4*/,  8 /*29d5*/,
    8 /*29d6*/,  9 /*29d7*/,  7 /*29d8*/,  8 /*29d9*/,  8 /*29da*/,
    9 /*29db*/,  8 /*29dc*/,  9 /*29dd*/,  9 /*29de*/,  10 /*29df*/,
    6 /*29e0*/,  7 /*29e1*/,  7 /*29e2*/,  8 /*29e3*/,  7 /*29e4*/,
    8 /*29e5*/,  8 /*29e6*/,  9 /*29e7*/,  7 /*29e8*/,  8 /*29e9*/,
    8 /*29ea*/,  9 /*29eb*/,  8 /*29ec*/,  9 /*29ed*/,  9 /*29ee*/,
    10 /*29ef*/, 7 /*29f0*/,  8 /*29f1*/,  8 /*29f2*/,  9 /*29f3*/,
    8 /*29f4*/,  9 /*29f5*/,  9 /*29f6*/,  10 /*29f7*/, 8 /*29f8*/,
    9 /*29f9*/,  9 /*29fa*/,  10 /*29fb*/, 9 /*29fc*/,  10 /*29fd*/,
    10 /*29fe*/, 11 /*29ff*/, 3 /*2a00*/,  4 /*2a01*/,  4 /*2a02*/,
    5 /*2a03*/,  4 /*2a04*/,  5 /*2a05*/,  5 /*2a06*/,  6 /*2a07*/,
    4 /*2a08*/,  5 /*2a09*/,  5 /*2a0a*/,  6 /*2a0b*/,  5 /*2a0c*/,
    6 /*2a0d*/,  6 /*2a0e*/,  7 /*2a0f*/,  4 /*2a10*/,  5 /*2a11*/,
    5 /*2a12*/,  6 /*2a13*/,  5 /*2a14*/,  6 /*2a15*/,  6 /*2a16*/,
    7 /*2a17*/,  5 /*2a18*/,  6 /*2a19*/,  6 /*2a1a*/,  7 /*2a1b*/,
    6 /*2a1c*/,  7 /*2a1d*/,  7 /*2a1e*/,  8 /*2a1f*/,  4 /*2a20*/,
    5 /*2a21*/,  5 /*2a22*/,  6 /*2a23*/,  5 /*2a24*/,  6 /*2a25*/,
    6 /*2a26*/,  7 /*2a27*/,  5 /*2a28*/,  6 /*2a29*/,  6 /*2a2a*/,
    7 /*2a2b*/,  6 /*2a2c*/,  7 /*2a2d*/,  7 /*2a2e*/,  8 /*2a2f*/,
    5 /*2a30*/,  6 /*2a31*/,  6 /*2a32*/,  7 /*2a33*/,  6 /*2a34*/,
    7 /*2a35*/,  7 /*2a36*/,  8 /*2a37*/,  6 /*2a38*/,  7 /*2a39*/,
    7 /*2a3a*/,  8 /*2a3b*/,  7 /*2a3c*/,  8 /*2a3d*/,  8 /*2a3e*/,
    9 /*2a3f*/,  4 /*2a40*/,  5 /*2a41*/,  5 /*2a42*/,  6 /*2a43*/,
    5 /*2a44*/,  6 /*2a45*/,  6 /*2a46*/,  7 /*2a47*/,  5 /*2a48*/,
    6 /*2a49*/,  6 /*2a4a*/,  7 /*2a4b*/,  6 /*2a4c*/,  7 /*2a4d*/,
    7 /*2a4e*/,  8 /*2a4f*/,  5 /*2a50*/,  6 /*2a51*/,  6 /*2a52*/,
    7 /*2a53*/,  6 /*2a54*/,  7 /*2a55*/,  7 /*2a56*/,  8 /*2a57*/,
    6 /*2a58*/,  7 /*2a59*/,  7 /*2a5a*/,  8 /*2a5b*/,  7 /*2a5c*/,
    8 /*2a5d*/,  8 /*2a5e*/,  9 /*2a5f*/,  5 /*2a60*/,  6 /*2a61*/,
    6 /*2a62*/,  7 /*2a63*/,  6 /*2a64*/,  7 /*2a65*/,  7 /*2a66*/,
    8 /*2a67*/,  6 /*2a68*/,  7 /*2a69*/,  7 /*2a6a*/,  8 /*2a6b*/,
    7 /*2a6c*/,  8 /*2a6d*/,  8 /*2a6e*/,  9 /*2a6f*/,  6 /*2a70*/,
    7 /*2a71*/,  7 /*2a72*/,  8 /*2a73*/,  7 /*2a74*/,  8 /*2a75*/,
    8 /*2a76*/,  9 /*2a77*/,  7 /*2a78*/,  8 /*2a79*/,  8 /*2a7a*/,
    9 /*2a7b*/,  8 /*2a7c*/,  9 /*2a7d*/,  9 /*2a7e*/,  10 /*2a7f*/,
    4 /*2a80*/,  5 /*2a81*/,  5 /*2a82*/,  6 /*2a83*/,  5 /*2a84*/,
    6 /*2a85*/,  6 /*2a86*/,  7 /*2a87*/,  5 /*2a88*/,  6 /*2a89*/,
    6 /*2a8a*/,  7 /*2a8b*/,  6 /*2a8c*/,  7 /*2a8d*/,  7 /*2a8e*/,
    8 /*2a8f*/,  5 /*2a90*/,  6 /*2a91*/,  6 /*2a92*/,  7 /*2a93*/,
    6 /*2a94*/,  7 /*2a95*/,  7 /*2a96*/,  8 /*2a97*/,  6 /*2a98*/,
    7 /*2a99*/,  7 /*2a9a*/,  8 /*2a9b*/,  7 /*2a9c*/,  8 /*2a9d*/,
    8 /*2a9e*/,  9 /*2a9f*/,  5 /*2aa0*/,  6 /*2aa1*/,  6 /*2aa2*/,
    7 /*2aa3*/,  6 /*2aa4*/,  7 /*2aa5*/,  7 /*2aa6*/,  8 /*2aa7*/,
    6 /*2aa8*/,  7 /*2aa9*/,  7 /*2aaa*/,  8 /*2aab*/,  7 /*2aac*/,
    8 /*2aad*/,  8 /*2aae*/,  9 /*2aaf*/,  6 /*2ab0*/,  7 /*2ab1*/,
    7 /*2ab2*/,  8 /*2ab3*/,  7 /*2ab4*/,  8 /*2ab5*/,  8 /*2ab6*/,
    9 /*2ab7*/,  7 /*2ab8*/,  8 /*2ab9*/,  8 /*2aba*/,  9 /*2abb*/,
    8 /*2abc*/,  9 /*2abd*/,  9 /*2abe*/,  10 /*2abf*/, 5 /*2ac0*/,
    6 /*2ac1*/,  6 /*2ac2*/,  7 /*2ac3*/,  6 /*2ac4*/,  7 /*2ac5*/,
    7 /*2ac6*/,  8 /*2ac7*/,  6 /*2ac8*/,  7 /*2ac9*/,  7 /*2aca*/,
    8 /*2acb*/,  7 /*2acc*/,  8 /*2acd*/,  8 /*2ace*/,  9 /*2acf*/,
    6 /*2ad0*/,  7 /*2ad1*/,  7 /*2ad2*/,  8 /*2ad3*/,  7 /*2ad4*/,
    8 /*2ad5*/,  8 /*2ad6*/,  9 /*2ad7*/,  7 /*2ad8*/,  8 /*2ad9*/,
    8 /*2ada*/,  9 /*2adb*/,  8 /*2adc*/,  9 /*2add*/,  9 /*2ade*/,
    10 /*2adf*/, 6 /*2ae0*/,  7 /*2ae1*/,  7 /*2ae2*/,  8 /*2ae3*/,
    7 /*2ae4*/,  8 /*2ae5*/,  8 /*2ae6*/,  9 /*2ae7*/,  7 /*2ae8*/,
    8 /*2ae9*/,  8 /*2aea*/,  9 /*2aeb*/,  8 /*2aec*/,  9 /*2aed*/,
    9 /*2aee*/,  10 /*2aef*/, 7 /*2af0*/,  8 /*2af1*/,  8 /*2af2*/,
    9 /*2af3*/,  8 /*2af4*/,  9 /*2af5*/,  9 /*2af6*/,  10 /*2af7*/,
    8 /*2af8*/,  9 /*2af9*/,  9 /*2afa*/,  10 /*2afb*/, 9 /*2afc*/,
    10 /*2afd*/, 10 /*2afe*/, 11 /*2aff*/, 4 /*2b00*/,  5 /*2b01*/,
    5 /*2b02*/,  6 /*2b03*/,  5 /*2b04*/,  6 /*2b05*/,  6 /*2b06*/,
    7 /*2b07*/,  5 /*2b08*/,  6 /*2b09*/,  6 /*2b0a*/,  7 /*2b0b*/,
    6 /*2b0c*/,  7 /*2b0d*/,  7 /*2b0e*/,  8 /*2b0f*/,  5 /*2b10*/,
    6 /*2b11*/,  6 /*2b12*/,  7 /*2b13*/,  6 /*2b14*/,  7 /*2b15*/,
    7 /*2b16*/,  8 /*2b17*/,  6 /*2b18*/,  7 /*2b19*/,  7 /*2b1a*/,
    8 /*2b1b*/,  7 /*2b1c*/,  8 /*2b1d*/,  8 /*2b1e*/,  9 /*2b1f*/,
    5 /*2b20*/,  6 /*2b21*/,  6 /*2b22*/,  7 /*2b23*/,  6 /*2b24*/,
    7 /*2b25*/,  7 /*2b26*/,  8 /*2b27*/,  6 /*2b28*/,  7 /*2b29*/,
    7 /*2b2a*/,  8 /*2b2b*/,  7 /*2b2c*/,  8 /*2b2d*/,  8 /*2b2e*/,
    9 /*2b2f*/,  6 /*2b30*/,  7 /*2b31*/,  7 /*2b32*/,  8 /*2b33*/,
    7 /*2b34*/,  8 /*2b35*/,  8 /*2b36*/,  9 /*2b37*/,  7 /*2b38*/,
    8 /*2b39*/,  8 /*2b3a*/,  9 /*2b3b*/,  8 /*2b3c*/,  9 /*2b3d*/,
    9 /*2b3e*/,  10 /*2b3f*/, 5 /*2b40*/,  6 /*2b41*/,  6 /*2b42*/,
    7 /*2b43*/,  6 /*2b44*/,  7 /*2b45*/,  7 /*2b46*/,  8 /*2b47*/,
    6 /*2b48*/,  7 /*2b49*/,  7 /*2b4a*/,  8 /*2b4b*/,  7 /*2b4c*/,
    8 /*2b4d*/,  8 /*2b4e*/,  9 /*2b4f*/,  6 /*2b50*/,  7 /*2b51*/,
    7 /*2b52*/,  8 /*2b53*/,  7 /*2b54*/,  8 /*2b55*/,  8 /*2b56*/,
    9 /*2b57*/,  7 /*2b58*/,  8 /*2b59*/,  8 /*2b5a*/,  9 /*2b5b*/,
    8 /*2b5c*/,  9 /*2b5d*/,  9 /*2b5e*/,  10 /*2b5f*/, 6 /*2b60*/,
    7 /*2b61*/,  7 /*2b62*/,  8 /*2b63*/,  7 /*2b64*/,  8 /*2b65*/,
    8 /*2b66*/,  9 /*2b67*/,  7 /*2b68*/,  8 /*2b69*/,  8 /*2b6a*/,
    9 /*2b6b*/,  8 /*2b6c*/,  9 /*2b6d*/,  9 /*2b6e*/,  10 /*2b6f*/,
    7 /*2b70*/,  8 /*2b71*/,  8 /*2b72*/,  9 /*2b73*/,  8 /*2b74*/,
    9 /*2b75*/,  9 /*2b76*/,  10 /*2b77*/, 8 /*2b78*/,  9 /*2b79*/,
    9 /*2b7a*/,  10 /*2b7b*/, 9 /*2b7c*/,  10 /*2b7d*/, 10 /*2b7e*/,
    11 /*2b7f*/, 5 /*2b80*/,  6 /*2b81*/,  6 /*2b82*/,  7 /*2b83*/,
    6 /*2b84*/,  7 /*2b85*/,  7 /*2b86*/,  8 /*2b87*/,  6 /*2b88*/,
    7 /*2b89*/,  7 /*2b8a*/,  8 /*2b8b*/,  7 /*2b8c*/,  8 /*2b8d*/,
    8 /*2b8e*/,  9 /*2b8f*/,  6 /*2b90*/,  7 /*2b91*/,  7 /*2b92*/,
    8 /*2b93*/,  7 /*2b94*/,  8 /*2b95*/,  8 /*2b96*/,  9 /*2b97*/,
    7 /*2b98*/,  8 /*2b99*/,  8 /*2b9a*/,  9 /*2b9b*/,  8 /*2b9c*/,
    9 /*2b9d*/,  9 /*2b9e*/,  10 /*2b9f*/, 6 /*2ba0*/,  7 /*2ba1*/,
    7 /*2ba2*/,  8 /*2ba3*/,  7 /*2ba4*/,  8 /*2ba5*/,  8 /*2ba6*/,
    9 /*2ba7*/,  7 /*2ba8*/,  8 /*2ba9*/,  8 /*2baa*/,  9 /*2bab*/,
    8 /*2bac*/,  9 /*2bad*/,  9 /*2bae*/,  10 /*2baf*/, 7 /*2bb0*/,
    8 /*2bb1*/,  8 /*2bb2*/,  9 /*2bb3*/,  8 /*2bb4*/,  9 /*2bb5*/,
    9 /*2bb6*/,  10 /*2bb7*/, 8 /*2bb8*/,  9 /*2bb9*/,  9 /*2bba*/,
    10 /*2bbb*/, 9 /*2bbc*/,  10 /*2bbd*/, 10 /*2bbe*/, 11 /*2bbf*/,
    6 /*2bc0*/,  7 /*2bc1*/,  7 /*2bc2*/,  8 /*2bc3*/,  7 /*2bc4*/,
    8 /*2bc5*/,  8 /*2bc6*/,  9 /*2bc7*/,  7 /*2bc8*/,  8 /*2bc9*/,
    8 /*2bca*/,  9 /*2bcb*/,  8 /*2bcc*/,  9 /*2bcd*/,  9 /*2bce*/,
    10 /*2bcf*/, 7 /*2bd0*/,  8 /*2bd1*/,  8 /*2bd2*/,  9 /*2bd3*/,
    8 /*2bd4*/,  9 /*2bd5*/,  9 /*2bd6*/,  10 /*2bd7*/, 8 /*2bd8*/,
    9 /*2bd9*/,  9 /*2bda*/,  10 /*2bdb*/, 9 /*2bdc*/,  10 /*2bdd*/,
    10 /*2bde*/, 11 /*2bdf*/, 7 /*2be0*/,  8 /*2be1*/,  8 /*2be2*/,
    9 /*2be3*/,  8 /*2be4*/,  9 /*2be5*/,  9 /*2be6*/,  10 /*2be7*/,
    8 /*2be8*/,  9 /*2be9*/,  9 /*2bea*/,  10 /*2beb*/, 9 /*2bec*/,
    10 /*2bed*/, 10 /*2bee*/, 11 /*2bef*/, 8 /*2bf0*/,  9 /*2bf1*/,
    9 /*2bf2*/,  10 /*2bf3*/, 9 /*2bf4*/,  10 /*2bf5*/, 10 /*2bf6*/,
    11 /*2bf7*/, 9 /*2bf8*/,  10 /*2bf9*/, 10 /*2bfa*/, 11 /*2bfb*/,
    10 /*2bfc*/, 11 /*2bfd*/, 11 /*2bfe*/, 12 /*2bff*/, 3 /*2c00*/,
    4 /*2c01*/,  4 /*2c02*/,  5 /*2c03*/,  4 /*2c04*/,  5 /*2c05*/,
    5 /*2c06*/,  6 /*2c07*/,  4 /*2c08*/,  5 /*2c09*/,  5 /*2c0a*/,
    6 /*2c0b*/,  5 /*2c0c*/,  6 /*2c0d*/,  6 /*2c0e*/,  7 /*2c0f*/,
    4 /*2c10*/,  5 /*2c11*/,  5 /*2c12*/,  6 /*2c13*/,  5 /*2c14*/,
    6 /*2c15*/,  6 /*2c16*/,  7 /*2c17*/,  5 /*2c18*/,  6 /*2c19*/,
    6 /*2c1a*/,  7 /*2c1b*/,  6 /*2c1c*/,  7 /*2c1d*/,  7 /*2c1e*/,
    8 /*2c1f*/,  4 /*2c20*/,  5 /*2c21*/,  5 /*2c22*/,  6 /*2c23*/,
    5 /*2c24*/,  6 /*2c25*/,  6 /*2c26*/,  7 /*2c27*/,  5 /*2c28*/,
    6 /*2c29*/,  6 /*2c2a*/,  7 /*2c2b*/,  6 /*2c2c*/,  7 /*2c2d*/,
    7 /*2c2e*/,  8 /*2c2f*/,  5 /*2c30*/,  6 /*2c31*/,  6 /*2c32*/,
    7 /*2c33*/,  6 /*2c34*/,  7 /*2c35*/,  7 /*2c36*/,  8 /*2c37*/,
    6 /*2c38*/,  7 /*2c39*/,  7 /*2c3a*/,  8 /*2c3b*/,  7 /*2c3c*/,
    8 /*2c3d*/,  8 /*2c3e*/,  9 /*2c3f*/,  4 /*2c40*/,  5 /*2c41*/,
    5 /*2c42*/,  6 /*2c43*/,  5 /*2c44*/,  6 /*2c45*/,  6 /*2c46*/,
    7 /*2c47*/,  5 /*2c48*/,  6 /*2c49*/,  6 /*2c4a*/,  7 /*2c4b*/,
    6 /*2c4c*/,  7 /*2c4d*/,  7 /*2c4e*/,  8 /*2c4f*/,  5 /*2c50*/,
    6 /*2c51*/,  6 /*2c52*/,  7 /*2c53*/,  6 /*2c54*/,  7 /*2c55*/,
    7 /*2c56*/,  8 /*2c57*/,  6 /*2c58*/,  7 /*2c59*/,  7 /*2c5a*/,
    8 /*2c5b*/,  7 /*2c5c*/,  8 /*2c5d*/,  8 /*2c5e*/,  9 /*2c5f*/,
    5 /*2c60*/,  6 /*2c61*/,  6 /*2c62*/,  7 /*2c63*/,  6 /*2c64*/,
    7 /*2c65*/,  7 /*2c66*/,  8 /*2c67*/,  6 /*2c68*/,  7 /*2c69*/,
    7 /*2c6a*/,  8 /*2c6b*/,  7 /*2c6c*/,  8 /*2c6d*/,  8 /*2c6e*/,
    9 /*2c6f*/,  6 /*2c70*/,  7 /*2c71*/,  7 /*2c72*/,  8 /*2c73*/,
    7 /*2c74*/,  8 /*2c75*/,  8 /*2c76*/,  9 /*2c77*/,  7 /*2c78*/,
    8 /*2c79*/,  8 /*2c7a*/,  9 /*2c7b*/,  8 /*2c7c*/,  9 /*2c7d*/,
    9 /*2c7e*/,  10 /*2c7f*/, 4 /*2c80*/,  5 /*2c81*/,  5 /*2c82*/,
    6 /*2c83*/,  5 /*2c84*/,  6 /*2c85*/,  6 /*2c86*/,  7 /*2c87*/,
    5 /*2c88*/,  6 /*2c89*/,  6 /*2c8a*/,  7 /*2c8b*/,  6 /*2c8c*/,
    7 /*2c8d*/,  7 /*2c8e*/,  8 /*2c8f*/,  5 /*2c90*/,  6 /*2c91*/,
    6 /*2c92*/,  7 /*2c93*/,  6 /*2c94*/,  7 /*2c95*/,  7 /*2c96*/,
    8 /*2c97*/,  6 /*2c98*/,  7 /*2c99*/,  7 /*2c9a*/,  8 /*2c9b*/,
    7 /*2c9c*/,  8 /*2c9d*/,  8 /*2c9e*/,  9 /*2c9f*/,  5 /*2ca0*/,
    6 /*2ca1*/,  6 /*2ca2*/,  7 /*2ca3*/,  6 /*2ca4*/,  7 /*2ca5*/,
    7 /*2ca6*/,  8 /*2ca7*/,  6 /*2ca8*/,  7 /*2ca9*/,  7 /*2caa*/,
    8 /*2cab*/,  7 /*2cac*/,  8 /*2cad*/,  8 /*2cae*/,  9 /*2caf*/,
    6 /*2cb0*/,  7 /*2cb1*/,  7 /*2cb2*/,  8 /*2cb3*/,  7 /*2cb4*/,
    8 /*2cb5*/,  8 /*2cb6*/,  9 /*2cb7*/,  7 /*2cb8*/,  8 /*2cb9*/,
    8 /*2cba*/,  9 /*2cbb*/,  8 /*2cbc*/,  9 /*2cbd*/,  9 /*2cbe*/,
    10 /*2cbf*/, 5 /*2cc0*/,  6 /*2cc1*/,  6 /*2cc2*/,  7 /*2cc3*/,
    6 /*2cc4*/,  7 /*2cc5*/,  7 /*2cc6*/,  8 /*2cc7*/,  6 /*2cc8*/,
    7 /*2cc9*/,  7 /*2cca*/,  8 /*2ccb*/,  7 /*2ccc*/,  8 /*2ccd*/,
    8 /*2cce*/,  9 /*2ccf*/,  6 /*2cd0*/,  7 /*2cd1*/,  7 /*2cd2*/,
    8 /*2cd3*/,  7 /*2cd4*/,  8 /*2cd5*/,  8 /*2cd6*/,  9 /*2cd7*/,
    7 /*2cd8*/,  8 /*2cd9*/,  8 /*2cda*/,  9 /*2cdb*/,  8 /*2cdc*/,
    9 /*2cdd*/,  9 /*2cde*/,  10 /*2cdf*/, 6 /*2ce0*/,  7 /*2ce1*/,
    7 /*2ce2*/,  8 /*2ce3*/,  7 /*2ce4*/,  8 /*2ce5*/,  8 /*2ce6*/,
    9 /*2ce7*/,  7 /*2ce8*/,  8 /*2ce9*/,  8 /*2cea*/,  9 /*2ceb*/,
    8 /*2cec*/,  9 /*2ced*/,  9 /*2cee*/,  10 /*2cef*/, 7 /*2cf0*/,
    8 /*2cf1*/,  8 /*2cf2*/,  9 /*2cf3*/,  8 /*2cf4*/,  9 /*2cf5*/,
    9 /*2cf6*/,  10 /*2cf7*/, 8 /*2cf8*/,  9 /*2cf9*/,  9 /*2cfa*/,
    10 /*2cfb*/, 9 /*2cfc*/,  10 /*2cfd*/, 10 /*2cfe*/, 11 /*2cff*/,
    4 /*2d00*/,  5 /*2d01*/,  5 /*2d02*/,  6 /*2d03*/,  5 /*2d04*/,
    6 /*2d05*/,  6 /*2d06*/,  7 /*2d07*/,  5 /*2d08*/,  6 /*2d09*/,
    6 /*2d0a*/,  7 /*2d0b*/,  6 /*2d0c*/,  7 /*2d0d*/,  7 /*2d0e*/,
    8 /*2d0f*/,  5 /*2d10*/,  6 /*2d11*/,  6 /*2d12*/,  7 /*2d13*/,
    6 /*2d14*/,  7 /*2d15*/,  7 /*2d16*/,  8 /*2d17*/,  6 /*2d18*/,
    7 /*2d19*/,  7 /*2d1a*/,  8 /*2d1b*/,  7 /*2d1c*/,  8 /*2d1d*/,
    8 /*2d1e*/,  9 /*2d1f*/,  5 /*2d20*/,  6 /*2d21*/,  6 /*2d22*/,
    7 /*2d23*/,  6 /*2d24*/,  7 /*2d25*/,  7 /*2d26*/,  8 /*2d27*/,
    6 /*2d28*/,  7 /*2d29*/,  7 /*2d2a*/,  8 /*2d2b*/,  7 /*2d2c*/,
    8 /*2d2d*/,  8 /*2d2e*/,  9 /*2d2f*/,  6 /*2d30*/,  7 /*2d31*/,
    7 /*2d32*/,  8 /*2d33*/,  7 /*2d34*/,  8 /*2d35*/,  8 /*2d36*/,
    9 /*2d37*/,  7 /*2d38*/,  8 /*2d39*/,  8 /*2d3a*/,  9 /*2d3b*/,
    8 /*2d3c*/,  9 /*2d3d*/,  9 /*2d3e*/,  10 /*2d3f*/, 5 /*2d40*/,
    6 /*2d41*/,  6 /*2d42*/,  7 /*2d43*/,  6 /*2d44*/,  7 /*2d45*/,
    7 /*2d46*/,  8 /*2d47*/,  6 /*2d48*/,  7 /*2d49*/,  7 /*2d4a*/,
    8 /*2d4b*/,  7 /*2d4c*/,  8 /*2d4d*/,  8 /*2d4e*/,  9 /*2d4f*/,
    6 /*2d50*/,  7 /*2d51*/,  7 /*2d52*/,  8 /*2d53*/,  7 /*2d54*/,
    8 /*2d55*/,  8 /*2d56*/,  9 /*2d57*/,  7 /*2d58*/,  8 /*2d59*/,
    8 /*2d5a*/,  9 /*2d5b*/,  8 /*2d5c*/,  9 /*2d5d*/,  9 /*2d5e*/,
    10 /*2d5f*/, 6 /*2d60*/,  7 /*2d61*/,  7 /*2d62*/,  8 /*2d63*/,
    7 /*2d64*/,  8 /*2d65*/,  8 /*2d66*/,  9 /*2d67*/,  7 /*2d68*/,
    8 /*2d69*/,  8 /*2d6a*/,  9 /*2d6b*/,  8 /*2d6c*/,  9 /*2d6d*/,
    9 /*2d6e*/,  10 /*2d6f*/, 7 /*2d70*/,  8 /*2d71*/,  8 /*2d72*/,
    9 /*2d73*/,  8 /*2d74*/,  9 /*2d75*/,  9 /*2d76*/,  10 /*2d77*/,
    8 /*2d78*/,  9 /*2d79*/,  9 /*2d7a*/,  10 /*2d7b*/, 9 /*2d7c*/,
    10 /*2d7d*/, 10 /*2d7e*/, 11 /*2d7f*/, 5 /*2d80*/,  6 /*2d81*/,
    6 /*2d82*/,  7 /*2d83*/,  6 /*2d84*/,  7 /*2d85*/,  7 /*2d86*/,
    8 /*2d87*/,  6 /*2d88*/,  7 /*2d89*/,  7 /*2d8a*/,  8 /*2d8b*/,
    7 /*2d8c*/,  8 /*2d8d*/,  8 /*2d8e*/,  9 /*2d8f*/,  6 /*2d90*/,
    7 /*2d91*/,  7 /*2d92*/,  8 /*2d93*/,  7 /*2d94*/,  8 /*2d95*/,
    8 /*2d96*/,  9 /*2d97*/,  7 /*2d98*/,  8 /*2d99*/,  8 /*2d9a*/,
    9 /*2d9b*/,  8 /*2d9c*/,  9 /*2d9d*/,  9 /*2d9e*/,  10 /*2d9f*/,
    6 /*2da0*/,  7 /*2da1*/,  7 /*2da2*/,  8 /*2da3*/,  7 /*2da4*/,
    8 /*2da5*/,  8 /*2da6*/,  9 /*2da7*/,  7 /*2da8*/,  8 /*2da9*/,
    8 /*2daa*/,  9 /*2dab*/,  8 /*2dac*/,  9 /*2dad*/,  9 /*2dae*/,
    10 /*2daf*/, 7 /*2db0*/,  8 /*2db1*/,  8 /*2db2*/,  9 /*2db3*/,
    8 /*2db4*/,  9 /*2db5*/,  9 /*2db6*/,  10 /*2db7*/, 8 /*2db8*/,
    9 /*2db9*/,  9 /*2dba*/,  10 /*2dbb*/, 9 /*2dbc*/,  10 /*2dbd*/,
    10 /*2dbe*/, 11 /*2dbf*/, 6 /*2dc0*/,  7 /*2dc1*/,  7 /*2dc2*/,
    8 /*2dc3*/,  7 /*2dc4*/,  8 /*2dc5*/,  8 /*2dc6*/,  9 /*2dc7*/,
    7 /*2dc8*/,  8 /*2dc9*/,  8 /*2dca*/,  9 /*2dcb*/,  8 /*2dcc*/,
    9 /*2dcd*/,  9 /*2dce*/,  10 /*2dcf*/, 7 /*2dd0*/,  8 /*2dd1*/,
    8 /*2dd2*/,  9 /*2dd3*/,  8 /*2dd4*/,  9 /*2dd5*/,  9 /*2dd6*/,
    10 /*2dd7*/, 8 /*2dd8*/,  9 /*2dd9*/,  9 /*2dda*/,  10 /*2ddb*/,
    9 /*2ddc*/,  10 /*2ddd*/, 10 /*2dde*/, 11 /*2ddf*/, 7 /*2de0*/,
    8 /*2de1*/,  8 /*2de2*/,  9 /*2de3*/,  8 /*2de4*/,  9 /*2de5*/,
    9 /*2de6*/,  10 /*2de7*/, 8 /*2de8*/,  9 /*2de9*/,  9 /*2dea*/,
    10 /*2deb*/, 9 /*2dec*/,  10 /*2ded*/, 10 /*2dee*/, 11 /*2def*/,
    8 /*2df0*/,  9 /*2df1*/,  9 /*2df2*/,  10 /*2df3*/, 9 /*2df4*/,
    10 /*2df5*/, 10 /*2df6*/, 11 /*2df7*/, 9 /*2df8*/,  10 /*2df9*/,
    10 /*2dfa*/, 11 /*2dfb*/, 10 /*2dfc*/, 11 /*2dfd*/, 11 /*2dfe*/,
    12 /*2dff*/, 4 /*2e00*/,  5 /*2e01*/,  5 /*2e02*/,  6 /*2e03*/,
    5 /*2e04*/,  6 /*2e05*/,  6 /*2e06*/,  7 /*2e07*/,  5 /*2e08*/,
    6 /*2e09*/,  6 /*2e0a*/,  7 /*2e0b*/,  6 /*2e0c*/,  7 /*2e0d*/,
    7 /*2e0e*/,  8 /*2e0f*/,  5 /*2e10*/,  6 /*2e11*/,  6 /*2e12*/,
    7 /*2e13*/,  6 /*2e14*/,  7 /*2e15*/,  7 /*2e16*/,  8 /*2e17*/,
    6 /*2e18*/,  7 /*2e19*/,  7 /*2e1a*/,  8 /*2e1b*/,  7 /*2e1c*/,
    8 /*2e1d*/,  8 /*2e1e*/,  9 /*2e1f*/,  5 /*2e20*/,  6 /*2e21*/,
    6 /*2e22*/,  7 /*2e23*/,  6 /*2e24*/,  7 /*2e25*/,  7 /*2e26*/,
    8 /*2e27*/,  6 /*2e28*/,  7 /*2e29*/,  7 /*2e2a*/,  8 /*2e2b*/,
    7 /*2e2c*/,  8 /*2e2d*/,  8 /*2e2e*/,  9 /*2e2f*/,  6 /*2e30*/,
    7 /*2e31*/,  7 /*2e32*/,  8 /*2e33*/,  7 /*2e34*/,  8 /*2e35*/,
    8 /*2e36*/,  9 /*2e37*/,  7 /*2e38*/,  8 /*2e39*/,  8 /*2e3a*/,
    9 /*2e3b*/,  8 /*2e3c*/,  9 /*2e3d*/,  9 /*2e3e*/,  10 /*2e3f*/,
    5 /*2e40*/,  6 /*2e41*/,  6 /*2e42*/,  7 /*2e43*/,  6 /*2e44*/,
    7 /*2e45*/,  7 /*2e46*/,  8 /*2e47*/,  6 /*2e48*/,  7 /*2e49*/,
    7 /*2e4a*/,  8 /*2e4b*/,  7 /*2e4c*/,  8 /*2e4d*/,  8 /*2e4e*/,
    9 /*2e4f*/,  6 /*2e50*/,  7 /*2e51*/,  7 /*2e52*/,  8 /*2e53*/,
    7 /*2e54*/,  8 /*2e55*/,  8 /*2e56*/,  9 /*2e57*/,  7 /*2e58*/,
    8 /*2e59*/,  8 /*2e5a*/,  9 /*2e5b*/,  8 /*2e5c*/,  9 /*2e5d*/,
    9 /*2e5e*/,  10 /*2e5f*/, 6 /*2e60*/,  7 /*2e61*/,  7 /*2e62*/,
    8 /*2e63*/,  7 /*2e64*/,  8 /*2e65*/,  8 /*2e66*/,  9 /*2e67*/,
    7 /*2e68*/,  8 /*2e69*/,  8 /*2e6a*/,  9 /*2e6b*/,  8 /*2e6c*/,
    9 /*2e6d*/,  9 /*2e6e*/,  10 /*2e6f*/, 7 /*2e70*/,  8 /*2e71*/,
    8 /*2e72*/,  9 /*2e73*/,  8 /*2e74*/,  9 /*2e75*/,  9 /*2e76*/,
    10 /*2e77*/, 8 /*2e78*/,  9 /*2e79*/,  9 /*2e7a*/,  10 /*2e7b*/,
    9 /*2e7c*/,  10 /*2e7d*/, 10 /*2e7e*/, 11 /*2e7f*/, 5 /*2e80*/,
    6 /*2e81*/,  6 /*2e82*/,  7 /*2e83*/,  6 /*2e84*/,  7 /*2e85*/,
    7 /*2e86*/,  8 /*2e87*/,  6 /*2e88*/,  7 /*2e89*/,  7 /*2e8a*/,
    8 /*2e8b*/,  7 /*2e8c*/,  8 /*2e8d*/,  8 /*2e8e*/,  9 /*2e8f*/,
    6 /*2e90*/,  7 /*2e91*/,  7 /*2e92*/,  8 /*2e93*/,  7 /*2e94*/,
    8 /*2e95*/,  8 /*2e96*/,  9 /*2e97*/,  7 /*2e98*/,  8 /*2e99*/,
    8 /*2e9a*/,  9 /*2e9b*/,  8 /*2e9c*/,  9 /*2e9d*/,  9 /*2e9e*/,
    10 /*2e9f*/, 6 /*2ea0*/,  7 /*2ea1*/,  7 /*2ea2*/,  8 /*2ea3*/,
    7 /*2ea4*/,  8 /*2ea5*/,  8 /*2ea6*/,  9 /*2ea7*/,  7 /*2ea8*/,
    8 /*2ea9*/,  8 /*2eaa*/,  9 /*2eab*/,  8 /*2eac*/,  9 /*2ead*/,
    9 /*2eae*/,  10 /*2eaf*/, 7 /*2eb0*/,  8 /*2eb1*/,  8 /*2eb2*/,
    9 /*2eb3*/,  8 /*2eb4*/,  9 /*2eb5*/,  9 /*2eb6*/,  10 /*2eb7*/,
    8 /*2eb8*/,  9 /*2eb9*/,  9 /*2eba*/,  10 /*2ebb*/, 9 /*2ebc*/,
    10 /*2ebd*/, 10 /*2ebe*/, 11 /*2ebf*/, 6 /*2ec0*/,  7 /*2ec1*/,
    7 /*2ec2*/,  8 /*2ec3*/,  7 /*2ec4*/,  8 /*2ec5*/,  8 /*2ec6*/,
    9 /*2ec7*/,  7 /*2ec8*/,  8 /*2ec9*/,  8 /*2eca*/,  9 /*2ecb*/,
    8 /*2ecc*/,  9 /*2ecd*/,  9 /*2ece*/,  10 /*2ecf*/, 7 /*2ed0*/,
    8 /*2ed1*/,  8 /*2ed2*/,  9 /*2ed3*/,  8 /*2ed4*/,  9 /*2ed5*/,
    9 /*2ed6*/,  10 /*2ed7*/, 8 /*2ed8*/,  9 /*2ed9*/,  9 /*2eda*/,
    10 /*2edb*/, 9 /*2edc*/,  10 /*2edd*/, 10 /*2ede*/, 11 /*2edf*/,
    7 /*2ee0*/,  8 /*2ee1*/,  8 /*2ee2*/,  9 /*2ee3*/,  8 /*2ee4*/,
    9 /*2ee5*/,  9 /*2ee6*/,  10 /*2ee7*/, 8 /*2ee8*/,  9 /*2ee9*/,
    9 /*2eea*/,  10 /*2eeb*/, 9 /*2eec*/,  10 /*2eed*/, 10 /*2eee*/,
    11 /*2eef*/, 8 /*2ef0*/,  9 /*2ef1*/,  9 /*2ef2*/,  10 /*2ef3*/,
    9 /*2ef4*/,  10 /*2ef5*/, 10 /*2ef6*/, 11 /*2ef7*/, 9 /*2ef8*/,
    10 /*2ef9*/, 10 /*2efa*/, 11 /*2efb*/, 10 /*2efc*/, 11 /*2efd*/,
    11 /*2efe*/, 12 /*2eff*/, 5 /*2f00*/,  6 /*2f01*/,  6 /*2f02*/,
    7 /*2f03*/,  6 /*2f04*/,  7 /*2f05*/,  7 /*2f06*/,  8 /*2f07*/,
    6 /*2f08*/,  7 /*2f09*/,  7 /*2f0a*/,  8 /*2f0b*/,  7 /*2f0c*/,
    8 /*2f0d*/,  8 /*2f0e*/,  9 /*2f0f*/,  6 /*2f10*/,  7 /*2f11*/,
    7 /*2f12*/,  8 /*2f13*/,  7 /*2f14*/,  8 /*2f15*/,  8 /*2f16*/,
    9 /*2f17*/,  7 /*2f18*/,  8 /*2f19*/,  8 /*2f1a*/,  9 /*2f1b*/,
    8 /*2f1c*/,  9 /*2f1d*/,  9 /*2f1e*/,  10 /*2f1f*/, 6 /*2f20*/,
    7 /*2f21*/,  7 /*2f22*/,  8 /*2f23*/,  7 /*2f24*/,  8 /*2f25*/,
    8 /*2f26*/,  9 /*2f27*/,  7 /*2f28*/,  8 /*2f29*/,  8 /*2f2a*/,
    9 /*2f2b*/,  8 /*2f2c*/,  9 /*2f2d*/,  9 /*2f2e*/,  10 /*2f2f*/,
    7 /*2f30*/,  8 /*2f31*/,  8 /*2f32*/,  9 /*2f33*/,  8 /*2f34*/,
    9 /*2f35*/,  9 /*2f36*/,  10 /*2f37*/, 8 /*2f38*/,  9 /*2f39*/,
    9 /*2f3a*/,  10 /*2f3b*/, 9 /*2f3c*/,  10 /*2f3d*/, 10 /*2f3e*/,
    11 /*2f3f*/, 6 /*2f40*/,  7 /*2f41*/,  7 /*2f42*/,  8 /*2f43*/,
    7 /*2f44*/,  8 /*2f45*/,  8 /*2f46*/,  9 /*2f47*/,  7 /*2f48*/,
    8 /*2f49*/,  8 /*2f4a*/,  9 /*2f4b*/,  8 /*2f4c*/,  9 /*2f4d*/,
    9 /*2f4e*/,  10 /*2f4f*/, 7 /*2f50*/,  8 /*2f51*/,  8 /*2f52*/,
    9 /*2f53*/,  8 /*2f54*/,  9 /*2f55*/,  9 /*2f56*/,  10 /*2f57*/,
    8 /*2f58*/,  9 /*2f59*/,  9 /*2f5a*/,  10 /*2f5b*/, 9 /*2f5c*/,
    10 /*2f5d*/, 10 /*2f5e*/, 11 /*2f5f*/, 7 /*2f60*/,  8 /*2f61*/,
    8 /*2f62*/,  9 /*2f63*/,  8 /*2f64*/,  9 /*2f65*/,  9 /*2f66*/,
    10 /*2f67*/, 8 /*2f68*/,  9 /*2f69*/,  9 /*2f6a*/,  10 /*2f6b*/,
    9 /*2f6c*/,  10 /*2f6d*/, 10 /*2f6e*/, 11 /*2f6f*/, 8 /*2f70*/,
    9 /*2f71*/,  9 /*2f72*/,  10 /*2f73*/, 9 /*2f74*/,  10 /*2f75*/,
    10 /*2f76*/, 11 /*2f77*/, 9 /*2f78*/,  10 /*2f79*/, 10 /*2f7a*/,
    11 /*2f7b*/, 10 /*2f7c*/, 11 /*2f7d*/, 11 /*2f7e*/, 12 /*2f7f*/,
    6 /*2f80*/,  7 /*2f81*/,  7 /*2f82*/,  8 /*2f83*/,  7 /*2f84*/,
    8 /*2f85*/,  8 /*2f86*/,  9 /*2f87*/,  7 /*2f88*/,  8 /*2f89*/,
    8 /*2f8a*/,  9 /*2f8b*/,  8 /*2f8c*/,  9 /*2f8d*/,  9 /*2f8e*/,
    10 /*2f8f*/, 7 /*2f90*/,  8 /*2f91*/,  8 /*2f92*/,  9 /*2f93*/,
    8 /*2f94*/,  9 /*2f95*/,  9 /*2f96*/,  10 /*2f97*/, 8 /*2f98*/,
    9 /*2f99*/,  9 /*2f9a*/,  10 /*2f9b*/, 9 /*2f9c*/,  10 /*2f9d*/,
    10 /*2f9e*/, 11 /*2f9f*/, 7 /*2fa0*/,  8 /*2fa1*/,  8 /*2fa2*/,
    9 /*2fa3*/,  8 /*2fa4*/,  9 /*2fa5*/,  9 /*2fa6*/,  10 /*2fa7*/,
    8 /*2fa8*/,  9 /*2fa9*/,  9 /*2faa*/,  10 /*2fab*/, 9 /*2fac*/,
    10 /*2fad*/, 10 /*2fae*/, 11 /*2faf*/, 8 /*2fb0*/,  9 /*2fb1*/,
    9 /*2fb2*/,  10 /*2fb3*/, 9 /*2fb4*/,  10 /*2fb5*/, 10 /*2fb6*/,
    11 /*2fb7*/, 9 /*2fb8*/,  10 /*2fb9*/, 10 /*2fba*/, 11 /*2fbb*/,
    10 /*2fbc*/, 11 /*2fbd*/, 11 /*2fbe*/, 12 /*2fbf*/, 7 /*2fc0*/,
    8 /*2fc1*/,  8 /*2fc2*/,  9 /*2fc3*/,  8 /*2fc4*/,  9 /*2fc5*/,
    9 /*2fc6*/,  10 /*2fc7*/, 8 /*2fc8*/,  9 /*2fc9*/,  9 /*2fca*/,
    10 /*2fcb*/, 9 /*2fcc*/,  10 /*2fcd*/, 10 /*2fce*/, 11 /*2fcf*/,
    8 /*2fd0*/,  9 /*2fd1*/,  9 /*2fd2*/,  10 /*2fd3*/, 9 /*2fd4*/,
    10 /*2fd5*/, 10 /*2fd6*/, 11 /*2fd7*/, 9 /*2fd8*/,  10 /*2fd9*/,
    10 /*2fda*/, 11 /*2fdb*/, 10 /*2fdc*/, 11 /*2fdd*/, 11 /*2fde*/,
    12 /*2fdf*/, 8 /*2fe0*/,  9 /*2fe1*/,  9 /*2fe2*/,  10 /*2fe3*/,
    9 /*2fe4*/,  10 /*2fe5*/, 10 /*2fe6*/, 11 /*2fe7*/, 9 /*2fe8*/,
    10 /*2fe9*/, 10 /*2fea*/, 11 /*2feb*/, 10 /*2fec*/, 11 /*2fed*/,
    11 /*2fee*/, 12 /*2fef*/, 9 /*2ff0*/,  10 /*2ff1*/, 10 /*2ff2*/,
    11 /*2ff3*/, 10 /*2ff4*/, 11 /*2ff5*/, 11 /*2ff6*/, 12 /*2ff7*/,
    10 /*2ff8*/, 11 /*2ff9*/, 11 /*2ffa*/, 12 /*2ffb*/, 11 /*2ffc*/,
    12 /*2ffd*/, 12 /*2ffe*/, 13 /*2fff*/, 2 /*3000*/,  3 /*3001*/,
    3 /*3002*/,  4 /*3003*/,  3 /*3004*/,  4 /*3005*/,  4 /*3006*/,
    5 /*3007*/,  3 /*3008*/,  4 /*3009*/,  4 /*300a*/,  5 /*300b*/,
    4 /*300c*/,  5 /*300d*/,  5 /*300e*/,  6 /*300f*/,  3 /*3010*/,
    4 /*3011*/,  4 /*3012*/,  5 /*3013*/,  4 /*3014*/,  5 /*3015*/,
    5 /*3016*/,  6 /*3017*/,  4 /*3018*/,  5 /*3019*/,  5 /*301a*/,
    6 /*301b*/,  5 /*301c*/,  6 /*301d*/,  6 /*301e*/,  7 /*301f*/,
    3 /*3020*/,  4 /*3021*/,  4 /*3022*/,  5 /*3023*/,  4 /*3024*/,
    5 /*3025*/,  5 /*3026*/,  6 /*3027*/,  4 /*3028*/,  5 /*3029*/,
    5 /*302a*/,  6 /*302b*/,  5 /*302c*/,  6 /*302d*/,  6 /*302e*/,
    7 /*302f*/,  4 /*3030*/,  5 /*3031*/,  5 /*3032*/,  6 /*3033*/,
    5 /*3034*/,  6 /*3035*/,  6 /*3036*/,  7 /*3037*/,  5 /*3038*/,
    6 /*3039*/,  6 /*303a*/,  7 /*303b*/,  6 /*303c*/,  7 /*303d*/,
    7 /*303e*/,  8 /*303f*/,  3 /*3040*/,  4 /*3041*/,  4 /*3042*/,
    5 /*3043*/,  4 /*3044*/,  5 /*3045*/,  5 /*3046*/,  6 /*3047*/,
    4 /*3048*/,  5 /*3049*/,  5 /*304a*/,  6 /*304b*/,  5 /*304c*/,
    6 /*304d*/,  6 /*304e*/,  7 /*304f*/,  4 /*3050*/,  5 /*3051*/,
    5 /*3052*/,  6 /*3053*/,  5 /*3054*/,  6 /*3055*/,  6 /*3056*/,
    7 /*3057*/,  5 /*3058*/,  6 /*3059*/,  6 /*305a*/,  7 /*305b*/,
    6 /*305c*/,  7 /*305d*/,  7 /*305e*/,  8 /*305f*/,  4 /*3060*/,
    5 /*3061*/,  5 /*3062*/,  6 /*3063*/,  5 /*3064*/,  6 /*3065*/,
    6 /*3066*/,  7 /*3067*/,  5 /*3068*/,  6 /*3069*/,  6 /*306a*/,
    7 /*306b*/,  6 /*306c*/,  7 /*306d*/,  7 /*306e*/,  8 /*306f*/,
    5 /*3070*/,  6 /*3071*/,  6 /*3072*/,  7 /*3073*/,  6 /*3074*/,
    7 /*3075*/,  7 /*3076*/,  8 /*3077*/,  6 /*3078*/,  7 /*3079*/,
    7 /*307a*/,  8 /*307b*/,  7 /*307c*/,  8 /*307d*/,  8 /*307e*/,
    9 /*307f*/,  3 /*3080*/,  4 /*3081*/,  4 /*3082*/,  5 /*3083*/,
    4 /*3084*/,  5 /*3085*/,  5 /*3086*/,  6 /*3087*/,  4 /*3088*/,
    5 /*3089*/,  5 /*308a*/,  6 /*308b*/,  5 /*308c*/,  6 /*308d*/,
    6 /*308e*/,  7 /*308f*/,  4 /*3090*/,  5 /*3091*/,  5 /*3092*/,
    6 /*3093*/,  5 /*3094*/,  6 /*3095*/,  6 /*3096*/,  7 /*3097*/,
    5 /*3098*/,  6 /*3099*/,  6 /*309a*/,  7 /*309b*/,  6 /*309c*/,
    7 /*309d*/,  7 /*309e*/,  8 /*309f*/,  4 /*30a0*/,  5 /*30a1*/,
    5 /*30a2*/,  6 /*30a3*/,  5 /*30a4*/,  6 /*30a5*/,  6 /*30a6*/,
    7 /*30a7*/,  5 /*30a8*/,  6 /*30a9*/,  6 /*30aa*/,  7 /*30ab*/,
    6 /*30ac*/,  7 /*30ad*/,  7 /*30ae*/,  8 /*30af*/,  5 /*30b0*/,
    6 /*30b1*/,  6 /*30b2*/,  7 /*30b3*/,  6 /*30b4*/,  7 /*30b5*/,
    7 /*30b6*/,  8 /*30b7*/,  6 /*30b8*/,  7 /*30b9*/,  7 /*30ba*/,
    8 /*30bb*/,  7 /*30bc*/,  8 /*30bd*/,  8 /*30be*/,  9 /*30bf*/,
    4 /*30c0*/,  5 /*30c1*/,  5 /*30c2*/,  6 /*30c3*/,  5 /*30c4*/,
    6 /*30c5*/,  6 /*30c6*/,  7 /*30c7*/,  5 /*30c8*/,  6 /*30c9*/,
    6 /*30ca*/,  7 /*30cb*/,  6 /*30cc*/,  7 /*30cd*/,  7 /*30ce*/,
    8 /*30cf*/,  5 /*30d0*/,  6 /*30d1*/,  6 /*30d2*/,  7 /*30d3*/,
    6 /*30d4*/,  7 /*30d5*/,  7 /*30d6*/,  8 /*30d7*/,  6 /*30d8*/,
    7 /*30d9*/,  7 /*30da*/,  8 /*30db*/,  7 /*30dc*/,  8 /*30dd*/,
    8 /*30de*/,  9 /*30df*/,  5 /*30e0*/,  6 /*30e1*/,  6 /*30e2*/,
    7 /*30e3*/,  6 /*30e4*/,  7 /*30e5*/,  7 /*30e6*/,  8 /*30e7*/,
    6 /*30e8*/,  7 /*30e9*/,  7 /*30ea*/,  8 /*30eb*/,  7 /*30ec*/,
    8 /*30ed*/,  8 /*30ee*/,  9 /*30ef*/,  6 /*30f0*/,  7 /*30f1*/,
    7 /*30f2*/,  8 /*30f3*/,  7 /*30f4*/,  8 /*30f5*/,  8 /*30f6*/,
    9 /*30f7*/,  7 /*30f8*/,  8 /*30f9*/,  8 /*30fa*/,  9 /*30fb*/,
    8 /*30fc*/,  9 /*30fd*/,  9 /*30fe*/,  10 /*30ff*/, 3 /*3100*/,
    4 /*3101*/,  4 /*3102*/,  5 /*3103*/,  4 /*3104*/,  5 /*3105*/,
    5 /*3106*/,  6 /*3107*/,  4 /*3108*/,  5 /*3109*/,  5 /*310a*/,
    6 /*310b*/,  5 /*310c*/,  6 /*310d*/,  6 /*310e*/,  7 /*310f*/,
    4 /*3110*/,  5 /*3111*/,  5 /*3112*/,  6 /*3113*/,  5 /*3114*/,
    6 /*3115*/,  6 /*3116*/,  7 /*3117*/,  5 /*3118*/,  6 /*3119*/,
    6 /*311a*/,  7 /*311b*/,  6 /*311c*/,  7 /*311d*/,  7 /*311e*/,
    8 /*311f*/,  4 /*3120*/,  5 /*3121*/,  5 /*3122*/,  6 /*3123*/,
    5 /*3124*/,  6 /*3125*/,  6 /*3126*/,  7 /*3127*/,  5 /*3128*/,
    6 /*3129*/,  6 /*312a*/,  7 /*312b*/,  6 /*312c*/,  7 /*312d*/,
    7 /*312e*/,  8 /*312f*/,  5 /*3130*/,  6 /*3131*/,  6 /*3132*/,
    7 /*3133*/,  6 /*3134*/,  7 /*3135*/,  7 /*3136*/,  8 /*3137*/,
    6 /*3138*/,  7 /*3139*/,  7 /*313a*/,  8 /*313b*/,  7 /*313c*/,
    8 /*313d*/,  8 /*313e*/,  9 /*313f*/,  4 /*3140*/,  5 /*3141*/,
    5 /*3142*/,  6 /*3143*/,  5 /*3144*/,  6 /*3145*/,  6 /*3146*/,
    7 /*3147*/,  5 /*3148*/,  6 /*3149*/,  6 /*314a*/,  7 /*314b*/,
    6 /*314c*/,  7 /*314d*/,  7 /*314e*/,  8 /*314f*/,  5 /*3150*/,
    6 /*3151*/,  6 /*3152*/,  7 /*3153*/,  6 /*3154*/,  7 /*3155*/,
    7 /*3156*/,  8 /*3157*/,  6 /*3158*/,  7 /*3159*/,  7 /*315a*/,
    8 /*315b*/,  7 /*315c*/,  8 /*315d*/,  8 /*315e*/,  9 /*315f*/,
    5 /*3160*/,  6 /*3161*/,  6 /*3162*/,  7 /*3163*/,  6 /*3164*/,
    7 /*3165*/,  7 /*3166*/,  8 /*3167*/,  6 /*3168*/,  7 /*3169*/,
    7 /*316a*/,  8 /*316b*/,  7 /*316c*/,  8 /*316d*/,  8 /*316e*/,
    9 /*316f*/,  6 /*3170*/,  7 /*3171*/,  7 /*3172*/,  8 /*3173*/,
    7 /*3174*/,  8 /*3175*/,  8 /*3176*/,  9 /*3177*/,  7 /*3178*/,
    8 /*3179*/,  8 /*317a*/,  9 /*317b*/,  8 /*317c*/,  9 /*317d*/,
    9 /*317e*/,  10 /*317f*/, 4 /*3180*/,  5 /*3181*/,  5 /*3182*/,
    6 /*3183*/,  5 /*3184*/,  6 /*3185*/,  6 /*3186*/,  7 /*3187*/,
    5 /*3188*/,  6 /*3189*/,  6 /*318a*/,  7 /*318b*/,  6 /*318c*/,
    7 /*318d*/,  7 /*318e*/,  8 /*318f*/,  5 /*3190*/,  6 /*3191*/,
    6 /*3192*/,  7 /*3193*/,  6 /*3194*/,  7 /*3195*/,  7 /*3196*/,
    8 /*3197*/,  6 /*3198*/,  7 /*3199*/,  7 /*319a*/,  8 /*319b*/,
    7 /*319c*/,  8 /*319d*/,  8 /*319e*/,  9 /*319f*/,  5 /*31a0*/,
    6 /*31a1*/,  6 /*31a2*/,  7 /*31a3*/,  6 /*31a4*/,  7 /*31a5*/,
    7 /*31a6*/,  8 /*31a7*/,  6 /*31a8*/,  7 /*31a9*/,  7 /*31aa*/,
    8 /*31ab*/,  7 /*31ac*/,  8 /*31ad*/,  8 /*31ae*/,  9 /*31af*/,
    6 /*31b0*/,  7 /*31b1*/,  7 /*31b2*/,  8 /*31b3*/,  7 /*31b4*/,
    8 /*31b5*/,  8 /*31b6*/,  9 /*31b7*/,  7 /*31b8*/,  8 /*31b9*/,
    8 /*31ba*/,  9 /*31bb*/,  8 /*31bc*/,  9 /*31bd*/,  9 /*31be*/,
    10 /*31bf*/, 5 /*31c0*/,  6 /*31c1*/,  6 /*31c2*/,  7 /*31c3*/,
    6 /*31c4*/,  7 /*31c5*/,  7 /*31c6*/,  8 /*31c7*/,  6 /*31c8*/,
    7 /*31c9*/,  7 /*31ca*/,  8 /*31cb*/,  7 /*31cc*/,  8 /*31cd*/,
    8 /*31ce*/,  9 /*31cf*/,  6 /*31d0*/,  7 /*31d1*/,  7 /*31d2*/,
    8 /*31d3*/,  7 /*31d4*/,  8 /*31d5*/,  8 /*31d6*/,  9 /*31d7*/,
    7 /*31d8*/,  8 /*31d9*/,  8 /*31da*/,  9 /*31db*/,  8 /*31dc*/,
    9 /*31dd*/,  9 /*31de*/,  10 /*31df*/, 6 /*31e0*/,  7 /*31e1*/,
    7 /*31e2*/,  8 /*31e3*/,  7 /*31e4*/,  8 /*31e5*/,  8 /*31e6*/,
    9 /*31e7*/,  7 /*31e8*/,  8 /*31e9*/,  8 /*31ea*/,  9 /*31eb*/,
    8 /*31ec*/,  9 /*31ed*/,  9 /*31ee*/,  10 /*31ef*/, 7 /*31f0*/,
    8 /*31f1*/,  8 /*31f2*/,  9 /*31f3*/,  8 /*31f4*/,  9 /*31f5*/,
    9 /*31f6*/,  10 /*31f7*/, 8 /*31f8*/,  9 /*31f9*/,  9 /*31fa*/,
    10 /*31fb*/, 9 /*31fc*/,  10 /*31fd*/, 10 /*31fe*/, 11 /*31ff*/,
    3 /*3200*/,  4 /*3201*/,  4 /*3202*/,  5 /*3203*/,  4 /*3204*/,
    5 /*3205*/,  5 /*3206*/,  6 /*3207*/,  4 /*3208*/,  5 /*3209*/,
    5 /*320a*/,  6 /*320b*/,  5 /*320c*/,  6 /*320d*/,  6 /*320e*/,
    7 /*320f*/,  4 /*3210*/,  5 /*3211*/,  5 /*3212*/,  6 /*3213*/,
    5 /*3214*/,  6 /*3215*/,  6 /*3216*/,  7 /*3217*/,  5 /*3218*/,
    6 /*3219*/,  6 /*321a*/,  7 /*321b*/,  6 /*321c*/,  7 /*321d*/,
    7 /*321e*/,  8 /*321f*/,  4 /*3220*/,  5 /*3221*/,  5 /*3222*/,
    6 /*3223*/,  5 /*3224*/,  6 /*3225*/,  6 /*3226*/,  7 /*3227*/,
    5 /*3228*/,  6 /*3229*/,  6 /*322a*/,  7 /*322b*/,  6 /*322c*/,
    7 /*322d*/,  7 /*322e*/,  8 /*322f*/,  5 /*3230*/,  6 /*3231*/,
    6 /*3232*/,  7 /*3233*/,  6 /*3234*/,  7 /*3235*/,  7 /*3236*/,
    8 /*3237*/,  6 /*3238*/,  7 /*3239*/,  7 /*323a*/,  8 /*323b*/,
    7 /*323c*/,  8 /*323d*/,  8 /*323e*/,  9 /*323f*/,  4 /*3240*/,
    5 /*3241*/,  5 /*3242*/,  6 /*3243*/,  5 /*3244*/,  6 /*3245*/,
    6 /*3246*/,  7 /*3247*/,  5 /*3248*/,  6 /*3249*/,  6 /*324a*/,
    7 /*324b*/,  6 /*324c*/,  7 /*324d*/,  7 /*324e*/,  8 /*324f*/,
    5 /*3250*/,  6 /*3251*/,  6 /*3252*/,  7 /*3253*/,  6 /*3254*/,
    7 /*3255*/,  7 /*3256*/,  8 /*3257*/,  6 /*3258*/,  7 /*3259*/,
    7 /*325a*/,  8 /*325b*/,  7 /*325c*/,  8 /*325d*/,  8 /*325e*/,
    9 /*325f*/,  5 /*3260*/,  6 /*3261*/,  6 /*3262*/,  7 /*3263*/,
    6 /*3264*/,  7 /*3265*/,  7 /*3266*/,  8 /*3267*/,  6 /*3268*/,
    7 /*3269*/,  7 /*326a*/,  8 /*326b*/,  7 /*326c*/,  8 /*326d*/,
    8 /*326e*/,  9 /*326f*/,  6 /*3270*/,  7 /*3271*/,  7 /*3272*/,
    8 /*3273*/,  7 /*3274*/,  8 /*3275*/,  8 /*3276*/,  9 /*3277*/,
    7 /*3278*/,  8 /*3279*/,  8 /*327a*/,  9 /*327b*/,  8 /*327c*/,
    9 /*327d*/,  9 /*327e*/,  10 /*327f*/, 4 /*3280*/,  5 /*3281*/,
    5 /*3282*/,  6 /*3283*/,  5 /*3284*/,  6 /*3285*/,  6 /*3286*/,
    7 /*3287*/,  5 /*3288*/,  6 /*3289*/,  6 /*328a*/,  7 /*328b*/,
    6 /*328c*/,  7 /*328d*/,  7 /*328e*/,  8 /*328f*/,  5 /*3290*/,
    6 /*3291*/,  6 /*3292*/,  7 /*3293*/,  6 /*3294*/,  7 /*3295*/,
    7 /*3296*/,  8 /*3297*/,  6 /*3298*/,  7 /*3299*/,  7 /*329a*/,
    8 /*329b*/,  7 /*329c*/,  8 /*329d*/,  8 /*329e*/,  9 /*329f*/,
    5 /*32a0*/,  6 /*32a1*/,  6 /*32a2*/,  7 /*32a3*/,  6 /*32a4*/,
    7 /*32a5*/,  7 /*32a6*/,  8 /*32a7*/,  6 /*32a8*/,  7 /*32a9*/,
    7 /*32aa*/,  8 /*32ab*/,  7 /*32ac*/,  8 /*32ad*/,  8 /*32ae*/,
    9 /*32af*/,  6 /*32b0*/,  7 /*32b1*/,  7 /*32b2*/,  8 /*32b3*/,
    7 /*32b4*/,  8 /*32b5*/,  8 /*32b6*/,  9 /*32b7*/,  7 /*32b8*/,
    8 /*32b9*/,  8 /*32ba*/,  9 /*32bb*/,  8 /*32bc*/,  9 /*32bd*/,
    9 /*32be*/,  10 /*32bf*/, 5 /*32c0*/,  6 /*32c1*/,  6 /*32c2*/,
    7 /*32c3*/,  6 /*32c4*/,  7 /*32c5*/,  7 /*32c6*/,  8 /*32c7*/,
    6 /*32c8*/,  7 /*32c9*/,  7 /*32ca*/,  8 /*32cb*/,  7 /*32cc*/,
    8 /*32cd*/,  8 /*32ce*/,  9 /*32cf*/,  6 /*32d0*/,  7 /*32d1*/,
    7 /*32d2*/,  8 /*32d3*/,  7 /*32d4*/,  8 /*32d5*/,  8 /*32d6*/,
    9 /*32d7*/,  7 /*32d8*/,  8 /*32d9*/,  8 /*32da*/,  9 /*32db*/,
    8 /*32dc*/,  9 /*32dd*/,  9 /*32de*/,  10 /*32df*/, 6 /*32e0*/,
    7 /*32e1*/,  7 /*32e2*/,  8 /*32e3*/,  7 /*32e4*/,  8 /*32e5*/,
    8 /*32e6*/,  9 /*32e7*/,  7 /*32e8*/,  8 /*32e9*/,  8 /*32ea*/,
    9 /*32eb*/,  8 /*32ec*/,  9 /*32ed*/,  9 /*32ee*/,  10 /*32ef*/,
    7 /*32f0*/,  8 /*32f1*/,  8 /*32f2*/,  9 /*32f3*/,  8 /*32f4*/,
    9 /*32f5*/,  9 /*32f6*/,  10 /*32f7*/, 8 /*32f8*/,  9 /*32f9*/,
    9 /*32fa*/,  10 /*32fb*/, 9 /*32fc*/,  10 /*32fd*/, 10 /*32fe*/,
    11 /*32ff*/, 4 /*3300*/,  5 /*3301*/,  5 /*3302*/,  6 /*3303*/,
    5 /*3304*/,  6 /*3305*/,  6 /*3306*/,  7 /*3307*/,  5 /*3308*/,
    6 /*3309*/,  6 /*330a*/,  7 /*330b*/,  6 /*330c*/,  7 /*330d*/,
    7 /*330e*/,  8 /*330f*/,  5 /*3310*/,  6 /*3311*/,  6 /*3312*/,
    7 /*3313*/,  6 /*3314*/,  7 /*3315*/,  7 /*3316*/,  8 /*3317*/,
    6 /*3318*/,  7 /*3319*/,  7 /*331a*/,  8 /*331b*/,  7 /*331c*/,
    8 /*331d*/,  8 /*331e*/,  9 /*331f*/,  5 /*3320*/,  6 /*3321*/,
    6 /*3322*/,  7 /*3323*/,  6 /*3324*/,  7 /*3325*/,  7 /*3326*/,
    8 /*3327*/,  6 /*3328*/,  7 /*3329*/,  7 /*332a*/,  8 /*332b*/,
    7 /*332c*/,  8 /*332d*/,  8 /*332e*/,  9 /*332f*/,  6 /*3330*/,
    7 /*3331*/,  7 /*3332*/,  8 /*3333*/,  7 /*3334*/,  8 /*3335*/,
    8 /*3336*/,  9 /*3337*/,  7 /*3338*/,  8 /*3339*/,  8 /*333a*/,
    9 /*333b*/,  8 /*333c*/,  9 /*333d*/,  9 /*333e*/,  10 /*333f*/,
    5 /*3340*/,  6 /*3341*/,  6 /*3342*/,  7 /*3343*/,  6 /*3344*/,
    7 /*3345*/,  7 /*3346*/,  8 /*3347*/,  6 /*3348*/,  7 /*3349*/,
    7 /*334a*/,  8 /*334b*/,  7 /*334c*/,  8 /*334d*/,  8 /*334e*/,
    9 /*334f*/,  6 /*3350*/,  7 /*3351*/,  7 /*3352*/,  8 /*3353*/,
    7 /*3354*/,  8 /*3355*/,  8 /*3356*/,  9 /*3357*/,  7 /*3358*/,
    8 /*3359*/,  8 /*335a*/,  9 /*335b*/,  8 /*335c*/,  9 /*335d*/,
    9 /*335e*/,  10 /*335f*/, 6 /*3360*/,  7 /*3361*/,  7 /*3362*/,
    8 /*3363*/,  7 /*3364*/,  8 /*3365*/,  8 /*3366*/,  9 /*3367*/,
    7 /*3368*/,  8 /*3369*/,  8 /*336a*/,  9 /*336b*/,  8 /*336c*/,
    9 /*336d*/,  9 /*336e*/,  10 /*336f*/, 7 /*3370*/,  8 /*3371*/,
    8 /*3372*/,  9 /*3373*/,  8 /*3374*/,  9 /*3375*/,  9 /*3376*/,
    10 /*3377*/, 8 /*3378*/,  9 /*3379*/,  9 /*337a*/,  10 /*337b*/,
    9 /*337c*/,  10 /*337d*/, 10 /*337e*/, 11 /*337f*/, 5 /*3380*/,
    6 /*3381*/,  6 /*3382*/,  7 /*3383*/,  6 /*3384*/,  7 /*3385*/,
    7 /*3386*/,  8 /*3387*/,  6 /*3388*/,  7 /*3389*/,  7 /*338a*/,
    8 /*338b*/,  7 /*338c*/,  8 /*338d*/,  8 /*338e*/,  9 /*338f*/,
    6 /*3390*/,  7 /*3391*/,  7 /*3392*/,  8 /*3393*/,  7 /*3394*/,
    8 /*3395*/,  8 /*3396*/,  9 /*3397*/,  7 /*3398*/,  8 /*3399*/,
    8 /*339a*/,  9 /*339b*/,  8 /*339c*/,  9 /*339d*/,  9 /*339e*/,
    10 /*339f*/, 6 /*33a0*/,  7 /*33a1*/,  7 /*33a2*/,  8 /*33a3*/,
    7 /*33a4*/,  8 /*33a5*/,  8 /*33a6*/,  9 /*33a7*/,  7 /*33a8*/,
    8 /*33a9*/,  8 /*33aa*/,  9 /*33ab*/,  8 /*33ac*/,  9 /*33ad*/,
    9 /*33ae*/,  10 /*33af*/, 7 /*33b0*/,  8 /*33b1*/,  8 /*33b2*/,
    9 /*33b3*/,  8 /*33b4*/,  9 /*33b5*/,  9 /*33b6*/,  10 /*33b7*/,
    8 /*33b8*/,  9 /*33b9*/,  9 /*33ba*/,  10 /*33bb*/, 9 /*33bc*/,
    10 /*33bd*/, 10 /*33be*/, 11 /*33bf*/, 6 /*33c0*/,  7 /*33c1*/,
    7 /*33c2*/,  8 /*33c3*/,  7 /*33c4*/,  8 /*33c5*/,  8 /*33c6*/,
    9 /*33c7*/,  7 /*33c8*/,  8 /*33c9*/,  8 /*33ca*/,  9 /*33cb*/,
    8 /*33cc*/,  9 /*33cd*/,  9 /*33ce*/,  10 /*33cf*/, 7 /*33d0*/,
    8 /*33d1*/,  8 /*33d2*/,  9 /*33d3*/,  8 /*33d4*/,  9 /*33d5*/,
    9 /*33d6*/,  10 /*33d7*/, 8 /*33d8*/,  9 /*33d9*/,  9 /*33da*/,
    10 /*33db*/, 9 /*33dc*/,  10 /*33dd*/, 10 /*33de*/, 11 /*33df*/,
    7 /*33e0*/,  8 /*33e1*/,  8 /*33e2*/,  9 /*33e3*/,  8 /*33e4*/,
    9 /*33e5*/,  9 /*33e6*/,  10 /*33e7*/, 8 /*33e8*/,  9 /*33e9*/,
    9 /*33ea*/,  10 /*33eb*/, 9 /*33ec*/,  10 /*33ed*/, 10 /*33ee*/,
    11 /*33ef*/, 8 /*33f0*/,  9 /*33f1*/,  9 /*33f2*/,  10 /*33f3*/,
    9 /*33f4*/,  10 /*33f5*/, 10 /*33f6*/, 11 /*33f7*/, 9 /*33f8*/,
    10 /*33f9*/, 10 /*33fa*/, 11 /*33fb*/, 10 /*33fc*/, 11 /*33fd*/,
    11 /*33fe*/, 12 /*33ff*/, 3 /*3400*/,  4 /*3401*/,  4 /*3402*/,
    5 /*3403*/,  4 /*3404*/,  5 /*3405*/,  5 /*3406*/,  6 /*3407*/,
    4 /*3408*/,  5 /*3409*/,  5 /*340a*/,  6 /*340b*/,  5 /*340c*/,
    6 /*340d*/,  6 /*340e*/,  7 /*340f*/,  4 /*3410*/,  5 /*3411*/,
    5 /*3412*/,  6 /*3413*/,  5 /*3414*/,  6 /*3415*/,  6 /*3416*/,
    7 /*3417*/,  5 /*3418*/,  6 /*3419*/,  6 /*341a*/,  7 /*341b*/,
    6 /*341c*/,  7 /*341d*/,  7 /*341e*/,  8 /*341f*/,  4 /*3420*/,
    5 /*3421*/,  5 /*3422*/,  6 /*3423*/,  5 /*3424*/,  6 /*3425*/,
    6 /*3426*/,  7 /*3427*/,  5 /*3428*/,  6 /*3429*/,  6 /*342a*/,
    7 /*342b*/,  6 /*342c*/,  7 /*342d*/,  7 /*342e*/,  8 /*342f*/,
    5 /*3430*/,  6 /*3431*/,  6 /*3432*/,  7 /*3433*/,  6 /*3434*/,
    7 /*3435*/,  7 /*3436*/,  8 /*3437*/,  6 /*3438*/,  7 /*3439*/,
    7 /*343a*/,  8 /*343b*/,  7 /*343c*/,  8 /*343d*/,  8 /*343e*/,
    9 /*343f*/,  4 /*3440*/,  5 /*3441*/,  5 /*3442*/,  6 /*3443*/,
    5 /*3444*/,  6 /*3445*/,  6 /*3446*/,  7 /*3447*/,  5 /*3448*/,
    6 /*3449*/,  6 /*344a*/,  7 /*344b*/,  6 /*344c*/,  7 /*344d*/,
    7 /*344e*/,  8 /*344f*/,  5 /*3450*/,  6 /*3451*/,  6 /*3452*/,
    7 /*3453*/,  6 /*3454*/,  7 /*3455*/,  7 /*3456*/,  8 /*3457*/,
    6 /*3458*/,  7 /*3459*/,  7 /*345a*/,  8 /*345b*/,  7 /*345c*/,
    8 /*345d*/,  8 /*345e*/,  9 /*345f*/,  5 /*3460*/,  6 /*3461*/,
    6 /*3462*/,  7 /*3463*/,  6 /*3464*/,  7 /*3465*/,  7 /*3466*/,
    8 /*3467*/,  6 /*3468*/,  7 /*3469*/,  7 /*346a*/,  8 /*346b*/,
    7 /*346c*/,  8 /*346d*/,  8 /*346e*/,  9 /*346f*/,  6 /*3470*/,
    7 /*3471*/,  7 /*3472*/,  8 /*3473*/,  7 /*3474*/,  8 /*3475*/,
    8 /*3476*/,  9 /*3477*/,  7 /*3478*/,  8 /*3479*/,  8 /*347a*/,
    9 /*347b*/,  8 /*347c*/,  9 /*347d*/,  9 /*347e*/,  10 /*347f*/,
    4 /*3480*/,  5 /*3481*/,  5 /*3482*/,  6 /*3483*/,  5 /*3484*/,
    6 /*3485*/,  6 /*3486*/,  7 /*3487*/,  5 /*3488*/,  6 /*3489*/,
    6 /*348a*/,  7 /*348b*/,  6 /*348c*/,  7 /*348d*/,  7 /*348e*/,
    8 /*348f*/,  5 /*3490*/,  6 /*3491*/,  6 /*3492*/,  7 /*3493*/,
    6 /*3494*/,  7 /*3495*/,  7 /*3496*/,  8 /*3497*/,  6 /*3498*/,
    7 /*3499*/,  7 /*349a*/,  8 /*349b*/,  7 /*349c*/,  8 /*349d*/,
    8 /*349e*/,  9 /*349f*/,  5 /*34a0*/,  6 /*34a1*/,  6 /*34a2*/,
    7 /*34a3*/,  6 /*34a4*/,  7 /*34a5*/,  7 /*34a6*/,  8 /*34a7*/,
    6 /*34a8*/,  7 /*34a9*/,  7 /*34aa*/,  8 /*34ab*/,  7 /*34ac*/,
    8 /*34ad*/,  8 /*34ae*/,  9 /*34af*/,  6 /*34b0*/,  7 /*34b1*/,
    7 /*34b2*/,  8 /*34b3*/,  7 /*34b4*/,  8 /*34b5*/,  8 /*34b6*/,
    9 /*34b7*/,  7 /*34b8*/,  8 /*34b9*/,  8 /*34ba*/,  9 /*34bb*/,
    8 /*34bc*/,  9 /*34bd*/,  9 /*34be*/,  10 /*34bf*/, 5 /*34c0*/,
    6 /*34c1*/,  6 /*34c2*/,  7 /*34c3*/,  6 /*34c4*/,  7 /*34c5*/,
    7 /*34c6*/,  8 /*34c7*/,  6 /*34c8*/,  7 /*34c9*/,  7 /*34ca*/,
    8 /*34cb*/,  7 /*34cc*/,  8 /*34cd*/,  8 /*34ce*/,  9 /*34cf*/,
    6 /*34d0*/,  7 /*34d1*/,  7 /*34d2*/,  8 /*34d3*/,  7 /*34d4*/,
    8 /*34d5*/,  8 /*34d6*/,  9 /*34d7*/,  7 /*34d8*/,  8 /*34d9*/,
    8 /*34da*/,  9 /*34db*/,  8 /*34dc*/,  9 /*34dd*/,  9 /*34de*/,
    10 /*34df*/, 6 /*34e0*/,  7 /*34e1*/,  7 /*34e2*/,  8 /*34e3*/,
    7 /*34e4*/,  8 /*34e5*/,  8 /*34e6*/,  9 /*34e7*/,  7 /*34e8*/,
    8 /*34e9*/,  8 /*34ea*/,  9 /*34eb*/,  8 /*34ec*/,  9 /*34ed*/,
    9 /*34ee*/,  10 /*34ef*/, 7 /*34f0*/,  8 /*34f1*/,  8 /*34f2*/,
    9 /*34f3*/,  8 /*34f4*/,  9 /*34f5*/,  9 /*34f6*/,  10 /*34f7*/,
    8 /*34f8*/,  9 /*34f9*/,  9 /*34fa*/,  10 /*34fb*/, 9 /*34fc*/,
    10 /*34fd*/, 10 /*34fe*/, 11 /*34ff*/, 4 /*3500*/,  5 /*3501*/,
    5 /*3502*/,  6 /*3503*/,  5 /*3504*/,  6 /*3505*/,  6 /*3506*/,
    7 /*3507*/,  5 /*3508*/,  6 /*3509*/,  6 /*350a*/,  7 /*350b*/,
    6 /*350c*/,  7 /*350d*/,  7 /*350e*/,  8 /*350f*/,  5 /*3510*/,
    6 /*3511*/,  6 /*3512*/,  7 /*3513*/,  6 /*3514*/,  7 /*3515*/,
    7 /*3516*/,  8 /*3517*/,  6 /*3518*/,  7 /*3519*/,  7 /*351a*/,
    8 /*351b*/,  7 /*351c*/,  8 /*351d*/,  8 /*351e*/,  9 /*351f*/,
    5 /*3520*/,  6 /*3521*/,  6 /*3522*/,  7 /*3523*/,  6 /*3524*/,
    7 /*3525*/,  7 /*3526*/,  8 /*3527*/,  6 /*3528*/,  7 /*3529*/,
    7 /*352a*/,  8 /*352b*/,  7 /*352c*/,  8 /*352d*/,  8 /*352e*/,
    9 /*352f*/,  6 /*3530*/,  7 /*3531*/,  7 /*3532*/,  8 /*3533*/,
    7 /*3534*/,  8 /*3535*/,  8 /*3536*/,  9 /*3537*/,  7 /*3538*/,
    8 /*3539*/,  8 /*353a*/,  9 /*353b*/,  8 /*353c*/,  9 /*353d*/,
    9 /*353e*/,  10 /*353f*/, 5 /*3540*/,  6 /*3541*/,  6 /*3542*/,
    7 /*3543*/,  6 /*3544*/,  7 /*3545*/,  7 /*3546*/,  8 /*3547*/,
    6 /*3548*/,  7 /*3549*/,  7 /*354a*/,  8 /*354b*/,  7 /*354c*/,
    8 /*354d*/,  8 /*354e*/,  9 /*354f*/,  6 /*3550*/,  7 /*3551*/,
    7 /*3552*/,  8 /*3553*/,  7 /*3554*/,  8 /*3555*/,  8 /*3556*/,
    9 /*3557*/,  7 /*3558*/,  8 /*3559*/,  8 /*355a*/,  9 /*355b*/,
    8 /*355c*/,  9 /*355d*/,  9 /*355e*/,  10 /*355f*/, 6 /*3560*/,
    7 /*3561*/,  7 /*3562*/,  8 /*3563*/,  7 /*3564*/,  8 /*3565*/,
    8 /*3566*/,  9 /*3567*/,  7 /*3568*/,  8 /*3569*/,  8 /*356a*/,
    9 /*356b*/,  8 /*356c*/,  9 /*356d*/,  9 /*356e*/,  10 /*356f*/,
    7 /*3570*/,  8 /*3571*/,  8 /*3572*/,  9 /*3573*/,  8 /*3574*/,
    9 /*3575*/,  9 /*3576*/,  10 /*3577*/, 8 /*3578*/,  9 /*3579*/,
    9 /*357a*/,  10 /*357b*/, 9 /*357c*/,  10 /*357d*/, 10 /*357e*/,
    11 /*357f*/, 5 /*3580*/,  6 /*3581*/,  6 /*3582*/,  7 /*3583*/,
    6 /*3584*/,  7 /*3585*/,  7 /*3586*/,  8 /*3587*/,  6 /*3588*/,
    7 /*3589*/,  7 /*358a*/,  8 /*358b*/,  7 /*358c*/,  8 /*358d*/,
    8 /*358e*/,  9 /*358f*/,  6 /*3590*/,  7 /*3591*/,  7 /*3592*/,
    8 /*3593*/,  7 /*3594*/,  8 /*3595*/,  8 /*3596*/,  9 /*3597*/,
    7 /*3598*/,  8 /*3599*/,  8 /*359a*/,  9 /*359b*/,  8 /*359c*/,
    9 /*359d*/,  9 /*359e*/,  10 /*359f*/, 6 /*35a0*/,  7 /*35a1*/,
    7 /*35a2*/,  8 /*35a3*/,  7 /*35a4*/,  8 /*35a5*/,  8 /*35a6*/,
    9 /*35a7*/,  7 /*35a8*/,  8 /*35a9*/,  8 /*35aa*/,  9 /*35ab*/,
    8 /*35ac*/,  9 /*35ad*/,  9 /*35ae*/,  10 /*35af*/, 7 /*35b0*/,
    8 /*35b1*/,  8 /*35b2*/,  9 /*35b3*/,  8 /*35b4*/,  9 /*35b5*/,
    9 /*35b6*/,  10 /*35b7*/, 8 /*35b8*/,  9 /*35b9*/,  9 /*35ba*/,
    10 /*35bb*/, 9 /*35bc*/,  10 /*35bd*/, 10 /*35be*/, 11 /*35bf*/,
    6 /*35c0*/,  7 /*35c1*/,  7 /*35c2*/,  8 /*35c3*/,  7 /*35c4*/,
    8 /*35c5*/,  8 /*35c6*/,  9 /*35c7*/,  7 /*35c8*/,  8 /*35c9*/,
    8 /*35ca*/,  9 /*35cb*/,  8 /*35cc*/,  9 /*35cd*/,  9 /*35ce*/,
    10 /*35cf*/, 7 /*35d0*/,  8 /*35d1*/,  8 /*35d2*/,  9 /*35d3*/,
    8 /*35d4*/,  9 /*35d5*/,  9 /*35d6*/,  10 /*35d7*/, 8 /*35d8*/,
    9 /*35d9*/,  9 /*35da*/,  10 /*35db*/, 9 /*35dc*/,  10 /*35dd*/,
    10 /*35de*/, 11 /*35df*/, 7 /*35e0*/,  8 /*35e1*/,  8 /*35e2*/,
    9 /*35e3*/,  8 /*35e4*/,  9 /*35e5*/,  9 /*35e6*/,  10 /*35e7*/,
    8 /*35e8*/,  9 /*35e9*/,  9 /*35ea*/,  10 /*35eb*/, 9 /*35ec*/,
    10 /*35ed*/, 10 /*35ee*/, 11 /*35ef*/, 8 /*35f0*/,  9 /*35f1*/,
    9 /*35f2*/,  10 /*35f3*/, 9 /*35f4*/,  10 /*35f5*/, 10 /*35f6*/,
    11 /*35f7*/, 9 /*35f8*/,  10 /*35f9*/, 10 /*35fa*/, 11 /*35fb*/,
    10 /*35fc*/, 11 /*35fd*/, 11 /*35fe*/, 12 /*35ff*/, 4 /*3600*/,
    5 /*3601*/,  5 /*3602*/,  6 /*3603*/,  5 /*3604*/,  6 /*3605*/,
    6 /*3606*/,  7 /*3607*/,  5 /*3608*/,  6 /*3609*/,  6 /*360a*/,
    7 /*360b*/,  6 /*360c*/,  7 /*360d*/,  7 /*360e*/,  8 /*360f*/,
    5 /*3610*/,  6 /*3611*/,  6 /*3612*/,  7 /*3613*/,  6 /*3614*/,
    7 /*3615*/,  7 /*3616*/,  8 /*3617*/,  6 /*3618*/,  7 /*3619*/,
    7 /*361a*/,  8 /*361b*/,  7 /*361c*/,  8 /*361d*/,  8 /*361e*/,
    9 /*361f*/,  5 /*3620*/,  6 /*3621*/,  6 /*3622*/,  7 /*3623*/,
    6 /*3624*/,  7 /*3625*/,  7 /*3626*/,  8 /*3627*/,  6 /*3628*/,
    7 /*3629*/,  7 /*362a*/,  8 /*362b*/,  7 /*362c*/,  8 /*362d*/,
    8 /*362e*/,  9 /*362f*/,  6 /*3630*/,  7 /*3631*/,  7 /*3632*/,
    8 /*3633*/,  7 /*3634*/,  8 /*3635*/,  8 /*3636*/,  9 /*3637*/,
    7 /*3638*/,  8 /*3639*/,  8 /*363a*/,  9 /*363b*/,  8 /*363c*/,
    9 /*363d*/,  9 /*363e*/,  10 /*363f*/, 5 /*3640*/,  6 /*3641*/,
    6 /*3642*/,  7 /*3643*/,  6 /*3644*/,  7 /*3645*/,  7 /*3646*/,
    8 /*3647*/,  6 /*3648*/,  7 /*3649*/,  7 /*364a*/,  8 /*364b*/,
    7 /*364c*/,  8 /*364d*/,  8 /*364e*/,  9 /*364f*/,  6 /*3650*/,
    7 /*3651*/,  7 /*3652*/,  8 /*3653*/,  7 /*3654*/,  8 /*3655*/,
    8 /*3656*/,  9 /*3657*/,  7 /*3658*/,  8 /*3659*/,  8 /*365a*/,
    9 /*365b*/,  8 /*365c*/,  9 /*365d*/,  9 /*365e*/,  10 /*365f*/,
    6 /*3660*/,  7 /*3661*/,  7 /*3662*/,  8 /*3663*/,  7 /*3664*/,
    8 /*3665*/,  8 /*3666*/,  9 /*3667*/,  7 /*3668*/,  8 /*3669*/,
    8 /*366a*/,  9 /*366b*/,  8 /*366c*/,  9 /*366d*/,  9 /*366e*/,
    10 /*366f*/, 7 /*3670*/,  8 /*3671*/,  8 /*3672*/,  9 /*3673*/,
    8 /*3674*/,  9 /*3675*/,  9 /*3676*/,  10 /*3677*/, 8 /*3678*/,
    9 /*3679*/,  9 /*367a*/,  10 /*367b*/, 9 /*367c*/,  10 /*367d*/,
    10 /*367e*/, 11 /*367f*/, 5 /*3680*/,  6 /*3681*/,  6 /*3682*/,
    7 /*3683*/,  6 /*3684*/,  7 /*3685*/,  7 /*3686*/,  8 /*3687*/,
    6 /*3688*/,  7 /*3689*/,  7 /*368a*/,  8 /*368b*/,  7 /*368c*/,
    8 /*368d*/,  8 /*368e*/,  9 /*368f*/,  6 /*3690*/,  7 /*3691*/,
    7 /*3692*/,  8 /*3693*/,  7 /*3694*/,  8 /*3695*/,  8 /*3696*/,
    9 /*3697*/,  7 /*3698*/,  8 /*3699*/,  8 /*369a*/,  9 /*369b*/,
    8 /*369c*/,  9 /*369d*/,  9 /*369e*/,  10 /*369f*/, 6 /*36a0*/,
    7 /*36a1*/,  7 /*36a2*/,  8 /*36a3*/,  7 /*36a4*/,  8 /*36a5*/,
    8 /*36a6*/,  9 /*36a7*/,  7 /*36a8*/,  8 /*36a9*/,  8 /*36aa*/,
    9 /*36ab*/,  8 /*36ac*/,  9 /*36ad*/,  9 /*36ae*/,  10 /*36af*/,
    7 /*36b0*/,  8 /*36b1*/,  8 /*36b2*/,  9 /*36b3*/,  8 /*36b4*/,
    9 /*36b5*/,  9 /*36b6*/,  10 /*36b7*/, 8 /*36b8*/,  9 /*36b9*/,
    9 /*36ba*/,  10 /*36bb*/, 9 /*36bc*/,  10 /*36bd*/, 10 /*36be*/,
    11 /*36bf*/, 6 /*36c0*/,  7 /*36c1*/,  7 /*36c2*/,  8 /*36c3*/,
    7 /*36c4*/,  8 /*36c5*/,  8 /*36c6*/,  9 /*36c7*/,  7 /*36c8*/,
    8 /*36c9*/,  8 /*36ca*/,  9 /*36cb*/,  8 /*36cc*/,  9 /*36cd*/,
    9 /*36ce*/,  10 /*36cf*/, 7 /*36d0*/,  8 /*36d1*/,  8 /*36d2*/,
    9 /*36d3*/,  8 /*36d4*/,  9 /*36d5*/,  9 /*36d6*/,  10 /*36d7*/,
    8 /*36d8*/,  9 /*36d9*/,  9 /*36da*/,  10 /*36db*/, 9 /*36dc*/,
    10 /*36dd*/, 10 /*36de*/, 11 /*36df*/, 7 /*36e0*/,  8 /*36e1*/,
    8 /*36e2*/,  9 /*36e3*/,  8 /*36e4*/,  9 /*36e5*/,  9 /*36e6*/,
    10 /*36e7*/, 8 /*36e8*/,  9 /*36e9*/,  9 /*36ea*/,  10 /*36eb*/,
    9 /*36ec*/,  10 /*36ed*/, 10 /*36ee*/, 11 /*36ef*/, 8 /*36f0*/,
    9 /*36f1*/,  9 /*36f2*/,  10 /*36f3*/, 9 /*36f4*/,  10 /*36f5*/,
    10 /*36f6*/, 11 /*36f7*/, 9 /*36f8*/,  10 /*36f9*/, 10 /*36fa*/,
    11 /*36fb*/, 10 /*36fc*/, 11 /*36fd*/, 11 /*36fe*/, 12 /*36ff*/,
    5 /*3700*/,  6 /*3701*/,  6 /*3702*/,  7 /*3703*/,  6 /*3704*/,
    7 /*3705*/,  7 /*3706*/,  8 /*3707*/,  6 /*3708*/,  7 /*3709*/,
    7 /*370a*/,  8 /*370b*/,  7 /*370c*/,  8 /*370d*/,  8 /*370e*/,
    9 /*370f*/,  6 /*3710*/,  7 /*3711*/,  7 /*3712*/,  8 /*3713*/,
    7 /*3714*/,  8 /*3715*/,  8 /*3716*/,  9 /*3717*/,  7 /*3718*/,
    8 /*3719*/,  8 /*371a*/,  9 /*371b*/,  8 /*371c*/,  9 /*371d*/,
    9 /*371e*/,  10 /*371f*/, 6 /*3720*/,  7 /*3721*/,  7 /*3722*/,
    8 /*3723*/,  7 /*3724*/,  8 /*3725*/,  8 /*3726*/,  9 /*3727*/,
    7 /*3728*/,  8 /*3729*/,  8 /*372a*/,  9 /*372b*/,  8 /*372c*/,
    9 /*372d*/,  9 /*372e*/,  10 /*372f*/, 7 /*3730*/,  8 /*3731*/,
    8 /*3732*/,  9 /*3733*/,  8 /*3734*/,  9 /*3735*/,  9 /*3736*/,
    10 /*3737*/, 8 /*3738*/,  9 /*3739*/,  9 /*373a*/,  10 /*373b*/,
    9 /*373c*/,  10 /*373d*/, 10 /*373e*/, 11 /*373f*/, 6 /*3740*/,
    7 /*3741*/,  7 /*3742*/,  8 /*3743*/,  7 /*3744*/,  8 /*3745*/,
    8 /*3746*/,  9 /*3747*/,  7 /*3748*/,  8 /*3749*/,  8 /*374a*/,
    9 /*374b*/,  8 /*374c*/,  9 /*374d*/,  9 /*374e*/,  10 /*374f*/,
    7 /*3750*/,  8 /*3751*/,  8 /*3752*/,  9 /*3753*/,  8 /*3754*/,
    9 /*3755*/,  9 /*3756*/,  10 /*3757*/, 8 /*3758*/,  9 /*3759*/,
    9 /*375a*/,  10 /*375b*/, 9 /*375c*/,  10 /*375d*/, 10 /*375e*/,
    11 /*375f*/, 7 /*3760*/,  8 /*3761*/,  8 /*3762*/,  9 /*3763*/,
    8 /*3764*/,  9 /*3765*/,  9 /*3766*/,  10 /*3767*/, 8 /*3768*/,
    9 /*3769*/,  9 /*376a*/,  10 /*376b*/, 9 /*376c*/,  10 /*376d*/,
    10 /*376e*/, 11 /*376f*/, 8 /*3770*/,  9 /*3771*/,  9 /*3772*/,
    10 /*3773*/, 9 /*3774*/,  10 /*3775*/, 10 /*3776*/, 11 /*3777*/,
    9 /*3778*/,  10 /*3779*/, 10 /*377a*/, 11 /*377b*/, 10 /*377c*/,
    11 /*377d*/, 11 /*377e*/, 12 /*377f*/, 6 /*3780*/,  7 /*3781*/,
    7 /*3782*/,  8 /*3783*/,  7 /*3784*/,  8 /*3785*/,  8 /*3786*/,
    9 /*3787*/,  7 /*3788*/,  8 /*3789*/,  8 /*378a*/,  9 /*378b*/,
    8 /*378c*/,  9 /*378d*/,  9 /*378e*/,  10 /*378f*/, 7 /*3790*/,
    8 /*3791*/,  8 /*3792*/,  9 /*3793*/,  8 /*3794*/,  9 /*3795*/,
    9 /*3796*/,  10 /*3797*/, 8 /*3798*/,  9 /*3799*/,  9 /*379a*/,
    10 /*379b*/, 9 /*379c*/,  10 /*379d*/, 10 /*379e*/, 11 /*379f*/,
    7 /*37a0*/,  8 /*37a1*/,  8 /*37a2*/,  9 /*37a3*/,  8 /*37a4*/,
    9 /*37a5*/,  9 /*37a6*/,  10 /*37a7*/, 8 /*37a8*/,  9 /*37a9*/,
    9 /*37aa*/,  10 /*37ab*/, 9 /*37ac*/,  10 /*37ad*/, 10 /*37ae*/,
    11 /*37af*/, 8 /*37b0*/,  9 /*37b1*/,  9 /*37b2*/,  10 /*37b3*/,
    9 /*37b4*/,  10 /*37b5*/, 10 /*37b6*/, 11 /*37b7*/, 9 /*37b8*/,
    10 /*37b9*/, 10 /*37ba*/, 11 /*37bb*/, 10 /*37bc*/, 11 /*37bd*/,
    11 /*37be*/, 12 /*37bf*/, 7 /*37c0*/,  8 /*37c1*/,  8 /*37c2*/,
    9 /*37c3*/,  8 /*37c4*/,  9 /*37c5*/,  9 /*37c6*/,  10 /*37c7*/,
    8 /*37c8*/,  9 /*37c9*/,  9 /*37ca*/,  10 /*37cb*/, 9 /*37cc*/,
    10 /*37cd*/, 10 /*37ce*/, 11 /*37cf*/, 8 /*37d0*/,  9 /*37d1*/,
    9 /*37d2*/,  10 /*37d3*/, 9 /*37d4*/,  10 /*37d5*/, 10 /*37d6*/,
    11 /*37d7*/, 9 /*37d8*/,  10 /*37d9*/, 10 /*37da*/, 11 /*37db*/,
    10 /*37dc*/, 11 /*37dd*/, 11 /*37de*/, 12 /*37df*/, 8 /*37e0*/,
    9 /*37e1*/,  9 /*37e2*/,  10 /*37e3*/, 9 /*37e4*/,  10 /*37e5*/,
    10 /*37e6*/, 11 /*37e7*/, 9 /*37e8*/,  10 /*37e9*/, 10 /*37ea*/,
    11 /*37eb*/, 10 /*37ec*/, 11 /*37ed*/, 11 /*37ee*/, 12 /*37ef*/,
    9 /*37f0*/,  10 /*37f1*/, 10 /*37f2*/, 11 /*37f3*/, 10 /*37f4*/,
    11 /*37f5*/, 11 /*37f6*/, 12 /*37f7*/, 10 /*37f8*/, 11 /*37f9*/,
    11 /*37fa*/, 12 /*37fb*/, 11 /*37fc*/, 12 /*37fd*/, 12 /*37fe*/,
    13 /*37ff*/, 3 /*3800*/,  4 /*3801*/,  4 /*3802*/,  5 /*3803*/,
    4 /*3804*/,  5 /*3805*/,  5 /*3806*/,  6 /*3807*/,  4 /*3808*/,
    5 /*3809*/,  5 /*380a*/,  6 /*380b*/,  5 /*380c*/,  6 /*380d*/,
    6 /*380e*/,  7 /*380f*/,  4 /*3810*/,  5 /*3811*/,  5 /*3812*/,
    6 /*3813*/,  5 /*3814*/,  6 /*3815*/,  6 /*3816*/,  7 /*3817*/,
    5 /*3818*/,  6 /*3819*/,  6 /*381a*/,  7 /*381b*/,  6 /*381c*/,
    7 /*381d*/,  7 /*381e*/,  8 /*381f*/,  4 /*3820*/,  5 /*3821*/,
    5 /*3822*/,  6 /*3823*/,  5 /*3824*/,  6 /*3825*/,  6 /*3826*/,
    7 /*3827*/,  5 /*3828*/,  6 /*3829*/,  6 /*382a*/,  7 /*382b*/,
    6 /*382c*/,  7 /*382d*/,  7 /*382e*/,  8 /*382f*/,  5 /*3830*/,
    6 /*3831*/,  6 /*3832*/,  7 /*3833*/,  6 /*3834*/,  7 /*3835*/,
    7 /*3836*/,  8 /*3837*/,  6 /*3838*/,  7 /*3839*/,  7 /*383a*/,
    8 /*383b*/,  7 /*383c*/,  8 /*383d*/,  8 /*383e*/,  9 /*383f*/,
    4 /*3840*/,  5 /*3841*/,  5 /*3842*/,  6 /*3843*/,  5 /*3844*/,
    6 /*3845*/,  6 /*3846*/,  7 /*3847*/,  5 /*3848*/,  6 /*3849*/,
    6 /*384a*/,  7 /*384b*/,  6 /*384c*/,  7 /*384d*/,  7 /*384e*/,
    8 /*384f*/,  5 /*3850*/,  6 /*3851*/,  6 /*3852*/,  7 /*3853*/,
    6 /*3854*/,  7 /*3855*/,  7 /*3856*/,  8 /*3857*/,  6 /*3858*/,
    7 /*3859*/,  7 /*385a*/,  8 /*385b*/,  7 /*385c*/,  8 /*385d*/,
    8 /*385e*/,  9 /*385f*/,  5 /*3860*/,  6 /*3861*/,  6 /*3862*/,
    7 /*3863*/,  6 /*3864*/,  7 /*3865*/,  7 /*3866*/,  8 /*3867*/,
    6 /*3868*/,  7 /*3869*/,  7 /*386a*/,  8 /*386b*/,  7 /*386c*/,
    8 /*386d*/,  8 /*386e*/,  9 /*386f*/,  6 /*3870*/,  7 /*3871*/,
    7 /*3872*/,  8 /*3873*/,  7 /*3874*/,  8 /*3875*/,  8 /*3876*/,
    9 /*3877*/,  7 /*3878*/,  8 /*3879*/,  8 /*387a*/,  9 /*387b*/,
    8 /*387c*/,  9 /*387d*/,  9 /*387e*/,  10 /*387f*/, 4 /*3880*/,
    5 /*3881*/,  5 /*3882*/,  6 /*3883*/,  5 /*3884*/,  6 /*3885*/,
    6 /*3886*/,  7 /*3887*/,  5 /*3888*/,  6 /*3889*/,  6 /*388a*/,
    7 /*388b*/,  6 /*388c*/,  7 /*388d*/,  7 /*388e*/,  8 /*388f*/,
    5 /*3890*/,  6 /*3891*/,  6 /*3892*/,  7 /*3893*/,  6 /*3894*/,
    7 /*3895*/,  7 /*3896*/,  8 /*3897*/,  6 /*3898*/,  7 /*3899*/,
    7 /*389a*/,  8 /*389b*/,  7 /*389c*/,  8 /*389d*/,  8 /*389e*/,
    9 /*389f*/,  5 /*38a0*/,  6 /*38a1*/,  6 /*38a2*/,  7 /*38a3*/,
    6 /*38a4*/,  7 /*38a5*/,  7 /*38a6*/,  8 /*38a7*/,  6 /*38a8*/,
    7 /*38a9*/,  7 /*38aa*/,  8 /*38ab*/,  7 /*38ac*/,  8 /*38ad*/,
    8 /*38ae*/,  9 /*38af*/,  6 /*38b0*/,  7 /*38b1*/,  7 /*38b2*/,
    8 /*38b3*/,  7 /*38b4*/,  8 /*38b5*/,  8 /*38b6*/,  9 /*38b7*/,
    7 /*38b8*/,  8 /*38b9*/,  8 /*38ba*/,  9 /*38bb*/,  8 /*38bc*/,
    9 /*38bd*/,  9 /*38be*/,  10 /*38bf*/, 5 /*38c0*/,  6 /*38c1*/,
    6 /*38c2*/,  7 /*38c3*/,  6 /*38c4*/,  7 /*38c5*/,  7 /*38c6*/,
    8 /*38c7*/,  6 /*38c8*/,  7 /*38c9*/,  7 /*38ca*/,  8 /*38cb*/,
    7 /*38cc*/,  8 /*38cd*/,  8 /*38ce*/,  9 /*38cf*/,  6 /*38d0*/,
    7 /*38d1*/,  7 /*38d2*/,  8 /*38d3*/,  7 /*38d4*/,  8 /*38d5*/,
    8 /*38d6*/,  9 /*38d7*/,  7 /*38d8*/,  8 /*38d9*/,  8 /*38da*/,
    9 /*38db*/,  8 /*38dc*/,  9 /*38dd*/,  9 /*38de*/,  10 /*38df*/,
    6 /*38e0*/,  7 /*38e1*/,  7 /*38e2*/,  8 /*38e3*/,  7 /*38e4*/,
    8 /*38e5*/,  8 /*38e6*/,  9 /*38e7*/,  7 /*38e8*/,  8 /*38e9*/,
    8 /*38ea*/,  9 /*38eb*/,  8 /*38ec*/,  9 /*38ed*/,  9 /*38ee*/,
    10 /*38ef*/, 7 /*38f0*/,  8 /*38f1*/,  8 /*38f2*/,  9 /*38f3*/,
    8 /*38f4*/,  9 /*38f5*/,  9 /*38f6*/,  10 /*38f7*/, 8 /*38f8*/,
    9 /*38f9*/,  9 /*38fa*/,  10 /*38fb*/, 9 /*38fc*/,  10 /*38fd*/,
    10 /*38fe*/, 11 /*38ff*/, 4 /*3900*/,  5 /*3901*/,  5 /*3902*/,
    6 /*3903*/,  5 /*3904*/,  6 /*3905*/,  6 /*3906*/,  7 /*3907*/,
    5 /*3908*/,  6 /*3909*/,  6 /*390a*/,  7 /*390b*/,  6 /*390c*/,
    7 /*390d*/,  7 /*390e*/,  8 /*390f*/,  5 /*3910*/,  6 /*3911*/,
    6 /*3912*/,  7 /*3913*/,  6 /*3914*/,  7 /*3915*/,  7 /*3916*/,
    8 /*3917*/,  6 /*3918*/,  7 /*3919*/,  7 /*391a*/,  8 /*391b*/,
    7 /*391c*/,  8 /*391d*/,  8 /*391e*/,  9 /*391f*/,  5 /*3920*/,
    6 /*3921*/,  6 /*3922*/,  7 /*3923*/,  6 /*3924*/,  7 /*3925*/,
    7 /*3926*/,  8 /*3927*/,  6 /*3928*/,  7 /*3929*/,  7 /*392a*/,
    8 /*392b*/,  7 /*392c*/,  8 /*392d*/,  8 /*392e*/,  9 /*392f*/,
    6 /*3930*/,  7 /*3931*/,  7 /*3932*/,  8 /*3933*/,  7 /*3934*/,
    8 /*3935*/,  8 /*3936*/,  9 /*3937*/,  7 /*3938*/,  8 /*3939*/,
    8 /*393a*/,  9 /*393b*/,  8 /*393c*/,  9 /*393d*/,  9 /*393e*/,
    10 /*393f*/, 5 /*3940*/,  6 /*3941*/,  6 /*3942*/,  7 /*3943*/,
    6 /*3944*/,  7 /*3945*/,  7 /*3946*/,  8 /*3947*/,  6 /*3948*/,
    7 /*3949*/,  7 /*394a*/,  8 /*394b*/,  7 /*394c*/,  8 /*394d*/,
    8 /*394e*/,  9 /*394f*/,  6 /*3950*/,  7 /*3951*/,  7 /*3952*/,
    8 /*3953*/,  7 /*3954*/,  8 /*3955*/,  8 /*3956*/,  9 /*3957*/,
    7 /*3958*/,  8 /*3959*/,  8 /*395a*/,  9 /*395b*/,  8 /*395c*/,
    9 /*395d*/,  9 /*395e*/,  10 /*395f*/, 6 /*3960*/,  7 /*3961*/,
    7 /*3962*/,  8 /*3963*/,  7 /*3964*/,  8 /*3965*/,  8 /*3966*/,
    9 /*3967*/,  7 /*3968*/,  8 /*3969*/,  8 /*396a*/,  9 /*396b*/,
    8 /*396c*/,  9 /*396d*/,  9 /*396e*/,  10 /*396f*/, 7 /*3970*/,
    8 /*3971*/,  8 /*3972*/,  9 /*3973*/,  8 /*3974*/,  9 /*3975*/,
    9 /*3976*/,  10 /*3977*/, 8 /*3978*/,  9 /*3979*/,  9 /*397a*/,
    10 /*397b*/, 9 /*397c*/,  10 /*397d*/, 10 /*397e*/, 11 /*397f*/,
    5 /*3980*/,  6 /*3981*/,  6 /*3982*/,  7 /*3983*/,  6 /*3984*/,
    7 /*3985*/,  7 /*3986*/,  8 /*3987*/,  6 /*3988*/,  7 /*3989*/,
    7 /*398a*/,  8 /*398b*/,  7 /*398c*/,  8 /*398d*/,  8 /*398e*/,
    9 /*398f*/,  6 /*3990*/,  7 /*3991*/,  7 /*3992*/,  8 /*3993*/,
    7 /*3994*/,  8 /*3995*/,  8 /*3996*/,  9 /*3997*/,  7 /*3998*/,
    8 /*3999*/,  8 /*399a*/,  9 /*399b*/,  8 /*399c*/,  9 /*399d*/,
    9 /*399e*/,  10 /*399f*/, 6 /*39a0*/,  7 /*39a1*/,  7 /*39a2*/,
    8 /*39a3*/,  7 /*39a4*/,  8 /*39a5*/,  8 /*39a6*/,  9 /*39a7*/,
    7 /*39a8*/,  8 /*39a9*/,  8 /*39aa*/,  9 /*39ab*/,  8 /*39ac*/,
    9 /*39ad*/,  9 /*39ae*/,  10 /*39af*/, 7 /*39b0*/,  8 /*39b1*/,
    8 /*39b2*/,  9 /*39b3*/,  8 /*39b4*/,  9 /*39b5*/,  9 /*39b6*/,
    10 /*39b7*/, 8 /*39b8*/,  9 /*39b9*/,  9 /*39ba*/,  10 /*39bb*/,
    9 /*39bc*/,  10 /*39bd*/, 10 /*39be*/, 11 /*39bf*/, 6 /*39c0*/,
    7 /*39c1*/,  7 /*39c2*/,  8 /*39c3*/,  7 /*39c4*/,  8 /*39c5*/,
    8 /*39c6*/,  9 /*39c7*/,  7 /*39c8*/,  8 /*39c9*/,  8 /*39ca*/,
    9 /*39cb*/,  8 /*39cc*/,  9 /*39cd*/,  9 /*39ce*/,  10 /*39cf*/,
    7 /*39d0*/,  8 /*39d1*/,  8 /*39d2*/,  9 /*39d3*/,  8 /*39d4*/,
    9 /*39d5*/,  9 /*39d6*/,  10 /*39d7*/, 8 /*39d8*/,  9 /*39d9*/,
    9 /*39da*/,  10 /*39db*/, 9 /*39dc*/,  10 /*39dd*/, 10 /*39de*/,
    11 /*39df*/, 7 /*39e0*/,  8 /*39e1*/,  8 /*39e2*/,  9 /*39e3*/,
    8 /*39e4*/,  9 /*39e5*/,  9 /*39e6*/,  10 /*39e7*/, 8 /*39e8*/,
    9 /*39e9*/,  9 /*39ea*/,  10 /*39eb*/, 9 /*39ec*/,  10 /*39ed*/,
    10 /*39ee*/, 11 /*39ef*/, 8 /*39f0*/,  9 /*39f1*/,  9 /*39f2*/,
    10 /*39f3*/, 9 /*39f4*/,  10 /*39f5*/, 10 /*39f6*/, 11 /*39f7*/,
    9 /*39f8*/,  10 /*39f9*/, 10 /*39fa*/, 11 /*39fb*/, 10 /*39fc*/,
    11 /*39fd*/, 11 /*39fe*/, 12 /*39ff*/, 4 /*3a00*/,  5 /*3a01*/,
    5 /*3a02*/,  6 /*3a03*/,  5 /*3a04*/,  6 /*3a05*/,  6 /*3a06*/,
    7 /*3a07*/,  5 /*3a08*/,  6 /*3a09*/,  6 /*3a0a*/,  7 /*3a0b*/,
    6 /*3a0c*/,  7 /*3a0d*/,  7 /*3a0e*/,  8 /*3a0f*/,  5 /*3a10*/,
    6 /*3a11*/,  6 /*3a12*/,  7 /*3a13*/,  6 /*3a14*/,  7 /*3a15*/,
    7 /*3a16*/,  8 /*3a17*/,  6 /*3a18*/,  7 /*3a19*/,  7 /*3a1a*/,
    8 /*3a1b*/,  7 /*3a1c*/,  8 /*3a1d*/,  8 /*3a1e*/,  9 /*3a1f*/,
    5 /*3a20*/,  6 /*3a21*/,  6 /*3a22*/,  7 /*3a23*/,  6 /*3a24*/,
    7 /*3a25*/,  7 /*3a26*/,  8 /*3a27*/,  6 /*3a28*/,  7 /*3a29*/,
    7 /*3a2a*/,  8 /*3a2b*/,  7 /*3a2c*/,  8 /*3a2d*/,  8 /*3a2e*/,
    9 /*3a2f*/,  6 /*3a30*/,  7 /*3a31*/,  7 /*3a32*/,  8 /*3a33*/,
    7 /*3a34*/,  8 /*3a35*/,  8 /*3a36*/,  9 /*3a37*/,  7 /*3a38*/,
    8 /*3a39*/,  8 /*3a3a*/,  9 /*3a3b*/,  8 /*3a3c*/,  9 /*3a3d*/,
    9 /*3a3e*/,  10 /*3a3f*/, 5 /*3a40*/,  6 /*3a41*/,  6 /*3a42*/,
    7 /*3a43*/,  6 /*3a44*/,  7 /*3a45*/,  7 /*3a46*/,  8 /*3a47*/,
    6 /*3a48*/,  7 /*3a49*/,  7 /*3a4a*/,  8 /*3a4b*/,  7 /*3a4c*/,
    8 /*3a4d*/,  8 /*3a4e*/,  9 /*3a4f*/,  6 /*3a50*/,  7 /*3a51*/,
    7 /*3a52*/,  8 /*3a53*/,  7 /*3a54*/,  8 /*3a55*/,  8 /*3a56*/,
    9 /*3a57*/,  7 /*3a58*/,  8 /*3a59*/,  8 /*3a5a*/,  9 /*3a5b*/,
    8 /*3a5c*/,  9 /*3a5d*/,  9 /*3a5e*/,  10 /*3a5f*/, 6 /*3a60*/,
    7 /*3a61*/,  7 /*3a62*/,  8 /*3a63*/,  7 /*3a64*/,  8 /*3a65*/,
    8 /*3a66*/,  9 /*3a67*/,  7 /*3a68*/,  8 /*3a69*/,  8 /*3a6a*/,
    9 /*3a6b*/,  8 /*3a6c*/,  9 /*3a6d*/,  9 /*3a6e*/,  10 /*3a6f*/,
    7 /*3a70*/,  8 /*3a71*/,  8 /*3a72*/,  9 /*3a73*/,  8 /*3a74*/,
    9 /*3a75*/,  9 /*3a76*/,  10 /*3a77*/, 8 /*3a78*/,  9 /*3a79*/,
    9 /*3a7a*/,  10 /*3a7b*/, 9 /*3a7c*/,  10 /*3a7d*/, 10 /*3a7e*/,
    11 /*3a7f*/, 5 /*3a80*/,  6 /*3a81*/,  6 /*3a82*/,  7 /*3a83*/,
    6 /*3a84*/,  7 /*3a85*/,  7 /*3a86*/,  8 /*3a87*/,  6 /*3a88*/,
    7 /*3a89*/,  7 /*3a8a*/,  8 /*3a8b*/,  7 /*3a8c*/,  8 /*3a8d*/,
    8 /*3a8e*/,  9 /*3a8f*/,  6 /*3a90*/,  7 /*3a91*/,  7 /*3a92*/,
    8 /*3a93*/,  7 /*3a94*/,  8 /*3a95*/,  8 /*3a96*/,  9 /*3a97*/,
    7 /*3a98*/,  8 /*3a99*/,  8 /*3a9a*/,  9 /*3a9b*/,  8 /*3a9c*/,
    9 /*3a9d*/,  9 /*3a9e*/,  10 /*3a9f*/, 6 /*3aa0*/,  7 /*3aa1*/,
    7 /*3aa2*/,  8 /*3aa3*/,  7 /*3aa4*/,  8 /*3aa5*/,  8 /*3aa6*/,
    9 /*3aa7*/,  7 /*3aa8*/,  8 /*3aa9*/,  8 /*3aaa*/,  9 /*3aab*/,
    8 /*3aac*/,  9 /*3aad*/,  9 /*3aae*/,  10 /*3aaf*/, 7 /*3ab0*/,
    8 /*3ab1*/,  8 /*3ab2*/,  9 /*3ab3*/,  8 /*3ab4*/,  9 /*3ab5*/,
    9 /*3ab6*/,  10 /*3ab7*/, 8 /*3ab8*/,  9 /*3ab9*/,  9 /*3aba*/,
    10 /*3abb*/, 9 /*3abc*/,  10 /*3abd*/, 10 /*3abe*/, 11 /*3abf*/,
    6 /*3ac0*/,  7 /*3ac1*/,  7 /*3ac2*/,  8 /*3ac3*/,  7 /*3ac4*/,
    8 /*3ac5*/,  8 /*3ac6*/,  9 /*3ac7*/,  7 /*3ac8*/,  8 /*3ac9*/,
    8 /*3aca*/,  9 /*3acb*/,  8 /*3acc*/,  9 /*3acd*/,  9 /*3ace*/,
    10 /*3acf*/, 7 /*3ad0*/,  8 /*3ad1*/,  8 /*3ad2*/,  9 /*3ad3*/,
    8 /*3ad4*/,  9 /*3ad5*/,  9 /*3ad6*/,  10 /*3ad7*/, 8 /*3ad8*/,
    9 /*3ad9*/,  9 /*3ada*/,  10 /*3adb*/, 9 /*3adc*/,  10 /*3add*/,
    10 /*3ade*/, 11 /*3adf*/, 7 /*3ae0*/,  8 /*3ae1*/,  8 /*3ae2*/,
    9 /*3ae3*/,  8 /*3ae4*/,  9 /*3ae5*/,  9 /*3ae6*/,  10 /*3ae7*/,
    8 /*3ae8*/,  9 /*3ae9*/,  9 /*3aea*/,  10 /*3aeb*/, 9 /*3aec*/,
    10 /*3aed*/, 10 /*3aee*/, 11 /*3aef*/, 8 /*3af0*/,  9 /*3af1*/,
    9 /*3af2*/,  10 /*3af3*/, 9 /*3af4*/,  10 /*3af5*/, 10 /*3af6*/,
    11 /*3af7*/, 9 /*3af8*/,  10 /*3af9*/, 10 /*3afa*/, 11 /*3afb*/,
    10 /*3afc*/, 11 /*3afd*/, 11 /*3afe*/, 12 /*3aff*/, 5 /*3b00*/,
    6 /*3b01*/,  6 /*3b02*/,  7 /*3b03*/,  6 /*3b04*/,  7 /*3b05*/,
    7 /*3b06*/,  8 /*3b07*/,  6 /*3b08*/,  7 /*3b09*/,  7 /*3b0a*/,
    8 /*3b0b*/,  7 /*3b0c*/,  8 /*3b0d*/,  8 /*3b0e*/,  9 /*3b0f*/,
    6 /*3b10*/,  7 /*3b11*/,  7 /*3b12*/,  8 /*3b13*/,  7 /*3b14*/,
    8 /*3b15*/,  8 /*3b16*/,  9 /*3b17*/,  7 /*3b18*/,  8 /*3b19*/,
    8 /*3b1a*/,  9 /*3b1b*/,  8 /*3b1c*/,  9 /*3b1d*/,  9 /*3b1e*/,
    10 /*3b1f*/, 6 /*3b20*/,  7 /*3b21*/,  7 /*3b22*/,  8 /*3b23*/,
    7 /*3b24*/,  8 /*3b25*/,  8 /*3b26*/,  9 /*3b27*/,  7 /*3b28*/,
    8 /*3b29*/,  8 /*3b2a*/,  9 /*3b2b*/,  8 /*3b2c*/,  9 /*3b2d*/,
    9 /*3b2e*/,  10 /*3b2f*/, 7 /*3b30*/,  8 /*3b31*/,  8 /*3b32*/,
    9 /*3b33*/,  8 /*3b34*/,  9 /*3b35*/,  9 /*3b36*/,  10 /*3b37*/,
    8 /*3b38*/,  9 /*3b39*/,  9 /*3b3a*/,  10 /*3b3b*/, 9 /*3b3c*/,
    10 /*3b3d*/, 10 /*3b3e*/, 11 /*3b3f*/, 6 /*3b40*/,  7 /*3b41*/,
    7 /*3b42*/,  8 /*3b43*/,  7 /*3b44*/,  8 /*3b45*/,  8 /*3b46*/,
    9 /*3b47*/,  7 /*3b48*/,  8 /*3b49*/,  8 /*3b4a*/,  9 /*3b4b*/,
    8 /*3b4c*/,  9 /*3b4d*/,  9 /*3b4e*/,  10 /*3b4f*/, 7 /*3b50*/,
    8 /*3b51*/,  8 /*3b52*/,  9 /*3b53*/,  8 /*3b54*/,  9 /*3b55*/,
    9 /*3b56*/,  10 /*3b57*/, 8 /*3b58*/,  9 /*3b59*/,  9 /*3b5a*/,
    10 /*3b5b*/, 9 /*3b5c*/,  10 /*3b5d*/, 10 /*3b5e*/, 11 /*3b5f*/,
    7 /*3b60*/,  8 /*3b61*/,  8 /*3b62*/,  9 /*3b63*/,  8 /*3b64*/,
    9 /*3b65*/,  9 /*3b66*/,  10 /*3b67*/, 8 /*3b68*/,  9 /*3b69*/,
    9 /*3b6a*/,  10 /*3b6b*/, 9 /*3b6c*/,  10 /*3b6d*/, 10 /*3b6e*/,
    11 /*3b6f*/, 8 /*3b70*/,  9 /*3b71*/,  9 /*3b72*/,  10 /*3b73*/,
    9 /*3b74*/,  10 /*3b75*/, 10 /*3b76*/, 11 /*3b77*/, 9 /*3b78*/,
    10 /*3b79*/, 10 /*3b7a*/, 11 /*3b7b*/, 10 /*3b7c*/, 11 /*3b7d*/,
    11 /*3b7e*/, 12 /*3b7f*/, 6 /*3b80*/,  7 /*3b81*/,  7 /*3b82*/,
    8 /*3b83*/,  7 /*3b84*/,  8 /*3b85*/,  8 /*3b86*/,  9 /*3b87*/,
    7 /*3b88*/,  8 /*3b89*/,  8 /*3b8a*/,  9 /*3b8b*/,  8 /*3b8c*/,
    9 /*3b8d*/,  9 /*3b8e*/,  10 /*3b8f*/, 7 /*3b90*/,  8 /*3b91*/,
    8 /*3b92*/,  9 /*3b93*/,  8 /*3b94*/,  9 /*3b95*/,  9 /*3b96*/,
    10 /*3b97*/, 8 /*3b98*/,  9 /*3b99*/,  9 /*3b9a*/,  10 /*3b9b*/,
    9 /*3b9c*/,  10 /*3b9d*/, 10 /*3b9e*/, 11 /*3b9f*/, 7 /*3ba0*/,
    8 /*3ba1*/,  8 /*3ba2*/,  9 /*3ba3*/,  8 /*3ba4*/,  9 /*3ba5*/,
    9 /*3ba6*/,  10 /*3ba7*/, 8 /*3ba8*/,  9 /*3ba9*/,  9 /*3baa*/,
    10 /*3bab*/, 9 /*3bac*/,  10 /*3bad*/, 10 /*3bae*/, 11 /*3baf*/,
    8 /*3bb0*/,  9 /*3bb1*/,  9 /*3bb2*/,  10 /*3bb3*/, 9 /*3bb4*/,
    10 /*3bb5*/, 10 /*3bb6*/, 11 /*3bb7*/, 9 /*3bb8*/,  10 /*3bb9*/,
    10 /*3bba*/, 11 /*3bbb*/, 10 /*3bbc*/, 11 /*3bbd*/, 11 /*3bbe*/,
    12 /*3bbf*/, 7 /*3bc0*/,  8 /*3bc1*/,  8 /*3bc2*/,  9 /*3bc3*/,
    8 /*3bc4*/,  9 /*3bc5*/,  9 /*3bc6*/,  10 /*3bc7*/, 8 /*3bc8*/,
    9 /*3bc9*/,  9 /*3bca*/,  10 /*3bcb*/, 9 /*3bcc*/,  10 /*3bcd*/,
    10 /*3bce*/, 11 /*3bcf*/, 8 /*3bd0*/,  9 /*3bd1*/,  9 /*3bd2*/,
    10 /*3bd3*/, 9 /*3bd4*/,  10 /*3bd5*/, 10 /*3bd6*/, 11 /*3bd7*/,
    9 /*3bd8*/,  10 /*3bd9*/, 10 /*3bda*/, 11 /*3bdb*/, 10 /*3bdc*/,
    11 /*3bdd*/, 11 /*3bde*/, 12 /*3bdf*/, 8 /*3be0*/,  9 /*3be1*/,
    9 /*3be2*/,  10 /*3be3*/, 9 /*3be4*/,  10 /*3be5*/, 10 /*3be6*/,
    11 /*3be7*/, 9 /*3be8*/,  10 /*3be9*/, 10 /*3bea*/, 11 /*3beb*/,
    10 /*3bec*/, 11 /*3bed*/, 11 /*3bee*/, 12 /*3bef*/, 9 /*3bf0*/,
    10 /*3bf1*/, 10 /*3bf2*/, 11 /*3bf3*/, 10 /*3bf4*/, 11 /*3bf5*/,
    11 /*3bf6*/, 12 /*3bf7*/, 10 /*3bf8*/, 11 /*3bf9*/, 11 /*3bfa*/,
    12 /*3bfb*/, 11 /*3bfc*/, 12 /*3bfd*/, 12 /*3bfe*/, 13 /*3bff*/,
    4 /*3c00*/,  5 /*3c01*/,  5 /*3c02*/,  6 /*3c03*/,  5 /*3c04*/,
    6 /*3c05*/,  6 /*3c06*/,  7 /*3c07*/,  5 /*3c08*/,  6 /*3c09*/,
    6 /*3c0a*/,  7 /*3c0b*/,  6 /*3c0c*/,  7 /*3c0d*/,  7 /*3c0e*/,
    8 /*3c0f*/,  5 /*3c10*/,  6 /*3c11*/,  6 /*3c12*/,  7 /*3c13*/,
    6 /*3c14*/,  7 /*3c15*/,  7 /*3c16*/,  8 /*3c17*/,  6 /*3c18*/,
    7 /*3c19*/,  7 /*3c1a*/,  8 /*3c1b*/,  7 /*3c1c*/,  8 /*3c1d*/,
    8 /*3c1e*/,  9 /*3c1f*/,  5 /*3c20*/,  6 /*3c21*/,  6 /*3c22*/,
    7 /*3c23*/,  6 /*3c24*/,  7 /*3c25*/,  7 /*3c26*/,  8 /*3c27*/,
    6 /*3c28*/,  7 /*3c29*/,  7 /*3c2a*/,  8 /*3c2b*/,  7 /*3c2c*/,
    8 /*3c2d*/,  8 /*3c2e*/,  9 /*3c2f*/,  6 /*3c30*/,  7 /*3c31*/,
    7 /*3c32*/,  8 /*3c33*/,  7 /*3c34*/,  8 /*3c35*/,  8 /*3c36*/,
    9 /*3c37*/,  7 /*3c38*/,  8 /*3c39*/,  8 /*3c3a*/,  9 /*3c3b*/,
    8 /*3c3c*/,  9 /*3c3d*/,  9 /*3c3e*/,  10 /*3c3f*/, 5 /*3c40*/,
    6 /*3c41*/,  6 /*3c42*/,  7 /*3c43*/,  6 /*3c44*/,  7 /*3c45*/,
    7 /*3c46*/,  8 /*3c47*/,  6 /*3c48*/,  7 /*3c49*/,  7 /*3c4a*/,
    8 /*3c4b*/,  7 /*3c4c*/,  8 /*3c4d*/,  8 /*3c4e*/,  9 /*3c4f*/,
    6 /*3c50*/,  7 /*3c51*/,  7 /*3c52*/,  8 /*3c53*/,  7 /*3c54*/,
    8 /*3c55*/,  8 /*3c56*/,  9 /*3c57*/,  7 /*3c58*/,  8 /*3c59*/,
    8 /*3c5a*/,  9 /*3c5b*/,  8 /*3c5c*/,  9 /*3c5d*/,  9 /*3c5e*/,
    10 /*3c5f*/, 6 /*3c60*/,  7 /*3c61*/,  7 /*3c62*/,  8 /*3c63*/,
    7 /*3c64*/,  8 /*3c65*/,  8 /*3c66*/,  9 /*3c67*/,  7 /*3c68*/,
    8 /*3c69*/,  8 /*3c6a*/,  9 /*3c6b*/,  8 /*3c6c*/,  9 /*3c6d*/,
    9 /*3c6e*/,  10 /*3c6f*/, 7 /*3c70*/,  8 /*3c71*/,  8 /*3c72*/,
    9 /*3c73*/,  8 /*3c74*/,  9 /*3c75*/,  9 /*3c76*/,  10 /*3c77*/,
    8 /*3c78*/,  9 /*3c79*/,  9 /*3c7a*/,  10 /*3c7b*/, 9 /*3c7c*/,
    10 /*3c7d*/, 10 /*3c7e*/, 11 /*3c7f*/, 5 /*3c80*/,  6 /*3c81*/,
    6 /*3c82*/,  7 /*3c83*/,  6 /*3c84*/,  7 /*3c85*/,  7 /*3c86*/,
    8 /*3c87*/,  6 /*3c88*/,  7 /*3c89*/,  7 /*3c8a*/,  8 /*3c8b*/,
    7 /*3c8c*/,  8 /*3c8d*/,  8 /*3c8e*/,  9 /*3c8f*/,  6 /*3c90*/,
    7 /*3c91*/,  7 /*3c92*/,  8 /*3c93*/,  7 /*3c94*/,  8 /*3c95*/,
    8 /*3c96*/,  9 /*3c97*/,  7 /*3c98*/,  8 /*3c99*/,  8 /*3c9a*/,
    9 /*3c9b*/,  8 /*3c9c*/,  9 /*3c9d*/,  9 /*3c9e*/,  10 /*3c9f*/,
    6 /*3ca0*/,  7 /*3ca1*/,  7 /*3ca2*/,  8 /*3ca3*/,  7 /*3ca4*/,
    8 /*3ca5*/,  8 /*3ca6*/,  9 /*3ca7*/,  7 /*3ca8*/,  8 /*3ca9*/,
    8 /*3caa*/,  9 /*3cab*/,  8 /*3cac*/,  9 /*3cad*/,  9 /*3cae*/,
    10 /*3caf*/, 7 /*3cb0*/,  8 /*3cb1*/,  8 /*3cb2*/,  9 /*3cb3*/,
    8 /*3cb4*/,  9 /*3cb5*/,  9 /*3cb6*/,  10 /*3cb7*/, 8 /*3cb8*/,
    9 /*3cb9*/,  9 /*3cba*/,  10 /*3cbb*/, 9 /*3cbc*/,  10 /*3cbd*/,
    10 /*3cbe*/, 11 /*3cbf*/, 6 /*3cc0*/,  7 /*3cc1*/,  7 /*3cc2*/,
    8 /*3cc3*/,  7 /*3cc4*/,  8 /*3cc5*/,  8 /*3cc6*/,  9 /*3cc7*/,
    7 /*3cc8*/,  8 /*3cc9*/,  8 /*3cca*/,  9 /*3ccb*/,  8 /*3ccc*/,
    9 /*3ccd*/,  9 /*3cce*/,  10 /*3ccf*/, 7 /*3cd0*/,  8 /*3cd1*/,
    8 /*3cd2*/,  9 /*3cd3*/,  8 /*3cd4*/,  9 /*3cd5*/,  9 /*3cd6*/,
    10 /*3cd7*/, 8 /*3cd8*/,  9 /*3cd9*/,  9 /*3cda*/,  10 /*3cdb*/,
    9 /*3cdc*/,  10 /*3cdd*/, 10 /*3cde*/, 11 /*3cdf*/, 7 /*3ce0*/,
    8 /*3ce1*/,  8 /*3ce2*/,  9 /*3ce3*/,  8 /*3ce4*/,  9 /*3ce5*/,
    9 /*3ce6*/,  10 /*3ce7*/, 8 /*3ce8*/,  9 /*3ce9*/,  9 /*3cea*/,
    10 /*3ceb*/, 9 /*3cec*/,  10 /*3ced*/, 10 /*3cee*/, 11 /*3cef*/,
    8 /*3cf0*/,  9 /*3cf1*/,  9 /*3cf2*/,  10 /*3cf3*/, 9 /*3cf4*/,
    10 /*3cf5*/, 10 /*3cf6*/, 11 /*3cf7*/, 9 /*3cf8*/,  10 /*3cf9*/,
    10 /*3cfa*/, 11 /*3cfb*/, 10 /*3cfc*/, 11 /*3cfd*/, 11 /*3cfe*/,
    12 /*3cff*/, 5 /*3d00*/,  6 /*3d01*/,  6 /*3d02*/,  7 /*3d03*/,
    6 /*3d04*/,  7 /*3d05*/,  7 /*3d06*/,  8 /*3d07*/,  6 /*3d08*/,
    7 /*3d09*/,  7 /*3d0a*/,  8 /*3d0b*/,  7 /*3d0c*/,  8 /*3d0d*/,
    8 /*3d0e*/,  9 /*3d0f*/,  6 /*3d10*/,  7 /*3d11*/,  7 /*3d12*/,
    8 /*3d13*/,  7 /*3d14*/,  8 /*3d15*/,  8 /*3d16*/,  9 /*3d17*/,
    7 /*3d18*/,  8 /*3d19*/,  8 /*3d1a*/,  9 /*3d1b*/,  8 /*3d1c*/,
    9 /*3d1d*/,  9 /*3d1e*/,  10 /*3d1f*/, 6 /*3d20*/,  7 /*3d21*/,
    7 /*3d22*/,  8 /*3d23*/,  7 /*3d24*/,  8 /*3d25*/,  8 /*3d26*/,
    9 /*3d27*/,  7 /*3d28*/,  8 /*3d29*/,  8 /*3d2a*/,  9 /*3d2b*/,
    8 /*3d2c*/,  9 /*3d2d*/,  9 /*3d2e*/,  10 /*3d2f*/, 7 /*3d30*/,
    8 /*3d31*/,  8 /*3d32*/,  9 /*3d33*/,  8 /*3d34*/,  9 /*3d35*/,
    9 /*3d36*/,  10 /*3d37*/, 8 /*3d38*/,  9 /*3d39*/,  9 /*3d3a*/,
    10 /*3d3b*/, 9 /*3d3c*/,  10 /*3d3d*/, 10 /*3d3e*/, 11 /*3d3f*/,
    6 /*3d40*/,  7 /*3d41*/,  7 /*3d42*/,  8 /*3d43*/,  7 /*3d44*/,
    8 /*3d45*/,  8 /*3d46*/,  9 /*3d47*/,  7 /*3d48*/,  8 /*3d49*/,
    8 /*3d4a*/,  9 /*3d4b*/,  8 /*3d4c*/,  9 /*3d4d*/,  9 /*3d4e*/,
    10 /*3d4f*/, 7 /*3d50*/,  8 /*3d51*/,  8 /*3d52*/,  9 /*3d53*/,
    8 /*3d54*/,  9 /*3d55*/,  9 /*3d56*/,  10 /*3d57*/, 8 /*3d58*/,
    9 /*3d59*/,  9 /*3d5a*/,  10 /*3d5b*/, 9 /*3d5c*/,  10 /*3d5d*/,
    10 /*3d5e*/, 11 /*3d5f*/, 7 /*3d60*/,  8 /*3d61*/,  8 /*3d62*/,
    9 /*3d63*/,  8 /*3d64*/,  9 /*3d65*/,  9 /*3d66*/,  10 /*3d67*/,
    8 /*3d68*/,  9 /*3d69*/,  9 /*3d6a*/,  10 /*3d6b*/, 9 /*3d6c*/,
    10 /*3d6d*/, 10 /*3d6e*/, 11 /*3d6f*/, 8 /*3d70*/,  9 /*3d71*/,
    9 /*3d72*/,  10 /*3d73*/, 9 /*3d74*/,  10 /*3d75*/, 10 /*3d76*/,
    11 /*3d77*/, 9 /*3d78*/,  10 /*3d79*/, 10 /*3d7a*/, 11 /*3d7b*/,
    10 /*3d7c*/, 11 /*3d7d*/, 11 /*3d7e*/, 12 /*3d7f*/, 6 /*3d80*/,
    7 /*3d81*/,  7 /*3d82*/,  8 /*3d83*/,  7 /*3d84*/,  8 /*3d85*/,
    8 /*3d86*/,  9 /*3d87*/,  7 /*3d88*/,  8 /*3d89*/,  8 /*3d8a*/,
    9 /*3d8b*/,  8 /*3d8c*/,  9 /*3d8d*/,  9 /*3d8e*/,  10 /*3d8f*/,
    7 /*3d90*/,  8 /*3d91*/,  8 /*3d92*/,  9 /*3d93*/,  8 /*3d94*/,
    9 /*3d95*/,  9 /*3d96*/,  10 /*3d97*/, 8 /*3d98*/,  9 /*3d99*/,
    9 /*3d9a*/,  10 /*3d9b*/, 9 /*3d9c*/,  10 /*3d9d*/, 10 /*3d9e*/,
    11 /*3d9f*/, 7 /*3da0*/,  8 /*3da1*/,  8 /*3da2*/,  9 /*3da3*/,
    8 /*3da4*/,  9 /*3da5*/,  9 /*3da6*/,  10 /*3da7*/, 8 /*3da8*/,
    9 /*3da9*/,  9 /*3daa*/,  10 /*3dab*/, 9 /*3dac*/,  10 /*3dad*/,
    10 /*3dae*/, 11 /*3daf*/, 8 /*3db0*/,  9 /*3db1*/,  9 /*3db2*/,
    10 /*3db3*/, 9 /*3db4*/,  10 /*3db5*/, 10 /*3db6*/, 11 /*3db7*/,
    9 /*3db8*/,  10 /*3db9*/, 10 /*3dba*/, 11 /*3dbb*/, 10 /*3dbc*/,
    11 /*3dbd*/, 11 /*3dbe*/, 12 /*3dbf*/, 7 /*3dc0*/,  8 /*3dc1*/,
    8 /*3dc2*/,  9 /*3dc3*/,  8 /*3dc4*/,  9 /*3dc5*/,  9 /*3dc6*/,
    10 /*3dc7*/, 8 /*3dc8*/,  9 /*3dc9*/,  9 /*3dca*/,  10 /*3dcb*/,
    9 /*3dcc*/,  10 /*3dcd*/, 10 /*3dce*/, 11 /*3dcf*/, 8 /*3dd0*/,
    9 /*3dd1*/,  9 /*3dd2*/,  10 /*3dd3*/, 9 /*3dd4*/,  10 /*3dd5*/,
    10 /*3dd6*/, 11 /*3dd7*/, 9 /*3dd8*/,  10 /*3dd9*/, 10 /*3dda*/,
    11 /*3ddb*/, 10 /*3ddc*/, 11 /*3ddd*/, 11 /*3dde*/, 12 /*3ddf*/,
    8 /*3de0*/,  9 /*3de1*/,  9 /*3de2*/,  10 /*3de3*/, 9 /*3de4*/,
    10 /*3de5*/, 10 /*3de6*/, 11 /*3de7*/, 9 /*3de8*/,  10 /*3de9*/,
    10 /*3dea*/, 11 /*3deb*/, 10 /*3dec*/, 11 /*3ded*/, 11 /*3dee*/,
    12 /*3def*/, 9 /*3df0*/,  10 /*3df1*/, 10 /*3df2*/, 11 /*3df3*/,
    10 /*3df4*/, 11 /*3df5*/, 11 /*3df6*/, 12 /*3df7*/, 10 /*3df8*/,
    11 /*3df9*/, 11 /*3dfa*/, 12 /*3dfb*/, 11 /*3dfc*/, 12 /*3dfd*/,
    12 /*3dfe*/, 13 /*3dff*/, 5 /*3e00*/,  6 /*3e01*/,  6 /*3e02*/,
    7 /*3e03*/,  6 /*3e04*/,  7 /*3e05*/,  7 /*3e06*/,  8 /*3e07*/,
    6 /*3e08*/,  7 /*3e09*/,  7 /*3e0a*/,  8 /*3e0b*/,  7 /*3e0c*/,
    8 /*3e0d*/,  8 /*3e0e*/,  9 /*3e0f*/,  6 /*3e10*/,  7 /*3e11*/,
    7 /*3e12*/,  8 /*3e13*/,  7 /*3e14*/,  8 /*3e15*/,  8 /*3e16*/,
    9 /*3e17*/,  7 /*3e18*/,  8 /*3e19*/,  8 /*3e1a*/,  9 /*3e1b*/,
    8 /*3e1c*/,  9 /*3e1d*/,  9 /*3e1e*/,  10 /*3e1f*/, 6 /*3e20*/,
    7 /*3e21*/,  7 /*3e22*/,  8 /*3e23*/,  7 /*3e24*/,  8 /*3e25*/,
    8 /*3e26*/,  9 /*3e27*/,  7 /*3e28*/,  8 /*3e29*/,  8 /*3e2a*/,
    9 /*3e2b*/,  8 /*3e2c*/,  9 /*3e2d*/,  9 /*3e2e*/,  10 /*3e2f*/,
    7 /*3e30*/,  8 /*3e31*/,  8 /*3e32*/,  9 /*3e33*/,  8 /*3e34*/,
    9 /*3e35*/,  9 /*3e36*/,  10 /*3e37*/, 8 /*3e38*/,  9 /*3e39*/,
    9 /*3e3a*/,  10 /*3e3b*/, 9 /*3e3c*/,  10 /*3e3d*/, 10 /*3e3e*/,
    11 /*3e3f*/, 6 /*3e40*/,  7 /*3e41*/,  7 /*3e42*/,  8 /*3e43*/,
    7 /*3e44*/,  8 /*3e45*/,  8 /*3e46*/,  9 /*3e47*/,  7 /*3e48*/,
    8 /*3e49*/,  8 /*3e4a*/,  9 /*3e4b*/,  8 /*3e4c*/,  9 /*3e4d*/,
    9 /*3e4e*/,  10 /*3e4f*/, 7 /*3e50*/,  8 /*3e51*/,  8 /*3e52*/,
    9 /*3e53*/,  8 /*3e54*/,  9 /*3e55*/,  9 /*3e56*/,  10 /*3e57*/,
    8 /*3e58*/,  9 /*3e59*/,  9 /*3e5a*/,  10 /*3e5b*/, 9 /*3e5c*/,
    10 /*3e5d*/, 10 /*3e5e*/, 11 /*3e5f*/, 7 /*3e60*/,  8 /*3e61*/,
    8 /*3e62*/,  9 /*3e63*/,  8 /*3e64*/,  9 /*3e65*/,  9 /*3e66*/,
    10 /*3e67*/, 8 /*3e68*/,  9 /*3e69*/,  9 /*3e6a*/,  10 /*3e6b*/,
    9 /*3e6c*/,  10 /*3e6d*/, 10 /*3e6e*/, 11 /*3e6f*/, 8 /*3e70*/,
    9 /*3e71*/,  9 /*3e72*/,  10 /*3e73*/, 9 /*3e74*/,  10 /*3e75*/,
    10 /*3e76*/, 11 /*3e77*/, 9 /*3e78*/,  10 /*3e79*/, 10 /*3e7a*/,
    11 /*3e7b*/, 10 /*3e7c*/, 11 /*3e7d*/, 11 /*3e7e*/, 12 /*3e7f*/,
    6 /*3e80*/,  7 /*3e81*/,  7 /*3e82*/,  8 /*3e83*/,  7 /*3e84*/,
    8 /*3e85*/,  8 /*3e86*/,  9 /*3e87*/,  7 /*3e88*/,  8 /*3e89*/,
    8 /*3e8a*/,  9 /*3e8b*/,  8 /*3e8c*/,  9 /*3e8d*/,  9 /*3e8e*/,
    10 /*3e8f*/, 7 /*3e90*/,  8 /*3e91*/,  8 /*3e92*/,  9 /*3e93*/,
    8 /*3e94*/,  9 /*3e95*/,  9 /*3e96*/,  10 /*3e97*/, 8 /*3e98*/,
    9 /*3e99*/,  9 /*3e9a*/,  10 /*3e9b*/, 9 /*3e9c*/,  10 /*3e9d*/,
    10 /*3e9e*/, 11 /*3e9f*/, 7 /*3ea0*/,  8 /*3ea1*/,  8 /*3ea2*/,
    9 /*3ea3*/,  8 /*3ea4*/,  9 /*3ea5*/,  9 /*3ea6*/,  10 /*3ea7*/,
    8 /*3ea8*/,  9 /*3ea9*/,  9 /*3eaa*/,  10 /*3eab*/, 9 /*3eac*/,
    10 /*3ead*/, 10 /*3eae*/, 11 /*3eaf*/, 8 /*3eb0*/,  9 /*3eb1*/,
    9 /*3eb2*/,  10 /*3eb3*/, 9 /*3eb4*/,  10 /*3eb5*/, 10 /*3eb6*/,
    11 /*3eb7*/, 9 /*3eb8*/,  10 /*3eb9*/, 10 /*3eba*/, 11 /*3ebb*/,
    10 /*3ebc*/, 11 /*3ebd*/, 11 /*3ebe*/, 12 /*3ebf*/, 7 /*3ec0*/,
    8 /*3ec1*/,  8 /*3ec2*/,  9 /*3ec3*/,  8 /*3ec4*/,  9 /*3ec5*/,
    9 /*3ec6*/,  10 /*3ec7*/, 8 /*3ec8*/,  9 /*3ec9*/,  9 /*3eca*/,
    10 /*3ecb*/, 9 /*3ecc*/,  10 /*3ecd*/, 10 /*3ece*/, 11 /*3ecf*/,
    8 /*3ed0*/,  9 /*3ed1*/,  9 /*3ed2*/,  10 /*3ed3*/, 9 /*3ed4*/,
    10 /*3ed5*/, 10 /*3ed6*/, 11 /*3ed7*/, 9 /*3ed8*/,  10 /*3ed9*/,
    10 /*3eda*/, 11 /*3edb*/, 10 /*3edc*/, 11 /*3edd*/, 11 /*3ede*/,
    12 /*3edf*/, 8 /*3ee0*/,  9 /*3ee1*/,  9 /*3ee2*/,  10 /*3ee3*/,
    9 /*3ee4*/,  10 /*3ee5*/, 10 /*3ee6*/, 11 /*3ee7*/, 9 /*3ee8*/,
    10 /*3ee9*/, 10 /*3eea*/, 11 /*3eeb*/, 10 /*3eec*/, 11 /*3eed*/,
    11 /*3eee*/, 12 /*3eef*/, 9 /*3ef0*/,  10 /*3ef1*/, 10 /*3ef2*/,
    11 /*3ef3*/, 10 /*3ef4*/, 11 /*3ef5*/, 11 /*3ef6*/, 12 /*3ef7*/,
    10 /*3ef8*/, 11 /*3ef9*/, 11 /*3efa*/, 12 /*3efb*/, 11 /*3efc*/,
    12 /*3efd*/, 12 /*3efe*/, 13 /*3eff*/, 6 /*3f00*/,  7 /*3f01*/,
    7 /*3f02*/,  8 /*3f03*/,  7 /*3f04*/,  8 /*3f05*/,  8 /*3f06*/,
    9 /*3f07*/,  7 /*3f08*/,  8 /*3f09*/,  8 /*3f0a*/,  9 /*3f0b*/,
    8 /*3f0c*/,  9 /*3f0d*/,  9 /*3f0e*/,  10 /*3f0f*/, 7 /*3f10*/,
    8 /*3f11*/,  8 /*3f12*/,  9 /*3f13*/,  8 /*3f14*/,  9 /*3f15*/,
    9 /*3f16*/,  10 /*3f17*/, 8 /*3f18*/,  9 /*3f19*/,  9 /*3f1a*/,
    10 /*3f1b*/, 9 /*3f1c*/,  10 /*3f1d*/, 10 /*3f1e*/, 11 /*3f1f*/,
    7 /*3f20*/,  8 /*3f21*/,  8 /*3f22*/,  9 /*3f23*/,  8 /*3f24*/,
    9 /*3f25*/,  9 /*3f26*/,  10 /*3f27*/, 8 /*3f28*/,  9 /*3f29*/,
    9 /*3f2a*/,  10 /*3f2b*/, 9 /*3f2c*/,  10 /*3f2d*/, 10 /*3f2e*/,
    11 /*3f2f*/, 8 /*3f30*/,  9 /*3f31*/,  9 /*3f32*/,  10 /*3f33*/,
    9 /*3f34*/,  10 /*3f35*/, 10 /*3f36*/, 11 /*3f37*/, 9 /*3f38*/,
    10 /*3f39*/, 10 /*3f3a*/, 11 /*3f3b*/, 10 /*3f3c*/, 11 /*3f3d*/,
    11 /*3f3e*/, 12 /*3f3f*/, 7 /*3f40*/,  8 /*3f41*/,  8 /*3f42*/,
    9 /*3f43*/,  8 /*3f44*/,  9 /*3f45*/,  9 /*3f46*/,  10 /*3f47*/,
    8 /*3f48*/,  9 /*3f49*/,  9 /*3f4a*/,  10 /*3f4b*/, 9 /*3f4c*/,
    10 /*3f4d*/, 10 /*3f4e*/, 11 /*3f4f*/, 8 /*3f50*/,  9 /*3f51*/,
    9 /*3f52*/,  10 /*3f53*/, 9 /*3f54*/,  10 /*3f55*/, 10 /*3f56*/,
    11 /*3f57*/, 9 /*3f58*/,  10 /*3f59*/, 10 /*3f5a*/, 11 /*3f5b*/,
    10 /*3f5c*/, 11 /*3f5d*/, 11 /*3f5e*/, 12 /*3f5f*/, 8 /*3f60*/,
    9 /*3f61*/,  9 /*3f62*/,  10 /*3f63*/, 9 /*3f64*/,  10 /*3f65*/,
    10 /*3f66*/, 11 /*3f67*/, 9 /*3f68*/,  10 /*3f69*/, 10 /*3f6a*/,
    11 /*3f6b*/, 10 /*3f6c*/, 11 /*3f6d*/, 11 /*3f6e*/, 12 /*3f6f*/,
    9 /*3f70*/,  10 /*3f71*/, 10 /*3f72*/, 11 /*3f73*/, 10 /*3f74*/,
    11 /*3f75*/, 11 /*3f76*/, 12 /*3f77*/, 10 /*3f78*/, 11 /*3f79*/,
    11 /*3f7a*/, 12 /*3f7b*/, 11 /*3f7c*/, 12 /*3f7d*/, 12 /*3f7e*/,
    13 /*3f7f*/, 7 /*3f80*/,  8 /*3f81*/,  8 /*3f82*/,  9 /*3f83*/,
    8 /*3f84*/,  9 /*3f85*/,  9 /*3f86*/,  10 /*3f87*/, 8 /*3f88*/,
    9 /*3f89*/,  9 /*3f8a*/,  10 /*3f8b*/, 9 /*3f8c*/,  10 /*3f8d*/,
    10 /*3f8e*/, 11 /*3f8f*/, 8 /*3f90*/,  9 /*3f91*/,  9 /*3f92*/,
    10 /*3f93*/, 9 /*3f94*/,  10 /*3f95*/, 10 /*3f96*/, 11 /*3f97*/,
    9 /*3f98*/,  10 /*3f99*/, 10 /*3f9a*/, 11 /*3f9b*/, 10 /*3f9c*/,
    11 /*3f9d*/, 11 /*3f9e*/, 12 /*3f9f*/, 8 /*3fa0*/,  9 /*3fa1*/,
    9 /*3fa2*/,  10 /*3fa3*/, 9 /*3fa4*/,  10 /*3fa5*/, 10 /*3fa6*/,
    11 /*3fa7*/, 9 /*3fa8*/,  10 /*3fa9*/, 10 /*3faa*/, 11 /*3fab*/,
    10 /*3fac*/, 11 /*3fad*/, 11 /*3fae*/, 12 /*3faf*/, 9 /*3fb0*/,
    10 /*3fb1*/, 10 /*3fb2*/, 11 /*3fb3*/, 10 /*3fb4*/, 11 /*3fb5*/,
    11 /*3fb6*/, 12 /*3fb7*/, 10 /*3fb8*/, 11 /*3fb9*/, 11 /*3fba*/,
    12 /*3fbb*/, 11 /*3fbc*/, 12 /*3fbd*/, 12 /*3fbe*/, 13 /*3fbf*/,
    8 /*3fc0*/,  9 /*3fc1*/,  9 /*3fc2*/,  10 /*3fc3*/, 9 /*3fc4*/,
    10 /*3fc5*/, 10 /*3fc6*/, 11 /*3fc7*/, 9 /*3fc8*/,  10 /*3fc9*/,
    10 /*3fca*/, 11 /*3fcb*/, 10 /*3fcc*/, 11 /*3fcd*/, 11 /*3fce*/,
    12 /*3fcf*/, 9 /*3fd0*/,  10 /*3fd1*/, 10 /*3fd2*/, 11 /*3fd3*/,
    10 /*3fd4*/, 11 /*3fd5*/, 11 /*3fd6*/, 12 /*3fd7*/, 10 /*3fd8*/,
    11 /*3fd9*/, 11 /*3fda*/, 12 /*3fdb*/, 11 /*3fdc*/, 12 /*3fdd*/,
    12 /*3fde*/, 13 /*3fdf*/, 9 /*3fe0*/,  10 /*3fe1*/, 10 /*3fe2*/,
    11 /*3fe3*/, 10 /*3fe4*/, 11 /*3fe5*/, 11 /*3fe6*/, 12 /*3fe7*/,
    10 /*3fe8*/, 11 /*3fe9*/, 11 /*3fea*/, 12 /*3feb*/, 11 /*3fec*/,
    12 /*3fed*/, 12 /*3fee*/, 13 /*3fef*/, 10 /*3ff0*/, 11 /*3ff1*/,
    11 /*3ff2*/, 12 /*3ff3*/, 11 /*3ff4*/, 12 /*3ff5*/, 12 /*3ff6*/,
    13 /*3ff7*/, 11 /*3ff8*/, 12 /*3ff9*/, 12 /*3ffa*/, 13 /*3ffb*/,
    12 /*3ffc*/, 13 /*3ffd*/, 13 /*3ffe*/, 14 /*3fff*/, 1 /*4000*/,
    2 /*4001*/,  2 /*4002*/,  3 /*4003*/,  2 /*4004*/,  3 /*4005*/,
    3 /*4006*/,  4 /*4007*/,  2 /*4008*/,  3 /*4009*/,  3 /*400a*/,
    4 /*400b*/,  3 /*400c*/,  4 /*400d*/,  4 /*400e*/,  5 /*400f*/,
    2 /*4010*/,  3 /*4011*/,  3 /*4012*/,  4 /*4013*/,  3 /*4014*/,
    4 /*4015*/,  4 /*4016*/,  5 /*4017*/,  3 /*4018*/,  4 /*4019*/,
    4 /*401a*/,  5 /*401b*/,  4 /*401c*/,  5 /*401d*/,  5 /*401e*/,
    6 /*401f*/,  2 /*4020*/,  3 /*4021*/,  3 /*4022*/,  4 /*4023*/,
    3 /*4024*/,  4 /*4025*/,  4 /*4026*/,  5 /*4027*/,  3 /*4028*/,
    4 /*4029*/,  4 /*402a*/,  5 /*402b*/,  4 /*402c*/,  5 /*402d*/,
    5 /*402e*/,  6 /*402f*/,  3 /*4030*/,  4 /*4031*/,  4 /*4032*/,
    5 /*4033*/,  4 /*4034*/,  5 /*4035*/,  5 /*4036*/,  6 /*4037*/,
    4 /*4038*/,  5 /*4039*/,  5 /*403a*/,  6 /*403b*/,  5 /*403c*/,
    6 /*403d*/,  6 /*403e*/,  7 /*403f*/,  2 /*4040*/,  3 /*4041*/,
    3 /*4042*/,  4 /*4043*/,  3 /*4044*/,  4 /*4045*/,  4 /*4046*/,
    5 /*4047*/,  3 /*4048*/,  4 /*4049*/,  4 /*404a*/,  5 /*404b*/,
    4 /*404c*/,  5 /*404d*/,  5 /*404e*/,  6 /*404f*/,  3 /*4050*/,
    4 /*4051*/,  4 /*4052*/,  5 /*4053*/,  4 /*4054*/,  5 /*4055*/,
    5 /*4056*/,  6 /*4057*/,  4 /*4058*/,  5 /*4059*/,  5 /*405a*/,
    6 /*405b*/,  5 /*405c*/,  6 /*405d*/,  6 /*405e*/,  7 /*405f*/,
    3 /*4060*/,  4 /*4061*/,  4 /*4062*/,  5 /*4063*/,  4 /*4064*/,
    5 /*4065*/,  5 /*4066*/,  6 /*4067*/,  4 /*4068*/,  5 /*4069*/,
    5 /*406a*/,  6 /*406b*/,  5 /*406c*/,  6 /*406d*/,  6 /*406e*/,
    7 /*406f*/,  4 /*4070*/,  5 /*4071*/,  5 /*4072*/,  6 /*4073*/,
    5 /*4074*/,  6 /*4075*/,  6 /*4076*/,  7 /*4077*/,  5 /*4078*/,
    6 /*4079*/,  6 /*407a*/,  7 /*407b*/,  6 /*407c*/,  7 /*407d*/,
    7 /*407e*/,  8 /*407f*/,  2 /*4080*/,  3 /*4081*/,  3 /*4082*/,
    4 /*4083*/,  3 /*4084*/,  4 /*4085*/,  4 /*4086*/,  5 /*4087*/,
    3 /*4088*/,  4 /*4089*/,  4 /*408a*/,  5 /*408b*/,  4 /*408c*/,
    5 /*408d*/,  5 /*408e*/,  6 /*408f*/,  3 /*4090*/,  4 /*4091*/,
    4 /*4092*/,  5 /*4093*/,  4 /*4094*/,  5 /*4095*/,  5 /*4096*/,
    6 /*4097*/,  4 /*4098*/,  5 /*4099*/,  5 /*409a*/,  6 /*409b*/,
    5 /*409c*/,  6 /*409d*/,  6 /*409e*/,  7 /*409f*/,  3 /*40a0*/,
    4 /*40a1*/,  4 /*40a2*/,  5 /*40a3*/,  4 /*40a4*/,  5 /*40a5*/,
    5 /*40a6*/,  6 /*40a7*/,  4 /*40a8*/,  5 /*40a9*/,  5 /*40aa*/,
    6 /*40ab*/,  5 /*40ac*/,  6 /*40ad*/,  6 /*40ae*/,  7 /*40af*/,
    4 /*40b0*/,  5 /*40b1*/,  5 /*40b2*/,  6 /*40b3*/,  5 /*40b4*/,
    6 /*40b5*/,  6 /*40b6*/,  7 /*40b7*/,  5 /*40b8*/,  6 /*40b9*/,
    6 /*40ba*/,  7 /*40bb*/,  6 /*40bc*/,  7 /*40bd*/,  7 /*40be*/,
    8 /*40bf*/,  3 /*40c0*/,  4 /*40c1*/,  4 /*40c2*/,  5 /*40c3*/,
    4 /*40c4*/,  5 /*40c5*/,  5 /*40c6*/,  6 /*40c7*/,  4 /*40c8*/,
    5 /*40c9*/,  5 /*40ca*/,  6 /*40cb*/,  5 /*40cc*/,  6 /*40cd*/,
    6 /*40ce*/,  7 /*40cf*/,  4 /*40d0*/,  5 /*40d1*/,  5 /*40d2*/,
    6 /*40d3*/,  5 /*40d4*/,  6 /*40d5*/,  6 /*40d6*/,  7 /*40d7*/,
    5 /*40d8*/,  6 /*40d9*/,  6 /*40da*/,  7 /*40db*/,  6 /*40dc*/,
    7 /*40dd*/,  7 /*40de*/,  8 /*40df*/,  4 /*40e0*/,  5 /*40e1*/,
    5 /*40e2*/,  6 /*40e3*/,  5 /*40e4*/,  6 /*40e5*/,  6 /*40e6*/,
    7 /*40e7*/,  5 /*40e8*/,  6 /*40e9*/,  6 /*40ea*/,  7 /*40eb*/,
    6 /*40ec*/,  7 /*40ed*/,  7 /*40ee*/,  8 /*40ef*/,  5 /*40f0*/,
    6 /*40f1*/,  6 /*40f2*/,  7 /*40f3*/,  6 /*40f4*/,  7 /*40f5*/,
    7 /*40f6*/,  8 /*40f7*/,  6 /*40f8*/,  7 /*40f9*/,  7 /*40fa*/,
    8 /*40fb*/,  7 /*40fc*/,  8 /*40fd*/,  8 /*40fe*/,  9 /*40ff*/,
    2 /*4100*/,  3 /*4101*/,  3 /*4102*/,  4 /*4103*/,  3 /*4104*/,
    4 /*4105*/,  4 /*4106*/,  5 /*4107*/,  3 /*4108*/,  4 /*4109*/,
    4 /*410a*/,  5 /*410b*/,  4 /*410c*/,  5 /*410d*/,  5 /*410e*/,
    6 /*410f*/,  3 /*4110*/,  4 /*4111*/,  4 /*4112*/,  5 /*4113*/,
    4 /*4114*/,  5 /*4115*/,  5 /*4116*/,  6 /*4117*/,  4 /*4118*/,
    5 /*4119*/,  5 /*411a*/,  6 /*411b*/,  5 /*411c*/,  6 /*411d*/,
    6 /*411e*/,  7 /*411f*/,  3 /*4120*/,  4 /*4121*/,  4 /*4122*/,
    5 /*4123*/,  4 /*4124*/,  5 /*4125*/,  5 /*4126*/,  6 /*4127*/,
    4 /*4128*/,  5 /*4129*/,  5 /*412a*/,  6 /*412b*/,  5 /*412c*/,
    6 /*412d*/,  6 /*412e*/,  7 /*412f*/,  4 /*4130*/,  5 /*4131*/,
    5 /*4132*/,  6 /*4133*/,  5 /*4134*/,  6 /*4135*/,  6 /*4136*/,
    7 /*4137*/,  5 /*4138*/,  6 /*4139*/,  6 /*413a*/,  7 /*413b*/,
    6 /*413c*/,  7 /*413d*/,  7 /*413e*/,  8 /*413f*/,  3 /*4140*/,
    4 /*4141*/,  4 /*4142*/,  5 /*4143*/,  4 /*4144*/,  5 /*4145*/,
    5 /*4146*/,  6 /*4147*/,  4 /*4148*/,  5 /*4149*/,  5 /*414a*/,
    6 /*414b*/,  5 /*414c*/,  6 /*414d*/,  6 /*414e*/,  7 /*414f*/,
    4 /*4150*/,  5 /*4151*/,  5 /*4152*/,  6 /*4153*/,  5 /*4154*/,
    6 /*4155*/,  6 /*4156*/,  7 /*4157*/,  5 /*4158*/,  6 /*4159*/,
    6 /*415a*/,  7 /*415b*/,  6 /*415c*/,  7 /*415d*/,  7 /*415e*/,
    8 /*415f*/,  4 /*4160*/,  5 /*4161*/,  5 /*4162*/,  6 /*4163*/,
    5 /*4164*/,  6 /*4165*/,  6 /*4166*/,  7 /*4167*/,  5 /*4168*/,
    6 /*4169*/,  6 /*416a*/,  7 /*416b*/,  6 /*416c*/,  7 /*416d*/,
    7 /*416e*/,  8 /*416f*/,  5 /*4170*/,  6 /*4171*/,  6 /*4172*/,
    7 /*4173*/,  6 /*4174*/,  7 /*4175*/,  7 /*4176*/,  8 /*4177*/,
    6 /*4178*/,  7 /*4179*/,  7 /*417a*/,  8 /*417b*/,  7 /*417c*/,
    8 /*417d*/,  8 /*417e*/,  9 /*417f*/,  3 /*4180*/,  4 /*4181*/,
    4 /*4182*/,  5 /*4183*/,  4 /*4184*/,  5 /*4185*/,  5 /*4186*/,
    6 /*4187*/,  4 /*4188*/,  5 /*4189*/,  5 /*418a*/,  6 /*418b*/,
    5 /*418c*/,  6 /*418d*/,  6 /*418e*/,  7 /*418f*/,  4 /*4190*/,
    5 /*4191*/,  5 /*4192*/,  6 /*4193*/,  5 /*4194*/,  6 /*4195*/,
    6 /*4196*/,  7 /*4197*/,  5 /*4198*/,  6 /*4199*/,  6 /*419a*/,
    7 /*419b*/,  6 /*419c*/,  7 /*419d*/,  7 /*419e*/,  8 /*419f*/,
    4 /*41a0*/,  5 /*41a1*/,  5 /*41a2*/,  6 /*41a3*/,  5 /*41a4*/,
    6 /*41a5*/,  6 /*41a6*/,  7 /*41a7*/,  5 /*41a8*/,  6 /*41a9*/,
    6 /*41aa*/,  7 /*41ab*/,  6 /*41ac*/,  7 /*41ad*/,  7 /*41ae*/,
    8 /*41af*/,  5 /*41b0*/,  6 /*41b1*/,  6 /*41b2*/,  7 /*41b3*/,
    6 /*41b4*/,  7 /*41b5*/,  7 /*41b6*/,  8 /*41b7*/,  6 /*41b8*/,
    7 /*41b9*/,  7 /*41ba*/,  8 /*41bb*/,  7 /*41bc*/,  8 /*41bd*/,
    8 /*41be*/,  9 /*41bf*/,  4 /*41c0*/,  5 /*41c1*/,  5 /*41c2*/,
    6 /*41c3*/,  5 /*41c4*/,  6 /*41c5*/,  6 /*41c6*/,  7 /*41c7*/,
    5 /*41c8*/,  6 /*41c9*/,  6 /*41ca*/,  7 /*41cb*/,  6 /*41cc*/,
    7 /*41cd*/,  7 /*41ce*/,  8 /*41cf*/,  5 /*41d0*/,  6 /*41d1*/,
    6 /*41d2*/,  7 /*41d3*/,  6 /*41d4*/,  7 /*41d5*/,  7 /*41d6*/,
    8 /*41d7*/,  6 /*41d8*/,  7 /*41d9*/,  7 /*41da*/,  8 /*41db*/,
    7 /*41dc*/,  8 /*41dd*/,  8 /*41de*/,  9 /*41df*/,  5 /*41e0*/,
    6 /*41e1*/,  6 /*41e2*/,  7 /*41e3*/,  6 /*41e4*/,  7 /*41e5*/,
    7 /*41e6*/,  8 /*41e7*/,  6 /*41e8*/,  7 /*41e9*/,  7 /*41ea*/,
    8 /*41eb*/,  7 /*41ec*/,  8 /*41ed*/,  8 /*41ee*/,  9 /*41ef*/,
    6 /*41f0*/,  7 /*41f1*/,  7 /*41f2*/,  8 /*41f3*/,  7 /*41f4*/,
    8 /*41f5*/,  8 /*41f6*/,  9 /*41f7*/,  7 /*41f8*/,  8 /*41f9*/,
    8 /*41fa*/,  9 /*41fb*/,  8 /*41fc*/,  9 /*41fd*/,  9 /*41fe*/,
    10 /*41ff*/, 2 /*4200*/,  3 /*4201*/,  3 /*4202*/,  4 /*4203*/,
    3 /*4204*/,  4 /*4205*/,  4 /*4206*/,  5 /*4207*/,  3 /*4208*/,
    4 /*4209*/,  4 /*420a*/,  5 /*420b*/,  4 /*420c*/,  5 /*420d*/,
    5 /*420e*/,  6 /*420f*/,  3 /*4210*/,  4 /*4211*/,  4 /*4212*/,
    5 /*4213*/,  4 /*4214*/,  5 /*4215*/,  5 /*4216*/,  6 /*4217*/,
    4 /*4218*/,  5 /*4219*/,  5 /*421a*/,  6 /*421b*/,  5 /*421c*/,
    6 /*421d*/,  6 /*421e*/,  7 /*421f*/,  3 /*4220*/,  4 /*4221*/,
    4 /*4222*/,  5 /*4223*/,  4 /*4224*/,  5 /*4225*/,  5 /*4226*/,
    6 /*4227*/,  4 /*4228*/,  5 /*4229*/,  5 /*422a*/,  6 /*422b*/,
    5 /*422c*/,  6 /*422d*/,  6 /*422e*/,  7 /*422f*/,  4 /*4230*/,
    5 /*4231*/,  5 /*4232*/,  6 /*4233*/,  5 /*4234*/,  6 /*4235*/,
    6 /*4236*/,  7 /*4237*/,  5 /*4238*/,  6 /*4239*/,  6 /*423a*/,
    7 /*423b*/,  6 /*423c*/,  7 /*423d*/,  7 /*423e*/,  8 /*423f*/,
    3 /*4240*/,  4 /*4241*/,  4 /*4242*/,  5 /*4243*/,  4 /*4244*/,
    5 /*4245*/,  5 /*4246*/,  6 /*4247*/,  4 /*4248*/,  5 /*4249*/,
    5 /*424a*/,  6 /*424b*/,  5 /*424c*/,  6 /*424d*/,  6 /*424e*/,
    7 /*424f*/,  4 /*4250*/,  5 /*4251*/,  5 /*4252*/,  6 /*4253*/,
    5 /*4254*/,  6 /*4255*/,  6 /*4256*/,  7 /*4257*/,  5 /*4258*/,
    6 /*4259*/,  6 /*425a*/,  7 /*425b*/,  6 /*425c*/,  7 /*425d*/,
    7 /*425e*/,  8 /*425f*/,  4 /*4260*/,  5 /*4261*/,  5 /*4262*/,
    6 /*4263*/,  5 /*4264*/,  6 /*4265*/,  6 /*4266*/,  7 /*4267*/,
    5 /*4268*/,  6 /*4269*/,  6 /*426a*/,  7 /*426b*/,  6 /*426c*/,
    7 /*426d*/,  7 /*426e*/,  8 /*426f*/,  5 /*4270*/,  6 /*4271*/,
    6 /*4272*/,  7 /*4273*/,  6 /*4274*/,  7 /*4275*/,  7 /*4276*/,
    8 /*4277*/,  6 /*4278*/,  7 /*4279*/,  7 /*427a*/,  8 /*427b*/,
    7 /*427c*/,  8 /*427d*/,  8 /*427e*/,  9 /*427f*/,  3 /*4280*/,
    4 /*4281*/,  4 /*4282*/,  5 /*4283*/,  4 /*4284*/,  5 /*4285*/,
    5 /*4286*/,  6 /*4287*/,  4 /*4288*/,  5 /*4289*/,  5 /*428a*/,
    6 /*428b*/,  5 /*428c*/,  6 /*428d*/,  6 /*428e*/,  7 /*428f*/,
    4 /*4290*/,  5 /*4291*/,  5 /*4292*/,  6 /*4293*/,  5 /*4294*/,
    6 /*4295*/,  6 /*4296*/,  7 /*4297*/,  5 /*4298*/,  6 /*4299*/,
    6 /*429a*/,  7 /*429b*/,  6 /*429c*/,  7 /*429d*/,  7 /*429e*/,
    8 /*429f*/,  4 /*42a0*/,  5 /*42a1*/,  5 /*42a2*/,  6 /*42a3*/,
    5 /*42a4*/,  6 /*42a5*/,  6 /*42a6*/,  7 /*42a7*/,  5 /*42a8*/,
    6 /*42a9*/,  6 /*42aa*/,  7 /*42ab*/,  6 /*42ac*/,  7 /*42ad*/,
    7 /*42ae*/,  8 /*42af*/,  5 /*42b0*/,  6 /*42b1*/,  6 /*42b2*/,
    7 /*42b3*/,  6 /*42b4*/,  7 /*42b5*/,  7 /*42b6*/,  8 /*42b7*/,
    6 /*42b8*/,  7 /*42b9*/,  7 /*42ba*/,  8 /*42bb*/,  7 /*42bc*/,
    8 /*42bd*/,  8 /*42be*/,  9 /*42bf*/,  4 /*42c0*/,  5 /*42c1*/,
    5 /*42c2*/,  6 /*42c3*/,  5 /*42c4*/,  6 /*42c5*/,  6 /*42c6*/,
    7 /*42c7*/,  5 /*42c8*/,  6 /*42c9*/,  6 /*42ca*/,  7 /*42cb*/,
    6 /*42cc*/,  7 /*42cd*/,  7 /*42ce*/,  8 /*42cf*/,  5 /*42d0*/,
    6 /*42d1*/,  6 /*42d2*/,  7 /*42d3*/,  6 /*42d4*/,  7 /*42d5*/,
    7 /*42d6*/,  8 /*42d7*/,  6 /*42d8*/,  7 /*42d9*/,  7 /*42da*/,
    8 /*42db*/,  7 /*42dc*/,  8 /*42dd*/,  8 /*42de*/,  9 /*42df*/,
    5 /*42e0*/,  6 /*42e1*/,  6 /*42e2*/,  7 /*42e3*/,  6 /*42e4*/,
    7 /*42e5*/,  7 /*42e6*/,  8 /*42e7*/,  6 /*42e8*/,  7 /*42e9*/,
    7 /*42ea*/,  8 /*42eb*/,  7 /*42ec*/,  8 /*42ed*/,  8 /*42ee*/,
    9 /*42ef*/,  6 /*42f0*/,  7 /*42f1*/,  7 /*42f2*/,  8 /*42f3*/,
    7 /*42f4*/,  8 /*42f5*/,  8 /*42f6*/,  9 /*42f7*/,  7 /*42f8*/,
    8 /*42f9*/,  8 /*42fa*/,  9 /*42fb*/,  8 /*42fc*/,  9 /*42fd*/,
    9 /*42fe*/,  10 /*42ff*/, 3 /*4300*/,  4 /*4301*/,  4 /*4302*/,
    5 /*4303*/,  4 /*4304*/,  5 /*4305*/,  5 /*4306*/,  6 /*4307*/,
    4 /*4308*/,  5 /*4309*/,  5 /*430a*/,  6 /*430b*/,  5 /*430c*/,
    6 /*430d*/,  6 /*430e*/,  7 /*430f*/,  4 /*4310*/,  5 /*4311*/,
    5 /*4312*/,  6 /*4313*/,  5 /*4314*/,  6 /*4315*/,  6 /*4316*/,
    7 /*4317*/,  5 /*4318*/,  6 /*4319*/,  6 /*431a*/,  7 /*431b*/,
    6 /*431c*/,  7 /*431d*/,  7 /*431e*/,  8 /*431f*/,  4 /*4320*/,
    5 /*4321*/,  5 /*4322*/,  6 /*4323*/,  5 /*4324*/,  6 /*4325*/,
    6 /*4326*/,  7 /*4327*/,  5 /*4328*/,  6 /*4329*/,  6 /*432a*/,
    7 /*432b*/,  6 /*432c*/,  7 /*432d*/,  7 /*432e*/,  8 /*432f*/,
    5 /*4330*/,  6 /*4331*/,  6 /*4332*/,  7 /*4333*/,  6 /*4334*/,
    7 /*4335*/,  7 /*4336*/,  8 /*4337*/,  6 /*4338*/,  7 /*4339*/,
    7 /*433a*/,  8 /*433b*/,  7 /*433c*/,  8 /*433d*/,  8 /*433e*/,
    9 /*433f*/,  4 /*4340*/,  5 /*4341*/,  5 /*4342*/,  6 /*4343*/,
    5 /*4344*/,  6 /*4345*/,  6 /*4346*/,  7 /*4347*/,  5 /*4348*/,
    6 /*4349*/,  6 /*434a*/,  7 /*434b*/,  6 /*434c*/,  7 /*434d*/,
    7 /*434e*/,  8 /*434f*/,  5 /*4350*/,  6 /*4351*/,  6 /*4352*/,
    7 /*4353*/,  6 /*4354*/,  7 /*4355*/,  7 /*4356*/,  8 /*4357*/,
    6 /*4358*/,  7 /*4359*/,  7 /*435a*/,  8 /*435b*/,  7 /*435c*/,
    8 /*435d*/,  8 /*435e*/,  9 /*435f*/,  5 /*4360*/,  6 /*4361*/,
    6 /*4362*/,  7 /*4363*/,  6 /*4364*/,  7 /*4365*/,  7 /*4366*/,
    8 /*4367*/,  6 /*4368*/,  7 /*4369*/,  7 /*436a*/,  8 /*436b*/,
    7 /*436c*/,  8 /*436d*/,  8 /*436e*/,  9 /*436f*/,  6 /*4370*/,
    7 /*4371*/,  7 /*4372*/,  8 /*4373*/,  7 /*4374*/,  8 /*4375*/,
    8 /*4376*/,  9 /*4377*/,  7 /*4378*/,  8 /*4379*/,  8 /*437a*/,
    9 /*437b*/,  8 /*437c*/,  9 /*437d*/,  9 /*437e*/,  10 /*437f*/,
    4 /*4380*/,  5 /*4381*/,  5 /*4382*/,  6 /*4383*/,  5 /*4384*/,
    6 /*4385*/,  6 /*4386*/,  7 /*4387*/,  5 /*4388*/,  6 /*4389*/,
    6 /*438a*/,  7 /*438b*/,  6 /*438c*/,  7 /*438d*/,  7 /*438e*/,
    8 /*438f*/,  5 /*4390*/,  6 /*4391*/,  6 /*4392*/,  7 /*4393*/,
    6 /*4394*/,  7 /*4395*/,  7 /*4396*/,  8 /*4397*/,  6 /*4398*/,
    7 /*4399*/,  7 /*439a*/,  8 /*439b*/,  7 /*439c*/,  8 /*439d*/,
    8 /*439e*/,  9 /*439f*/,  5 /*43a0*/,  6 /*43a1*/,  6 /*43a2*/,
    7 /*43a3*/,  6 /*43a4*/,  7 /*43a5*/,  7 /*43a6*/,  8 /*43a7*/,
    6 /*43a8*/,  7 /*43a9*/,  7 /*43aa*/,  8 /*43ab*/,  7 /*43ac*/,
    8 /*43ad*/,  8 /*43ae*/,  9 /*43af*/,  6 /*43b0*/,  7 /*43b1*/,
    7 /*43b2*/,  8 /*43b3*/,  7 /*43b4*/,  8 /*43b5*/,  8 /*43b6*/,
    9 /*43b7*/,  7 /*43b8*/,  8 /*43b9*/,  8 /*43ba*/,  9 /*43bb*/,
    8 /*43bc*/,  9 /*43bd*/,  9 /*43be*/,  10 /*43bf*/, 5 /*43c0*/,
    6 /*43c1*/,  6 /*43c2*/,  7 /*43c3*/,  6 /*43c4*/,  7 /*43c5*/,
    7 /*43c6*/,  8 /*43c7*/,  6 /*43c8*/,  7 /*43c9*/,  7 /*43ca*/,
    8 /*43cb*/,  7 /*43cc*/,  8 /*43cd*/,  8 /*43ce*/,  9 /*43cf*/,
    6 /*43d0*/,  7 /*43d1*/,  7 /*43d2*/,  8 /*43d3*/,  7 /*43d4*/,
    8 /*43d5*/,  8 /*43d6*/,  9 /*43d7*/,  7 /*43d8*/,  8 /*43d9*/,
    8 /*43da*/,  9 /*43db*/,  8 /*43dc*/,  9 /*43dd*/,  9 /*43de*/,
    10 /*43df*/, 6 /*43e0*/,  7 /*43e1*/,  7 /*43e2*/,  8 /*43e3*/,
    7 /*43e4*/,  8 /*43e5*/,  8 /*43e6*/,  9 /*43e7*/,  7 /*43e8*/,
    8 /*43e9*/,  8 /*43ea*/,  9 /*43eb*/,  8 /*43ec*/,  9 /*43ed*/,
    9 /*43ee*/,  10 /*43ef*/, 7 /*43f0*/,  8 /*43f1*/,  8 /*43f2*/,
    9 /*43f3*/,  8 /*43f4*/,  9 /*43f5*/,  9 /*43f6*/,  10 /*43f7*/,
    8 /*43f8*/,  9 /*43f9*/,  9 /*43fa*/,  10 /*43fb*/, 9 /*43fc*/,
    10 /*43fd*/, 10 /*43fe*/, 11 /*43ff*/, 2 /*4400*/,  3 /*4401*/,
    3 /*4402*/,  4 /*4403*/,  3 /*4404*/,  4 /*4405*/,  4 /*4406*/,
    5 /*4407*/,  3 /*4408*/,  4 /*4409*/,  4 /*440a*/,  5 /*440b*/,
    4 /*440c*/,  5 /*440d*/,  5 /*440e*/,  6 /*440f*/,  3 /*4410*/,
    4 /*4411*/,  4 /*4412*/,  5 /*4413*/,  4 /*4414*/,  5 /*4415*/,
    5 /*4416*/,  6 /*4417*/,  4 /*4418*/,  5 /*4419*/,  5 /*441a*/,
    6 /*441b*/,  5 /*441c*/,  6 /*441d*/,  6 /*441e*/,  7 /*441f*/,
    3 /*4420*/,  4 /*4421*/,  4 /*4422*/,  5 /*4423*/,  4 /*4424*/,
    5 /*4425*/,  5 /*4426*/,  6 /*4427*/,  4 /*4428*/,  5 /*4429*/,
    5 /*442a*/,  6 /*442b*/,  5 /*442c*/,  6 /*442d*/,  6 /*442e*/,
    7 /*442f*/,  4 /*4430*/,  5 /*4431*/,  5 /*4432*/,  6 /*4433*/,
    5 /*4434*/,  6 /*4435*/,  6 /*4436*/,  7 /*4437*/,  5 /*4438*/,
    6 /*4439*/,  6 /*443a*/,  7 /*443b*/,  6 /*443c*/,  7 /*443d*/,
    7 /*443e*/,  8 /*443f*/,  3 /*4440*/,  4 /*4441*/,  4 /*4442*/,
    5 /*4443*/,  4 /*4444*/,  5 /*4445*/,  5 /*4446*/,  6 /*4447*/,
    4 /*4448*/,  5 /*4449*/,  5 /*444a*/,  6 /*444b*/,  5 /*444c*/,
    6 /*444d*/,  6 /*444e*/,  7 /*444f*/,  4 /*4450*/,  5 /*4451*/,
    5 /*4452*/,  6 /*4453*/,  5 /*4454*/,  6 /*4455*/,  6 /*4456*/,
    7 /*4457*/,  5 /*4458*/,  6 /*4459*/,  6 /*445a*/,  7 /*445b*/,
    6 /*445c*/,  7 /*445d*/,  7 /*445e*/,  8 /*445f*/,  4 /*4460*/,
    5 /*4461*/,  5 /*4462*/,  6 /*4463*/,  5 /*4464*/,  6 /*4465*/,
    6 /*4466*/,  7 /*4467*/,  5 /*4468*/,  6 /*4469*/,  6 /*446a*/,
    7 /*446b*/,  6 /*446c*/,  7 /*446d*/,  7 /*446e*/,  8 /*446f*/,
    5 /*4470*/,  6 /*4471*/,  6 /*4472*/,  7 /*4473*/,  6 /*4474*/,
    7 /*4475*/,  7 /*4476*/,  8 /*4477*/,  6 /*4478*/,  7 /*4479*/,
    7 /*447a*/,  8 /*447b*/,  7 /*447c*/,  8 /*447d*/,  8 /*447e*/,
    9 /*447f*/,  3 /*4480*/,  4 /*4481*/,  4 /*4482*/,  5 /*4483*/,
    4 /*4484*/,  5 /*4485*/,  5 /*4486*/,  6 /*4487*/,  4 /*4488*/,
    5 /*4489*/,  5 /*448a*/,  6 /*448b*/,  5 /*448c*/,  6 /*448d*/,
    6 /*448e*/,  7 /*448f*/,  4 /*4490*/,  5 /*4491*/,  5 /*4492*/,
    6 /*4493*/,  5 /*4494*/,  6 /*4495*/,  6 /*4496*/,  7 /*4497*/,
    5 /*4498*/,  6 /*4499*/,  6 /*449a*/,  7 /*449b*/,  6 /*449c*/,
    7 /*449d*/,  7 /*449e*/,  8 /*449f*/,  4 /*44a0*/,  5 /*44a1*/,
    5 /*44a2*/,  6 /*44a3*/,  5 /*44a4*/,  6 /*44a5*/,  6 /*44a6*/,
    7 /*44a7*/,  5 /*44a8*/,  6 /*44a9*/,  6 /*44aa*/,  7 /*44ab*/,
    6 /*44ac*/,  7 /*44ad*/,  7 /*44ae*/,  8 /*44af*/,  5 /*44b0*/,
    6 /*44b1*/,  6 /*44b2*/,  7 /*44b3*/,  6 /*44b4*/,  7 /*44b5*/,
    7 /*44b6*/,  8 /*44b7*/,  6 /*44b8*/,  7 /*44b9*/,  7 /*44ba*/,
    8 /*44bb*/,  7 /*44bc*/,  8 /*44bd*/,  8 /*44be*/,  9 /*44bf*/,
    4 /*44c0*/,  5 /*44c1*/,  5 /*44c2*/,  6 /*44c3*/,  5 /*44c4*/,
    6 /*44c5*/,  6 /*44c6*/,  7 /*44c7*/,  5 /*44c8*/,  6 /*44c9*/,
    6 /*44ca*/,  7 /*44cb*/,  6 /*44cc*/,  7 /*44cd*/,  7 /*44ce*/,
    8 /*44cf*/,  5 /*44d0*/,  6 /*44d1*/,  6 /*44d2*/,  7 /*44d3*/,
    6 /*44d4*/,  7 /*44d5*/,  7 /*44d6*/,  8 /*44d7*/,  6 /*44d8*/,
    7 /*44d9*/,  7 /*44da*/,  8 /*44db*/,  7 /*44dc*/,  8 /*44dd*/,
    8 /*44de*/,  9 /*44df*/,  5 /*44e0*/,  6 /*44e1*/,  6 /*44e2*/,
    7 /*44e3*/,  6 /*44e4*/,  7 /*44e5*/,  7 /*44e6*/,  8 /*44e7*/,
    6 /*44e8*/,  7 /*44e9*/,  7 /*44ea*/,  8 /*44eb*/,  7 /*44ec*/,
    8 /*44ed*/,  8 /*44ee*/,  9 /*44ef*/,  6 /*44f0*/,  7 /*44f1*/,
    7 /*44f2*/,  8 /*44f3*/,  7 /*44f4*/,  8 /*44f5*/,  8 /*44f6*/,
    9 /*44f7*/,  7 /*44f8*/,  8 /*44f9*/,  8 /*44fa*/,  9 /*44fb*/,
    8 /*44fc*/,  9 /*44fd*/,  9 /*44fe*/,  10 /*44ff*/, 3 /*4500*/,
    4 /*4501*/,  4 /*4502*/,  5 /*4503*/,  4 /*4504*/,  5 /*4505*/,
    5 /*4506*/,  6 /*4507*/,  4 /*4508*/,  5 /*4509*/,  5 /*450a*/,
    6 /*450b*/,  5 /*450c*/,  6 /*450d*/,  6 /*450e*/,  7 /*450f*/,
    4 /*4510*/,  5 /*4511*/,  5 /*4512*/,  6 /*4513*/,  5 /*4514*/,
    6 /*4515*/,  6 /*4516*/,  7 /*4517*/,  5 /*4518*/,  6 /*4519*/,
    6 /*451a*/,  7 /*451b*/,  6 /*451c*/,  7 /*451d*/,  7 /*451e*/,
    8 /*451f*/,  4 /*4520*/,  5 /*4521*/,  5 /*4522*/,  6 /*4523*/,
    5 /*4524*/,  6 /*4525*/,  6 /*4526*/,  7 /*4527*/,  5 /*4528*/,
    6 /*4529*/,  6 /*452a*/,  7 /*452b*/,  6 /*452c*/,  7 /*452d*/,
    7 /*452e*/,  8 /*452f*/,  5 /*4530*/,  6 /*4531*/,  6 /*4532*/,
    7 /*4533*/,  6 /*4534*/,  7 /*4535*/,  7 /*4536*/,  8 /*4537*/,
    6 /*4538*/,  7 /*4539*/,  7 /*453a*/,  8 /*453b*/,  7 /*453c*/,
    8 /*453d*/,  8 /*453e*/,  9 /*453f*/,  4 /*4540*/,  5 /*4541*/,
    5 /*4542*/,  6 /*4543*/,  5 /*4544*/,  6 /*4545*/,  6 /*4546*/,
    7 /*4547*/,  5 /*4548*/,  6 /*4549*/,  6 /*454a*/,  7 /*454b*/,
    6 /*454c*/,  7 /*454d*/,  7 /*454e*/,  8 /*454f*/,  5 /*4550*/,
    6 /*4551*/,  6 /*4552*/,  7 /*4553*/,  6 /*4554*/,  7 /*4555*/,
    7 /*4556*/,  8 /*4557*/,  6 /*4558*/,  7 /*4559*/,  7 /*455a*/,
    8 /*455b*/,  7 /*455c*/,  8 /*455d*/,  8 /*455e*/,  9 /*455f*/,
    5 /*4560*/,  6 /*4561*/,  6 /*4562*/,  7 /*4563*/,  6 /*4564*/,
    7 /*4565*/,  7 /*4566*/,  8 /*4567*/,  6 /*4568*/,  7 /*4569*/,
    7 /*456a*/,  8 /*456b*/,  7 /*456c*/,  8 /*456d*/,  8 /*456e*/,
    9 /*456f*/,  6 /*4570*/,  7 /*4571*/,  7 /*4572*/,  8 /*4573*/,
    7 /*4574*/,  8 /*4575*/,  8 /*4576*/,  9 /*4577*/,  7 /*4578*/,
    8 /*4579*/,  8 /*457a*/,  9 /*457b*/,  8 /*457c*/,  9 /*457d*/,
    9 /*457e*/,  10 /*457f*/, 4 /*4580*/,  5 /*4581*/,  5 /*4582*/,
    6 /*4583*/,  5 /*4584*/,  6 /*4585*/,  6 /*4586*/,  7 /*4587*/,
    5 /*4588*/,  6 /*4589*/,  6 /*458a*/,  7 /*458b*/,  6 /*458c*/,
    7 /*458d*/,  7 /*458e*/,  8 /*458f*/,  5 /*4590*/,  6 /*4591*/,
    6 /*4592*/,  7 /*4593*/,  6 /*4594*/,  7 /*4595*/,  7 /*4596*/,
    8 /*4597*/,  6 /*4598*/,  7 /*4599*/,  7 /*459a*/,  8 /*459b*/,
    7 /*459c*/,  8 /*459d*/,  8 /*459e*/,  9 /*459f*/,  5 /*45a0*/,
    6 /*45a1*/,  6 /*45a2*/,  7 /*45a3*/,  6 /*45a4*/,  7 /*45a5*/,
    7 /*45a6*/,  8 /*45a7*/,  6 /*45a8*/,  7 /*45a9*/,  7 /*45aa*/,
    8 /*45ab*/,  7 /*45ac*/,  8 /*45ad*/,  8 /*45ae*/,  9 /*45af*/,
    6 /*45b0*/,  7 /*45b1*/,  7 /*45b2*/,  8 /*45b3*/,  7 /*45b4*/,
    8 /*45b5*/,  8 /*45b6*/,  9 /*45b7*/,  7 /*45b8*/,  8 /*45b9*/,
    8 /*45ba*/,  9 /*45bb*/,  8 /*45bc*/,  9 /*45bd*/,  9 /*45be*/,
    10 /*45bf*/, 5 /*45c0*/,  6 /*45c1*/,  6 /*45c2*/,  7 /*45c3*/,
    6 /*45c4*/,  7 /*45c5*/,  7 /*45c6*/,  8 /*45c7*/,  6 /*45c8*/,
    7 /*45c9*/,  7 /*45ca*/,  8 /*45cb*/,  7 /*45cc*/,  8 /*45cd*/,
    8 /*45ce*/,  9 /*45cf*/,  6 /*45d0*/,  7 /*45d1*/,  7 /*45d2*/,
    8 /*45d3*/,  7 /*45d4*/,  8 /*45d5*/,  8 /*45d6*/,  9 /*45d7*/,
    7 /*45d8*/,  8 /*45d9*/,  8 /*45da*/,  9 /*45db*/,  8 /*45dc*/,
    9 /*45dd*/,  9 /*45de*/,  10 /*45df*/, 6 /*45e0*/,  7 /*45e1*/,
    7 /*45e2*/,  8 /*45e3*/,  7 /*45e4*/,  8 /*45e5*/,  8 /*45e6*/,
    9 /*45e7*/,  7 /*45e8*/,  8 /*45e9*/,  8 /*45ea*/,  9 /*45eb*/,
    8 /*45ec*/,  9 /*45ed*/,  9 /*45ee*/,  10 /*45ef*/, 7 /*45f0*/,
    8 /*45f1*/,  8 /*45f2*/,  9 /*45f3*/,  8 /*45f4*/,  9 /*45f5*/,
    9 /*45f6*/,  10 /*45f7*/, 8 /*45f8*/,  9 /*45f9*/,  9 /*45fa*/,
    10 /*45fb*/, 9 /*45fc*/,  10 /*45fd*/, 10 /*45fe*/, 11 /*45ff*/,
    3 /*4600*/,  4 /*4601*/,  4 /*4602*/,  5 /*4603*/,  4 /*4604*/,
    5 /*4605*/,  5 /*4606*/,  6 /*4607*/,  4 /*4608*/,  5 /*4609*/,
    5 /*460a*/,  6 /*460b*/,  5 /*460c*/,  6 /*460d*/,  6 /*460e*/,
    7 /*460f*/,  4 /*4610*/,  5 /*4611*/,  5 /*4612*/,  6 /*4613*/,
    5 /*4614*/,  6 /*4615*/,  6 /*4616*/,  7 /*4617*/,  5 /*4618*/,
    6 /*4619*/,  6 /*461a*/,  7 /*461b*/,  6 /*461c*/,  7 /*461d*/,
    7 /*461e*/,  8 /*461f*/,  4 /*4620*/,  5 /*4621*/,  5 /*4622*/,
    6 /*4623*/,  5 /*4624*/,  6 /*4625*/,  6 /*4626*/,  7 /*4627*/,
    5 /*4628*/,  6 /*4629*/,  6 /*462a*/,  7 /*462b*/,  6 /*462c*/,
    7 /*462d*/,  7 /*462e*/,  8 /*462f*/,  5 /*4630*/,  6 /*4631*/,
    6 /*4632*/,  7 /*4633*/,  6 /*4634*/,  7 /*4635*/,  7 /*4636*/,
    8 /*4637*/,  6 /*4638*/,  7 /*4639*/,  7 /*463a*/,  8 /*463b*/,
    7 /*463c*/,  8 /*463d*/,  8 /*463e*/,  9 /*463f*/,  4 /*4640*/,
    5 /*4641*/,  5 /*4642*/,  6 /*4643*/,  5 /*4644*/,  6 /*4645*/,
    6 /*4646*/,  7 /*4647*/,  5 /*4648*/,  6 /*4649*/,  6 /*464a*/,
    7 /*464b*/,  6 /*464c*/,  7 /*464d*/,  7 /*464e*/,  8 /*464f*/,
    5 /*4650*/,  6 /*4651*/,  6 /*4652*/,  7 /*4653*/,  6 /*4654*/,
    7 /*4655*/,  7 /*4656*/,  8 /*4657*/,  6 /*4658*/,  7 /*4659*/,
    7 /*465a*/,  8 /*465b*/,  7 /*465c*/,  8 /*465d*/,  8 /*465e*/,
    9 /*465f*/,  5 /*4660*/,  6 /*4661*/,  6 /*4662*/,  7 /*4663*/,
    6 /*4664*/,  7 /*4665*/,  7 /*4666*/,  8 /*4667*/,  6 /*4668*/,
    7 /*4669*/,  7 /*466a*/,  8 /*466b*/,  7 /*466c*/,  8 /*466d*/,
    8 /*466e*/,  9 /*466f*/,  6 /*4670*/,  7 /*4671*/,  7 /*4672*/,
    8 /*4673*/,  7 /*4674*/,  8 /*4675*/,  8 /*4676*/,  9 /*4677*/,
    7 /*4678*/,  8 /*4679*/,  8 /*467a*/,  9 /*467b*/,  8 /*467c*/,
    9 /*467d*/,  9 /*467e*/,  10 /*467f*/, 4 /*4680*/,  5 /*4681*/,
    5 /*4682*/,  6 /*4683*/,  5 /*4684*/,  6 /*4685*/,  6 /*4686*/,
    7 /*4687*/,  5 /*4688*/,  6 /*4689*/,  6 /*468a*/,  7 /*468b*/,
    6 /*468c*/,  7 /*468d*/,  7 /*468e*/,  8 /*468f*/,  5 /*4690*/,
    6 /*4691*/,  6 /*4692*/,  7 /*4693*/,  6 /*4694*/,  7 /*4695*/,
    7 /*4696*/,  8 /*4697*/,  6 /*4698*/,  7 /*4699*/,  7 /*469a*/,
    8 /*469b*/,  7 /*469c*/,  8 /*469d*/,  8 /*469e*/,  9 /*469f*/,
    5 /*46a0*/,  6 /*46a1*/,  6 /*46a2*/,  7 /*46a3*/,  6 /*46a4*/,
    7 /*46a5*/,  7 /*46a6*/,  8 /*46a7*/,  6 /*46a8*/,  7 /*46a9*/,
    7 /*46aa*/,  8 /*46ab*/,  7 /*46ac*/,  8 /*46ad*/,  8 /*46ae*/,
    9 /*46af*/,  6 /*46b0*/,  7 /*46b1*/,  7 /*46b2*/,  8 /*46b3*/,
    7 /*46b4*/,  8 /*46b5*/,  8 /*46b6*/,  9 /*46b7*/,  7 /*46b8*/,
    8 /*46b9*/,  8 /*46ba*/,  9 /*46bb*/,  8 /*46bc*/,  9 /*46bd*/,
    9 /*46be*/,  10 /*46bf*/, 5 /*46c0*/,  6 /*46c1*/,  6 /*46c2*/,
    7 /*46c3*/,  6 /*46c4*/,  7 /*46c5*/,  7 /*46c6*/,  8 /*46c7*/,
    6 /*46c8*/,  7 /*46c9*/,  7 /*46ca*/,  8 /*46cb*/,  7 /*46cc*/,
    8 /*46cd*/,  8 /*46ce*/,  9 /*46cf*/,  6 /*46d0*/,  7 /*46d1*/,
    7 /*46d2*/,  8 /*46d3*/,  7 /*46d4*/,  8 /*46d5*/,  8 /*46d6*/,
    9 /*46d7*/,  7 /*46d8*/,  8 /*46d9*/,  8 /*46da*/,  9 /*46db*/,
    8 /*46dc*/,  9 /*46dd*/,  9 /*46de*/,  10 /*46df*/, 6 /*46e0*/,
    7 /*46e1*/,  7 /*46e2*/,  8 /*46e3*/,  7 /*46e4*/,  8 /*46e5*/,
    8 /*46e6*/,  9 /*46e7*/,  7 /*46e8*/,  8 /*46e9*/,  8 /*46ea*/,
    9 /*46eb*/,  8 /*46ec*/,  9 /*46ed*/,  9 /*46ee*/,  10 /*46ef*/,
    7 /*46f0*/,  8 /*46f1*/,  8 /*46f2*/,  9 /*46f3*/,  8 /*46f4*/,
    9 /*46f5*/,  9 /*46f6*/,  10 /*46f7*/, 8 /*46f8*/,  9 /*46f9*/,
    9 /*46fa*/,  10 /*46fb*/, 9 /*46fc*/,  10 /*46fd*/, 10 /*46fe*/,
    11 /*46ff*/, 4 /*4700*/,  5 /*4701*/,  5 /*4702*/,  6 /*4703*/,
    5 /*4704*/,  6 /*4705*/,  6 /*4706*/,  7 /*4707*/,  5 /*4708*/,
    6 /*4709*/,  6 /*470a*/,  7 /*470b*/,  6 /*470c*/,  7 /*470d*/,
    7 /*470e*/,  8 /*470f*/,  5 /*4710*/,  6 /*4711*/,  6 /*4712*/,
    7 /*4713*/,  6 /*4714*/,  7 /*4715*/,  7 /*4716*/,  8 /*4717*/,
    6 /*4718*/,  7 /*4719*/,  7 /*471a*/,  8 /*471b*/,  7 /*471c*/,
    8 /*471d*/,  8 /*471e*/,  9 /*471f*/,  5 /*4720*/,  6 /*4721*/,
    6 /*4722*/,  7 /*4723*/,  6 /*4724*/,  7 /*4725*/,  7 /*4726*/,
    8 /*4727*/,  6 /*4728*/,  7 /*4729*/,  7 /*472a*/,  8 /*472b*/,
    7 /*472c*/,  8 /*472d*/,  8 /*472e*/,  9 /*472f*/,  6 /*4730*/,
    7 /*4731*/,  7 /*4732*/,  8 /*4733*/,  7 /*4734*/,  8 /*4735*/,
    8 /*4736*/,  9 /*4737*/,  7 /*4738*/,  8 /*4739*/,  8 /*473a*/,
    9 /*473b*/,  8 /*473c*/,  9 /*473d*/,  9 /*473e*/,  10 /*473f*/,
    5 /*4740*/,  6 /*4741*/,  6 /*4742*/,  7 /*4743*/,  6 /*4744*/,
    7 /*4745*/,  7 /*4746*/,  8 /*4747*/,  6 /*4748*/,  7 /*4749*/,
    7 /*474a*/,  8 /*474b*/,  7 /*474c*/,  8 /*474d*/,  8 /*474e*/,
    9 /*474f*/,  6 /*4750*/,  7 /*4751*/,  7 /*4752*/,  8 /*4753*/,
    7 /*4754*/,  8 /*4755*/,  8 /*4756*/,  9 /*4757*/,  7 /*4758*/,
    8 /*4759*/,  8 /*475a*/,  9 /*475b*/,  8 /*475c*/,  9 /*475d*/,
    9 /*475e*/,  10 /*475f*/, 6 /*4760*/,  7 /*4761*/,  7 /*4762*/,
    8 /*4763*/,  7 /*4764*/,  8 /*4765*/,  8 /*4766*/,  9 /*4767*/,
    7 /*4768*/,  8 /*4769*/,  8 /*476a*/,  9 /*476b*/,  8 /*476c*/,
    9 /*476d*/,  9 /*476e*/,  10 /*476f*/, 7 /*4770*/,  8 /*4771*/,
    8 /*4772*/,  9 /*4773*/,  8 /*4774*/,  9 /*4775*/,  9 /*4776*/,
    10 /*4777*/, 8 /*4778*/,  9 /*4779*/,  9 /*477a*/,  10 /*477b*/,
    9 /*477c*/,  10 /*477d*/, 10 /*477e*/, 11 /*477f*/, 5 /*4780*/,
    6 /*4781*/,  6 /*4782*/,  7 /*4783*/,  6 /*4784*/,  7 /*4785*/,
    7 /*4786*/,  8 /*4787*/,  6 /*4788*/,  7 /*4789*/,  7 /*478a*/,
    8 /*478b*/,  7 /*478c*/,  8 /*478d*/,  8 /*478e*/,  9 /*478f*/,
    6 /*4790*/,  7 /*4791*/,  7 /*4792*/,  8 /*4793*/,  7 /*4794*/,
    8 /*4795*/,  8 /*4796*/,  9 /*4797*/,  7 /*4798*/,  8 /*4799*/,
    8 /*479a*/,  9 /*479b*/,  8 /*479c*/,  9 /*479d*/,  9 /*479e*/,
    10 /*479f*/, 6 /*47a0*/,  7 /*47a1*/,  7 /*47a2*/,  8 /*47a3*/,
    7 /*47a4*/,  8 /*47a5*/,  8 /*47a6*/,  9 /*47a7*/,  7 /*47a8*/,
    8 /*47a9*/,  8 /*47aa*/,  9 /*47ab*/,  8 /*47ac*/,  9 /*47ad*/,
    9 /*47ae*/,  10 /*47af*/, 7 /*47b0*/,  8 /*47b1*/,  8 /*47b2*/,
    9 /*47b3*/,  8 /*47b4*/,  9 /*47b5*/,  9 /*47b6*/,  10 /*47b7*/,
    8 /*47b8*/,  9 /*47b9*/,  9 /*47ba*/,  10 /*47bb*/, 9 /*47bc*/,
    10 /*47bd*/, 10 /*47be*/, 11 /*47bf*/, 6 /*47c0*/,  7 /*47c1*/,
    7 /*47c2*/,  8 /*47c3*/,  7 /*47c4*/,  8 /*47c5*/,  8 /*47c6*/,
    9 /*47c7*/,  7 /*47c8*/,  8 /*47c9*/,  8 /*47ca*/,  9 /*47cb*/,
    8 /*47cc*/,  9 /*47cd*/,  9 /*47ce*/,  10 /*47cf*/, 7 /*47d0*/,
    8 /*47d1*/,  8 /*47d2*/,  9 /*47d3*/,  8 /*47d4*/,  9 /*47d5*/,
    9 /*47d6*/,  10 /*47d7*/, 8 /*47d8*/,  9 /*47d9*/,  9 /*47da*/,
    10 /*47db*/, 9 /*47dc*/,  10 /*47dd*/, 10 /*47de*/, 11 /*47df*/,
    7 /*47e0*/,  8 /*47e1*/,  8 /*47e2*/,  9 /*47e3*/,  8 /*47e4*/,
    9 /*47e5*/,  9 /*47e6*/,  10 /*47e7*/, 8 /*47e8*/,  9 /*47e9*/,
    9 /*47ea*/,  10 /*47eb*/, 9 /*47ec*/,  10 /*47ed*/, 10 /*47ee*/,
    11 /*47ef*/, 8 /*47f0*/,  9 /*47f1*/,  9 /*47f2*/,  10 /*47f3*/,
    9 /*47f4*/,  10 /*47f5*/, 10 /*47f6*/, 11 /*47f7*/, 9 /*47f8*/,
    10 /*47f9*/, 10 /*47fa*/, 11 /*47fb*/, 10 /*47fc*/, 11 /*47fd*/,
    11 /*47fe*/, 12 /*47ff*/, 2 /*4800*/,  3 /*4801*/,  3 /*4802*/,
    4 /*4803*/,  3 /*4804*/,  4 /*4805*/,  4 /*4806*/,  5 /*4807*/,
    3 /*4808*/,  4 /*4809*/,  4 /*480a*/,  5 /*480b*/,  4 /*480c*/,
    5 /*480d*/,  5 /*480e*/,  6 /*480f*/,  3 /*4810*/,  4 /*4811*/,
    4 /*4812*/,  5 /*4813*/,  4 /*4814*/,  5 /*4815*/,  5 /*4816*/,
    6 /*4817*/,  4 /*4818*/,  5 /*4819*/,  5 /*481a*/,  6 /*481b*/,
    5 /*481c*/,  6 /*481d*/,  6 /*481e*/,  7 /*481f*/,  3 /*4820*/,
    4 /*4821*/,  4 /*4822*/,  5 /*4823*/,  4 /*4824*/,  5 /*4825*/,
    5 /*4826*/,  6 /*4827*/,  4 /*4828*/,  5 /*4829*/,  5 /*482a*/,
    6 /*482b*/,  5 /*482c*/,  6 /*482d*/,  6 /*482e*/,  7 /*482f*/,
    4 /*4830*/,  5 /*4831*/,  5 /*4832*/,  6 /*4833*/,  5 /*4834*/,
    6 /*4835*/,  6 /*4836*/,  7 /*4837*/,  5 /*4838*/,  6 /*4839*/,
    6 /*483a*/,  7 /*483b*/,  6 /*483c*/,  7 /*483d*/,  7 /*483e*/,
    8 /*483f*/,  3 /*4840*/,  4 /*4841*/,  4 /*4842*/,  5 /*4843*/,
    4 /*4844*/,  5 /*4845*/,  5 /*4846*/,  6 /*4847*/,  4 /*4848*/,
    5 /*4849*/,  5 /*484a*/,  6 /*484b*/,  5 /*484c*/,  6 /*484d*/,
    6 /*484e*/,  7 /*484f*/,  4 /*4850*/,  5 /*4851*/,  5 /*4852*/,
    6 /*4853*/,  5 /*4854*/,  6 /*4855*/,  6 /*4856*/,  7 /*4857*/,
    5 /*4858*/,  6 /*4859*/,  6 /*485a*/,  7 /*485b*/,  6 /*485c*/,
    7 /*485d*/,  7 /*485e*/,  8 /*485f*/,  4 /*4860*/,  5 /*4861*/,
    5 /*4862*/,  6 /*4863*/,  5 /*4864*/,  6 /*4865*/,  6 /*4866*/,
    7 /*4867*/,  5 /*4868*/,  6 /*4869*/,  6 /*486a*/,  7 /*486b*/,
    6 /*486c*/,  7 /*486d*/,  7 /*486e*/,  8 /*486f*/,  5 /*4870*/,
    6 /*4871*/,  6 /*4872*/,  7 /*4873*/,  6 /*4874*/,  7 /*4875*/,
    7 /*4876*/,  8 /*4877*/,  6 /*4878*/,  7 /*4879*/,  7 /*487a*/,
    8 /*487b*/,  7 /*487c*/,  8 /*487d*/,  8 /*487e*/,  9 /*487f*/,
    3 /*4880*/,  4 /*4881*/,  4 /*4882*/,  5 /*4883*/,  4 /*4884*/,
    5 /*4885*/,  5 /*4886*/,  6 /*4887*/,  4 /*4888*/,  5 /*4889*/,
    5 /*488a*/,  6 /*488b*/,  5 /*488c*/,  6 /*488d*/,  6 /*488e*/,
    7 /*488f*/,  4 /*4890*/,  5 /*4891*/,  5 /*4892*/,  6 /*4893*/,
    5 /*4894*/,  6 /*4895*/,  6 /*4896*/,  7 /*4897*/,  5 /*4898*/,
    6 /*4899*/,  6 /*489a*/,  7 /*489b*/,  6 /*489c*/,  7 /*489d*/,
    7 /*489e*/,  8 /*489f*/,  4 /*48a0*/,  5 /*48a1*/,  5 /*48a2*/,
    6 /*48a3*/,  5 /*48a4*/,  6 /*48a5*/,  6 /*48a6*/,  7 /*48a7*/,
    5 /*48a8*/,  6 /*48a9*/,  6 /*48aa*/,  7 /*48ab*/,  6 /*48ac*/,
    7 /*48ad*/,  7 /*48ae*/,  8 /*48af*/,  5 /*48b0*/,  6 /*48b1*/,
    6 /*48b2*/,  7 /*48b3*/,  6 /*48b4*/,  7 /*48b5*/,  7 /*48b6*/,
    8 /*48b7*/,  6 /*48b8*/,  7 /*48b9*/,  7 /*48ba*/,  8 /*48bb*/,
    7 /*48bc*/,  8 /*48bd*/,  8 /*48be*/,  9 /*48bf*/,  4 /*48c0*/,
    5 /*48c1*/,  5 /*48c2*/,  6 /*48c3*/,  5 /*48c4*/,  6 /*48c5*/,
    6 /*48c6*/,  7 /*48c7*/,  5 /*48c8*/,  6 /*48c9*/,  6 /*48ca*/,
    7 /*48cb*/,  6 /*48cc*/,  7 /*48cd*/,  7 /*48ce*/,  8 /*48cf*/,
    5 /*48d0*/,  6 /*48d1*/,  6 /*48d2*/,  7 /*48d3*/,  6 /*48d4*/,
    7 /*48d5*/,  7 /*48d6*/,  8 /*48d7*/,  6 /*48d8*/,  7 /*48d9*/,
    7 /*48da*/,  8 /*48db*/,  7 /*48dc*/,  8 /*48dd*/,  8 /*48de*/,
    9 /*48df*/,  5 /*48e0*/,  6 /*48e1*/,  6 /*48e2*/,  7 /*48e3*/,
    6 /*48e4*/,  7 /*48e5*/,  7 /*48e6*/,  8 /*48e7*/,  6 /*48e8*/,
    7 /*48e9*/,  7 /*48ea*/,  8 /*48eb*/,  7 /*48ec*/,  8 /*48ed*/,
    8 /*48ee*/,  9 /*48ef*/,  6 /*48f0*/,  7 /*48f1*/,  7 /*48f2*/,
    8 /*48f3*/,  7 /*48f4*/,  8 /*48f5*/,  8 /*48f6*/,  9 /*48f7*/,
    7 /*48f8*/,  8 /*48f9*/,  8 /*48fa*/,  9 /*48fb*/,  8 /*48fc*/,
    9 /*48fd*/,  9 /*48fe*/,  10 /*48ff*/, 3 /*4900*/,  4 /*4901*/,
    4 /*4902*/,  5 /*4903*/,  4 /*4904*/,  5 /*4905*/,  5 /*4906*/,
    6 /*4907*/,  4 /*4908*/,  5 /*4909*/,  5 /*490a*/,  6 /*490b*/,
    5 /*490c*/,  6 /*490d*/,  6 /*490e*/,  7 /*490f*/,  4 /*4910*/,
    5 /*4911*/,  5 /*4912*/,  6 /*4913*/,  5 /*4914*/,  6 /*4915*/,
    6 /*4916*/,  7 /*4917*/,  5 /*4918*/,  6 /*4919*/,  6 /*491a*/,
    7 /*491b*/,  6 /*491c*/,  7 /*491d*/,  7 /*491e*/,  8 /*491f*/,
    4 /*4920*/,  5 /*4921*/,  5 /*4922*/,  6 /*4923*/,  5 /*4924*/,
    6 /*4925*/,  6 /*4926*/,  7 /*4927*/,  5 /*4928*/,  6 /*4929*/,
    6 /*492a*/,  7 /*492b*/,  6 /*492c*/,  7 /*492d*/,  7 /*492e*/,
    8 /*492f*/,  5 /*4930*/,  6 /*4931*/,  6 /*4932*/,  7 /*4933*/,
    6 /*4934*/,  7 /*4935*/,  7 /*4936*/,  8 /*4937*/,  6 /*4938*/,
    7 /*4939*/,  7 /*493a*/,  8 /*493b*/,  7 /*493c*/,  8 /*493d*/,
    8 /*493e*/,  9 /*493f*/,  4 /*4940*/,  5 /*4941*/,  5 /*4942*/,
    6 /*4943*/,  5 /*4944*/,  6 /*4945*/,  6 /*4946*/,  7 /*4947*/,
    5 /*4948*/,  6 /*4949*/,  6 /*494a*/,  7 /*494b*/,  6 /*494c*/,
    7 /*494d*/,  7 /*494e*/,  8 /*494f*/,  5 /*4950*/,  6 /*4951*/,
    6 /*4952*/,  7 /*4953*/,  6 /*4954*/,  7 /*4955*/,  7 /*4956*/,
    8 /*4957*/,  6 /*4958*/,  7 /*4959*/,  7 /*495a*/,  8 /*495b*/,
    7 /*495c*/,  8 /*495d*/,  8 /*495e*/,  9 /*495f*/,  5 /*4960*/,
    6 /*4961*/,  6 /*4962*/,  7 /*4963*/,  6 /*4964*/,  7 /*4965*/,
    7 /*4966*/,  8 /*4967*/,  6 /*4968*/,  7 /*4969*/,  7 /*496a*/,
    8 /*496b*/,  7 /*496c*/,  8 /*496d*/,  8 /*496e*/,  9 /*496f*/,
    6 /*4970*/,  7 /*4971*/,  7 /*4972*/,  8 /*4973*/,  7 /*4974*/,
    8 /*4975*/,  8 /*4976*/,  9 /*4977*/,  7 /*4978*/,  8 /*4979*/,
    8 /*497a*/,  9 /*497b*/,  8 /*497c*/,  9 /*497d*/,  9 /*497e*/,
    10 /*497f*/, 4 /*4980*/,  5 /*4981*/,  5 /*4982*/,  6 /*4983*/,
    5 /*4984*/,  6 /*4985*/,  6 /*4986*/,  7 /*4987*/,  5 /*4988*/,
    6 /*4989*/,  6 /*498a*/,  7 /*498b*/,  6 /*498c*/,  7 /*498d*/,
    7 /*498e*/,  8 /*498f*/,  5 /*4990*/,  6 /*4991*/,  6 /*4992*/,
    7 /*4993*/,  6 /*4994*/,  7 /*4995*/,  7 /*4996*/,  8 /*4997*/,
    6 /*4998*/,  7 /*4999*/,  7 /*499a*/,  8 /*499b*/,  7 /*499c*/,
    8 /*499d*/,  8 /*499e*/,  9 /*499f*/,  5 /*49a0*/,  6 /*49a1*/,
    6 /*49a2*/,  7 /*49a3*/,  6 /*49a4*/,  7 /*49a5*/,  7 /*49a6*/,
    8 /*49a7*/,  6 /*49a8*/,  7 /*49a9*/,  7 /*49aa*/,  8 /*49ab*/,
    7 /*49ac*/,  8 /*49ad*/,  8 /*49ae*/,  9 /*49af*/,  6 /*49b0*/,
    7 /*49b1*/,  7 /*49b2*/,  8 /*49b3*/,  7 /*49b4*/,  8 /*49b5*/,
    8 /*49b6*/,  9 /*49b7*/,  7 /*49b8*/,  8 /*49b9*/,  8 /*49ba*/,
    9 /*49bb*/,  8 /*49bc*/,  9 /*49bd*/,  9 /*49be*/,  10 /*49bf*/,
    5 /*49c0*/,  6 /*49c1*/,  6 /*49c2*/,  7 /*49c3*/,  6 /*49c4*/,
    7 /*49c5*/,  7 /*49c6*/,  8 /*49c7*/,  6 /*49c8*/,  7 /*49c9*/,
    7 /*49ca*/,  8 /*49cb*/,  7 /*49cc*/,  8 /*49cd*/,  8 /*49ce*/,
    9 /*49cf*/,  6 /*49d0*/,  7 /*49d1*/,  7 /*49d2*/,  8 /*49d3*/,
    7 /*49d4*/,  8 /*49d5*/,  8 /*49d6*/,  9 /*49d7*/,  7 /*49d8*/,
    8 /*49d9*/,  8 /*49da*/,  9 /*49db*/,  8 /*49dc*/,  9 /*49dd*/,
    9 /*49de*/,  10 /*49df*/, 6 /*49e0*/,  7 /*49e1*/,  7 /*49e2*/,
    8 /*49e3*/,  7 /*49e4*/,  8 /*49e5*/,  8 /*49e6*/,  9 /*49e7*/,
    7 /*49e8*/,  8 /*49e9*/,  8 /*49ea*/,  9 /*49eb*/,  8 /*49ec*/,
    9 /*49ed*/,  9 /*49ee*/,  10 /*49ef*/, 7 /*49f0*/,  8 /*49f1*/,
    8 /*49f2*/,  9 /*49f3*/,  8 /*49f4*/,  9 /*49f5*/,  9 /*49f6*/,
    10 /*49f7*/, 8 /*49f8*/,  9 /*49f9*/,  9 /*49fa*/,  10 /*49fb*/,
    9 /*49fc*/,  10 /*49fd*/, 10 /*49fe*/, 11 /*49ff*/, 3 /*4a00*/,
    4 /*4a01*/,  4 /*4a02*/,  5 /*4a03*/,  4 /*4a04*/,  5 /*4a05*/,
    5 /*4a06*/,  6 /*4a07*/,  4 /*4a08*/,  5 /*4a09*/,  5 /*4a0a*/,
    6 /*4a0b*/,  5 /*4a0c*/,  6 /*4a0d*/,  6 /*4a0e*/,  7 /*4a0f*/,
    4 /*4a10*/,  5 /*4a11*/,  5 /*4a12*/,  6 /*4a13*/,  5 /*4a14*/,
    6 /*4a15*/,  6 /*4a16*/,  7 /*4a17*/,  5 /*4a18*/,  6 /*4a19*/,
    6 /*4a1a*/,  7 /*4a1b*/,  6 /*4a1c*/,  7 /*4a1d*/,  7 /*4a1e*/,
    8 /*4a1f*/,  4 /*4a20*/,  5 /*4a21*/,  5 /*4a22*/,  6 /*4a23*/,
    5 /*4a24*/,  6 /*4a25*/,  6 /*4a26*/,  7 /*4a27*/,  5 /*4a28*/,
    6 /*4a29*/,  6 /*4a2a*/,  7 /*4a2b*/,  6 /*4a2c*/,  7 /*4a2d*/,
    7 /*4a2e*/,  8 /*4a2f*/,  5 /*4a30*/,  6 /*4a31*/,  6 /*4a32*/,
    7 /*4a33*/,  6 /*4a34*/,  7 /*4a35*/,  7 /*4a36*/,  8 /*4a37*/,
    6 /*4a38*/,  7 /*4a39*/,  7 /*4a3a*/,  8 /*4a3b*/,  7 /*4a3c*/,
    8 /*4a3d*/,  8 /*4a3e*/,  9 /*4a3f*/,  4 /*4a40*/,  5 /*4a41*/,
    5 /*4a42*/,  6 /*4a43*/,  5 /*4a44*/,  6 /*4a45*/,  6 /*4a46*/,
    7 /*4a47*/,  5 /*4a48*/,  6 /*4a49*/,  6 /*4a4a*/,  7 /*4a4b*/,
    6 /*4a4c*/,  7 /*4a4d*/,  7 /*4a4e*/,  8 /*4a4f*/,  5 /*4a50*/,
    6 /*4a51*/,  6 /*4a52*/,  7 /*4a53*/,  6 /*4a54*/,  7 /*4a55*/,
    7 /*4a56*/,  8 /*4a57*/,  6 /*4a58*/,  7 /*4a59*/,  7 /*4a5a*/,
    8 /*4a5b*/,  7 /*4a5c*/,  8 /*4a5d*/,  8 /*4a5e*/,  9 /*4a5f*/,
    5 /*4a60*/,  6 /*4a61*/,  6 /*4a62*/,  7 /*4a63*/,  6 /*4a64*/,
    7 /*4a65*/,  7 /*4a66*/,  8 /*4a67*/,  6 /*4a68*/,  7 /*4a69*/,
    7 /*4a6a*/,  8 /*4a6b*/,  7 /*4a6c*/,  8 /*4a6d*/,  8 /*4a6e*/,
    9 /*4a6f*/,  6 /*4a70*/,  7 /*4a71*/,  7 /*4a72*/,  8 /*4a73*/,
    7 /*4a74*/,  8 /*4a75*/,  8 /*4a76*/,  9 /*4a77*/,  7 /*4a78*/,
    8 /*4a79*/,  8 /*4a7a*/,  9 /*4a7b*/,  8 /*4a7c*/,  9 /*4a7d*/,
    9 /*4a7e*/,  10 /*4a7f*/, 4 /*4a80*/,  5 /*4a81*/,  5 /*4a82*/,
    6 /*4a83*/,  5 /*4a84*/,  6 /*4a85*/,  6 /*4a86*/,  7 /*4a87*/,
    5 /*4a88*/,  6 /*4a89*/,  6 /*4a8a*/,  7 /*4a8b*/,  6 /*4a8c*/,
    7 /*4a8d*/,  7 /*4a8e*/,  8 /*4a8f*/,  5 /*4a90*/,  6 /*4a91*/,
    6 /*4a92*/,  7 /*4a93*/,  6 /*4a94*/,  7 /*4a95*/,  7 /*4a96*/,
    8 /*4a97*/,  6 /*4a98*/,  7 /*4a99*/,  7 /*4a9a*/,  8 /*4a9b*/,
    7 /*4a9c*/,  8 /*4a9d*/,  8 /*4a9e*/,  9 /*4a9f*/,  5 /*4aa0*/,
    6 /*4aa1*/,  6 /*4aa2*/,  7 /*4aa3*/,  6 /*4aa4*/,  7 /*4aa5*/,
    7 /*4aa6*/,  8 /*4aa7*/,  6 /*4aa8*/,  7 /*4aa9*/,  7 /*4aaa*/,
    8 /*4aab*/,  7 /*4aac*/,  8 /*4aad*/,  8 /*4aae*/,  9 /*4aaf*/,
    6 /*4ab0*/,  7 /*4ab1*/,  7 /*4ab2*/,  8 /*4ab3*/,  7 /*4ab4*/,
    8 /*4ab5*/,  8 /*4ab6*/,  9 /*4ab7*/,  7 /*4ab8*/,  8 /*4ab9*/,
    8 /*4aba*/,  9 /*4abb*/,  8 /*4abc*/,  9 /*4abd*/,  9 /*4abe*/,
    10 /*4abf*/, 5 /*4ac0*/,  6 /*4ac1*/,  6 /*4ac2*/,  7 /*4ac3*/,
    6 /*4ac4*/,  7 /*4ac5*/,  7 /*4ac6*/,  8 /*4ac7*/,  6 /*4ac8*/,
    7 /*4ac9*/,  7 /*4aca*/,  8 /*4acb*/,  7 /*4acc*/,  8 /*4acd*/,
    8 /*4ace*/,  9 /*4acf*/,  6 /*4ad0*/,  7 /*4ad1*/,  7 /*4ad2*/,
    8 /*4ad3*/,  7 /*4ad4*/,  8 /*4ad5*/,  8 /*4ad6*/,  9 /*4ad7*/,
    7 /*4ad8*/,  8 /*4ad9*/,  8 /*4ada*/,  9 /*4adb*/,  8 /*4adc*/,
    9 /*4add*/,  9 /*4ade*/,  10 /*4adf*/, 6 /*4ae0*/,  7 /*4ae1*/,
    7 /*4ae2*/,  8 /*4ae3*/,  7 /*4ae4*/,  8 /*4ae5*/,  8 /*4ae6*/,
    9 /*4ae7*/,  7 /*4ae8*/,  8 /*4ae9*/,  8 /*4aea*/,  9 /*4aeb*/,
    8 /*4aec*/,  9 /*4aed*/,  9 /*4aee*/,  10 /*4aef*/, 7 /*4af0*/,
    8 /*4af1*/,  8 /*4af2*/,  9 /*4af3*/,  8 /*4af4*/,  9 /*4af5*/,
    9 /*4af6*/,  10 /*4af7*/, 8 /*4af8*/,  9 /*4af9*/,  9 /*4afa*/,
    10 /*4afb*/, 9 /*4afc*/,  10 /*4afd*/, 10 /*4afe*/, 11 /*4aff*/,
    4 /*4b00*/,  5 /*4b01*/,  5 /*4b02*/,  6 /*4b03*/,  5 /*4b04*/,
    6 /*4b05*/,  6 /*4b06*/,  7 /*4b07*/,  5 /*4b08*/,  6 /*4b09*/,
    6 /*4b0a*/,  7 /*4b0b*/,  6 /*4b0c*/,  7 /*4b0d*/,  7 /*4b0e*/,
    8 /*4b0f*/,  5 /*4b10*/,  6 /*4b11*/,  6 /*4b12*/,  7 /*4b13*/,
    6 /*4b14*/,  7 /*4b15*/,  7 /*4b16*/,  8 /*4b17*/,  6 /*4b18*/,
    7 /*4b19*/,  7 /*4b1a*/,  8 /*4b1b*/,  7 /*4b1c*/,  8 /*4b1d*/,
    8 /*4b1e*/,  9 /*4b1f*/,  5 /*4b20*/,  6 /*4b21*/,  6 /*4b22*/,
    7 /*4b23*/,  6 /*4b24*/,  7 /*4b25*/,  7 /*4b26*/,  8 /*4b27*/,
    6 /*4b28*/,  7 /*4b29*/,  7 /*4b2a*/,  8 /*4b2b*/,  7 /*4b2c*/,
    8 /*4b2d*/,  8 /*4b2e*/,  9 /*4b2f*/,  6 /*4b30*/,  7 /*4b31*/,
    7 /*4b32*/,  8 /*4b33*/,  7 /*4b34*/,  8 /*4b35*/,  8 /*4b36*/,
    9 /*4b37*/,  7 /*4b38*/,  8 /*4b39*/,  8 /*4b3a*/,  9 /*4b3b*/,
    8 /*4b3c*/,  9 /*4b3d*/,  9 /*4b3e*/,  10 /*4b3f*/, 5 /*4b40*/,
    6 /*4b41*/,  6 /*4b42*/,  7 /*4b43*/,  6 /*4b44*/,  7 /*4b45*/,
    7 /*4b46*/,  8 /*4b47*/,  6 /*4b48*/,  7 /*4b49*/,  7 /*4b4a*/,
    8 /*4b4b*/,  7 /*4b4c*/,  8 /*4b4d*/,  8 /*4b4e*/,  9 /*4b4f*/,
    6 /*4b50*/,  7 /*4b51*/,  7 /*4b52*/,  8 /*4b53*/,  7 /*4b54*/,
    8 /*4b55*/,  8 /*4b56*/,  9 /*4b57*/,  7 /*4b58*/,  8 /*4b59*/,
    8 /*4b5a*/,  9 /*4b5b*/,  8 /*4b5c*/,  9 /*4b5d*/,  9 /*4b5e*/,
    10 /*4b5f*/, 6 /*4b60*/,  7 /*4b61*/,  7 /*4b62*/,  8 /*4b63*/,
    7 /*4b64*/,  8 /*4b65*/,  8 /*4b66*/,  9 /*4b67*/,  7 /*4b68*/,
    8 /*4b69*/,  8 /*4b6a*/,  9 /*4b6b*/,  8 /*4b6c*/,  9 /*4b6d*/,
    9 /*4b6e*/,  10 /*4b6f*/, 7 /*4b70*/,  8 /*4b71*/,  8 /*4b72*/,
    9 /*4b73*/,  8 /*4b74*/,  9 /*4b75*/,  9 /*4b76*/,  10 /*4b77*/,
    8 /*4b78*/,  9 /*4b79*/,  9 /*4b7a*/,  10 /*4b7b*/, 9 /*4b7c*/,
    10 /*4b7d*/, 10 /*4b7e*/, 11 /*4b7f*/, 5 /*4b80*/,  6 /*4b81*/,
    6 /*4b82*/,  7 /*4b83*/,  6 /*4b84*/,  7 /*4b85*/,  7 /*4b86*/,
    8 /*4b87*/,  6 /*4b88*/,  7 /*4b89*/,  7 /*4b8a*/,  8 /*4b8b*/,
    7 /*4b8c*/,  8 /*4b8d*/,  8 /*4b8e*/,  9 /*4b8f*/,  6 /*4b90*/,
    7 /*4b91*/,  7 /*4b92*/,  8 /*4b93*/,  7 /*4b94*/,  8 /*4b95*/,
    8 /*4b96*/,  9 /*4b97*/,  7 /*4b98*/,  8 /*4b99*/,  8 /*4b9a*/,
    9 /*4b9b*/,  8 /*4b9c*/,  9 /*4b9d*/,  9 /*4b9e*/,  10 /*4b9f*/,
    6 /*4ba0*/,  7 /*4ba1*/,  7 /*4ba2*/,  8 /*4ba3*/,  7 /*4ba4*/,
    8 /*4ba5*/,  8 /*4ba6*/,  9 /*4ba7*/,  7 /*4ba8*/,  8 /*4ba9*/,
    8 /*4baa*/,  9 /*4bab*/,  8 /*4bac*/,  9 /*4bad*/,  9 /*4bae*/,
    10 /*4baf*/, 7 /*4bb0*/,  8 /*4bb1*/,  8 /*4bb2*/,  9 /*4bb3*/,
    8 /*4bb4*/,  9 /*4bb5*/,  9 /*4bb6*/,  10 /*4bb7*/, 8 /*4bb8*/,
    9 /*4bb9*/,  9 /*4bba*/,  10 /*4bbb*/, 9 /*4bbc*/,  10 /*4bbd*/,
    10 /*4bbe*/, 11 /*4bbf*/, 6 /*4bc0*/,  7 /*4bc1*/,  7 /*4bc2*/,
    8 /*4bc3*/,  7 /*4bc4*/,  8 /*4bc5*/,  8 /*4bc6*/,  9 /*4bc7*/,
    7 /*4bc8*/,  8 /*4bc9*/,  8 /*4bca*/,  9 /*4bcb*/,  8 /*4bcc*/,
    9 /*4bcd*/,  9 /*4bce*/,  10 /*4bcf*/, 7 /*4bd0*/,  8 /*4bd1*/,
    8 /*4bd2*/,  9 /*4bd3*/,  8 /*4bd4*/,  9 /*4bd5*/,  9 /*4bd6*/,
    10 /*4bd7*/, 8 /*4bd8*/,  9 /*4bd9*/,  9 /*4bda*/,  10 /*4bdb*/,
    9 /*4bdc*/,  10 /*4bdd*/, 10 /*4bde*/, 11 /*4bdf*/, 7 /*4be0*/,
    8 /*4be1*/,  8 /*4be2*/,  9 /*4be3*/,  8 /*4be4*/,  9 /*4be5*/,
    9 /*4be6*/,  10 /*4be7*/, 8 /*4be8*/,  9 /*4be9*/,  9 /*4bea*/,
    10 /*4beb*/, 9 /*4bec*/,  10 /*4bed*/, 10 /*4bee*/, 11 /*4bef*/,
    8 /*4bf0*/,  9 /*4bf1*/,  9 /*4bf2*/,  10 /*4bf3*/, 9 /*4bf4*/,
    10 /*4bf5*/, 10 /*4bf6*/, 11 /*4bf7*/, 9 /*4bf8*/,  10 /*4bf9*/,
    10 /*4bfa*/, 11 /*4bfb*/, 10 /*4bfc*/, 11 /*4bfd*/, 11 /*4bfe*/,
    12 /*4bff*/, 3 /*4c00*/,  4 /*4c01*/,  4 /*4c02*/,  5 /*4c03*/,
    4 /*4c04*/,  5 /*4c05*/,  5 /*4c06*/,  6 /*4c07*/,  4 /*4c08*/,
    5 /*4c09*/,  5 /*4c0a*/,  6 /*4c0b*/,  5 /*4c0c*/,  6 /*4c0d*/,
    6 /*4c0e*/,  7 /*4c0f*/,  4 /*4c10*/,  5 /*4c11*/,  5 /*4c12*/,
    6 /*4c13*/,  5 /*4c14*/,  6 /*4c15*/,  6 /*4c16*/,  7 /*4c17*/,
    5 /*4c18*/,  6 /*4c19*/,  6 /*4c1a*/,  7 /*4c1b*/,  6 /*4c1c*/,
    7 /*4c1d*/,  7 /*4c1e*/,  8 /*4c1f*/,  4 /*4c20*/,  5 /*4c21*/,
    5 /*4c22*/,  6 /*4c23*/,  5 /*4c24*/,  6 /*4c25*/,  6 /*4c26*/,
    7 /*4c27*/,  5 /*4c28*/,  6 /*4c29*/,  6 /*4c2a*/,  7 /*4c2b*/,
    6 /*4c2c*/,  7 /*4c2d*/,  7 /*4c2e*/,  8 /*4c2f*/,  5 /*4c30*/,
    6 /*4c31*/,  6 /*4c32*/,  7 /*4c33*/,  6 /*4c34*/,  7 /*4c35*/,
    7 /*4c36*/,  8 /*4c37*/,  6 /*4c38*/,  7 /*4c39*/,  7 /*4c3a*/,
    8 /*4c3b*/,  7 /*4c3c*/,  8 /*4c3d*/,  8 /*4c3e*/,  9 /*4c3f*/,
    4 /*4c40*/,  5 /*4c41*/,  5 /*4c42*/,  6 /*4c43*/,  5 /*4c44*/,
    6 /*4c45*/,  6 /*4c46*/,  7 /*4c47*/,  5 /*4c48*/,  6 /*4c49*/,
    6 /*4c4a*/,  7 /*4c4b*/,  6 /*4c4c*/,  7 /*4c4d*/,  7 /*4c4e*/,
    8 /*4c4f*/,  5 /*4c50*/,  6 /*4c51*/,  6 /*4c52*/,  7 /*4c53*/,
    6 /*4c54*/,  7 /*4c55*/,  7 /*4c56*/,  8 /*4c57*/,  6 /*4c58*/,
    7 /*4c59*/,  7 /*4c5a*/,  8 /*4c5b*/,  7 /*4c5c*/,  8 /*4c5d*/,
    8 /*4c5e*/,  9 /*4c5f*/,  5 /*4c60*/,  6 /*4c61*/,  6 /*4c62*/,
    7 /*4c63*/,  6 /*4c64*/,  7 /*4c65*/,  7 /*4c66*/,  8 /*4c67*/,
    6 /*4c68*/,  7 /*4c69*/,  7 /*4c6a*/,  8 /*4c6b*/,  7 /*4c6c*/,
    8 /*4c6d*/,  8 /*4c6e*/,  9 /*4c6f*/,  6 /*4c70*/,  7 /*4c71*/,
    7 /*4c72*/,  8 /*4c73*/,  7 /*4c74*/,  8 /*4c75*/,  8 /*4c76*/,
    9 /*4c77*/,  7 /*4c78*/,  8 /*4c79*/,  8 /*4c7a*/,  9 /*4c7b*/,
    8 /*4c7c*/,  9 /*4c7d*/,  9 /*4c7e*/,  10 /*4c7f*/, 4 /*4c80*/,
    5 /*4c81*/,  5 /*4c82*/,  6 /*4c83*/,  5 /*4c84*/,  6 /*4c85*/,
    6 /*4c86*/,  7 /*4c87*/,  5 /*4c88*/,  6 /*4c89*/,  6 /*4c8a*/,
    7 /*4c8b*/,  6 /*4c8c*/,  7 /*4c8d*/,  7 /*4c8e*/,  8 /*4c8f*/,
    5 /*4c90*/,  6 /*4c91*/,  6 /*4c92*/,  7 /*4c93*/,  6 /*4c94*/,
    7 /*4c95*/,  7 /*4c96*/,  8 /*4c97*/,  6 /*4c98*/,  7 /*4c99*/,
    7 /*4c9a*/,  8 /*4c9b*/,  7 /*4c9c*/,  8 /*4c9d*/,  8 /*4c9e*/,
    9 /*4c9f*/,  5 /*4ca0*/,  6 /*4ca1*/,  6 /*4ca2*/,  7 /*4ca3*/,
    6 /*4ca4*/,  7 /*4ca5*/,  7 /*4ca6*/,  8 /*4ca7*/,  6 /*4ca8*/,
    7 /*4ca9*/,  7 /*4caa*/,  8 /*4cab*/,  7 /*4cac*/,  8 /*4cad*/,
    8 /*4cae*/,  9 /*4caf*/,  6 /*4cb0*/,  7 /*4cb1*/,  7 /*4cb2*/,
    8 /*4cb3*/,  7 /*4cb4*/,  8 /*4cb5*/,  8 /*4cb6*/,  9 /*4cb7*/,
    7 /*4cb8*/,  8 /*4cb9*/,  8 /*4cba*/,  9 /*4cbb*/,  8 /*4cbc*/,
    9 /*4cbd*/,  9 /*4cbe*/,  10 /*4cbf*/, 5 /*4cc0*/,  6 /*4cc1*/,
    6 /*4cc2*/,  7 /*4cc3*/,  6 /*4cc4*/,  7 /*4cc5*/,  7 /*4cc6*/,
    8 /*4cc7*/,  6 /*4cc8*/,  7 /*4cc9*/,  7 /*4cca*/,  8 /*4ccb*/,
    7 /*4ccc*/,  8 /*4ccd*/,  8 /*4cce*/,  9 /*4ccf*/,  6 /*4cd0*/,
    7 /*4cd1*/,  7 /*4cd2*/,  8 /*4cd3*/,  7 /*4cd4*/,  8 /*4cd5*/,
    8 /*4cd6*/,  9 /*4cd7*/,  7 /*4cd8*/,  8 /*4cd9*/,  8 /*4cda*/,
    9 /*4cdb*/,  8 /*4cdc*/,  9 /*4cdd*/,  9 /*4cde*/,  10 /*4cdf*/,
    6 /*4ce0*/,  7 /*4ce1*/,  7 /*4ce2*/,  8 /*4ce3*/,  7 /*4ce4*/,
    8 /*4ce5*/,  8 /*4ce6*/,  9 /*4ce7*/,  7 /*4ce8*/,  8 /*4ce9*/,
    8 /*4cea*/,  9 /*4ceb*/,  8 /*4cec*/,  9 /*4ced*/,  9 /*4cee*/,
    10 /*4cef*/, 7 /*4cf0*/,  8 /*4cf1*/,  8 /*4cf2*/,  9 /*4cf3*/,
    8 /*4cf4*/,  9 /*4cf5*/,  9 /*4cf6*/,  10 /*4cf7*/, 8 /*4cf8*/,
    9 /*4cf9*/,  9 /*4cfa*/,  10 /*4cfb*/, 9 /*4cfc*/,  10 /*4cfd*/,
    10 /*4cfe*/, 11 /*4cff*/, 4 /*4d00*/,  5 /*4d01*/,  5 /*4d02*/,
    6 /*4d03*/,  5 /*4d04*/,  6 /*4d05*/,  6 /*4d06*/,  7 /*4d07*/,
    5 /*4d08*/,  6 /*4d09*/,  6 /*4d0a*/,  7 /*4d0b*/,  6 /*4d0c*/,
    7 /*4d0d*/,  7 /*4d0e*/,  8 /*4d0f*/,  5 /*4d10*/,  6 /*4d11*/,
    6 /*4d12*/,  7 /*4d13*/,  6 /*4d14*/,  7 /*4d15*/,  7 /*4d16*/,
    8 /*4d17*/,  6 /*4d18*/,  7 /*4d19*/,  7 /*4d1a*/,  8 /*4d1b*/,
    7 /*4d1c*/,  8 /*4d1d*/,  8 /*4d1e*/,  9 /*4d1f*/,  5 /*4d20*/,
    6 /*4d21*/,  6 /*4d22*/,  7 /*4d23*/,  6 /*4d24*/,  7 /*4d25*/,
    7 /*4d26*/,  8 /*4d27*/,  6 /*4d28*/,  7 /*4d29*/,  7 /*4d2a*/,
    8 /*4d2b*/,  7 /*4d2c*/,  8 /*4d2d*/,  8 /*4d2e*/,  9 /*4d2f*/,
    6 /*4d30*/,  7 /*4d31*/,  7 /*4d32*/,  8 /*4d33*/,  7 /*4d34*/,
    8 /*4d35*/,  8 /*4d36*/,  9 /*4d37*/,  7 /*4d38*/,  8 /*4d39*/,
    8 /*4d3a*/,  9 /*4d3b*/,  8 /*4d3c*/,  9 /*4d3d*/,  9 /*4d3e*/,
    10 /*4d3f*/, 5 /*4d40*/,  6 /*4d41*/,  6 /*4d42*/,  7 /*4d43*/,
    6 /*4d44*/,  7 /*4d45*/,  7 /*4d46*/,  8 /*4d47*/,  6 /*4d48*/,
    7 /*4d49*/,  7 /*4d4a*/,  8 /*4d4b*/,  7 /*4d4c*/,  8 /*4d4d*/,
    8 /*4d4e*/,  9 /*4d4f*/,  6 /*4d50*/,  7 /*4d51*/,  7 /*4d52*/,
    8 /*4d53*/,  7 /*4d54*/,  8 /*4d55*/,  8 /*4d56*/,  9 /*4d57*/,
    7 /*4d58*/,  8 /*4d59*/,  8 /*4d5a*/,  9 /*4d5b*/,  8 /*4d5c*/,
    9 /*4d5d*/,  9 /*4d5e*/,  10 /*4d5f*/, 6 /*4d60*/,  7 /*4d61*/,
    7 /*4d62*/,  8 /*4d63*/,  7 /*4d64*/,  8 /*4d65*/,  8 /*4d66*/,
    9 /*4d67*/,  7 /*4d68*/,  8 /*4d69*/,  8 /*4d6a*/,  9 /*4d6b*/,
    8 /*4d6c*/,  9 /*4d6d*/,  9 /*4d6e*/,  10 /*4d6f*/, 7 /*4d70*/,
    8 /*4d71*/,  8 /*4d72*/,  9 /*4d73*/,  8 /*4d74*/,  9 /*4d75*/,
    9 /*4d76*/,  10 /*4d77*/, 8 /*4d78*/,  9 /*4d79*/,  9 /*4d7a*/,
    10 /*4d7b*/, 9 /*4d7c*/,  10 /*4d7d*/, 10 /*4d7e*/, 11 /*4d7f*/,
    5 /*4d80*/,  6 /*4d81*/,  6 /*4d82*/,  7 /*4d83*/,  6 /*4d84*/,
    7 /*4d85*/,  7 /*4d86*/,  8 /*4d87*/,  6 /*4d88*/,  7 /*4d89*/,
    7 /*4d8a*/,  8 /*4d8b*/,  7 /*4d8c*/,  8 /*4d8d*/,  8 /*4d8e*/,
    9 /*4d8f*/,  6 /*4d90*/,  7 /*4d91*/,  7 /*4d92*/,  8 /*4d93*/,
    7 /*4d94*/,  8 /*4d95*/,  8 /*4d96*/,  9 /*4d97*/,  7 /*4d98*/,
    8 /*4d99*/,  8 /*4d9a*/,  9 /*4d9b*/,  8 /*4d9c*/,  9 /*4d9d*/,
    9 /*4d9e*/,  10 /*4d9f*/, 6 /*4da0*/,  7 /*4da1*/,  7 /*4da2*/,
    8 /*4da3*/,  7 /*4da4*/,  8 /*4da5*/,  8 /*4da6*/,  9 /*4da7*/,
    7 /*4da8*/,  8 /*4da9*/,  8 /*4daa*/,  9 /*4dab*/,  8 /*4dac*/,
    9 /*4dad*/,  9 /*4dae*/,  10 /*4daf*/, 7 /*4db0*/,  8 /*4db1*/,
    8 /*4db2*/,  9 /*4db3*/,  8 /*4db4*/,  9 /*4db5*/,  9 /*4db6*/,
    10 /*4db7*/, 8 /*4db8*/,  9 /*4db9*/,  9 /*4dba*/,  10 /*4dbb*/,
    9 /*4dbc*/,  10 /*4dbd*/, 10 /*4dbe*/, 11 /*4dbf*/, 6 /*4dc0*/,
    7 /*4dc1*/,  7 /*4dc2*/,  8 /*4dc3*/,  7 /*4dc4*/,  8 /*4dc5*/,
    8 /*4dc6*/,  9 /*4dc7*/,  7 /*4dc8*/,  8 /*4dc9*/,  8 /*4dca*/,
    9 /*4dcb*/,  8 /*4dcc*/,  9 /*4dcd*/,  9 /*4dce*/,  10 /*4dcf*/,
    7 /*4dd0*/,  8 /*4dd1*/,  8 /*4dd2*/,  9 /*4dd3*/,  8 /*4dd4*/,
    9 /*4dd5*/,  9 /*4dd6*/,  10 /*4dd7*/, 8 /*4dd8*/,  9 /*4dd9*/,
    9 /*4dda*/,  10 /*4ddb*/, 9 /*4ddc*/,  10 /*4ddd*/, 10 /*4dde*/,
    11 /*4ddf*/, 7 /*4de0*/,  8 /*4de1*/,  8 /*4de2*/,  9 /*4de3*/,
    8 /*4de4*/,  9 /*4de5*/,  9 /*4de6*/,  10 /*4de7*/, 8 /*4de8*/,
    9 /*4de9*/,  9 /*4dea*/,  10 /*4deb*/, 9 /*4dec*/,  10 /*4ded*/,
    10 /*4dee*/, 11 /*4def*/, 8 /*4df0*/,  9 /*4df1*/,  9 /*4df2*/,
    10 /*4df3*/, 9 /*4df4*/,  10 /*4df5*/, 10 /*4df6*/, 11 /*4df7*/,
    9 /*4df8*/,  10 /*4df9*/, 10 /*4dfa*/, 11 /*4dfb*/, 10 /*4dfc*/,
    11 /*4dfd*/, 11 /*4dfe*/, 12 /*4dff*/, 4 /*4e00*/,  5 /*4e01*/,
    5 /*4e02*/,  6 /*4e03*/,  5 /*4e04*/,  6 /*4e05*/,  6 /*4e06*/,
    7 /*4e07*/,  5 /*4e08*/,  6 /*4e09*/,  6 /*4e0a*/,  7 /*4e0b*/,
    6 /*4e0c*/,  7 /*4e0d*/,  7 /*4e0e*/,  8 /*4e0f*/,  5 /*4e10*/,
    6 /*4e11*/,  6 /*4e12*/,  7 /*4e13*/,  6 /*4e14*/,  7 /*4e15*/,
    7 /*4e16*/,  8 /*4e17*/,  6 /*4e18*/,  7 /*4e19*/,  7 /*4e1a*/,
    8 /*4e1b*/,  7 /*4e1c*/,  8 /*4e1d*/,  8 /*4e1e*/,  9 /*4e1f*/,
    5 /*4e20*/,  6 /*4e21*/,  6 /*4e22*/,  7 /*4e23*/,  6 /*4e24*/,
    7 /*4e25*/,  7 /*4e26*/,  8 /*4e27*/,  6 /*4e28*/,  7 /*4e29*/,
    7 /*4e2a*/,  8 /*4e2b*/,  7 /*4e2c*/,  8 /*4e2d*/,  8 /*4e2e*/,
    9 /*4e2f*/,  6 /*4e30*/,  7 /*4e31*/,  7 /*4e32*/,  8 /*4e33*/,
    7 /*4e34*/,  8 /*4e35*/,  8 /*4e36*/,  9 /*4e37*/,  7 /*4e38*/,
    8 /*4e39*/,  8 /*4e3a*/,  9 /*4e3b*/,  8 /*4e3c*/,  9 /*4e3d*/,
    9 /*4e3e*/,  10 /*4e3f*/, 5 /*4e40*/,  6 /*4e41*/,  6 /*4e42*/,
    7 /*4e43*/,  6 /*4e44*/,  7 /*4e45*/,  7 /*4e46*/,  8 /*4e47*/,
    6 /*4e48*/,  7 /*4e49*/,  7 /*4e4a*/,  8 /*4e4b*/,  7 /*4e4c*/,
    8 /*4e4d*/,  8 /*4e4e*/,  9 /*4e4f*/,  6 /*4e50*/,  7 /*4e51*/,
    7 /*4e52*/,  8 /*4e53*/,  7 /*4e54*/,  8 /*4e55*/,  8 /*4e56*/,
    9 /*4e57*/,  7 /*4e58*/,  8 /*4e59*/,  8 /*4e5a*/,  9 /*4e5b*/,
    8 /*4e5c*/,  9 /*4e5d*/,  9 /*4e5e*/,  10 /*4e5f*/, 6 /*4e60*/,
    7 /*4e61*/,  7 /*4e62*/,  8 /*4e63*/,  7 /*4e64*/,  8 /*4e65*/,
    8 /*4e66*/,  9 /*4e67*/,  7 /*4e68*/,  8 /*4e69*/,  8 /*4e6a*/,
    9 /*4e6b*/,  8 /*4e6c*/,  9 /*4e6d*/,  9 /*4e6e*/,  10 /*4e6f*/,
    7 /*4e70*/,  8 /*4e71*/,  8 /*4e72*/,  9 /*4e73*/,  8 /*4e74*/,
    9 /*4e75*/,  9 /*4e76*/,  10 /*4e77*/, 8 /*4e78*/,  9 /*4e79*/,
    9 /*4e7a*/,  10 /*4e7b*/, 9 /*4e7c*/,  10 /*4e7d*/, 10 /*4e7e*/,
    11 /*4e7f*/, 5 /*4e80*/,  6 /*4e81*/,  6 /*4e82*/,  7 /*4e83*/,
    6 /*4e84*/,  7 /*4e85*/,  7 /*4e86*/,  8 /*4e87*/,  6 /*4e88*/,
    7 /*4e89*/,  7 /*4e8a*/,  8 /*4e8b*/,  7 /*4e8c*/,  8 /*4e8d*/,
    8 /*4e8e*/,  9 /*4e8f*/,  6 /*4e90*/,  7 /*4e91*/,  7 /*4e92*/,
    8 /*4e93*/,  7 /*4e94*/,  8 /*4e95*/,  8 /*4e96*/,  9 /*4e97*/,
    7 /*4e98*/,  8 /*4e99*/,  8 /*4e9a*/,  9 /*4e9b*/,  8 /*4e9c*/,
    9 /*4e9d*/,  9 /*4e9e*/,  10 /*4e9f*/, 6 /*4ea0*/,  7 /*4ea1*/,
    7 /*4ea2*/,  8 /*4ea3*/,  7 /*4ea4*/,  8 /*4ea5*/,  8 /*4ea6*/,
    9 /*4ea7*/,  7 /*4ea8*/,  8 /*4ea9*/,  8 /*4eaa*/,  9 /*4eab*/,
    8 /*4eac*/,  9 /*4ead*/,  9 /*4eae*/,  10 /*4eaf*/, 7 /*4eb0*/,
    8 /*4eb1*/,  8 /*4eb2*/,  9 /*4eb3*/,  8 /*4eb4*/,  9 /*4eb5*/,
    9 /*4eb6*/,  10 /*4eb7*/, 8 /*4eb8*/,  9 /*4eb9*/,  9 /*4eba*/,
    10 /*4ebb*/, 9 /*4ebc*/,  10 /*4ebd*/, 10 /*4ebe*/, 11 /*4ebf*/,
    6 /*4ec0*/,  7 /*4ec1*/,  7 /*4ec2*/,  8 /*4ec3*/,  7 /*4ec4*/,
    8 /*4ec5*/,  8 /*4ec6*/,  9 /*4ec7*/,  7 /*4ec8*/,  8 /*4ec9*/,
    8 /*4eca*/,  9 /*4ecb*/,  8 /*4ecc*/,  9 /*4ecd*/,  9 /*4ece*/,
    10 /*4ecf*/, 7 /*4ed0*/,  8 /*4ed1*/,  8 /*4ed2*/,  9 /*4ed3*/,
    8 /*4ed4*/,  9 /*4ed5*/,  9 /*4ed6*/,  10 /*4ed7*/, 8 /*4ed8*/,
    9 /*4ed9*/,  9 /*4eda*/,  10 /*4edb*/, 9 /*4edc*/,  10 /*4edd*/,
    10 /*4ede*/, 11 /*4edf*/, 7 /*4ee0*/,  8 /*4ee1*/,  8 /*4ee2*/,
    9 /*4ee3*/,  8 /*4ee4*/,  9 /*4ee5*/,  9 /*4ee6*/,  10 /*4ee7*/,
    8 /*4ee8*/,  9 /*4ee9*/,  9 /*4eea*/,  10 /*4eeb*/, 9 /*4eec*/,
    10 /*4eed*/, 10 /*4eee*/, 11 /*4eef*/, 8 /*4ef0*/,  9 /*4ef1*/,
    9 /*4ef2*/,  10 /*4ef3*/, 9 /*4ef4*/,  10 /*4ef5*/, 10 /*4ef6*/,
    11 /*4ef7*/, 9 /*4ef8*/,  10 /*4ef9*/, 10 /*4efa*/, 11 /*4efb*/,
    10 /*4efc*/, 11 /*4efd*/, 11 /*4efe*/, 12 /*4eff*/, 5 /*4f00*/,
    6 /*4f01*/,  6 /*4f02*/,  7 /*4f03*/,  6 /*4f04*/,  7 /*4f05*/,
    7 /*4f06*/,  8 /*4f07*/,  6 /*4f08*/,  7 /*4f09*/,  7 /*4f0a*/,
    8 /*4f0b*/,  7 /*4f0c*/,  8 /*4f0d*/,  8 /*4f0e*/,  9 /*4f0f*/,
    6 /*4f10*/,  7 /*4f11*/,  7 /*4f12*/,  8 /*4f13*/,  7 /*4f14*/,
    8 /*4f15*/,  8 /*4f16*/,  9 /*4f17*/,  7 /*4f18*/,  8 /*4f19*/,
    8 /*4f1a*/,  9 /*4f1b*/,  8 /*4f1c*/,  9 /*4f1d*/,  9 /*4f1e*/,
    10 /*4f1f*/, 6 /*4f20*/,  7 /*4f21*/,  7 /*4f22*/,  8 /*4f23*/,
    7 /*4f24*/,  8 /*4f25*/,  8 /*4f26*/,  9 /*4f27*/,  7 /*4f28*/,
    8 /*4f29*/,  8 /*4f2a*/,  9 /*4f2b*/,  8 /*4f2c*/,  9 /*4f2d*/,
    9 /*4f2e*/,  10 /*4f2f*/, 7 /*4f30*/,  8 /*4f31*/,  8 /*4f32*/,
    9 /*4f33*/,  8 /*4f34*/,  9 /*4f35*/,  9 /*4f36*/,  10 /*4f37*/,
    8 /*4f38*/,  9 /*4f39*/,  9 /*4f3a*/,  10 /*4f3b*/, 9 /*4f3c*/,
    10 /*4f3d*/, 10 /*4f3e*/, 11 /*4f3f*/, 6 /*4f40*/,  7 /*4f41*/,
    7 /*4f42*/,  8 /*4f43*/,  7 /*4f44*/,  8 /*4f45*/,  8 /*4f46*/,
    9 /*4f47*/,  7 /*4f48*/,  8 /*4f49*/,  8 /*4f4a*/,  9 /*4f4b*/,
    8 /*4f4c*/,  9 /*4f4d*/,  9 /*4f4e*/,  10 /*4f4f*/, 7 /*4f50*/,
    8 /*4f51*/,  8 /*4f52*/,  9 /*4f53*/,  8 /*4f54*/,  9 /*4f55*/,
    9 /*4f56*/,  10 /*4f57*/, 8 /*4f58*/,  9 /*4f59*/,  9 /*4f5a*/,
    10 /*4f5b*/, 9 /*4f5c*/,  10 /*4f5d*/, 10 /*4f5e*/, 11 /*4f5f*/,
    7 /*4f60*/,  8 /*4f61*/,  8 /*4f62*/,  9 /*4f63*/,  8 /*4f64*/,
    9 /*4f65*/,  9 /*4f66*/,  10 /*4f67*/, 8 /*4f68*/,  9 /*4f69*/,
    9 /*4f6a*/,  10 /*4f6b*/, 9 /*4f6c*/,  10 /*4f6d*/, 10 /*4f6e*/,
    11 /*4f6f*/, 8 /*4f70*/,  9 /*4f71*/,  9 /*4f72*/,  10 /*4f73*/,
    9 /*4f74*/,  10 /*4f75*/, 10 /*4f76*/, 11 /*4f77*/, 9 /*4f78*/,
    10 /*4f79*/, 10 /*4f7a*/, 11 /*4f7b*/, 10 /*4f7c*/, 11 /*4f7d*/,
    11 /*4f7e*/, 12 /*4f7f*/, 6 /*4f80*/,  7 /*4f81*/,  7 /*4f82*/,
    8 /*4f83*/,  7 /*4f84*/,  8 /*4f85*/,  8 /*4f86*/,  9 /*4f87*/,
    7 /*4f88*/,  8 /*4f89*/,  8 /*4f8a*/,  9 /*4f8b*/,  8 /*4f8c*/,
    9 /*4f8d*/,  9 /*4f8e*/,  10 /*4f8f*/, 7 /*4f90*/,  8 /*4f91*/,
    8 /*4f92*/,  9 /*4f93*/,  8 /*4f94*/,  9 /*4f95*/,  9 /*4f96*/,
    10 /*4f97*/, 8 /*4f98*/,  9 /*4f99*/,  9 /*4f9a*/,  10 /*4f9b*/,
    9 /*4f9c*/,  10 /*4f9d*/, 10 /*4f9e*/, 11 /*4f9f*/, 7 /*4fa0*/,
    8 /*4fa1*/,  8 /*4fa2*/,  9 /*4fa3*/,  8 /*4fa4*/,  9 /*4fa5*/,
    9 /*4fa6*/,  10 /*4fa7*/, 8 /*4fa8*/,  9 /*4fa9*/,  9 /*4faa*/,
    10 /*4fab*/, 9 /*4fac*/,  10 /*4fad*/, 10 /*4fae*/, 11 /*4faf*/,
    8 /*4fb0*/,  9 /*4fb1*/,  9 /*4fb2*/,  10 /*4fb3*/, 9 /*4fb4*/,
    10 /*4fb5*/, 10 /*4fb6*/, 11 /*4fb7*/, 9 /*4fb8*/,  10 /*4fb9*/,
    10 /*4fba*/, 11 /*4fbb*/, 10 /*4fbc*/, 11 /*4fbd*/, 11 /*4fbe*/,
    12 /*4fbf*/, 7 /*4fc0*/,  8 /*4fc1*/,  8 /*4fc2*/,  9 /*4fc3*/,
    8 /*4fc4*/,  9 /*4fc5*/,  9 /*4fc6*/,  10 /*4fc7*/, 8 /*4fc8*/,
    9 /*4fc9*/,  9 /*4fca*/,  10 /*4fcb*/, 9 /*4fcc*/,  10 /*4fcd*/,
    10 /*4fce*/, 11 /*4fcf*/, 8 /*4fd0*/,  9 /*4fd1*/,  9 /*4fd2*/,
    10 /*4fd3*/, 9 /*4fd4*/,  10 /*4fd5*/, 10 /*4fd6*/, 11 /*4fd7*/,
    9 /*4fd8*/,  10 /*4fd9*/, 10 /*4fda*/, 11 /*4fdb*/, 10 /*4fdc*/,
    11 /*4fdd*/, 11 /*4fde*/, 12 /*4fdf*/, 8 /*4fe0*/,  9 /*4fe1*/,
    9 /*4fe2*/,  10 /*4fe3*/, 9 /*4fe4*/,  10 /*4fe5*/, 10 /*4fe6*/,
    11 /*4fe7*/, 9 /*4fe8*/,  10 /*4fe9*/, 10 /*4fea*/, 11 /*4feb*/,
    10 /*4fec*/, 11 /*4fed*/, 11 /*4fee*/, 12 /*4fef*/, 9 /*4ff0*/,
    10 /*4ff1*/, 10 /*4ff2*/, 11 /*4ff3*/, 10 /*4ff4*/, 11 /*4ff5*/,
    11 /*4ff6*/, 12 /*4ff7*/, 10 /*4ff8*/, 11 /*4ff9*/, 11 /*4ffa*/,
    12 /*4ffb*/, 11 /*4ffc*/, 12 /*4ffd*/, 12 /*4ffe*/, 13 /*4fff*/,
    2 /*5000*/,  3 /*5001*/,  3 /*5002*/,  4 /*5003*/,  3 /*5004*/,
    4 /*5005*/,  4 /*5006*/,  5 /*5007*/,  3 /*5008*/,  4 /*5009*/,
    4 /*500a*/,  5 /*500b*/,  4 /*500c*/,  5 /*500d*/,  5 /*500e*/,
    6 /*500f*/,  3 /*5010*/,  4 /*5011*/,  4 /*5012*/,  5 /*5013*/,
    4 /*5014*/,  5 /*5015*/,  5 /*5016*/,  6 /*5017*/,  4 /*5018*/,
    5 /*5019*/,  5 /*501a*/,  6 /*501b*/,  5 /*501c*/,  6 /*501d*/,
    6 /*501e*/,  7 /*501f*/,  3 /*5020*/,  4 /*5021*/,  4 /*5022*/,
    5 /*5023*/,  4 /*5024*/,  5 /*5025*/,  5 /*5026*/,  6 /*5027*/,
    4 /*5028*/,  5 /*5029*/,  5 /*502a*/,  6 /*502b*/,  5 /*502c*/,
    6 /*502d*/,  6 /*502e*/,  7 /*502f*/,  4 /*5030*/,  5 /*5031*/,
    5 /*5032*/,  6 /*5033*/,  5 /*5034*/,  6 /*5035*/,  6 /*5036*/,
    7 /*5037*/,  5 /*5038*/,  6 /*5039*/,  6 /*503a*/,  7 /*503b*/,
    6 /*503c*/,  7 /*503d*/,  7 /*503e*/,  8 /*503f*/,  3 /*5040*/,
    4 /*5041*/,  4 /*5042*/,  5 /*5043*/,  4 /*5044*/,  5 /*5045*/,
    5 /*5046*/,  6 /*5047*/,  4 /*5048*/,  5 /*5049*/,  5 /*504a*/,
    6 /*504b*/,  5 /*504c*/,  6 /*504d*/,  6 /*504e*/,  7 /*504f*/,
    4 /*5050*/,  5 /*5051*/,  5 /*5052*/,  6 /*5053*/,  5 /*5054*/,
    6 /*5055*/,  6 /*5056*/,  7 /*5057*/,  5 /*5058*/,  6 /*5059*/,
    6 /*505a*/,  7 /*505b*/,  6 /*505c*/,  7 /*505d*/,  7 /*505e*/,
    8 /*505f*/,  4 /*5060*/,  5 /*5061*/,  5 /*5062*/,  6 /*5063*/,
    5 /*5064*/,  6 /*5065*/,  6 /*5066*/,  7 /*5067*/,  5 /*5068*/,
    6 /*5069*/,  6 /*506a*/,  7 /*506b*/,  6 /*506c*/,  7 /*506d*/,
    7 /*506e*/,  8 /*506f*/,  5 /*5070*/,  6 /*5071*/,  6 /*5072*/,
    7 /*5073*/,  6 /*5074*/,  7 /*5075*/,  7 /*5076*/,  8 /*5077*/,
    6 /*5078*/,  7 /*5079*/,  7 /*507a*/,  8 /*507b*/,  7 /*507c*/,
    8 /*507d*/,  8 /*507e*/,  9 /*507f*/,  3 /*5080*/,  4 /*5081*/,
    4 /*5082*/,  5 /*5083*/,  4 /*5084*/,  5 /*5085*/,  5 /*5086*/,
    6 /*5087*/,  4 /*5088*/,  5 /*5089*/,  5 /*508a*/,  6 /*508b*/,
    5 /*508c*/,  6 /*508d*/,  6 /*508e*/,  7 /*508f*/,  4 /*5090*/,
    5 /*5091*/,  5 /*5092*/,  6 /*5093*/,  5 /*5094*/,  6 /*5095*/,
    6 /*5096*/,  7 /*5097*/,  5 /*5098*/,  6 /*5099*/,  6 /*509a*/,
    7 /*509b*/,  6 /*509c*/,  7 /*509d*/,  7 /*509e*/,  8 /*509f*/,
    4 /*50a0*/,  5 /*50a1*/,  5 /*50a2*/,  6 /*50a3*/,  5 /*50a4*/,
    6 /*50a5*/,  6 /*50a6*/,  7 /*50a7*/,  5 /*50a8*/,  6 /*50a9*/,
    6 /*50aa*/,  7 /*50ab*/,  6 /*50ac*/,  7 /*50ad*/,  7 /*50ae*/,
    8 /*50af*/,  5 /*50b0*/,  6 /*50b1*/,  6 /*50b2*/,  7 /*50b3*/,
    6 /*50b4*/,  7 /*50b5*/,  7 /*50b6*/,  8 /*50b7*/,  6 /*50b8*/,
    7 /*50b9*/,  7 /*50ba*/,  8 /*50bb*/,  7 /*50bc*/,  8 /*50bd*/,
    8 /*50be*/,  9 /*50bf*/,  4 /*50c0*/,  5 /*50c1*/,  5 /*50c2*/,
    6 /*50c3*/,  5 /*50c4*/,  6 /*50c5*/,  6 /*50c6*/,  7 /*50c7*/,
    5 /*50c8*/,  6 /*50c9*/,  6 /*50ca*/,  7 /*50cb*/,  6 /*50cc*/,
    7 /*50cd*/,  7 /*50ce*/,  8 /*50cf*/,  5 /*50d0*/,  6 /*50d1*/,
    6 /*50d2*/,  7 /*50d3*/,  6 /*50d4*/,  7 /*50d5*/,  7 /*50d6*/,
    8 /*50d7*/,  6 /*50d8*/,  7 /*50d9*/,  7 /*50da*/,  8 /*50db*/,
    7 /*50dc*/,  8 /*50dd*/,  8 /*50de*/,  9 /*50df*/,  5 /*50e0*/,
    6 /*50e1*/,  6 /*50e2*/,  7 /*50e3*/,  6 /*50e4*/,  7 /*50e5*/,
    7 /*50e6*/,  8 /*50e7*/,  6 /*50e8*/,  7 /*50e9*/,  7 /*50ea*/,
    8 /*50eb*/,  7 /*50ec*/,  8 /*50ed*/,  8 /*50ee*/,  9 /*50ef*/,
    6 /*50f0*/,  7 /*50f1*/,  7 /*50f2*/,  8 /*50f3*/,  7 /*50f4*/,
    8 /*50f5*/,  8 /*50f6*/,  9 /*50f7*/,  7 /*50f8*/,  8 /*50f9*/,
    8 /*50fa*/,  9 /*50fb*/,  8 /*50fc*/,  9 /*50fd*/,  9 /*50fe*/,
    10 /*50ff*/, 3 /*5100*/,  4 /*5101*/,  4 /*5102*/,  5 /*5103*/,
    4 /*5104*/,  5 /*5105*/,  5 /*5106*/,  6 /*5107*/,  4 /*5108*/,
    5 /*5109*/,  5 /*510a*/,  6 /*510b*/,  5 /*510c*/,  6 /*510d*/,
    6 /*510e*/,  7 /*510f*/,  4 /*5110*/,  5 /*5111*/,  5 /*5112*/,
    6 /*5113*/,  5 /*5114*/,  6 /*5115*/,  6 /*5116*/,  7 /*5117*/,
    5 /*5118*/,  6 /*5119*/,  6 /*511a*/,  7 /*511b*/,  6 /*511c*/,
    7 /*511d*/,  7 /*511e*/,  8 /*511f*/,  4 /*5120*/,  5 /*5121*/,
    5 /*5122*/,  6 /*5123*/,  5 /*5124*/,  6 /*5125*/,  6 /*5126*/,
    7 /*5127*/,  5 /*5128*/,  6 /*5129*/,  6 /*512a*/,  7 /*512b*/,
    6 /*512c*/,  7 /*512d*/,  7 /*512e*/,  8 /*512f*/,  5 /*5130*/,
    6 /*5131*/,  6 /*5132*/,  7 /*5133*/,  6 /*5134*/,  7 /*5135*/,
    7 /*5136*/,  8 /*5137*/,  6 /*5138*/,  7 /*5139*/,  7 /*513a*/,
    8 /*513b*/,  7 /*513c*/,  8 /*513d*/,  8 /*513e*/,  9 /*513f*/,
    4 /*5140*/,  5 /*5141*/,  5 /*5142*/,  6 /*5143*/,  5 /*5144*/,
    6 /*5145*/,  6 /*5146*/,  7 /*5147*/,  5 /*5148*/,  6 /*5149*/,
    6 /*514a*/,  7 /*514b*/,  6 /*514c*/,  7 /*514d*/,  7 /*514e*/,
    8 /*514f*/,  5 /*5150*/,  6 /*5151*/,  6 /*5152*/,  7 /*5153*/,
    6 /*5154*/,  7 /*5155*/,  7 /*5156*/,  8 /*5157*/,  6 /*5158*/,
    7 /*5159*/,  7 /*515a*/,  8 /*515b*/,  7 /*515c*/,  8 /*515d*/,
    8 /*515e*/,  9 /*515f*/,  5 /*5160*/,  6 /*5161*/,  6 /*5162*/,
    7 /*5163*/,  6 /*5164*/,  7 /*5165*/,  7 /*5166*/,  8 /*5167*/,
    6 /*5168*/,  7 /*5169*/,  7 /*516a*/,  8 /*516b*/,  7 /*516c*/,
    8 /*516d*/,  8 /*516e*/,  9 /*516f*/,  6 /*5170*/,  7 /*5171*/,
    7 /*5172*/,  8 /*5173*/,  7 /*5174*/,  8 /*5175*/,  8 /*5176*/,
    9 /*5177*/,  7 /*5178*/,  8 /*5179*/,  8 /*517a*/,  9 /*517b*/,
    8 /*517c*/,  9 /*517d*/,  9 /*517e*/,  10 /*517f*/, 4 /*5180*/,
    5 /*5181*/,  5 /*5182*/,  6 /*5183*/,  5 /*5184*/,  6 /*5185*/,
    6 /*5186*/,  7 /*5187*/,  5 /*5188*/,  6 /*5189*/,  6 /*518a*/,
    7 /*518b*/,  6 /*518c*/,  7 /*518d*/,  7 /*518e*/,  8 /*518f*/,
    5 /*5190*/,  6 /*5191*/,  6 /*5192*/,  7 /*5193*/,  6 /*5194*/,
    7 /*5195*/,  7 /*5196*/,  8 /*5197*/,  6 /*5198*/,  7 /*5199*/,
    7 /*519a*/,  8 /*519b*/,  7 /*519c*/,  8 /*519d*/,  8 /*519e*/,
    9 /*519f*/,  5 /*51a0*/,  6 /*51a1*/,  6 /*51a2*/,  7 /*51a3*/,
    6 /*51a4*/,  7 /*51a5*/,  7 /*51a6*/,  8 /*51a7*/,  6 /*51a8*/,
    7 /*51a9*/,  7 /*51aa*/,  8 /*51ab*/,  7 /*51ac*/,  8 /*51ad*/,
    8 /*51ae*/,  9 /*51af*/,  6 /*51b0*/,  7 /*51b1*/,  7 /*51b2*/,
    8 /*51b3*/,  7 /*51b4*/,  8 /*51b5*/,  8 /*51b6*/,  9 /*51b7*/,
    7 /*51b8*/,  8 /*51b9*/,  8 /*51ba*/,  9 /*51bb*/,  8 /*51bc*/,
    9 /*51bd*/,  9 /*51be*/,  10 /*51bf*/, 5 /*51c0*/,  6 /*51c1*/,
    6 /*51c2*/,  7 /*51c3*/,  6 /*51c4*/,  7 /*51c5*/,  7 /*51c6*/,
    8 /*51c7*/,  6 /*51c8*/,  7 /*51c9*/,  7 /*51ca*/,  8 /*51cb*/,
    7 /*51cc*/,  8 /*51cd*/,  8 /*51ce*/,  9 /*51cf*/,  6 /*51d0*/,
    7 /*51d1*/,  7 /*51d2*/,  8 /*51d3*/,  7 /*51d4*/,  8 /*51d5*/,
    8 /*51d6*/,  9 /*51d7*/,  7 /*51d8*/,  8 /*51d9*/,  8 /*51da*/,
    9 /*51db*/,  8 /*51dc*/,  9 /*51dd*/,  9 /*51de*/,  10 /*51df*/,
    6 /*51e0*/,  7 /*51e1*/,  7 /*51e2*/,  8 /*51e3*/,  7 /*51e4*/,
    8 /*51e5*/,  8 /*51e6*/,  9 /*51e7*/,  7 /*51e8*/,  8 /*51e9*/,
    8 /*51ea*/,  9 /*51eb*/,  8 /*51ec*/,  9 /*51ed*/,  9 /*51ee*/,
    10 /*51ef*/, 7 /*51f0*/,  8 /*51f1*/,  8 /*51f2*/,  9 /*51f3*/,
    8 /*51f4*/,  9 /*51f5*/,  9 /*51f6*/,  10 /*51f7*/, 8 /*51f8*/,
    9 /*51f9*/,  9 /*51fa*/,  10 /*51fb*/, 9 /*51fc*/,  10 /*51fd*/,
    10 /*51fe*/, 11 /*51ff*/, 3 /*5200*/,  4 /*5201*/,  4 /*5202*/,
    5 /*5203*/,  4 /*5204*/,  5 /*5205*/,  5 /*5206*/,  6 /*5207*/,
    4 /*5208*/,  5 /*5209*/,  5 /*520a*/,  6 /*520b*/,  5 /*520c*/,
    6 /*520d*/,  6 /*520e*/,  7 /*520f*/,  4 /*5210*/,  5 /*5211*/,
    5 /*5212*/,  6 /*5213*/,  5 /*5214*/,  6 /*5215*/,  6 /*5216*/,
    7 /*5217*/,  5 /*5218*/,  6 /*5219*/,  6 /*521a*/,  7 /*521b*/,
    6 /*521c*/,  7 /*521d*/,  7 /*521e*/,  8 /*521f*/,  4 /*5220*/,
    5 /*5221*/,  5 /*5222*/,  6 /*5223*/,  5 /*5224*/,  6 /*5225*/,
    6 /*5226*/,  7 /*5227*/,  5 /*5228*/,  6 /*5229*/,  6 /*522a*/,
    7 /*522b*/,  6 /*522c*/,  7 /*522d*/,  7 /*522e*/,  8 /*522f*/,
    5 /*5230*/,  6 /*5231*/,  6 /*5232*/,  7 /*5233*/,  6 /*5234*/,
    7 /*5235*/,  7 /*5236*/,  8 /*5237*/,  6 /*5238*/,  7 /*5239*/,
    7 /*523a*/,  8 /*523b*/,  7 /*523c*/,  8 /*523d*/,  8 /*523e*/,
    9 /*523f*/,  4 /*5240*/,  5 /*5241*/,  5 /*5242*/,  6 /*5243*/,
    5 /*5244*/,  6 /*5245*/,  6 /*5246*/,  7 /*5247*/,  5 /*5248*/,
    6 /*5249*/,  6 /*524a*/,  7 /*524b*/,  6 /*524c*/,  7 /*524d*/,
    7 /*524e*/,  8 /*524f*/,  5 /*5250*/,  6 /*5251*/,  6 /*5252*/,
    7 /*5253*/,  6 /*5254*/,  7 /*5255*/,  7 /*5256*/,  8 /*5257*/,
    6 /*5258*/,  7 /*5259*/,  7 /*525a*/,  8 /*525b*/,  7 /*525c*/,
    8 /*525d*/,  8 /*525e*/,  9 /*525f*/,  5 /*5260*/,  6 /*5261*/,
    6 /*5262*/,  7 /*5263*/,  6 /*5264*/,  7 /*5265*/,  7 /*5266*/,
    8 /*5267*/,  6 /*5268*/,  7 /*5269*/,  7 /*526a*/,  8 /*526b*/,
    7 /*526c*/,  8 /*526d*/,  8 /*526e*/,  9 /*526f*/,  6 /*5270*/,
    7 /*5271*/,  7 /*5272*/,  8 /*5273*/,  7 /*5274*/,  8 /*5275*/,
    8 /*5276*/,  9 /*5277*/,  7 /*5278*/,  8 /*5279*/,  8 /*527a*/,
    9 /*527b*/,  8 /*527c*/,  9 /*527d*/,  9 /*527e*/,  10 /*527f*/,
    4 /*5280*/,  5 /*5281*/,  5 /*5282*/,  6 /*5283*/,  5 /*5284*/,
    6 /*5285*/,  6 /*5286*/,  7 /*5287*/,  5 /*5288*/,  6 /*5289*/,
    6 /*528a*/,  7 /*528b*/,  6 /*528c*/,  7 /*528d*/,  7 /*528e*/,
    8 /*528f*/,  5 /*5290*/,  6 /*5291*/,  6 /*5292*/,  7 /*5293*/,
    6 /*5294*/,  7 /*5295*/,  7 /*5296*/,  8 /*5297*/,  6 /*5298*/,
    7 /*5299*/,  7 /*529a*/,  8 /*529b*/,  7 /*529c*/,  8 /*529d*/,
    8 /*529e*/,  9 /*529f*/,  5 /*52a0*/,  6 /*52a1*/,  6 /*52a2*/,
    7 /*52a3*/,  6 /*52a4*/,  7 /*52a5*/,  7 /*52a6*/,  8 /*52a7*/,
    6 /*52a8*/,  7 /*52a9*/,  7 /*52aa*/,  8 /*52ab*/,  7 /*52ac*/,
    8 /*52ad*/,  8 /*52ae*/,  9 /*52af*/,  6 /*52b0*/,  7 /*52b1*/,
    7 /*52b2*/,  8 /*52b3*/,  7 /*52b4*/,  8 /*52b5*/,  8 /*52b6*/,
    9 /*52b7*/,  7 /*52b8*/,  8 /*52b9*/,  8 /*52ba*/,  9 /*52bb*/,
    8 /*52bc*/,  9 /*52bd*/,  9 /*52be*/,  10 /*52bf*/, 5 /*52c0*/,
    6 /*52c1*/,  6 /*52c2*/,  7 /*52c3*/,  6 /*52c4*/,  7 /*52c5*/,
    7 /*52c6*/,  8 /*52c7*/,  6 /*52c8*/,  7 /*52c9*/,  7 /*52ca*/,
    8 /*52cb*/,  7 /*52cc*/,  8 /*52cd*/,  8 /*52ce*/,  9 /*52cf*/,
    6 /*52d0*/,  7 /*52d1*/,  7 /*52d2*/,  8 /*52d3*/,  7 /*52d4*/,
    8 /*52d5*/,  8 /*52d6*/,  9 /*52d7*/,  7 /*52d8*/,  8 /*52d9*/,
    8 /*52da*/,  9 /*52db*/,  8 /*52dc*/,  9 /*52dd*/,  9 /*52de*/,
    10 /*52df*/, 6 /*52e0*/,  7 /*52e1*/,  7 /*52e2*/,  8 /*52e3*/,
    7 /*52e4*/,  8 /*52e5*/,  8 /*52e6*/,  9 /*52e7*/,  7 /*52e8*/,
    8 /*52e9*/,  8 /*52ea*/,  9 /*52eb*/,  8 /*52ec*/,  9 /*52ed*/,
    9 /*52ee*/,  10 /*52ef*/, 7 /*52f0*/,  8 /*52f1*/,  8 /*52f2*/,
    9 /*52f3*/,  8 /*52f4*/,  9 /*52f5*/,  9 /*52f6*/,  10 /*52f7*/,
    8 /*52f8*/,  9 /*52f9*/,  9 /*52fa*/,  10 /*52fb*/, 9 /*52fc*/,
    10 /*52fd*/, 10 /*52fe*/, 11 /*52ff*/, 4 /*5300*/,  5 /*5301*/,
    5 /*5302*/,  6 /*5303*/,  5 /*5304*/,  6 /*5305*/,  6 /*5306*/,
    7 /*5307*/,  5 /*5308*/,  6 /*5309*/,  6 /*530a*/,  7 /*530b*/,
    6 /*530c*/,  7 /*530d*/,  7 /*530e*/,  8 /*530f*/,  5 /*5310*/,
    6 /*5311*/,  6 /*5312*/,  7 /*5313*/,  6 /*5314*/,  7 /*5315*/,
    7 /*5316*/,  8 /*5317*/,  6 /*5318*/,  7 /*5319*/,  7 /*531a*/,
    8 /*531b*/,  7 /*531c*/,  8 /*531d*/,  8 /*531e*/,  9 /*531f*/,
    5 /*5320*/,  6 /*5321*/,  6 /*5322*/,  7 /*5323*/,  6 /*5324*/,
    7 /*5325*/,  7 /*5326*/,  8 /*5327*/,  6 /*5328*/,  7 /*5329*/,
    7 /*532a*/,  8 /*532b*/,  7 /*532c*/,  8 /*532d*/,  8 /*532e*/,
    9 /*532f*/,  6 /*5330*/,  7 /*5331*/,  7 /*5332*/,  8 /*5333*/,
    7 /*5334*/,  8 /*5335*/,  8 /*5336*/,  9 /*5337*/,  7 /*5338*/,
    8 /*5339*/,  8 /*533a*/,  9 /*533b*/,  8 /*533c*/,  9 /*533d*/,
    9 /*533e*/,  10 /*533f*/, 5 /*5340*/,  6 /*5341*/,  6 /*5342*/,
    7 /*5343*/,  6 /*5344*/,  7 /*5345*/,  7 /*5346*/,  8 /*5347*/,
    6 /*5348*/,  7 /*5349*/,  7 /*534a*/,  8 /*534b*/,  7 /*534c*/,
    8 /*534d*/,  8 /*534e*/,  9 /*534f*/,  6 /*5350*/,  7 /*5351*/,
    7 /*5352*/,  8 /*5353*/,  7 /*5354*/,  8 /*5355*/,  8 /*5356*/,
    9 /*5357*/,  7 /*5358*/,  8 /*5359*/,  8 /*535a*/,  9 /*535b*/,
    8 /*535c*/,  9 /*535d*/,  9 /*535e*/,  10 /*535f*/, 6 /*5360*/,
    7 /*5361*/,  7 /*5362*/,  8 /*5363*/,  7 /*5364*/,  8 /*5365*/,
    8 /*5366*/,  9 /*5367*/,  7 /*5368*/,  8 /*5369*/,  8 /*536a*/,
    9 /*536b*/,  8 /*536c*/,  9 /*536d*/,  9 /*536e*/,  10 /*536f*/,
    7 /*5370*/,  8 /*5371*/,  8 /*5372*/,  9 /*5373*/,  8 /*5374*/,
    9 /*5375*/,  9 /*5376*/,  10 /*5377*/, 8 /*5378*/,  9 /*5379*/,
    9 /*537a*/,  10 /*537b*/, 9 /*537c*/,  10 /*537d*/, 10 /*537e*/,
    11 /*537f*/, 5 /*5380*/,  6 /*5381*/,  6 /*5382*/,  7 /*5383*/,
    6 /*5384*/,  7 /*5385*/,  7 /*5386*/,  8 /*5387*/,  6 /*5388*/,
    7 /*5389*/,  7 /*538a*/,  8 /*538b*/,  7 /*538c*/,  8 /*538d*/,
    8 /*538e*/,  9 /*538f*/,  6 /*5390*/,  7 /*5391*/,  7 /*5392*/,
    8 /*5393*/,  7 /*5394*/,  8 /*5395*/,  8 /*5396*/,  9 /*5397*/,
    7 /*5398*/,  8 /*5399*/,  8 /*539a*/,  9 /*539b*/,  8 /*539c*/,
    9 /*539d*/,  9 /*539e*/,  10 /*539f*/, 6 /*53a0*/,  7 /*53a1*/,
    7 /*53a2*/,  8 /*53a3*/,  7 /*53a4*/,  8 /*53a5*/,  8 /*53a6*/,
    9 /*53a7*/,  7 /*53a8*/,  8 /*53a9*/,  8 /*53aa*/,  9 /*53ab*/,
    8 /*53ac*/,  9 /*53ad*/,  9 /*53ae*/,  10 /*53af*/, 7 /*53b0*/,
    8 /*53b1*/,  8 /*53b2*/,  9 /*53b3*/,  8 /*53b4*/,  9 /*53b5*/,
    9 /*53b6*/,  10 /*53b7*/, 8 /*53b8*/,  9 /*53b9*/,  9 /*53ba*/,
    10 /*53bb*/, 9 /*53bc*/,  10 /*53bd*/, 10 /*53be*/, 11 /*53bf*/,
    6 /*53c0*/,  7 /*53c1*/,  7 /*53c2*/,  8 /*53c3*/,  7 /*53c4*/,
    8 /*53c5*/,  8 /*53c6*/,  9 /*53c7*/,  7 /*53c8*/,  8 /*53c9*/,
    8 /*53ca*/,  9 /*53cb*/,  8 /*53cc*/,  9 /*53cd*/,  9 /*53ce*/,
    10 /*53cf*/, 7 /*53d0*/,  8 /*53d1*/,  8 /*53d2*/,  9 /*53d3*/,
    8 /*53d4*/,  9 /*53d5*/,  9 /*53d6*/,  10 /*53d7*/, 8 /*53d8*/,
    9 /*53d9*/,  9 /*53da*/,  10 /*53db*/, 9 /*53dc*/,  10 /*53dd*/,
    10 /*53de*/, 11 /*53df*/, 7 /*53e0*/,  8 /*53e1*/,  8 /*53e2*/,
    9 /*53e3*/,  8 /*53e4*/,  9 /*53e5*/,  9 /*53e6*/,  10 /*53e7*/,
    8 /*53e8*/,  9 /*53e9*/,  9 /*53ea*/,  10 /*53eb*/, 9 /*53ec*/,
    10 /*53ed*/, 10 /*53ee*/, 11 /*53ef*/, 8 /*53f0*/,  9 /*53f1*/,
    9 /*53f2*/,  10 /*53f3*/, 9 /*53f4*/,  10 /*53f5*/, 10 /*53f6*/,
    11 /*53f7*/, 9 /*53f8*/,  10 /*53f9*/, 10 /*53fa*/, 11 /*53fb*/,
    10 /*53fc*/, 11 /*53fd*/, 11 /*53fe*/, 12 /*53ff*/, 3 /*5400*/,
    4 /*5401*/,  4 /*5402*/,  5 /*5403*/,  4 /*5404*/,  5 /*5405*/,
    5 /*5406*/,  6 /*5407*/,  4 /*5408*/,  5 /*5409*/,  5 /*540a*/,
    6 /*540b*/,  5 /*540c*/,  6 /*540d*/,  6 /*540e*/,  7 /*540f*/,
    4 /*5410*/,  5 /*5411*/,  5 /*5412*/,  6 /*5413*/,  5 /*5414*/,
    6 /*5415*/,  6 /*5416*/,  7 /*5417*/,  5 /*5418*/,  6 /*5419*/,
    6 /*541a*/,  7 /*541b*/,  6 /*541c*/,  7 /*541d*/,  7 /*541e*/,
    8 /*541f*/,  4 /*5420*/,  5 /*5421*/,  5 /*5422*/,  6 /*5423*/,
    5 /*5424*/,  6 /*5425*/,  6 /*5426*/,  7 /*5427*/,  5 /*5428*/,
    6 /*5429*/,  6 /*542a*/,  7 /*542b*/,  6 /*542c*/,  7 /*542d*/,
    7 /*542e*/,  8 /*542f*/,  5 /*5430*/,  6 /*5431*/,  6 /*5432*/,
    7 /*5433*/,  6 /*5434*/,  7 /*5435*/,  7 /*5436*/,  8 /*5437*/,
    6 /*5438*/,  7 /*5439*/,  7 /*543a*/,  8 /*543b*/,  7 /*543c*/,
    8 /*543d*/,  8 /*543e*/,  9 /*543f*/,  4 /*5440*/,  5 /*5441*/,
    5 /*5442*/,  6 /*5443*/,  5 /*5444*/,  6 /*5445*/,  6 /*5446*/,
    7 /*5447*/,  5 /*5448*/,  6 /*5449*/,  6 /*544a*/,  7 /*544b*/,
    6 /*544c*/,  7 /*544d*/,  7 /*544e*/,  8 /*544f*/,  5 /*5450*/,
    6 /*5451*/,  6 /*5452*/,  7 /*5453*/,  6 /*5454*/,  7 /*5455*/,
    7 /*5456*/,  8 /*5457*/,  6 /*5458*/,  7 /*5459*/,  7 /*545a*/,
    8 /*545b*/,  7 /*545c*/,  8 /*545d*/,  8 /*545e*/,  9 /*545f*/,
    5 /*5460*/,  6 /*5461*/,  6 /*5462*/,  7 /*5463*/,  6 /*5464*/,
    7 /*5465*/,  7 /*5466*/,  8 /*5467*/,  6 /*5468*/,  7 /*5469*/,
    7 /*546a*/,  8 /*546b*/,  7 /*546c*/,  8 /*546d*/,  8 /*546e*/,
    9 /*546f*/,  6 /*5470*/,  7 /*5471*/,  7 /*5472*/,  8 /*5473*/,
    7 /*5474*/,  8 /*5475*/,  8 /*5476*/,  9 /*5477*/,  7 /*5478*/,
    8 /*5479*/,  8 /*547a*/,  9 /*547b*/,  8 /*547c*/,  9 /*547d*/,
    9 /*547e*/,  10 /*547f*/, 4 /*5480*/,  5 /*5481*/,  5 /*5482*/,
    6 /*5483*/,  5 /*5484*/,  6 /*5485*/,  6 /*5486*/,  7 /*5487*/,
    5 /*5488*/,  6 /*5489*/,  6 /*548a*/,  7 /*548b*/,  6 /*548c*/,
    7 /*548d*/,  7 /*548e*/,  8 /*548f*/,  5 /*5490*/,  6 /*5491*/,
    6 /*5492*/,  7 /*5493*/,  6 /*5494*/,  7 /*5495*/,  7 /*5496*/,
    8 /*5497*/,  6 /*5498*/,  7 /*5499*/,  7 /*549a*/,  8 /*549b*/,
    7 /*549c*/,  8 /*549d*/,  8 /*549e*/,  9 /*549f*/,  5 /*54a0*/,
    6 /*54a1*/,  6 /*54a2*/,  7 /*54a3*/,  6 /*54a4*/,  7 /*54a5*/,
    7 /*54a6*/,  8 /*54a7*/,  6 /*54a8*/,  7 /*54a9*/,  7 /*54aa*/,
    8 /*54ab*/,  7 /*54ac*/,  8 /*54ad*/,  8 /*54ae*/,  9 /*54af*/,
    6 /*54b0*/,  7 /*54b1*/,  7 /*54b2*/,  8 /*54b3*/,  7 /*54b4*/,
    8 /*54b5*/,  8 /*54b6*/,  9 /*54b7*/,  7 /*54b8*/,  8 /*54b9*/,
    8 /*54ba*/,  9 /*54bb*/,  8 /*54bc*/,  9 /*54bd*/,  9 /*54be*/,
    10 /*54bf*/, 5 /*54c0*/,  6 /*54c1*/,  6 /*54c2*/,  7 /*54c3*/,
    6 /*54c4*/,  7 /*54c5*/,  7 /*54c6*/,  8 /*54c7*/,  6 /*54c8*/,
    7 /*54c9*/,  7 /*54ca*/,  8 /*54cb*/,  7 /*54cc*/,  8 /*54cd*/,
    8 /*54ce*/,  9 /*54cf*/,  6 /*54d0*/,  7 /*54d1*/,  7 /*54d2*/,
    8 /*54d3*/,  7 /*54d4*/,  8 /*54d5*/,  8 /*54d6*/,  9 /*54d7*/,
    7 /*54d8*/,  8 /*54d9*/,  8 /*54da*/,  9 /*54db*/,  8 /*54dc*/,
    9 /*54dd*/,  9 /*54de*/,  10 /*54df*/, 6 /*54e0*/,  7 /*54e1*/,
    7 /*54e2*/,  8 /*54e3*/,  7 /*54e4*/,  8 /*54e5*/,  8 /*54e6*/,
    9 /*54e7*/,  7 /*54e8*/,  8 /*54e9*/,  8 /*54ea*/,  9 /*54eb*/,
    8 /*54ec*/,  9 /*54ed*/,  9 /*54ee*/,  10 /*54ef*/, 7 /*54f0*/,
    8 /*54f1*/,  8 /*54f2*/,  9 /*54f3*/,  8 /*54f4*/,  9 /*54f5*/,
    9 /*54f6*/,  10 /*54f7*/, 8 /*54f8*/,  9 /*54f9*/,  9 /*54fa*/,
    10 /*54fb*/, 9 /*54fc*/,  10 /*54fd*/, 10 /*54fe*/, 11 /*54ff*/,
    4 /*5500*/,  5 /*5501*/,  5 /*5502*/,  6 /*5503*/,  5 /*5504*/,
    6 /*5505*/,  6 /*5506*/,  7 /*5507*/,  5 /*5508*/,  6 /*5509*/,
    6 /*550a*/,  7 /*550b*/,  6 /*550c*/,  7 /*550d*/,  7 /*550e*/,
    8 /*550f*/,  5 /*5510*/,  6 /*5511*/,  6 /*5512*/,  7 /*5513*/,
    6 /*5514*/,  7 /*5515*/,  7 /*5516*/,  8 /*5517*/,  6 /*5518*/,
    7 /*5519*/,  7 /*551a*/,  8 /*551b*/,  7 /*551c*/,  8 /*551d*/,
    8 /*551e*/,  9 /*551f*/,  5 /*5520*/,  6 /*5521*/,  6 /*5522*/,
    7 /*5523*/,  6 /*5524*/,  7 /*5525*/,  7 /*5526*/,  8 /*5527*/,
    6 /*5528*/,  7 /*5529*/,  7 /*552a*/,  8 /*552b*/,  7 /*552c*/,
    8 /*552d*/,  8 /*552e*/,  9 /*552f*/,  6 /*5530*/,  7 /*5531*/,
    7 /*5532*/,  8 /*5533*/,  7 /*5534*/,  8 /*5535*/,  8 /*5536*/,
    9 /*5537*/,  7 /*5538*/,  8 /*5539*/,  8 /*553a*/,  9 /*553b*/,
    8 /*553c*/,  9 /*553d*/,  9 /*553e*/,  10 /*553f*/, 5 /*5540*/,
    6 /*5541*/,  6 /*5542*/,  7 /*5543*/,  6 /*5544*/,  7 /*5545*/,
    7 /*5546*/,  8 /*5547*/,  6 /*5548*/,  7 /*5549*/,  7 /*554a*/,
    8 /*554b*/,  7 /*554c*/,  8 /*554d*/,  8 /*554e*/,  9 /*554f*/,
    6 /*5550*/,  7 /*5551*/,  7 /*5552*/,  8 /*5553*/,  7 /*5554*/,
    8 /*5555*/,  8 /*5556*/,  9 /*5557*/,  7 /*5558*/,  8 /*5559*/,
    8 /*555a*/,  9 /*555b*/,  8 /*555c*/,  9 /*555d*/,  9 /*555e*/,
    10 /*555f*/, 6 /*5560*/,  7 /*5561*/,  7 /*5562*/,  8 /*5563*/,
    7 /*5564*/,  8 /*5565*/,  8 /*5566*/,  9 /*5567*/,  7 /*5568*/,
    8 /*5569*/,  8 /*556a*/,  9 /*556b*/,  8 /*556c*/,  9 /*556d*/,
    9 /*556e*/,  10 /*556f*/, 7 /*5570*/,  8 /*5571*/,  8 /*5572*/,
    9 /*5573*/,  8 /*5574*/,  9 /*5575*/,  9 /*5576*/,  10 /*5577*/,
    8 /*5578*/,  9 /*5579*/,  9 /*557a*/,  10 /*557b*/, 9 /*557c*/,
    10 /*557d*/, 10 /*557e*/, 11 /*557f*/, 5 /*5580*/,  6 /*5581*/,
    6 /*5582*/,  7 /*5583*/,  6 /*5584*/,  7 /*5585*/,  7 /*5586*/,
    8 /*5587*/,  6 /*5588*/,  7 /*5589*/,  7 /*558a*/,  8 /*558b*/,
    7 /*558c*/,  8 /*558d*/,  8 /*558e*/,  9 /*558f*/,  6 /*5590*/,
    7 /*5591*/,  7 /*5592*/,  8 /*5593*/,  7 /*5594*/,  8 /*5595*/,
    8 /*5596*/,  9 /*5597*/,  7 /*5598*/,  8 /*5599*/,  8 /*559a*/,
    9 /*559b*/,  8 /*559c*/,  9 /*559d*/,  9 /*559e*/,  10 /*559f*/,
    6 /*55a0*/,  7 /*55a1*/,  7 /*55a2*/,  8 /*55a3*/,  7 /*55a4*/,
    8 /*55a5*/,  8 /*55a6*/,  9 /*55a7*/,  7 /*55a8*/,  8 /*55a9*/,
    8 /*55aa*/,  9 /*55ab*/,  8 /*55ac*/,  9 /*55ad*/,  9 /*55ae*/,
    10 /*55af*/, 7 /*55b0*/,  8 /*55b1*/,  8 /*55b2*/,  9 /*55b3*/,
    8 /*55b4*/,  9 /*55b5*/,  9 /*55b6*/,  10 /*55b7*/, 8 /*55b8*/,
    9 /*55b9*/,  9 /*55ba*/,  10 /*55bb*/, 9 /*55bc*/,  10 /*55bd*/,
    10 /*55be*/, 11 /*55bf*/, 6 /*55c0*/,  7 /*55c1*/,  7 /*55c2*/,
    8 /*55c3*/,  7 /*55c4*/,  8 /*55c5*/,  8 /*55c6*/,  9 /*55c7*/,
    7 /*55c8*/,  8 /*55c9*/,  8 /*55ca*/,  9 /*55cb*/,  8 /*55cc*/,
    9 /*55cd*/,  9 /*55ce*/,  10 /*55cf*/, 7 /*55d0*/,  8 /*55d1*/,
    8 /*55d2*/,  9 /*55d3*/,  8 /*55d4*/,  9 /*55d5*/,  9 /*55d6*/,
    10 /*55d7*/, 8 /*55d8*/,  9 /*55d9*/,  9 /*55da*/,  10 /*55db*/,
    9 /*55dc*/,  10 /*55dd*/, 10 /*55de*/, 11 /*55df*/, 7 /*55e0*/,
    8 /*55e1*/,  8 /*55e2*/,  9 /*55e3*/,  8 /*55e4*/,  9 /*55e5*/,
    9 /*55e6*/,  10 /*55e7*/, 8 /*55e8*/,  9 /*55e9*/,  9 /*55ea*/,
    10 /*55eb*/, 9 /*55ec*/,  10 /*55ed*/, 10 /*55ee*/, 11 /*55ef*/,
    8 /*55f0*/,  9 /*55f1*/,  9 /*55f2*/,  10 /*55f3*/, 9 /*55f4*/,
    10 /*55f5*/, 10 /*55f6*/, 11 /*55f7*/, 9 /*55f8*/,  10 /*55f9*/,
    10 /*55fa*/, 11 /*55fb*/, 10 /*55fc*/, 11 /*55fd*/, 11 /*55fe*/,
    12 /*55ff*/, 4 /*5600*/,  5 /*5601*/,  5 /*5602*/,  6 /*5603*/,
    5 /*5604*/,  6 /*5605*/,  6 /*5606*/,  7 /*5607*/,  5 /*5608*/,
    6 /*5609*/,  6 /*560a*/,  7 /*560b*/,  6 /*560c*/,  7 /*560d*/,
    7 /*560e*/,  8 /*560f*/,  5 /*5610*/,  6 /*5611*/,  6 /*5612*/,
    7 /*5613*/,  6 /*5614*/,  7 /*5615*/,  7 /*5616*/,  8 /*5617*/,
    6 /*5618*/,  7 /*5619*/,  7 /*561a*/,  8 /*561b*/,  7 /*561c*/,
    8 /*561d*/,  8 /*561e*/,  9 /*561f*/,  5 /*5620*/,  6 /*5621*/,
    6 /*5622*/,  7 /*5623*/,  6 /*5624*/,  7 /*5625*/,  7 /*5626*/,
    8 /*5627*/,  6 /*5628*/,  7 /*5629*/,  7 /*562a*/,  8 /*562b*/,
    7 /*562c*/,  8 /*562d*/,  8 /*562e*/,  9 /*562f*/,  6 /*5630*/,
    7 /*5631*/,  7 /*5632*/,  8 /*5633*/,  7 /*5634*/,  8 /*5635*/,
    8 /*5636*/,  9 /*5637*/,  7 /*5638*/,  8 /*5639*/,  8 /*563a*/,
    9 /*563b*/,  8 /*563c*/,  9 /*563d*/,  9 /*563e*/,  10 /*563f*/,
    5 /*5640*/,  6 /*5641*/,  6 /*5642*/,  7 /*5643*/,  6 /*5644*/,
    7 /*5645*/,  7 /*5646*/,  8 /*5647*/,  6 /*5648*/,  7 /*5649*/,
    7 /*564a*/,  8 /*564b*/,  7 /*564c*/,  8 /*564d*/,  8 /*564e*/,
    9 /*564f*/,  6 /*5650*/,  7 /*5651*/,  7 /*5652*/,  8 /*5653*/,
    7 /*5654*/,  8 /*5655*/,  8 /*5656*/,  9 /*5657*/,  7 /*5658*/,
    8 /*5659*/,  8 /*565a*/,  9 /*565b*/,  8 /*565c*/,  9 /*565d*/,
    9 /*565e*/,  10 /*565f*/, 6 /*5660*/,  7 /*5661*/,  7 /*5662*/,
    8 /*5663*/,  7 /*5664*/,  8 /*5665*/,  8 /*5666*/,  9 /*5667*/,
    7 /*5668*/,  8 /*5669*/,  8 /*566a*/,  9 /*566b*/,  8 /*566c*/,
    9 /*566d*/,  9 /*566e*/,  10 /*566f*/, 7 /*5670*/,  8 /*5671*/,
    8 /*5672*/,  9 /*5673*/,  8 /*5674*/,  9 /*5675*/,  9 /*5676*/,
    10 /*5677*/, 8 /*5678*/,  9 /*5679*/,  9 /*567a*/,  10 /*567b*/,
    9 /*567c*/,  10 /*567d*/, 10 /*567e*/, 11 /*567f*/, 5 /*5680*/,
    6 /*5681*/,  6 /*5682*/,  7 /*5683*/,  6 /*5684*/,  7 /*5685*/,
    7 /*5686*/,  8 /*5687*/,  6 /*5688*/,  7 /*5689*/,  7 /*568a*/,
    8 /*568b*/,  7 /*568c*/,  8 /*568d*/,  8 /*568e*/,  9 /*568f*/,
    6 /*5690*/,  7 /*5691*/,  7 /*5692*/,  8 /*5693*/,  7 /*5694*/,
    8 /*5695*/,  8 /*5696*/,  9 /*5697*/,  7 /*5698*/,  8 /*5699*/,
    8 /*569a*/,  9 /*569b*/,  8 /*569c*/,  9 /*569d*/,  9 /*569e*/,
    10 /*569f*/, 6 /*56a0*/,  7 /*56a1*/,  7 /*56a2*/,  8 /*56a3*/,
    7 /*56a4*/,  8 /*56a5*/,  8 /*56a6*/,  9 /*56a7*/,  7 /*56a8*/,
    8 /*56a9*/,  8 /*56aa*/,  9 /*56ab*/,  8 /*56ac*/,  9 /*56ad*/,
    9 /*56ae*/,  10 /*56af*/, 7 /*56b0*/,  8 /*56b1*/,  8 /*56b2*/,
    9 /*56b3*/,  8 /*56b4*/,  9 /*56b5*/,  9 /*56b6*/,  10 /*56b7*/,
    8 /*56b8*/,  9 /*56b9*/,  9 /*56ba*/,  10 /*56bb*/, 9 /*56bc*/,
    10 /*56bd*/, 10 /*56be*/, 11 /*56bf*/, 6 /*56c0*/,  7 /*56c1*/,
    7 /*56c2*/,  8 /*56c3*/,  7 /*56c4*/,  8 /*56c5*/,  8 /*56c6*/,
    9 /*56c7*/,  7 /*56c8*/,  8 /*56c9*/,  8 /*56ca*/,  9 /*56cb*/,
    8 /*56cc*/,  9 /*56cd*/,  9 /*56ce*/,  10 /*56cf*/, 7 /*56d0*/,
    8 /*56d1*/,  8 /*56d2*/,  9 /*56d3*/,  8 /*56d4*/,  9 /*56d5*/,
    9 /*56d6*/,  10 /*56d7*/, 8 /*56d8*/,  9 /*56d9*/,  9 /*56da*/,
    10 /*56db*/, 9 /*56dc*/,  10 /*56dd*/, 10 /*56de*/, 11 /*56df*/,
    7 /*56e0*/,  8 /*56e1*/,  8 /*56e2*/,  9 /*56e3*/,  8 /*56e4*/,
    9 /*56e5*/,  9 /*56e6*/,  10 /*56e7*/, 8 /*56e8*/,  9 /*56e9*/,
    9 /*56ea*/,  10 /*56eb*/, 9 /*56ec*/,  10 /*56ed*/, 10 /*56ee*/,
    11 /*56ef*/, 8 /*56f0*/,  9 /*56f1*/,  9 /*56f2*/,  10 /*56f3*/,
    9 /*56f4*/,  10 /*56f5*/, 10 /*56f6*/, 11 /*56f7*/, 9 /*56f8*/,
    10 /*56f9*/, 10 /*56fa*/, 11 /*56fb*/, 10 /*56fc*/, 11 /*56fd*/,
    11 /*56fe*/, 12 /*56ff*/, 5 /*5700*/,  6 /*5701*/,  6 /*5702*/,
    7 /*5703*/,  6 /*5704*/,  7 /*5705*/,  7 /*5706*/,  8 /*5707*/,
    6 /*5708*/,  7 /*5709*/,  7 /*570a*/,  8 /*570b*/,  7 /*570c*/,
    8 /*570d*/,  8 /*570e*/,  9 /*570f*/,  6 /*5710*/,  7 /*5711*/,
    7 /*5712*/,  8 /*5713*/,  7 /*5714*/,  8 /*5715*/,  8 /*5716*/,
    9 /*5717*/,  7 /*5718*/,  8 /*5719*/,  8 /*571a*/,  9 /*571b*/,
    8 /*571c*/,  9 /*571d*/,  9 /*571e*/,  10 /*571f*/, 6 /*5720*/,
    7 /*5721*/,  7 /*5722*/,  8 /*5723*/,  7 /*5724*/,  8 /*5725*/,
    8 /*5726*/,  9 /*5727*/,  7 /*5728*/,  8 /*5729*/,  8 /*572a*/,
    9 /*572b*/,  8 /*572c*/,  9 /*572d*/,  9 /*572e*/,  10 /*572f*/,
    7 /*5730*/,  8 /*5731*/,  8 /*5732*/,  9 /*5733*/,  8 /*5734*/,
    9 /*5735*/,  9 /*5736*/,  10 /*5737*/, 8 /*5738*/,  9 /*5739*/,
    9 /*573a*/,  10 /*573b*/, 9 /*573c*/,  10 /*573d*/, 10 /*573e*/,
    11 /*573f*/, 6 /*5740*/,  7 /*5741*/,  7 /*5742*/,  8 /*5743*/,
    7 /*5744*/,  8 /*5745*/,  8 /*5746*/,  9 /*5747*/,  7 /*5748*/,
    8 /*5749*/,  8 /*574a*/,  9 /*574b*/,  8 /*574c*/,  9 /*574d*/,
    9 /*574e*/,  10 /*574f*/, 7 /*5750*/,  8 /*5751*/,  8 /*5752*/,
    9 /*5753*/,  8 /*5754*/,  9 /*5755*/,  9 /*5756*/,  10 /*5757*/,
    8 /*5758*/,  9 /*5759*/,  9 /*575a*/,  10 /*575b*/, 9 /*575c*/,
    10 /*575d*/, 10 /*575e*/, 11 /*575f*/, 7 /*5760*/,  8 /*5761*/,
    8 /*5762*/,  9 /*5763*/,  8 /*5764*/,  9 /*5765*/,  9 /*5766*/,
    10 /*5767*/, 8 /*5768*/,  9 /*5769*/,  9 /*576a*/,  10 /*576b*/,
    9 /*576c*/,  10 /*576d*/, 10 /*576e*/, 11 /*576f*/, 8 /*5770*/,
    9 /*5771*/,  9 /*5772*/,  10 /*5773*/, 9 /*5774*/,  10 /*5775*/,
    10 /*5776*/, 11 /*5777*/, 9 /*5778*/,  10 /*5779*/, 10 /*577a*/,
    11 /*577b*/, 10 /*577c*/, 11 /*577d*/, 11 /*577e*/, 12 /*577f*/,
    6 /*5780*/,  7 /*5781*/,  7 /*5782*/,  8 /*5783*/,  7 /*5784*/,
    8 /*5785*/,  8 /*5786*/,  9 /*5787*/,  7 /*5788*/,  8 /*5789*/,
    8 /*578a*/,  9 /*578b*/,  8 /*578c*/,  9 /*578d*/,  9 /*578e*/,
    10 /*578f*/, 7 /*5790*/,  8 /*5791*/,  8 /*5792*/,  9 /*5793*/,
    8 /*5794*/,  9 /*5795*/,  9 /*5796*/,  10 /*5797*/, 8 /*5798*/,
    9 /*5799*/,  9 /*579a*/,  10 /*579b*/, 9 /*579c*/,  10 /*579d*/,
    10 /*579e*/, 11 /*579f*/, 7 /*57a0*/,  8 /*57a1*/,  8 /*57a2*/,
    9 /*57a3*/,  8 /*57a4*/,  9 /*57a5*/,  9 /*57a6*/,  10 /*57a7*/,
    8 /*57a8*/,  9 /*57a9*/,  9 /*57aa*/,  10 /*57ab*/, 9 /*57ac*/,
    10 /*57ad*/, 10 /*57ae*/, 11 /*57af*/, 8 /*57b0*/,  9 /*57b1*/,
    9 /*57b2*/,  10 /*57b3*/, 9 /*57b4*/,  10 /*57b5*/, 10 /*57b6*/,
    11 /*57b7*/, 9 /*57b8*/,  10 /*57b9*/, 10 /*57ba*/, 11 /*57bb*/,
    10 /*57bc*/, 11 /*57bd*/, 11 /*57be*/, 12 /*57bf*/, 7 /*57c0*/,
    8 /*57c1*/,  8 /*57c2*/,  9 /*57c3*/,  8 /*57c4*/,  9 /*57c5*/,
    9 /*57c6*/,  10 /*57c7*/, 8 /*57c8*/,  9 /*57c9*/,  9 /*57ca*/,
    10 /*57cb*/, 9 /*57cc*/,  10 /*57cd*/, 10 /*57ce*/, 11 /*57cf*/,
    8 /*57d0*/,  9 /*57d1*/,  9 /*57d2*/,  10 /*57d3*/, 9 /*57d4*/,
    10 /*57d5*/, 10 /*57d6*/, 11 /*57d7*/, 9 /*57d8*/,  10 /*57d9*/,
    10 /*57da*/, 11 /*57db*/, 10 /*57dc*/, 11 /*57dd*/, 11 /*57de*/,
    12 /*57df*/, 8 /*57e0*/,  9 /*57e1*/,  9 /*57e2*/,  10 /*57e3*/,
    9 /*57e4*/,  10 /*57e5*/, 10 /*57e6*/, 11 /*57e7*/, 9 /*57e8*/,
    10 /*57e9*/, 10 /*57ea*/, 11 /*57eb*/, 10 /*57ec*/, 11 /*57ed*/,
    11 /*57ee*/, 12 /*57ef*/, 9 /*57f0*/,  10 /*57f1*/, 10 /*57f2*/,
    11 /*57f3*/, 10 /*57f4*/, 11 /*57f5*/, 11 /*57f6*/, 12 /*57f7*/,
    10 /*57f8*/, 11 /*57f9*/, 11 /*57fa*/, 12 /*57fb*/, 11 /*57fc*/,
    12 /*57fd*/, 12 /*57fe*/, 13 /*57ff*/, 3 /*5800*/,  4 /*5801*/,
    4 /*5802*/,  5 /*5803*/,  4 /*5804*/,  5 /*5805*/,  5 /*5806*/,
    6 /*5807*/,  4 /*5808*/,  5 /*5809*/,  5 /*580a*/,  6 /*580b*/,
    5 /*580c*/,  6 /*580d*/,  6 /*580e*/,  7 /*580f*/,  4 /*5810*/,
    5 /*5811*/,  5 /*5812*/,  6 /*5813*/,  5 /*5814*/,  6 /*5815*/,
    6 /*5816*/,  7 /*5817*/,  5 /*5818*/,  6 /*5819*/,  6 /*581a*/,
    7 /*581b*/,  6 /*581c*/,  7 /*581d*/,  7 /*581e*/,  8 /*581f*/,
    4 /*5820*/,  5 /*5821*/,  5 /*5822*/,  6 /*5823*/,  5 /*5824*/,
    6 /*5825*/,  6 /*5826*/,  7 /*5827*/,  5 /*5828*/,  6 /*5829*/,
    6 /*582a*/,  7 /*582b*/,  6 /*582c*/,  7 /*582d*/,  7 /*582e*/,
    8 /*582f*/,  5 /*5830*/,  6 /*5831*/,  6 /*5832*/,  7 /*5833*/,
    6 /*5834*/,  7 /*5835*/,  7 /*5836*/,  8 /*5837*/,  6 /*5838*/,
    7 /*5839*/,  7 /*583a*/,  8 /*583b*/,  7 /*583c*/,  8 /*583d*/,
    8 /*583e*/,  9 /*583f*/,  4 /*5840*/,  5 /*5841*/,  5 /*5842*/,
    6 /*5843*/,  5 /*5844*/,  6 /*5845*/,  6 /*5846*/,  7 /*5847*/,
    5 /*5848*/,  6 /*5849*/,  6 /*584a*/,  7 /*584b*/,  6 /*584c*/,
    7 /*584d*/,  7 /*584e*/,  8 /*584f*/,  5 /*5850*/,  6 /*5851*/,
    6 /*5852*/,  7 /*5853*/,  6 /*5854*/,  7 /*5855*/,  7 /*5856*/,
    8 /*5857*/,  6 /*5858*/,  7 /*5859*/,  7 /*585a*/,  8 /*585b*/,
    7 /*585c*/,  8 /*585d*/,  8 /*585e*/,  9 /*585f*/,  5 /*5860*/,
    6 /*5861*/,  6 /*5862*/,  7 /*5863*/,  6 /*5864*/,  7 /*5865*/,
    7 /*5866*/,  8 /*5867*/,  6 /*5868*/,  7 /*5869*/,  7 /*586a*/,
    8 /*586b*/,  7 /*586c*/,  8 /*586d*/,  8 /*586e*/,  9 /*586f*/,
    6 /*5870*/,  7 /*5871*/,  7 /*5872*/,  8 /*5873*/,  7 /*5874*/,
    8 /*5875*/,  8 /*5876*/,  9 /*5877*/,  7 /*5878*/,  8 /*5879*/,
    8 /*587a*/,  9 /*587b*/,  8 /*587c*/,  9 /*587d*/,  9 /*587e*/,
    10 /*587f*/, 4 /*5880*/,  5 /*5881*/,  5 /*5882*/,  6 /*5883*/,
    5 /*5884*/,  6 /*5885*/,  6 /*5886*/,  7 /*5887*/,  5 /*5888*/,
    6 /*5889*/,  6 /*588a*/,  7 /*588b*/,  6 /*588c*/,  7 /*588d*/,
    7 /*588e*/,  8 /*588f*/,  5 /*5890*/,  6 /*5891*/,  6 /*5892*/,
    7 /*5893*/,  6 /*5894*/,  7 /*5895*/,  7 /*5896*/,  8 /*5897*/,
    6 /*5898*/,  7 /*5899*/,  7 /*589a*/,  8 /*589b*/,  7 /*589c*/,
    8 /*589d*/,  8 /*589e*/,  9 /*589f*/,  5 /*58a0*/,  6 /*58a1*/,
    6 /*58a2*/,  7 /*58a3*/,  6 /*58a4*/,  7 /*58a5*/,  7 /*58a6*/,
    8 /*58a7*/,  6 /*58a8*/,  7 /*58a9*/,  7 /*58aa*/,  8 /*58ab*/,
    7 /*58ac*/,  8 /*58ad*/,  8 /*58ae*/,  9 /*58af*/,  6 /*58b0*/,
    7 /*58b1*/,  7 /*58b2*/,  8 /*58b3*/,  7 /*58b4*/,  8 /*58b5*/,
    8 /*58b6*/,  9 /*58b7*/,  7 /*58b8*/,  8 /*58b9*/,  8 /*58ba*/,
    9 /*58bb*/,  8 /*58bc*/,  9 /*58bd*/,  9 /*58be*/,  10 /*58bf*/,
    5 /*58c0*/,  6 /*58c1*/,  6 /*58c2*/,  7 /*58c3*/,  6 /*58c4*/,
    7 /*58c5*/,  7 /*58c6*/,  8 /*58c7*/,  6 /*58c8*/,  7 /*58c9*/,
    7 /*58ca*/,  8 /*58cb*/,  7 /*58cc*/,  8 /*58cd*/,  8 /*58ce*/,
    9 /*58cf*/,  6 /*58d0*/,  7 /*58d1*/,  7 /*58d2*/,  8 /*58d3*/,
    7 /*58d4*/,  8 /*58d5*/,  8 /*58d6*/,  9 /*58d7*/,  7 /*58d8*/,
    8 /*58d9*/,  8 /*58da*/,  9 /*58db*/,  8 /*58dc*/,  9 /*58dd*/,
    9 /*58de*/,  10 /*58df*/, 6 /*58e0*/,  7 /*58e1*/,  7 /*58e2*/,
    8 /*58e3*/,  7 /*58e4*/,  8 /*58e5*/,  8 /*58e6*/,  9 /*58e7*/,
    7 /*58e8*/,  8 /*58e9*/,  8 /*58ea*/,  9 /*58eb*/,  8 /*58ec*/,
    9 /*58ed*/,  9 /*58ee*/,  10 /*58ef*/, 7 /*58f0*/,  8 /*58f1*/,
    8 /*58f2*/,  9 /*58f3*/,  8 /*58f4*/,  9 /*58f5*/,  9 /*58f6*/,
    10 /*58f7*/, 8 /*58f8*/,  9 /*58f9*/,  9 /*58fa*/,  10 /*58fb*/,
    9 /*58fc*/,  10 /*58fd*/, 10 /*58fe*/, 11 /*58ff*/, 4 /*5900*/,
    5 /*5901*/,  5 /*5902*/,  6 /*5903*/,  5 /*5904*/,  6 /*5905*/,
    6 /*5906*/,  7 /*5907*/,  5 /*5908*/,  6 /*5909*/,  6 /*590a*/,
    7 /*590b*/,  6 /*590c*/,  7 /*590d*/,  7 /*590e*/,  8 /*590f*/,
    5 /*5910*/,  6 /*5911*/,  6 /*5912*/,  7 /*5913*/,  6 /*5914*/,
    7 /*5915*/,  7 /*5916*/,  8 /*5917*/,  6 /*5918*/,  7 /*5919*/,
    7 /*591a*/,  8 /*591b*/,  7 /*591c*/,  8 /*591d*/,  8 /*591e*/,
    9 /*591f*/,  5 /*5920*/,  6 /*5921*/,  6 /*5922*/,  7 /*5923*/,
    6 /*5924*/,  7 /*5925*/,  7 /*5926*/,  8 /*5927*/,  6 /*5928*/,
    7 /*5929*/,  7 /*592a*/,  8 /*592b*/,  7 /*592c*/,  8 /*592d*/,
    8 /*592e*/,  9 /*592f*/,  6 /*5930*/,  7 /*5931*/,  7 /*5932*/,
    8 /*5933*/,  7 /*5934*/,  8 /*5935*/,  8 /*5936*/,  9 /*5937*/,
    7 /*5938*/,  8 /*5939*/,  8 /*593a*/,  9 /*593b*/,  8 /*593c*/,
    9 /*593d*/,  9 /*593e*/,  10 /*593f*/, 5 /*5940*/,  6 /*5941*/,
    6 /*5942*/,  7 /*5943*/,  6 /*5944*/,  7 /*5945*/,  7 /*5946*/,
    8 /*5947*/,  6 /*5948*/,  7 /*5949*/,  7 /*594a*/,  8 /*594b*/,
    7 /*594c*/,  8 /*594d*/,  8 /*594e*/,  9 /*594f*/,  6 /*5950*/,
    7 /*5951*/,  7 /*5952*/,  8 /*5953*/,  7 /*5954*/,  8 /*5955*/,
    8 /*5956*/,  9 /*5957*/,  7 /*5958*/,  8 /*5959*/,  8 /*595a*/,
    9 /*595b*/,  8 /*595c*/,  9 /*595d*/,  9 /*595e*/,  10 /*595f*/,
    6 /*5960*/,  7 /*5961*/,  7 /*5962*/,  8 /*5963*/,  7 /*5964*/,
    8 /*5965*/,  8 /*5966*/,  9 /*5967*/,  7 /*5968*/,  8 /*5969*/,
    8 /*596a*/,  9 /*596b*/,  8 /*596c*/,  9 /*596d*/,  9 /*596e*/,
    10 /*596f*/, 7 /*5970*/,  8 /*5971*/,  8 /*5972*/,  9 /*5973*/,
    8 /*5974*/,  9 /*5975*/,  9 /*5976*/,  10 /*5977*/, 8 /*5978*/,
    9 /*5979*/,  9 /*597a*/,  10 /*597b*/, 9 /*597c*/,  10 /*597d*/,
    10 /*597e*/, 11 /*597f*/, 5 /*5980*/,  6 /*5981*/,  6 /*5982*/,
    7 /*5983*/,  6 /*5984*/,  7 /*5985*/,  7 /*5986*/,  8 /*5987*/,
    6 /*5988*/,  7 /*5989*/,  7 /*598a*/,  8 /*598b*/,  7 /*598c*/,
    8 /*598d*/,  8 /*598e*/,  9 /*598f*/,  6 /*5990*/,  7 /*5991*/,
    7 /*5992*/,  8 /*5993*/,  7 /*5994*/,  8 /*5995*/,  8 /*5996*/,
    9 /*5997*/,  7 /*5998*/,  8 /*5999*/,  8 /*599a*/,  9 /*599b*/,
    8 /*599c*/,  9 /*599d*/,  9 /*599e*/,  10 /*599f*/, 6 /*59a0*/,
    7 /*59a1*/,  7 /*59a2*/,  8 /*59a3*/,  7 /*59a4*/,  8 /*59a5*/,
    8 /*59a6*/,  9 /*59a7*/,  7 /*59a8*/,  8 /*59a9*/,  8 /*59aa*/,
    9 /*59ab*/,  8 /*59ac*/,  9 /*59ad*/,  9 /*59ae*/,  10 /*59af*/,
    7 /*59b0*/,  8 /*59b1*/,  8 /*59b2*/,  9 /*59b3*/,  8 /*59b4*/,
    9 /*59b5*/,  9 /*59b6*/,  10 /*59b7*/, 8 /*59b8*/,  9 /*59b9*/,
    9 /*59ba*/,  10 /*59bb*/, 9 /*59bc*/,  10 /*59bd*/, 10 /*59be*/,
    11 /*59bf*/, 6 /*59c0*/,  7 /*59c1*/,  7 /*59c2*/,  8 /*59c3*/,
    7 /*59c4*/,  8 /*59c5*/,  8 /*59c6*/,  9 /*59c7*/,  7 /*59c8*/,
    8 /*59c9*/,  8 /*59ca*/,  9 /*59cb*/,  8 /*59cc*/,  9 /*59cd*/,
    9 /*59ce*/,  10 /*59cf*/, 7 /*59d0*/,  8 /*59d1*/,  8 /*59d2*/,
    9 /*59d3*/,  8 /*59d4*/,  9 /*59d5*/,  9 /*59d6*/,  10 /*59d7*/,
    8 /*59d8*/,  9 /*59d9*/,  9 /*59da*/,  10 /*59db*/, 9 /*59dc*/,
    10 /*59dd*/, 10 /*59de*/, 11 /*59df*/, 7 /*59e0*/,  8 /*59e1*/,
    8 /*59e2*/,  9 /*59e3*/,  8 /*59e4*/,  9 /*59e5*/,  9 /*59e6*/,
    10 /*59e7*/, 8 /*59e8*/,  9 /*59e9*/,  9 /*59ea*/,  10 /*59eb*/,
    9 /*59ec*/,  10 /*59ed*/, 10 /*59ee*/, 11 /*59ef*/, 8 /*59f0*/,
    9 /*59f1*/,  9 /*59f2*/,  10 /*59f3*/, 9 /*59f4*/,  10 /*59f5*/,
    10 /*59f6*/, 11 /*59f7*/, 9 /*59f8*/,  10 /*59f9*/, 10 /*59fa*/,
    11 /*59fb*/, 10 /*59fc*/, 11 /*59fd*/, 11 /*59fe*/, 12 /*59ff*/,
    4 /*5a00*/,  5 /*5a01*/,  5 /*5a02*/,  6 /*5a03*/,  5 /*5a04*/,
    6 /*5a05*/,  6 /*5a06*/,  7 /*5a07*/,  5 /*5a08*/,  6 /*5a09*/,
    6 /*5a0a*/,  7 /*5a0b*/,  6 /*5a0c*/,  7 /*5a0d*/,  7 /*5a0e*/,
    8 /*5a0f*/,  5 /*5a10*/,  6 /*5a11*/,  6 /*5a12*/,  7 /*5a13*/,
    6 /*5a14*/,  7 /*5a15*/,  7 /*5a16*/,  8 /*5a17*/,  6 /*5a18*/,
    7 /*5a19*/,  7 /*5a1a*/,  8 /*5a1b*/,  7 /*5a1c*/,  8 /*5a1d*/,
    8 /*5a1e*/,  9 /*5a1f*/,  5 /*5a20*/,  6 /*5a21*/,  6 /*5a22*/,
    7 /*5a23*/,  6 /*5a24*/,  7 /*5a25*/,  7 /*5a26*/,  8 /*5a27*/,
    6 /*5a28*/,  7 /*5a29*/,  7 /*5a2a*/,  8 /*5a2b*/,  7 /*5a2c*/,
    8 /*5a2d*/,  8 /*5a2e*/,  9 /*5a2f*/,  6 /*5a30*/,  7 /*5a31*/,
    7 /*5a32*/,  8 /*5a33*/,  7 /*5a34*/,  8 /*5a35*/,  8 /*5a36*/,
    9 /*5a37*/,  7 /*5a38*/,  8 /*5a39*/,  8 /*5a3a*/,  9 /*5a3b*/,
    8 /*5a3c*/,  9 /*5a3d*/,  9 /*5a3e*/,  10 /*5a3f*/, 5 /*5a40*/,
    6 /*5a41*/,  6 /*5a42*/,  7 /*5a43*/,  6 /*5a44*/,  7 /*5a45*/,
    7 /*5a46*/,  8 /*5a47*/,  6 /*5a48*/,  7 /*5a49*/,  7 /*5a4a*/,
    8 /*5a4b*/,  7 /*5a4c*/,  8 /*5a4d*/,  8 /*5a4e*/,  9 /*5a4f*/,
    6 /*5a50*/,  7 /*5a51*/,  7 /*5a52*/,  8 /*5a53*/,  7 /*5a54*/,
    8 /*5a55*/,  8 /*5a56*/,  9 /*5a57*/,  7 /*5a58*/,  8 /*5a59*/,
    8 /*5a5a*/,  9 /*5a5b*/,  8 /*5a5c*/,  9 /*5a5d*/,  9 /*5a5e*/,
    10 /*5a5f*/, 6 /*5a60*/,  7 /*5a61*/,  7 /*5a62*/,  8 /*5a63*/,
    7 /*5a64*/,  8 /*5a65*/,  8 /*5a66*/,  9 /*5a67*/,  7 /*5a68*/,
    8 /*5a69*/,  8 /*5a6a*/,  9 /*5a6b*/,  8 /*5a6c*/,  9 /*5a6d*/,
    9 /*5a6e*/,  10 /*5a6f*/, 7 /*5a70*/,  8 /*5a71*/,  8 /*5a72*/,
    9 /*5a73*/,  8 /*5a74*/,  9 /*5a75*/,  9 /*5a76*/,  10 /*5a77*/,
    8 /*5a78*/,  9 /*5a79*/,  9 /*5a7a*/,  10 /*5a7b*/, 9 /*5a7c*/,
    10 /*5a7d*/, 10 /*5a7e*/, 11 /*5a7f*/, 5 /*5a80*/,  6 /*5a81*/,
    6 /*5a82*/,  7 /*5a83*/,  6 /*5a84*/,  7 /*5a85*/,  7 /*5a86*/,
    8 /*5a87*/,  6 /*5a88*/,  7 /*5a89*/,  7 /*5a8a*/,  8 /*5a8b*/,
    7 /*5a8c*/,  8 /*5a8d*/,  8 /*5a8e*/,  9 /*5a8f*/,  6 /*5a90*/,
    7 /*5a91*/,  7 /*5a92*/,  8 /*5a93*/,  7 /*5a94*/,  8 /*5a95*/,
    8 /*5a96*/,  9 /*5a97*/,  7 /*5a98*/,  8 /*5a99*/,  8 /*5a9a*/,
    9 /*5a9b*/,  8 /*5a9c*/,  9 /*5a9d*/,  9 /*5a9e*/,  10 /*5a9f*/,
    6 /*5aa0*/,  7 /*5aa1*/,  7 /*5aa2*/,  8 /*5aa3*/,  7 /*5aa4*/,
    8 /*5aa5*/,  8 /*5aa6*/,  9 /*5aa7*/,  7 /*5aa8*/,  8 /*5aa9*/,
    8 /*5aaa*/,  9 /*5aab*/,  8 /*5aac*/,  9 /*5aad*/,  9 /*5aae*/,
    10 /*5aaf*/, 7 /*5ab0*/,  8 /*5ab1*/,  8 /*5ab2*/,  9 /*5ab3*/,
    8 /*5ab4*/,  9 /*5ab5*/,  9 /*5ab6*/,  10 /*5ab7*/, 8 /*5ab8*/,
    9 /*5ab9*/,  9 /*5aba*/,  10 /*5abb*/, 9 /*5abc*/,  10 /*5abd*/,
    10 /*5abe*/, 11 /*5abf*/, 6 /*5ac0*/,  7 /*5ac1*/,  7 /*5ac2*/,
    8 /*5ac3*/,  7 /*5ac4*/,  8 /*5ac5*/,  8 /*5ac6*/,  9 /*5ac7*/,
    7 /*5ac8*/,  8 /*5ac9*/,  8 /*5aca*/,  9 /*5acb*/,  8 /*5acc*/,
    9 /*5acd*/,  9 /*5ace*/,  10 /*5acf*/, 7 /*5ad0*/,  8 /*5ad1*/,
    8 /*5ad2*/,  9 /*5ad3*/,  8 /*5ad4*/,  9 /*5ad5*/,  9 /*5ad6*/,
    10 /*5ad7*/, 8 /*5ad8*/,  9 /*5ad9*/,  9 /*5ada*/,  10 /*5adb*/,
    9 /*5adc*/,  10 /*5add*/, 10 /*5ade*/, 11 /*5adf*/, 7 /*5ae0*/,
    8 /*5ae1*/,  8 /*5ae2*/,  9 /*5ae3*/,  8 /*5ae4*/,  9 /*5ae5*/,
    9 /*5ae6*/,  10 /*5ae7*/, 8 /*5ae8*/,  9 /*5ae9*/,  9 /*5aea*/,
    10 /*5aeb*/, 9 /*5aec*/,  10 /*5aed*/, 10 /*5aee*/, 11 /*5aef*/,
    8 /*5af0*/,  9 /*5af1*/,  9 /*5af2*/,  10 /*5af3*/, 9 /*5af4*/,
    10 /*5af5*/, 10 /*5af6*/, 11 /*5af7*/, 9 /*5af8*/,  10 /*5af9*/,
    10 /*5afa*/, 11 /*5afb*/, 10 /*5afc*/, 11 /*5afd*/, 11 /*5afe*/,
    12 /*5aff*/, 5 /*5b00*/,  6 /*5b01*/,  6 /*5b02*/,  7 /*5b03*/,
    6 /*5b04*/,  7 /*5b05*/,  7 /*5b06*/,  8 /*5b07*/,  6 /*5b08*/,
    7 /*5b09*/,  7 /*5b0a*/,  8 /*5b0b*/,  7 /*5b0c*/,  8 /*5b0d*/,
    8 /*5b0e*/,  9 /*5b0f*/,  6 /*5b10*/,  7 /*5b11*/,  7 /*5b12*/,
    8 /*5b13*/,  7 /*5b14*/,  8 /*5b15*/,  8 /*5b16*/,  9 /*5b17*/,
    7 /*5b18*/,  8 /*5b19*/,  8 /*5b1a*/,  9 /*5b1b*/,  8 /*5b1c*/,
    9 /*5b1d*/,  9 /*5b1e*/,  10 /*5b1f*/, 6 /*5b20*/,  7 /*5b21*/,
    7 /*5b22*/,  8 /*5b23*/,  7 /*5b24*/,  8 /*5b25*/,  8 /*5b26*/,
    9 /*5b27*/,  7 /*5b28*/,  8 /*5b29*/,  8 /*5b2a*/,  9 /*5b2b*/,
    8 /*5b2c*/,  9 /*5b2d*/,  9 /*5b2e*/,  10 /*5b2f*/, 7 /*5b30*/,
    8 /*5b31*/,  8 /*5b32*/,  9 /*5b33*/,  8 /*5b34*/,  9 /*5b35*/,
    9 /*5b36*/,  10 /*5b37*/, 8 /*5b38*/,  9 /*5b39*/,  9 /*5b3a*/,
    10 /*5b3b*/, 9 /*5b3c*/,  10 /*5b3d*/, 10 /*5b3e*/, 11 /*5b3f*/,
    6 /*5b40*/,  7 /*5b41*/,  7 /*5b42*/,  8 /*5b43*/,  7 /*5b44*/,
    8 /*5b45*/,  8 /*5b46*/,  9 /*5b47*/,  7 /*5b48*/,  8 /*5b49*/,
    8 /*5b4a*/,  9 /*5b4b*/,  8 /*5b4c*/,  9 /*5b4d*/,  9 /*5b4e*/,
    10 /*5b4f*/, 7 /*5b50*/,  8 /*5b51*/,  8 /*5b52*/,  9 /*5b53*/,
    8 /*5b54*/,  9 /*5b55*/,  9 /*5b56*/,  10 /*5b57*/, 8 /*5b58*/,
    9 /*5b59*/,  9 /*5b5a*/,  10 /*5b5b*/, 9 /*5b5c*/,  10 /*5b5d*/,
    10 /*5b5e*/, 11 /*5b5f*/, 7 /*5b60*/,  8 /*5b61*/,  8 /*5b62*/,
    9 /*5b63*/,  8 /*5b64*/,  9 /*5b65*/,  9 /*5b66*/,  10 /*5b67*/,
    8 /*5b68*/,  9 /*5b69*/,  9 /*5b6a*/,  10 /*5b6b*/, 9 /*5b6c*/,
    10 /*5b6d*/, 10 /*5b6e*/, 11 /*5b6f*/, 8 /*5b70*/,  9 /*5b71*/,
    9 /*5b72*/,  10 /*5b73*/, 9 /*5b74*/,  10 /*5b75*/, 10 /*5b76*/,
    11 /*5b77*/, 9 /*5b78*/,  10 /*5b79*/, 10 /*5b7a*/, 11 /*5b7b*/,
    10 /*5b7c*/, 11 /*5b7d*/, 11 /*5b7e*/, 12 /*5b7f*/, 6 /*5b80*/,
    7 /*5b81*/,  7 /*5b82*/,  8 /*5b83*/,  7 /*5b84*/,  8 /*5b85*/,
    8 /*5b86*/,  9 /*5b87*/,  7 /*5b88*/,  8 /*5b89*/,  8 /*5b8a*/,
    9 /*5b8b*/,  8 /*5b8c*/,  9 /*5b8d*/,  9 /*5b8e*/,  10 /*5b8f*/,
    7 /*5b90*/,  8 /*5b91*/,  8 /*5b92*/,  9 /*5b93*/,  8 /*5b94*/,
    9 /*5b95*/,  9 /*5b96*/,  10 /*5b97*/, 8 /*5b98*/,  9 /*5b99*/,
    9 /*5b9a*/,  10 /*5b9b*/, 9 /*5b9c*/,  10 /*5b9d*/, 10 /*5b9e*/,
    11 /*5b9f*/, 7 /*5ba0*/,  8 /*5ba1*/,  8 /*5ba2*/,  9 /*5ba3*/,
    8 /*5ba4*/,  9 /*5ba5*/,  9 /*5ba6*/,  10 /*5ba7*/, 8 /*5ba8*/,
    9 /*5ba9*/,  9 /*5baa*/,  10 /*5bab*/, 9 /*5bac*/,  10 /*5bad*/,
    10 /*5bae*/, 11 /*5baf*/, 8 /*5bb0*/,  9 /*5bb1*/,  9 /*5bb2*/,
    10 /*5bb3*/, 9 /*5bb4*/,  10 /*5bb5*/, 10 /*5bb6*/, 11 /*5bb7*/,
    9 /*5bb8*/,  10 /*5bb9*/, 10 /*5bba*/, 11 /*5bbb*/, 10 /*5bbc*/,
    11 /*5bbd*/, 11 /*5bbe*/, 12 /*5bbf*/, 7 /*5bc0*/,  8 /*5bc1*/,
    8 /*5bc2*/,  9 /*5bc3*/,  8 /*5bc4*/,  9 /*5bc5*/,  9 /*5bc6*/,
    10 /*5bc7*/, 8 /*5bc8*/,  9 /*5bc9*/,  9 /*5bca*/,  10 /*5bcb*/,
    9 /*5bcc*/,  10 /*5bcd*/, 10 /*5bce*/, 11 /*5bcf*/, 8 /*5bd0*/,
    9 /*5bd1*/,  9 /*5bd2*/,  10 /*5bd3*/, 9 /*5bd4*/,  10 /*5bd5*/,
    10 /*5bd6*/, 11 /*5bd7*/, 9 /*5bd8*/,  10 /*5bd9*/, 10 /*5bda*/,
    11 /*5bdb*/, 10 /*5bdc*/, 11 /*5bdd*/, 11 /*5bde*/, 12 /*5bdf*/,
    8 /*5be0*/,  9 /*5be1*/,  9 /*5be2*/,  10 /*5be3*/, 9 /*5be4*/,
    10 /*5be5*/, 10 /*5be6*/, 11 /*5be7*/, 9 /*5be8*/,  10 /*5be9*/,
    10 /*5bea*/, 11 /*5beb*/, 10 /*5bec*/, 11 /*5bed*/, 11 /*5bee*/,
    12 /*5bef*/, 9 /*5bf0*/,  10 /*5bf1*/, 10 /*5bf2*/, 11 /*5bf3*/,
    10 /*5bf4*/, 11 /*5bf5*/, 11 /*5bf6*/, 12 /*5bf7*/, 10 /*5bf8*/,
    11 /*5bf9*/, 11 /*5bfa*/, 12 /*5bfb*/, 11 /*5bfc*/, 12 /*5bfd*/,
    12 /*5bfe*/, 13 /*5bff*/, 4 /*5c00*/,  5 /*5c01*/,  5 /*5c02*/,
    6 /*5c03*/,  5 /*5c04*/,  6 /*5c05*/,  6 /*5c06*/,  7 /*5c07*/,
    5 /*5c08*/,  6 /*5c09*/,  6 /*5c0a*/,  7 /*5c0b*/,  6 /*5c0c*/,
    7 /*5c0d*/,  7 /*5c0e*/,  8 /*5c0f*/,  5 /*5c10*/,  6 /*5c11*/,
    6 /*5c12*/,  7 /*5c13*/,  6 /*5c14*/,  7 /*5c15*/,  7 /*5c16*/,
    8 /*5c17*/,  6 /*5c18*/,  7 /*5c19*/,  7 /*5c1a*/,  8 /*5c1b*/,
    7 /*5c1c*/,  8 /*5c1d*/,  8 /*5c1e*/,  9 /*5c1f*/,  5 /*5c20*/,
    6 /*5c21*/,  6 /*5c22*/,  7 /*5c23*/,  6 /*5c24*/,  7 /*5c25*/,
    7 /*5c26*/,  8 /*5c27*/,  6 /*5c28*/,  7 /*5c29*/,  7 /*5c2a*/,
    8 /*5c2b*/,  7 /*5c2c*/,  8 /*5c2d*/,  8 /*5c2e*/,  9 /*5c2f*/,
    6 /*5c30*/,  7 /*5c31*/,  7 /*5c32*/,  8 /*5c33*/,  7 /*5c34*/,
    8 /*5c35*/,  8 /*5c36*/,  9 /*5c37*/,  7 /*5c38*/,  8 /*5c39*/,
    8 /*5c3a*/,  9 /*5c3b*/,  8 /*5c3c*/,  9 /*5c3d*/,  9 /*5c3e*/,
    10 /*5c3f*/, 5 /*5c40*/,  6 /*5c41*/,  6 /*5c42*/,  7 /*5c43*/,
    6 /*5c44*/,  7 /*5c45*/,  7 /*5c46*/,  8 /*5c47*/,  6 /*5c48*/,
    7 /*5c49*/,  7 /*5c4a*/,  8 /*5c4b*/,  7 /*5c4c*/,  8 /*5c4d*/,
    8 /*5c4e*/,  9 /*5c4f*/,  6 /*5c50*/,  7 /*5c51*/,  7 /*5c52*/,
    8 /*5c53*/,  7 /*5c54*/,  8 /*5c55*/,  8 /*5c56*/,  9 /*5c57*/,
    7 /*5c58*/,  8 /*5c59*/,  8 /*5c5a*/,  9 /*5c5b*/,  8 /*5c5c*/,
    9 /*5c5d*/,  9 /*5c5e*/,  10 /*5c5f*/, 6 /*5c60*/,  7 /*5c61*/,
    7 /*5c62*/,  8 /*5c63*/,  7 /*5c64*/,  8 /*5c65*/,  8 /*5c66*/,
    9 /*5c67*/,  7 /*5c68*/,  8 /*5c69*/,  8 /*5c6a*/,  9 /*5c6b*/,
    8 /*5c6c*/,  9 /*5c6d*/,  9 /*5c6e*/,  10 /*5c6f*/, 7 /*5c70*/,
    8 /*5c71*/,  8 /*5c72*/,  9 /*5c73*/,  8 /*5c74*/,  9 /*5c75*/,
    9 /*5c76*/,  10 /*5c77*/, 8 /*5c78*/,  9 /*5c79*/,  9 /*5c7a*/,
    10 /*5c7b*/, 9 /*5c7c*/,  10 /*5c7d*/, 10 /*5c7e*/, 11 /*5c7f*/,
    5 /*5c80*/,  6 /*5c81*/,  6 /*5c82*/,  7 /*5c83*/,  6 /*5c84*/,
    7 /*5c85*/,  7 /*5c86*/,  8 /*5c87*/,  6 /*5c88*/,  7 /*5c89*/,
    7 /*5c8a*/,  8 /*5c8b*/,  7 /*5c8c*/,  8 /*5c8d*/,  8 /*5c8e*/,
    9 /*5c8f*/,  6 /*5c90*/,  7 /*5c91*/,  7 /*5c92*/,  8 /*5c93*/,
    7 /*5c94*/,  8 /*5c95*/,  8 /*5c96*/,  9 /*5c97*/,  7 /*5c98*/,
    8 /*5c99*/,  8 /*5c9a*/,  9 /*5c9b*/,  8 /*5c9c*/,  9 /*5c9d*/,
    9 /*5c9e*/,  10 /*5c9f*/, 6 /*5ca0*/,  7 /*5ca1*/,  7 /*5ca2*/,
    8 /*5ca3*/,  7 /*5ca4*/,  8 /*5ca5*/,  8 /*5ca6*/,  9 /*5ca7*/,
    7 /*5ca8*/,  8 /*5ca9*/,  8 /*5caa*/,  9 /*5cab*/,  8 /*5cac*/,
    9 /*5cad*/,  9 /*5cae*/,  10 /*5caf*/, 7 /*5cb0*/,  8 /*5cb1*/,
    8 /*5cb2*/,  9 /*5cb3*/,  8 /*5cb4*/,  9 /*5cb5*/,  9 /*5cb6*/,
    10 /*5cb7*/, 8 /*5cb8*/,  9 /*5cb9*/,  9 /*5cba*/,  10 /*5cbb*/,
    9 /*5cbc*/,  10 /*5cbd*/, 10 /*5cbe*/, 11 /*5cbf*/, 6 /*5cc0*/,
    7 /*5cc1*/,  7 /*5cc2*/,  8 /*5cc3*/,  7 /*5cc4*/,  8 /*5cc5*/,
    8 /*5cc6*/,  9 /*5cc7*/,  7 /*5cc8*/,  8 /*5cc9*/,  8 /*5cca*/,
    9 /*5ccb*/,  8 /*5ccc*/,  9 /*5ccd*/,  9 /*5cce*/,  10 /*5ccf*/,
    7 /*5cd0*/,  8 /*5cd1*/,  8 /*5cd2*/,  9 /*5cd3*/,  8 /*5cd4*/,
    9 /*5cd5*/,  9 /*5cd6*/,  10 /*5cd7*/, 8 /*5cd8*/,  9 /*5cd9*/,
    9 /*5cda*/,  10 /*5cdb*/, 9 /*5cdc*/,  10 /*5cdd*/, 10 /*5cde*/,
    11 /*5cdf*/, 7 /*5ce0*/,  8 /*5ce1*/,  8 /*5ce2*/,  9 /*5ce3*/,
    8 /*5ce4*/,  9 /*5ce5*/,  9 /*5ce6*/,  10 /*5ce7*/, 8 /*5ce8*/,
    9 /*5ce9*/,  9 /*5cea*/,  10 /*5ceb*/, 9 /*5cec*/,  10 /*5ced*/,
    10 /*5cee*/, 11 /*5cef*/, 8 /*5cf0*/,  9 /*5cf1*/,  9 /*5cf2*/,
    10 /*5cf3*/, 9 /*5cf4*/,  10 /*5cf5*/, 10 /*5cf6*/, 11 /*5cf7*/,
    9 /*5cf8*/,  10 /*5cf9*/, 10 /*5cfa*/, 11 /*5cfb*/, 10 /*5cfc*/,
    11 /*5cfd*/, 11 /*5cfe*/, 12 /*5cff*/, 5 /*5d00*/,  6 /*5d01*/,
    6 /*5d02*/,  7 /*5d03*/,  6 /*5d04*/,  7 /*5d05*/,  7 /*5d06*/,
    8 /*5d07*/,  6 /*5d08*/,  7 /*5d09*/,  7 /*5d0a*/,  8 /*5d0b*/,
    7 /*5d0c*/,  8 /*5d0d*/,  8 /*5d0e*/,  9 /*5d0f*/,  6 /*5d10*/,
    7 /*5d11*/,  7 /*5d12*/,  8 /*5d13*/,  7 /*5d14*/,  8 /*5d15*/,
    8 /*5d16*/,  9 /*5d17*/,  7 /*5d18*/,  8 /*5d19*/,  8 /*5d1a*/,
    9 /*5d1b*/,  8 /*5d1c*/,  9 /*5d1d*/,  9 /*5d1e*/,  10 /*5d1f*/,
    6 /*5d20*/,  7 /*5d21*/,  7 /*5d22*/,  8 /*5d23*/,  7 /*5d24*/,
    8 /*5d25*/,  8 /*5d26*/,  9 /*5d27*/,  7 /*5d28*/,  8 /*5d29*/,
    8 /*5d2a*/,  9 /*5d2b*/,  8 /*5d2c*/,  9 /*5d2d*/,  9 /*5d2e*/,
    10 /*5d2f*/, 7 /*5d30*/,  8 /*5d31*/,  8 /*5d32*/,  9 /*5d33*/,
    8 /*5d34*/,  9 /*5d35*/,  9 /*5d36*/,  10 /*5d37*/, 8 /*5d38*/,
    9 /*5d39*/,  9 /*5d3a*/,  10 /*5d3b*/, 9 /*5d3c*/,  10 /*5d3d*/,
    10 /*5d3e*/, 11 /*5d3f*/, 6 /*5d40*/,  7 /*5d41*/,  7 /*5d42*/,
    8 /*5d43*/,  7 /*5d44*/,  8 /*5d45*/,  8 /*5d46*/,  9 /*5d47*/,
    7 /*5d48*/,  8 /*5d49*/,  8 /*5d4a*/,  9 /*5d4b*/,  8 /*5d4c*/,
    9 /*5d4d*/,  9 /*5d4e*/,  10 /*5d4f*/, 7 /*5d50*/,  8 /*5d51*/,
    8 /*5d52*/,  9 /*5d53*/,  8 /*5d54*/,  9 /*5d55*/,  9 /*5d56*/,
    10 /*5d57*/, 8 /*5d58*/,  9 /*5d59*/,  9 /*5d5a*/,  10 /*5d5b*/,
    9 /*5d5c*/,  10 /*5d5d*/, 10 /*5d5e*/, 11 /*5d5f*/, 7 /*5d60*/,
    8 /*5d61*/,  8 /*5d62*/,  9 /*5d63*/,  8 /*5d64*/,  9 /*5d65*/,
    9 /*5d66*/,  10 /*5d67*/, 8 /*5d68*/,  9 /*5d69*/,  9 /*5d6a*/,
    10 /*5d6b*/, 9 /*5d6c*/,  10 /*5d6d*/, 10 /*5d6e*/, 11 /*5d6f*/,
    8 /*5d70*/,  9 /*5d71*/,  9 /*5d72*/,  10 /*5d73*/, 9 /*5d74*/,
    10 /*5d75*/, 10 /*5d76*/, 11 /*5d77*/, 9 /*5d78*/,  10 /*5d79*/,
    10 /*5d7a*/, 11 /*5d7b*/, 10 /*5d7c*/, 11 /*5d7d*/, 11 /*5d7e*/,
    12 /*5d7f*/, 6 /*5d80*/,  7 /*5d81*/,  7 /*5d82*/,  8 /*5d83*/,
    7 /*5d84*/,  8 /*5d85*/,  8 /*5d86*/,  9 /*5d87*/,  7 /*5d88*/,
    8 /*5d89*/,  8 /*5d8a*/,  9 /*5d8b*/,  8 /*5d8c*/,  9 /*5d8d*/,
    9 /*5d8e*/,  10 /*5d8f*/, 7 /*5d90*/,  8 /*5d91*/,  8 /*5d92*/,
    9 /*5d93*/,  8 /*5d94*/,  9 /*5d95*/,  9 /*5d96*/,  10 /*5d97*/,
    8 /*5d98*/,  9 /*5d99*/,  9 /*5d9a*/,  10 /*5d9b*/, 9 /*5d9c*/,
    10 /*5d9d*/, 10 /*5d9e*/, 11 /*5d9f*/, 7 /*5da0*/,  8 /*5da1*/,
    8 /*5da2*/,  9 /*5da3*/,  8 /*5da4*/,  9 /*5da5*/,  9 /*5da6*/,
    10 /*5da7*/, 8 /*5da8*/,  9 /*5da9*/,  9 /*5daa*/,  10 /*5dab*/,
    9 /*5dac*/,  10 /*5dad*/, 10 /*5dae*/, 11 /*5daf*/, 8 /*5db0*/,
    9 /*5db1*/,  9 /*5db2*/,  10 /*5db3*/, 9 /*5db4*/,  10 /*5db5*/,
    10 /*5db6*/, 11 /*5db7*/, 9 /*5db8*/,  10 /*5db9*/, 10 /*5dba*/,
    11 /*5dbb*/, 10 /*5dbc*/, 11 /*5dbd*/, 11 /*5dbe*/, 12 /*5dbf*/,
    7 /*5dc0*/,  8 /*5dc1*/,  8 /*5dc2*/,  9 /*5dc3*/,  8 /*5dc4*/,
    9 /*5dc5*/,  9 /*5dc6*/,  10 /*5dc7*/, 8 /*5dc8*/,  9 /*5dc9*/,
    9 /*5dca*/,  10 /*5dcb*/, 9 /*5dcc*/,  10 /*5dcd*/, 10 /*5dce*/,
    11 /*5dcf*/, 8 /*5dd0*/,  9 /*5dd1*/,  9 /*5dd2*/,  10 /*5dd3*/,
    9 /*5dd4*/,  10 /*5dd5*/, 10 /*5dd6*/, 11 /*5dd7*/, 9 /*5dd8*/,
    10 /*5dd9*/, 10 /*5dda*/, 11 /*5ddb*/, 10 /*5ddc*/, 11 /*5ddd*/,
    11 /*5dde*/, 12 /*5ddf*/, 8 /*5de0*/,  9 /*5de1*/,  9 /*5de2*/,
    10 /*5de3*/, 9 /*5de4*/,  10 /*5de5*/, 10 /*5de6*/, 11 /*5de7*/,
    9 /*5de8*/,  10 /*5de9*/, 10 /*5dea*/, 11 /*5deb*/, 10 /*5dec*/,
    11 /*5ded*/, 11 /*5dee*/, 12 /*5def*/, 9 /*5df0*/,  10 /*5df1*/,
    10 /*5df2*/, 11 /*5df3*/, 10 /*5df4*/, 11 /*5df5*/, 11 /*5df6*/,
    12 /*5df7*/, 10 /*5df8*/, 11 /*5df9*/, 11 /*5dfa*/, 12 /*5dfb*/,
    11 /*5dfc*/, 12 /*5dfd*/, 12 /*5dfe*/, 13 /*5dff*/, 5 /*5e00*/,
    6 /*5e01*/,  6 /*5e02*/,  7 /*5e03*/,  6 /*5e04*/,  7 /*5e05*/,
    7 /*5e06*/,  8 /*5e07*/,  6 /*5e08*/,  7 /*5e09*/,  7 /*5e0a*/,
    8 /*5e0b*/,  7 /*5e0c*/,  8 /*5e0d*/,  8 /*5e0e*/,  9 /*5e0f*/,
    6 /*5e10*/,  7 /*5e11*/,  7 /*5e12*/,  8 /*5e13*/,  7 /*5e14*/,
    8 /*5e15*/,  8 /*5e16*/,  9 /*5e17*/,  7 /*5e18*/,  8 /*5e19*/,
    8 /*5e1a*/,  9 /*5e1b*/,  8 /*5e1c*/,  9 /*5e1d*/,  9 /*5e1e*/,
    10 /*5e1f*/, 6 /*5e20*/,  7 /*5e21*/,  7 /*5e22*/,  8 /*5e23*/,
    7 /*5e24*/,  8 /*5e25*/,  8 /*5e26*/,  9 /*5e27*/,  7 /*5e28*/,
    8 /*5e29*/,  8 /*5e2a*/,  9 /*5e2b*/,  8 /*5e2c*/,  9 /*5e2d*/,
    9 /*5e2e*/,  10 /*5e2f*/, 7 /*5e30*/,  8 /*5e31*/,  8 /*5e32*/,
    9 /*5e33*/,  8 /*5e34*/,  9 /*5e35*/,  9 /*5e36*/,  10 /*5e37*/,
    8 /*5e38*/,  9 /*5e39*/,  9 /*5e3a*/,  10 /*5e3b*/, 9 /*5e3c*/,
    10 /*5e3d*/, 10 /*5e3e*/, 11 /*5e3f*/, 6 /*5e40*/,  7 /*5e41*/,
    7 /*5e42*/,  8 /*5e43*/,  7 /*5e44*/,  8 /*5e45*/,  8 /*5e46*/,
    9 /*5e47*/,  7 /*5e48*/,  8 /*5e49*/,  8 /*5e4a*/,  9 /*5e4b*/,
    8 /*5e4c*/,  9 /*5e4d*/,  9 /*5e4e*/,  10 /*5e4f*/, 7 /*5e50*/,
    8 /*5e51*/,  8 /*5e52*/,  9 /*5e53*/,  8 /*5e54*/,  9 /*5e55*/,
    9 /*5e56*/,  10 /*5e57*/, 8 /*5e58*/,  9 /*5e59*/,  9 /*5e5a*/,
    10 /*5e5b*/, 9 /*5e5c*/,  10 /*5e5d*/, 10 /*5e5e*/, 11 /*5e5f*/,
    7 /*5e60*/,  8 /*5e61*/,  8 /*5e62*/,  9 /*5e63*/,  8 /*5e64*/,
    9 /*5e65*/,  9 /*5e66*/,  10 /*5e67*/, 8 /*5e68*/,  9 /*5e69*/,
    9 /*5e6a*/,  10 /*5e6b*/, 9 /*5e6c*/,  10 /*5e6d*/, 10 /*5e6e*/,
    11 /*5e6f*/, 8 /*5e70*/,  9 /*5e71*/,  9 /*5e72*/,  10 /*5e73*/,
    9 /*5e74*/,  10 /*5e75*/, 10 /*5e76*/, 11 /*5e77*/, 9 /*5e78*/,
    10 /*5e79*/, 10 /*5e7a*/, 11 /*5e7b*/, 10 /*5e7c*/, 11 /*5e7d*/,
    11 /*5e7e*/, 12 /*5e7f*/, 6 /*5e80*/,  7 /*5e81*/,  7 /*5e82*/,
    8 /*5e83*/,  7 /*5e84*/,  8 /*5e85*/,  8 /*5e86*/,  9 /*5e87*/,
    7 /*5e88*/,  8 /*5e89*/,  8 /*5e8a*/,  9 /*5e8b*/,  8 /*5e8c*/,
    9 /*5e8d*/,  9 /*5e8e*/,  10 /*5e8f*/, 7 /*5e90*/,  8 /*5e91*/,
    8 /*5e92*/,  9 /*5e93*/,  8 /*5e94*/,  9 /*5e95*/,  9 /*5e96*/,
    10 /*5e97*/, 8 /*5e98*/,  9 /*5e99*/,  9 /*5e9a*/,  10 /*5e9b*/,
    9 /*5e9c*/,  10 /*5e9d*/, 10 /*5e9e*/, 11 /*5e9f*/, 7 /*5ea0*/,
    8 /*5ea1*/,  8 /*5ea2*/,  9 /*5ea3*/,  8 /*5ea4*/,  9 /*5ea5*/,
    9 /*5ea6*/,  10 /*5ea7*/, 8 /*5ea8*/,  9 /*5ea9*/,  9 /*5eaa*/,
    10 /*5eab*/, 9 /*5eac*/,  10 /*5ead*/, 10 /*5eae*/, 11 /*5eaf*/,
    8 /*5eb0*/,  9 /*5eb1*/,  9 /*5eb2*/,  10 /*5eb3*/, 9 /*5eb4*/,
    10 /*5eb5*/, 10 /*5eb6*/, 11 /*5eb7*/, 9 /*5eb8*/,  10 /*5eb9*/,
    10 /*5eba*/, 11 /*5ebb*/, 10 /*5ebc*/, 11 /*5ebd*/, 11 /*5ebe*/,
    12 /*5ebf*/, 7 /*5ec0*/,  8 /*5ec1*/,  8 /*5ec2*/,  9 /*5ec3*/,
    8 /*5ec4*/,  9 /*5ec5*/,  9 /*5ec6*/,  10 /*5ec7*/, 8 /*5ec8*/,
    9 /*5ec9*/,  9 /*5eca*/,  10 /*5ecb*/, 9 /*5ecc*/,  10 /*5ecd*/,
    10 /*5ece*/, 11 /*5ecf*/, 8 /*5ed0*/,  9 /*5ed1*/,  9 /*5ed2*/,
    10 /*5ed3*/, 9 /*5ed4*/,  10 /*5ed5*/, 10 /*5ed6*/, 11 /*5ed7*/,
    9 /*5ed8*/,  10 /*5ed9*/, 10 /*5eda*/, 11 /*5edb*/, 10 /*5edc*/,
    11 /*5edd*/, 11 /*5ede*/, 12 /*5edf*/, 8 /*5ee0*/,  9 /*5ee1*/,
    9 /*5ee2*/,  10 /*5ee3*/, 9 /*5ee4*/,  10 /*5ee5*/, 10 /*5ee6*/,
    11 /*5ee7*/, 9 /*5ee8*/,  10 /*5ee9*/, 10 /*5eea*/, 11 /*5eeb*/,
    10 /*5eec*/, 11 /*5eed*/, 11 /*5eee*/, 12 /*5eef*/, 9 /*5ef0*/,
    10 /*5ef1*/, 10 /*5ef2*/, 11 /*5ef3*/, 10 /*5ef4*/, 11 /*5ef5*/,
    11 /*5ef6*/, 12 /*5ef7*/, 10 /*5ef8*/, 11 /*5ef9*/, 11 /*5efa*/,
    12 /*5efb*/, 11 /*5efc*/, 12 /*5efd*/, 12 /*5efe*/, 13 /*5eff*/,
    6 /*5f00*/,  7 /*5f01*/,  7 /*5f02*/,  8 /*5f03*/,  7 /*5f04*/,
    8 /*5f05*/,  8 /*5f06*/,  9 /*5f07*/,  7 /*5f08*/,  8 /*5f09*/,
    8 /*5f0a*/,  9 /*5f0b*/,  8 /*5f0c*/,  9 /*5f0d*/,  9 /*5f0e*/,
    10 /*5f0f*/, 7 /*5f10*/,  8 /*5f11*/,  8 /*5f12*/,  9 /*5f13*/,
    8 /*5f14*/,  9 /*5f15*/,  9 /*5f16*/,  10 /*5f17*/, 8 /*5f18*/,
    9 /*5f19*/,  9 /*5f1a*/,  10 /*5f1b*/, 9 /*5f1c*/,  10 /*5f1d*/,
    10 /*5f1e*/, 11 /*5f1f*/, 7 /*5f20*/,  8 /*5f21*/,  8 /*5f22*/,
    9 /*5f23*/,  8 /*5f24*/,  9 /*5f25*/,  9 /*5f26*/,  10 /*5f27*/,
    8 /*5f28*/,  9 /*5f29*/,  9 /*5f2a*/,  10 /*5f2b*/, 9 /*5f2c*/,
    10 /*5f2d*/, 10 /*5f2e*/, 11 /*5f2f*/, 8 /*5f30*/,  9 /*5f31*/,
    9 /*5f32*/,  10 /*5f33*/, 9 /*5f34*/,  10 /*5f35*/, 10 /*5f36*/,
    11 /*5f37*/, 9 /*5f38*/,  10 /*5f39*/, 10 /*5f3a*/, 11 /*5f3b*/,
    10 /*5f3c*/, 11 /*5f3d*/, 11 /*5f3e*/, 12 /*5f3f*/, 7 /*5f40*/,
    8 /*5f41*/,  8 /*5f42*/,  9 /*5f43*/,  8 /*5f44*/,  9 /*5f45*/,
    9 /*5f46*/,  10 /*5f47*/, 8 /*5f48*/,  9 /*5f49*/,  9 /*5f4a*/,
    10 /*5f4b*/, 9 /*5f4c*/,  10 /*5f4d*/, 10 /*5f4e*/, 11 /*5f4f*/,
    8 /*5f50*/,  9 /*5f51*/,  9 /*5f52*/,  10 /*5f53*/, 9 /*5f54*/,
    10 /*5f55*/, 10 /*5f56*/, 11 /*5f57*/, 9 /*5f58*/,  10 /*5f59*/,
    10 /*5f5a*/, 11 /*5f5b*/, 10 /*5f5c*/, 11 /*5f5d*/, 11 /*5f5e*/,
    12 /*5f5f*/, 8 /*5f60*/,  9 /*5f61*/,  9 /*5f62*/,  10 /*5f63*/,
    9 /*5f64*/,  10 /*5f65*/, 10 /*5f66*/, 11 /*5f67*/, 9 /*5f68*/,
    10 /*5f69*/, 10 /*5f6a*/, 11 /*5f6b*/, 10 /*5f6c*/, 11 /*5f6d*/,
    11 /*5f6e*/, 12 /*5f6f*/, 9 /*5f70*/,  10 /*5f71*/, 10 /*5f72*/,
    11 /*5f73*/, 10 /*5f74*/, 11 /*5f75*/, 11 /*5f76*/, 12 /*5f77*/,
    10 /*5f78*/, 11 /*5f79*/, 11 /*5f7a*/, 12 /*5f7b*/, 11 /*5f7c*/,
    12 /*5f7d*/, 12 /*5f7e*/, 13 /*5f7f*/, 7 /*5f80*/,  8 /*5f81*/,
    8 /*5f82*/,  9 /*5f83*/,  8 /*5f84*/,  9 /*5f85*/,  9 /*5f86*/,
    10 /*5f87*/, 8 /*5f88*/,  9 /*5f89*/,  9 /*5f8a*/,  10 /*5f8b*/,
    9 /*5f8c*/,  10 /*5f8d*/, 10 /*5f8e*/, 11 /*5f8f*/, 8 /*5f90*/,
    9 /*5f91*/,  9 /*5f92*/,  10 /*5f93*/, 9 /*5f94*/,  10 /*5f95*/,
    10 /*5f96*/, 11 /*5f97*/, 9 /*5f98*/,  10 /*5f99*/, 10 /*5f9a*/,
    11 /*5f9b*/, 10 /*5f9c*/, 11 /*5f9d*/, 11 /*5f9e*/, 12 /*5f9f*/,
    8 /*5fa0*/,  9 /*5fa1*/,  9 /*5fa2*/,  10 /*5fa3*/, 9 /*5fa4*/,
    10 /*5fa5*/, 10 /*5fa6*/, 11 /*5fa7*/, 9 /*5fa8*/,  10 /*5fa9*/,
    10 /*5faa*/, 11 /*5fab*/, 10 /*5fac*/, 11 /*5fad*/, 11 /*5fae*/,
    12 /*5faf*/, 9 /*5fb0*/,  10 /*5fb1*/, 10 /*5fb2*/, 11 /*5fb3*/,
    10 /*5fb4*/, 11 /*5fb5*/, 11 /*5fb6*/, 12 /*5fb7*/, 10 /*5fb8*/,
    11 /*5fb9*/, 11 /*5fba*/, 12 /*5fbb*/, 11 /*5fbc*/, 12 /*5fbd*/,
    12 /*5fbe*/, 13 /*5fbf*/, 8 /*5fc0*/,  9 /*5fc1*/,  9 /*5fc2*/,
    10 /*5fc3*/, 9 /*5fc4*/,  10 /*5fc5*/, 10 /*5fc6*/, 11 /*5fc7*/,
    9 /*5fc8*/,  10 /*5fc9*/, 10 /*5fca*/, 11 /*5fcb*/, 10 /*5fcc*/,
    11 /*5fcd*/, 11 /*5fce*/, 12 /*5fcf*/, 9 /*5fd0*/,  10 /*5fd1*/,
    10 /*5fd2*/, 11 /*5fd3*/, 10 /*5fd4*/, 11 /*5fd5*/, 11 /*5fd6*/,
    12 /*5fd7*/, 10 /*5fd8*/, 11 /*5fd9*/, 11 /*5fda*/, 12 /*5fdb*/,
    11 /*5fdc*/, 12 /*5fdd*/, 12 /*5fde*/, 13 /*5fdf*/, 9 /*5fe0*/,
    10 /*5fe1*/, 10 /*5fe2*/, 11 /*5fe3*/, 10 /*5fe4*/, 11 /*5fe5*/,
    11 /*5fe6*/, 12 /*5fe7*/, 10 /*5fe8*/, 11 /*5fe9*/, 11 /*5fea*/,
    12 /*5feb*/, 11 /*5fec*/, 12 /*5fed*/, 12 /*5fee*/, 13 /*5fef*/,
    10 /*5ff0*/, 11 /*5ff1*/, 11 /*5ff2*/, 12 /*5ff3*/, 11 /*5ff4*/,
    12 /*5ff5*/, 12 /*5ff6*/, 13 /*5ff7*/, 11 /*5ff8*/, 12 /*5ff9*/,
    12 /*5ffa*/, 13 /*5ffb*/, 12 /*5ffc*/, 13 /*5ffd*/, 13 /*5ffe*/,
    14 /*5fff*/, 2 /*6000*/,  3 /*6001*/,  3 /*6002*/,  4 /*6003*/,
    3 /*6004*/,  4 /*6005*/,  4 /*6006*/,  5 /*6007*/,  3 /*6008*/,
    4 /*6009*/,  4 /*600a*/,  5 /*600b*/,  4 /*600c*/,  5 /*600d*/,
    5 /*600e*/,  6 /*600f*/,  3 /*6010*/,  4 /*6011*/,  4 /*6012*/,
    5 /*6013*/,  4 /*6014*/,  5 /*6015*/,  5 /*6016*/,  6 /*6017*/,
    4 /*6018*/,  5 /*6019*/,  5 /*601a*/,  6 /*601b*/,  5 /*601c*/,
    6 /*601d*/,  6 /*601e*/,  7 /*601f*/,  3 /*6020*/,  4 /*6021*/,
    4 /*6022*/,  5 /*6023*/,  4 /*6024*/,  5 /*6025*/,  5 /*6026*/,
    6 /*6027*/,  4 /*6028*/,  5 /*6029*/,  5 /*602a*/,  6 /*602b*/,
    5 /*602c*/,  6 /*602d*/,  6 /*602e*/,  7 /*602f*/,  4 /*6030*/,
    5 /*6031*/,  5 /*6032*/,  6 /*6033*/,  5 /*6034*/,  6 /*6035*/,
    6 /*6036*/,  7 /*6037*/,  5 /*6038*/,  6 /*6039*/,  6 /*603a*/,
    7 /*603b*/,  6 /*603c*/,  7 /*603d*/,  7 /*603e*/,  8 /*603f*/,
    3 /*6040*/,  4 /*6041*/,  4 /*6042*/,  5 /*6043*/,  4 /*6044*/,
    5 /*6045*/,  5 /*6046*/,  6 /*6047*/,  4 /*6048*/,  5 /*6049*/,
    5 /*604a*/,  6 /*604b*/,  5 /*604c*/,  6 /*604d*/,  6 /*604e*/,
    7 /*604f*/,  4 /*6050*/,  5 /*6051*/,  5 /*6052*/,  6 /*6053*/,
    5 /*6054*/,  6 /*6055*/,  6 /*6056*/,  7 /*6057*/,  5 /*6058*/,
    6 /*6059*/,  6 /*605a*/,  7 /*605b*/,  6 /*605c*/,  7 /*605d*/,
    7 /*605e*/,  8 /*605f*/,  4 /*6060*/,  5 /*6061*/,  5 /*6062*/,
    6 /*6063*/,  5 /*6064*/,  6 /*6065*/,  6 /*6066*/,  7 /*6067*/,
    5 /*6068*/,  6 /*6069*/,  6 /*606a*/,  7 /*606b*/,  6 /*606c*/,
    7 /*606d*/,  7 /*606e*/,  8 /*606f*/,  5 /*6070*/,  6 /*6071*/,
    6 /*6072*/,  7 /*6073*/,  6 /*6074*/,  7 /*6075*/,  7 /*6076*/,
    8 /*6077*/,  6 /*6078*/,  7 /*6079*/,  7 /*607a*/,  8 /*607b*/,
    7 /*607c*/,  8 /*607d*/,  8 /*607e*/,  9 /*607f*/,  3 /*6080*/,
    4 /*6081*/,  4 /*6082*/,  5 /*6083*/,  4 /*6084*/,  5 /*6085*/,
    5 /*6086*/,  6 /*6087*/,  4 /*6088*/,  5 /*6089*/,  5 /*608a*/,
    6 /*608b*/,  5 /*608c*/,  6 /*608d*/,  6 /*608e*/,  7 /*608f*/,
    4 /*6090*/,  5 /*6091*/,  5 /*6092*/,  6 /*6093*/,  5 /*6094*/,
    6 /*6095*/,  6 /*6096*/,  7 /*6097*/,  5 /*6098*/,  6 /*6099*/,
    6 /*609a*/,  7 /*609b*/,  6 /*609c*/,  7 /*609d*/,  7 /*609e*/,
    8 /*609f*/,  4 /*60a0*/,  5 /*60a1*/,  5 /*60a2*/,  6 /*60a3*/,
    5 /*60a4*/,  6 /*60a5*/,  6 /*60a6*/,  7 /*60a7*/,  5 /*60a8*/,
    6 /*60a9*/,  6 /*60aa*/,  7 /*60ab*/,  6 /*60ac*/,  7 /*60ad*/,
    7 /*60ae*/,  8 /*60af*/,  5 /*60b0*/,  6 /*60b1*/,  6 /*60b2*/,
    7 /*60b3*/,  6 /*60b4*/,  7 /*60b5*/,  7 /*60b6*/,  8 /*60b7*/,
    6 /*60b8*/,  7 /*60b9*/,  7 /*60ba*/,  8 /*60bb*/,  7 /*60bc*/,
    8 /*60bd*/,  8 /*60be*/,  9 /*60bf*/,  4 /*60c0*/,  5 /*60c1*/,
    5 /*60c2*/,  6 /*60c3*/,  5 /*60c4*/,  6 /*60c5*/,  6 /*60c6*/,
    7 /*60c7*/,  5 /*60c8*/,  6 /*60c9*/,  6 /*60ca*/,  7 /*60cb*/,
    6 /*60cc*/,  7 /*60cd*/,  7 /*60ce*/,  8 /*60cf*/,  5 /*60d0*/,
    6 /*60d1*/,  6 /*60d2*/,  7 /*60d3*/,  6 /*60d4*/,  7 /*60d5*/,
    7 /*60d6*/,  8 /*60d7*/,  6 /*60d8*/,  7 /*60d9*/,  7 /*60da*/,
    8 /*60db*/,  7 /*60dc*/,  8 /*60dd*/,  8 /*60de*/,  9 /*60df*/,
    5 /*60e0*/,  6 /*60e1*/,  6 /*60e2*/,  7 /*60e3*/,  6 /*60e4*/,
    7 /*60e5*/,  7 /*60e6*/,  8 /*60e7*/,  6 /*60e8*/,  7 /*60e9*/,
    7 /*60ea*/,  8 /*60eb*/,  7 /*60ec*/,  8 /*60ed*/,  8 /*60ee*/,
    9 /*60ef*/,  6 /*60f0*/,  7 /*60f1*/,  7 /*60f2*/,  8 /*60f3*/,
    7 /*60f4*/,  8 /*60f5*/,  8 /*60f6*/,  9 /*60f7*/,  7 /*60f8*/,
    8 /*60f9*/,  8 /*60fa*/,  9 /*60fb*/,  8 /*60fc*/,  9 /*60fd*/,
    9 /*60fe*/,  10 /*60ff*/, 3 /*6100*/,  4 /*6101*/,  4 /*6102*/,
    5 /*6103*/,  4 /*6104*/,  5 /*6105*/,  5 /*6106*/,  6 /*6107*/,
    4 /*6108*/,  5 /*6109*/,  5 /*610a*/,  6 /*610b*/,  5 /*610c*/,
    6 /*610d*/,  6 /*610e*/,  7 /*610f*/,  4 /*6110*/,  5 /*6111*/,
    5 /*6112*/,  6 /*6113*/,  5 /*6114*/,  6 /*6115*/,  6 /*6116*/,
    7 /*6117*/,  5 /*6118*/,  6 /*6119*/,  6 /*611a*/,  7 /*611b*/,
    6 /*611c*/,  7 /*611d*/,  7 /*611e*/,  8 /*611f*/,  4 /*6120*/,
    5 /*6121*/,  5 /*6122*/,  6 /*6123*/,  5 /*6124*/,  6 /*6125*/,
    6 /*6126*/,  7 /*6127*/,  5 /*6128*/,  6 /*6129*/,  6 /*612a*/,
    7 /*612b*/,  6 /*612c*/,  7 /*612d*/,  7 /*612e*/,  8 /*612f*/,
    5 /*6130*/,  6 /*6131*/,  6 /*6132*/,  7 /*6133*/,  6 /*6134*/,
    7 /*6135*/,  7 /*6136*/,  8 /*6137*/,  6 /*6138*/,  7 /*6139*/,
    7 /*613a*/,  8 /*613b*/,  7 /*613c*/,  8 /*613d*/,  8 /*613e*/,
    9 /*613f*/,  4 /*6140*/,  5 /*6141*/,  5 /*6142*/,  6 /*6143*/,
    5 /*6144*/,  6 /*6145*/,  6 /*6146*/,  7 /*6147*/,  5 /*6148*/,
    6 /*6149*/,  6 /*614a*/,  7 /*614b*/,  6 /*614c*/,  7 /*614d*/,
    7 /*614e*/,  8 /*614f*/,  5 /*6150*/,  6 /*6151*/,  6 /*6152*/,
    7 /*6153*/,  6 /*6154*/,  7 /*6155*/,  7 /*6156*/,  8 /*6157*/,
    6 /*6158*/,  7 /*6159*/,  7 /*615a*/,  8 /*615b*/,  7 /*615c*/,
    8 /*615d*/,  8 /*615e*/,  9 /*615f*/,  5 /*6160*/,  6 /*6161*/,
    6 /*6162*/,  7 /*6163*/,  6 /*6164*/,  7 /*6165*/,  7 /*6166*/,
    8 /*6167*/,  6 /*6168*/,  7 /*6169*/,  7 /*616a*/,  8 /*616b*/,
    7 /*616c*/,  8 /*616d*/,  8 /*616e*/,  9 /*616f*/,  6 /*6170*/,
    7 /*6171*/,  7 /*6172*/,  8 /*6173*/,  7 /*6174*/,  8 /*6175*/,
    8 /*6176*/,  9 /*6177*/,  7 /*6178*/,  8 /*6179*/,  8 /*617a*/,
    9 /*617b*/,  8 /*617c*/,  9 /*617d*/,  9 /*617e*/,  10 /*617f*/,
    4 /*6180*/,  5 /*6181*/,  5 /*6182*/,  6 /*6183*/,  5 /*6184*/,
    6 /*6185*/,  6 /*6186*/,  7 /*6187*/,  5 /*6188*/,  6 /*6189*/,
    6 /*618a*/,  7 /*618b*/,  6 /*618c*/,  7 /*618d*/,  7 /*618e*/,
    8 /*618f*/,  5 /*6190*/,  6 /*6191*/,  6 /*6192*/,  7 /*6193*/,
    6 /*6194*/,  7 /*6195*/,  7 /*6196*/,  8 /*6197*/,  6 /*6198*/,
    7 /*6199*/,  7 /*619a*/,  8 /*619b*/,  7 /*619c*/,  8 /*619d*/,
    8 /*619e*/,  9 /*619f*/,  5 /*61a0*/,  6 /*61a1*/,  6 /*61a2*/,
    7 /*61a3*/,  6 /*61a4*/,  7 /*61a5*/,  7 /*61a6*/,  8 /*61a7*/,
    6 /*61a8*/,  7 /*61a9*/,  7 /*61aa*/,  8 /*61ab*/,  7 /*61ac*/,
    8 /*61ad*/,  8 /*61ae*/,  9 /*61af*/,  6 /*61b0*/,  7 /*61b1*/,
    7 /*61b2*/,  8 /*61b3*/,  7 /*61b4*/,  8 /*61b5*/,  8 /*61b6*/,
    9 /*61b7*/,  7 /*61b8*/,  8 /*61b9*/,  8 /*61ba*/,  9 /*61bb*/,
    8 /*61bc*/,  9 /*61bd*/,  9 /*61be*/,  10 /*61bf*/, 5 /*61c0*/,
    6 /*61c1*/,  6 /*61c2*/,  7 /*61c3*/,  6 /*61c4*/,  7 /*61c5*/,
    7 /*61c6*/,  8 /*61c7*/,  6 /*61c8*/,  7 /*61c9*/,  7 /*61ca*/,
    8 /*61cb*/,  7 /*61cc*/,  8 /*61cd*/,  8 /*61ce*/,  9 /*61cf*/,
    6 /*61d0*/,  7 /*61d1*/,  7 /*61d2*/,  8 /*61d3*/,  7 /*61d4*/,
    8 /*61d5*/,  8 /*61d6*/,  9 /*61d7*/,  7 /*61d8*/,  8 /*61d9*/,
    8 /*61da*/,  9 /*61db*/,  8 /*61dc*/,  9 /*61dd*/,  9 /*61de*/,
    10 /*61df*/, 6 /*61e0*/,  7 /*61e1*/,  7 /*61e2*/,  8 /*61e3*/,
    7 /*61e4*/,  8 /*61e5*/,  8 /*61e6*/,  9 /*61e7*/,  7 /*61e8*/,
    8 /*61e9*/,  8 /*61ea*/,  9 /*61eb*/,  8 /*61ec*/,  9 /*61ed*/,
    9 /*61ee*/,  10 /*61ef*/, 7 /*61f0*/,  8 /*61f1*/,  8 /*61f2*/,
    9 /*61f3*/,  8 /*61f4*/,  9 /*61f5*/,  9 /*61f6*/,  10 /*61f7*/,
    8 /*61f8*/,  9 /*61f9*/,  9 /*61fa*/,  10 /*61fb*/, 9 /*61fc*/,
    10 /*61fd*/, 10 /*61fe*/, 11 /*61ff*/, 3 /*6200*/,  4 /*6201*/,
    4 /*6202*/,  5 /*6203*/,  4 /*6204*/,  5 /*6205*/,  5 /*6206*/,
    6 /*6207*/,  4 /*6208*/,  5 /*6209*/,  5 /*620a*/,  6 /*620b*/,
    5 /*620c*/,  6 /*620d*/,  6 /*620e*/,  7 /*620f*/,  4 /*6210*/,
    5 /*6211*/,  5 /*6212*/,  6 /*6213*/,  5 /*6214*/,  6 /*6215*/,
    6 /*6216*/,  7 /*6217*/,  5 /*6218*/,  6 /*6219*/,  6 /*621a*/,
    7 /*621b*/,  6 /*621c*/,  7 /*621d*/,  7 /*621e*/,  8 /*621f*/,
    4 /*6220*/,  5 /*6221*/,  5 /*6222*/,  6 /*6223*/,  5 /*6224*/,
    6 /*6225*/,  6 /*6226*/,  7 /*6227*/,  5 /*6228*/,  6 /*6229*/,
    6 /*622a*/,  7 /*622b*/,  6 /*622c*/,  7 /*622d*/,  7 /*622e*/,
    8 /*622f*/,  5 /*6230*/,  6 /*6231*/,  6 /*6232*/,  7 /*6233*/,
    6 /*6234*/,  7 /*6235*/,  7 /*6236*/,  8 /*6237*/,  6 /*6238*/,
    7 /*6239*/,  7 /*623a*/,  8 /*623b*/,  7 /*623c*/,  8 /*623d*/,
    8 /*623e*/,  9 /*623f*/,  4 /*6240*/,  5 /*6241*/,  5 /*6242*/,
    6 /*6243*/,  5 /*6244*/,  6 /*6245*/,  6 /*6246*/,  7 /*6247*/,
    5 /*6248*/,  6 /*6249*/,  6 /*624a*/,  7 /*624b*/,  6 /*624c*/,
    7 /*624d*/,  7 /*624e*/,  8 /*624f*/,  5 /*6250*/,  6 /*6251*/,
    6 /*6252*/,  7 /*6253*/,  6 /*6254*/,  7 /*6255*/,  7 /*6256*/,
    8 /*6257*/,  6 /*6258*/,  7 /*6259*/,  7 /*625a*/,  8 /*625b*/,
    7 /*625c*/,  8 /*625d*/,  8 /*625e*/,  9 /*625f*/,  5 /*6260*/,
    6 /*6261*/,  6 /*6262*/,  7 /*6263*/,  6 /*6264*/,  7 /*6265*/,
    7 /*6266*/,  8 /*6267*/,  6 /*6268*/,  7 /*6269*/,  7 /*626a*/,
    8 /*626b*/,  7 /*626c*/,  8 /*626d*/,  8 /*626e*/,  9 /*626f*/,
    6 /*6270*/,  7 /*6271*/,  7 /*6272*/,  8 /*6273*/,  7 /*6274*/,
    8 /*6275*/,  8 /*6276*/,  9 /*6277*/,  7 /*6278*/,  8 /*6279*/,
    8 /*627a*/,  9 /*627b*/,  8 /*627c*/,  9 /*627d*/,  9 /*627e*/,
    10 /*627f*/, 4 /*6280*/,  5 /*6281*/,  5 /*6282*/,  6 /*6283*/,
    5 /*6284*/,  6 /*6285*/,  6 /*6286*/,  7 /*6287*/,  5 /*6288*/,
    6 /*6289*/,  6 /*628a*/,  7 /*628b*/,  6 /*628c*/,  7 /*628d*/,
    7 /*628e*/,  8 /*628f*/,  5 /*6290*/,  6 /*6291*/,  6 /*6292*/,
    7 /*6293*/,  6 /*6294*/,  7 /*6295*/,  7 /*6296*/,  8 /*6297*/,
    6 /*6298*/,  7 /*6299*/,  7 /*629a*/,  8 /*629b*/,  7 /*629c*/,
    8 /*629d*/,  8 /*629e*/,  9 /*629f*/,  5 /*62a0*/,  6 /*62a1*/,
    6 /*62a2*/,  7 /*62a3*/,  6 /*62a4*/,  7 /*62a5*/,  7 /*62a6*/,
    8 /*62a7*/,  6 /*62a8*/,  7 /*62a9*/,  7 /*62aa*/,  8 /*62ab*/,
    7 /*62ac*/,  8 /*62ad*/,  8 /*62ae*/,  9 /*62af*/,  6 /*62b0*/,
    7 /*62b1*/,  7 /*62b2*/,  8 /*62b3*/,  7 /*62b4*/,  8 /*62b5*/,
    8 /*62b6*/,  9 /*62b7*/,  7 /*62b8*/,  8 /*62b9*/,  8 /*62ba*/,
    9 /*62bb*/,  8 /*62bc*/,  9 /*62bd*/,  9 /*62be*/,  10 /*62bf*/,
    5 /*62c0*/,  6 /*62c1*/,  6 /*62c2*/,  7 /*62c3*/,  6 /*62c4*/,
    7 /*62c5*/,  7 /*62c6*/,  8 /*62c7*/,  6 /*62c8*/,  7 /*62c9*/,
    7 /*62ca*/,  8 /*62cb*/,  7 /*62cc*/,  8 /*62cd*/,  8 /*62ce*/,
    9 /*62cf*/,  6 /*62d0*/,  7 /*62d1*/,  7 /*62d2*/,  8 /*62d3*/,
    7 /*62d4*/,  8 /*62d5*/,  8 /*62d6*/,  9 /*62d7*/,  7 /*62d8*/,
    8 /*62d9*/,  8 /*62da*/,  9 /*62db*/,  8 /*62dc*/,  9 /*62dd*/,
    9 /*62de*/,  10 /*62df*/, 6 /*62e0*/,  7 /*62e1*/,  7 /*62e2*/,
    8 /*62e3*/,  7 /*62e4*/,  8 /*62e5*/,  8 /*62e6*/,  9 /*62e7*/,
    7 /*62e8*/,  8 /*62e9*/,  8 /*62ea*/,  9 /*62eb*/,  8 /*62ec*/,
    9 /*62ed*/,  9 /*62ee*/,  10 /*62ef*/, 7 /*62f0*/,  8 /*62f1*/,
    8 /*62f2*/,  9 /*62f3*/,  8 /*62f4*/,  9 /*62f5*/,  9 /*62f6*/,
    10 /*62f7*/, 8 /*62f8*/,  9 /*62f9*/,  9 /*62fa*/,  10 /*62fb*/,
    9 /*62fc*/,  10 /*62fd*/, 10 /*62fe*/, 11 /*62ff*/, 4 /*6300*/,
    5 /*6301*/,  5 /*6302*/,  6 /*6303*/,  5 /*6304*/,  6 /*6305*/,
    6 /*6306*/,  7 /*6307*/,  5 /*6308*/,  6 /*6309*/,  6 /*630a*/,
    7 /*630b*/,  6 /*630c*/,  7 /*630d*/,  7 /*630e*/,  8 /*630f*/,
    5 /*6310*/,  6 /*6311*/,  6 /*6312*/,  7 /*6313*/,  6 /*6314*/,
    7 /*6315*/,  7 /*6316*/,  8 /*6317*/,  6 /*6318*/,  7 /*6319*/,
    7 /*631a*/,  8 /*631b*/,  7 /*631c*/,  8 /*631d*/,  8 /*631e*/,
    9 /*631f*/,  5 /*6320*/,  6 /*6321*/,  6 /*6322*/,  7 /*6323*/,
    6 /*6324*/,  7 /*6325*/,  7 /*6326*/,  8 /*6327*/,  6 /*6328*/,
    7 /*6329*/,  7 /*632a*/,  8 /*632b*/,  7 /*632c*/,  8 /*632d*/,
    8 /*632e*/,  9 /*632f*/,  6 /*6330*/,  7 /*6331*/,  7 /*6332*/,
    8 /*6333*/,  7 /*6334*/,  8 /*6335*/,  8 /*6336*/,  9 /*6337*/,
    7 /*6338*/,  8 /*6339*/,  8 /*633a*/,  9 /*633b*/,  8 /*633c*/,
    9 /*633d*/,  9 /*633e*/,  10 /*633f*/, 5 /*6340*/,  6 /*6341*/,
    6 /*6342*/,  7 /*6343*/,  6 /*6344*/,  7 /*6345*/,  7 /*6346*/,
    8 /*6347*/,  6 /*6348*/,  7 /*6349*/,  7 /*634a*/,  8 /*634b*/,
    7 /*634c*/,  8 /*634d*/,  8 /*634e*/,  9 /*634f*/,  6 /*6350*/,
    7 /*6351*/,  7 /*6352*/,  8 /*6353*/,  7 /*6354*/,  8 /*6355*/,
    8 /*6356*/,  9 /*6357*/,  7 /*6358*/,  8 /*6359*/,  8 /*635a*/,
    9 /*635b*/,  8 /*635c*/,  9 /*635d*/,  9 /*635e*/,  10 /*635f*/,
    6 /*6360*/,  7 /*6361*/,  7 /*6362*/,  8 /*6363*/,  7 /*6364*/,
    8 /*6365*/,  8 /*6366*/,  9 /*6367*/,  7 /*6368*/,  8 /*6369*/,
    8 /*636a*/,  9 /*636b*/,  8 /*636c*/,  9 /*636d*/,  9 /*636e*/,
    10 /*636f*/, 7 /*6370*/,  8 /*6371*/,  8 /*6372*/,  9 /*6373*/,
    8 /*6374*/,  9 /*6375*/,  9 /*6376*/,  10 /*6377*/, 8 /*6378*/,
    9 /*6379*/,  9 /*637a*/,  10 /*637b*/, 9 /*637c*/,  10 /*637d*/,
    10 /*637e*/, 11 /*637f*/, 5 /*6380*/,  6 /*6381*/,  6 /*6382*/,
    7 /*6383*/,  6 /*6384*/,  7 /*6385*/,  7 /*6386*/,  8 /*6387*/,
    6 /*6388*/,  7 /*6389*/,  7 /*638a*/,  8 /*638b*/,  7 /*638c*/,
    8 /*638d*/,  8 /*638e*/,  9 /*638f*/,  6 /*6390*/,  7 /*6391*/,
    7 /*6392*/,  8 /*6393*/,  7 /*6394*/,  8 /*6395*/,  8 /*6396*/,
    9 /*6397*/,  7 /*6398*/,  8 /*6399*/,  8 /*639a*/,  9 /*639b*/,
    8 /*639c*/,  9 /*639d*/,  9 /*639e*/,  10 /*639f*/, 6 /*63a0*/,
    7 /*63a1*/,  7 /*63a2*/,  8 /*63a3*/,  7 /*63a4*/,  8 /*63a5*/,
    8 /*63a6*/,  9 /*63a7*/,  7 /*63a8*/,  8 /*63a9*/,  8 /*63aa*/,
    9 /*63ab*/,  8 /*63ac*/,  9 /*63ad*/,  9 /*63ae*/,  10 /*63af*/,
    7 /*63b0*/,  8 /*63b1*/,  8 /*63b2*/,  9 /*63b3*/,  8 /*63b4*/,
    9 /*63b5*/,  9 /*63b6*/,  10 /*63b7*/, 8 /*63b8*/,  9 /*63b9*/,
    9 /*63ba*/,  10 /*63bb*/, 9 /*63bc*/,  10 /*63bd*/, 10 /*63be*/,
    11 /*63bf*/, 6 /*63c0*/,  7 /*63c1*/,  7 /*63c2*/,  8 /*63c3*/,
    7 /*63c4*/,  8 /*63c5*/,  8 /*63c6*/,  9 /*63c7*/,  7 /*63c8*/,
    8 /*63c9*/,  8 /*63ca*/,  9 /*63cb*/,  8 /*63cc*/,  9 /*63cd*/,
    9 /*63ce*/,  10 /*63cf*/, 7 /*63d0*/,  8 /*63d1*/,  8 /*63d2*/,
    9 /*63d3*/,  8 /*63d4*/,  9 /*63d5*/,  9 /*63d6*/,  10 /*63d7*/,
    8 /*63d8*/,  9 /*63d9*/,  9 /*63da*/,  10 /*63db*/, 9 /*63dc*/,
    10 /*63dd*/, 10 /*63de*/, 11 /*63df*/, 7 /*63e0*/,  8 /*63e1*/,
    8 /*63e2*/,  9 /*63e3*/,  8 /*63e4*/,  9 /*63e5*/,  9 /*63e6*/,
    10 /*63e7*/, 8 /*63e8*/,  9 /*63e9*/,  9 /*63ea*/,  10 /*63eb*/,
    9 /*63ec*/,  10 /*63ed*/, 10 /*63ee*/, 11 /*63ef*/, 8 /*63f0*/,
    9 /*63f1*/,  9 /*63f2*/,  10 /*63f3*/, 9 /*63f4*/,  10 /*63f5*/,
    10 /*63f6*/, 11 /*63f7*/, 9 /*63f8*/,  10 /*63f9*/, 10 /*63fa*/,
    11 /*63fb*/, 10 /*63fc*/, 11 /*63fd*/, 11 /*63fe*/, 12 /*63ff*/,
    3 /*6400*/,  4 /*6401*/,  4 /*6402*/,  5 /*6403*/,  4 /*6404*/,
    5 /*6405*/,  5 /*6406*/,  6 /*6407*/,  4 /*6408*/,  5 /*6409*/,
    5 /*640a*/,  6 /*640b*/,  5 /*640c*/,  6 /*640d*/,  6 /*640e*/,
    7 /*640f*/,  4 /*6410*/,  5 /*6411*/,  5 /*6412*/,  6 /*6413*/,
    5 /*6414*/,  6 /*6415*/,  6 /*6416*/,  7 /*6417*/,  5 /*6418*/,
    6 /*6419*/,  6 /*641a*/,  7 /*641b*/,  6 /*641c*/,  7 /*641d*/,
    7 /*641e*/,  8 /*641f*/,  4 /*6420*/,  5 /*6421*/,  5 /*6422*/,
    6 /*6423*/,  5 /*6424*/,  6 /*6425*/,  6 /*6426*/,  7 /*6427*/,
    5 /*6428*/,  6 /*6429*/,  6 /*642a*/,  7 /*642b*/,  6 /*642c*/,
    7 /*642d*/,  7 /*642e*/,  8 /*642f*/,  5 /*6430*/,  6 /*6431*/,
    6 /*6432*/,  7 /*6433*/,  6 /*6434*/,  7 /*6435*/,  7 /*6436*/,
    8 /*6437*/,  6 /*6438*/,  7 /*6439*/,  7 /*643a*/,  8 /*643b*/,
    7 /*643c*/,  8 /*643d*/,  8 /*643e*/,  9 /*643f*/,  4 /*6440*/,
    5 /*6441*/,  5 /*6442*/,  6 /*6443*/,  5 /*6444*/,  6 /*6445*/,
    6 /*6446*/,  7 /*6447*/,  5 /*6448*/,  6 /*6449*/,  6 /*644a*/,
    7 /*644b*/,  6 /*644c*/,  7 /*644d*/,  7 /*644e*/,  8 /*644f*/,
    5 /*6450*/,  6 /*6451*/,  6 /*6452*/,  7 /*6453*/,  6 /*6454*/,
    7 /*6455*/,  7 /*6456*/,  8 /*6457*/,  6 /*6458*/,  7 /*6459*/,
    7 /*645a*/,  8 /*645b*/,  7 /*645c*/,  8 /*645d*/,  8 /*645e*/,
    9 /*645f*/,  5 /*6460*/,  6 /*6461*/,  6 /*6462*/,  7 /*6463*/,
    6 /*6464*/,  7 /*6465*/,  7 /*6466*/,  8 /*6467*/,  6 /*6468*/,
    7 /*6469*/,  7 /*646a*/,  8 /*646b*/,  7 /*646c*/,  8 /*646d*/,
    8 /*646e*/,  9 /*646f*/,  6 /*6470*/,  7 /*6471*/,  7 /*6472*/,
    8 /*6473*/,  7 /*6474*/,  8 /*6475*/,  8 /*6476*/,  9 /*6477*/,
    7 /*6478*/,  8 /*6479*/,  8 /*647a*/,  9 /*647b*/,  8 /*647c*/,
    9 /*647d*/,  9 /*647e*/,  10 /*647f*/, 4 /*6480*/,  5 /*6481*/,
    5 /*6482*/,  6 /*6483*/,  5 /*6484*/,  6 /*6485*/,  6 /*6486*/,
    7 /*6487*/,  5 /*6488*/,  6 /*6489*/,  6 /*648a*/,  7 /*648b*/,
    6 /*648c*/,  7 /*648d*/,  7 /*648e*/,  8 /*648f*/,  5 /*6490*/,
    6 /*6491*/,  6 /*6492*/,  7 /*6493*/,  6 /*6494*/,  7 /*6495*/,
    7 /*6496*/,  8 /*6497*/,  6 /*6498*/,  7 /*6499*/,  7 /*649a*/,
    8 /*649b*/,  7 /*649c*/,  8 /*649d*/,  8 /*649e*/,  9 /*649f*/,
    5 /*64a0*/,  6 /*64a1*/,  6 /*64a2*/,  7 /*64a3*/,  6 /*64a4*/,
    7 /*64a5*/,  7 /*64a6*/,  8 /*64a7*/,  6 /*64a8*/,  7 /*64a9*/,
    7 /*64aa*/,  8 /*64ab*/,  7 /*64ac*/,  8 /*64ad*/,  8 /*64ae*/,
    9 /*64af*/,  6 /*64b0*/,  7 /*64b1*/,  7 /*64b2*/,  8 /*64b3*/,
    7 /*64b4*/,  8 /*64b5*/,  8 /*64b6*/,  9 /*64b7*/,  7 /*64b8*/,
    8 /*64b9*/,  8 /*64ba*/,  9 /*64bb*/,  8 /*64bc*/,  9 /*64bd*/,
    9 /*64be*/,  10 /*64bf*/, 5 /*64c0*/,  6 /*64c1*/,  6 /*64c2*/,
    7 /*64c3*/,  6 /*64c4*/,  7 /*64c5*/,  7 /*64c6*/,  8 /*64c7*/,
    6 /*64c8*/,  7 /*64c9*/,  7 /*64ca*/,  8 /*64cb*/,  7 /*64cc*/,
    8 /*64cd*/,  8 /*64ce*/,  9 /*64cf*/,  6 /*64d0*/,  7 /*64d1*/,
    7 /*64d2*/,  8 /*64d3*/,  7 /*64d4*/,  8 /*64d5*/,  8 /*64d6*/,
    9 /*64d7*/,  7 /*64d8*/,  8 /*64d9*/,  8 /*64da*/,  9 /*64db*/,
    8 /*64dc*/,  9 /*64dd*/,  9 /*64de*/,  10 /*64df*/, 6 /*64e0*/,
    7 /*64e1*/,  7 /*64e2*/,  8 /*64e3*/,  7 /*64e4*/,  8 /*64e5*/,
    8 /*64e6*/,  9 /*64e7*/,  7 /*64e8*/,  8 /*64e9*/,  8 /*64ea*/,
    9 /*64eb*/,  8 /*64ec*/,  9 /*64ed*/,  9 /*64ee*/,  10 /*64ef*/,
    7 /*64f0*/,  8 /*64f1*/,  8 /*64f2*/,  9 /*64f3*/,  8 /*64f4*/,
    9 /*64f5*/,  9 /*64f6*/,  10 /*64f7*/, 8 /*64f8*/,  9 /*64f9*/,
    9 /*64fa*/,  10 /*64fb*/, 9 /*64fc*/,  10 /*64fd*/, 10 /*64fe*/,
    11 /*64ff*/, 4 /*6500*/,  5 /*6501*/,  5 /*6502*/,  6 /*6503*/,
    5 /*6504*/,  6 /*6505*/,  6 /*6506*/,  7 /*6507*/,  5 /*6508*/,
    6 /*6509*/,  6 /*650a*/,  7 /*650b*/,  6 /*650c*/,  7 /*650d*/,
    7 /*650e*/,  8 /*650f*/,  5 /*6510*/,  6 /*6511*/,  6 /*6512*/,
    7 /*6513*/,  6 /*6514*/,  7 /*6515*/,  7 /*6516*/,  8 /*6517*/,
    6 /*6518*/,  7 /*6519*/,  7 /*651a*/,  8 /*651b*/,  7 /*651c*/,
    8 /*651d*/,  8 /*651e*/,  9 /*651f*/,  5 /*6520*/,  6 /*6521*/,
    6 /*6522*/,  7 /*6523*/,  6 /*6524*/,  7 /*6525*/,  7 /*6526*/,
    8 /*6527*/,  6 /*6528*/,  7 /*6529*/,  7 /*652a*/,  8 /*652b*/,
    7 /*652c*/,  8 /*652d*/,  8 /*652e*/,  9 /*652f*/,  6 /*6530*/,
    7 /*6531*/,  7 /*6532*/,  8 /*6533*/,  7 /*6534*/,  8 /*6535*/,
    8 /*6536*/,  9 /*6537*/,  7 /*6538*/,  8 /*6539*/,  8 /*653a*/,
    9 /*653b*/,  8 /*653c*/,  9 /*653d*/,  9 /*653e*/,  10 /*653f*/,
    5 /*6540*/,  6 /*6541*/,  6 /*6542*/,  7 /*6543*/,  6 /*6544*/,
    7 /*6545*/,  7 /*6546*/,  8 /*6547*/,  6 /*6548*/,  7 /*6549*/,
    7 /*654a*/,  8 /*654b*/,  7 /*654c*/,  8 /*654d*/,  8 /*654e*/,
    9 /*654f*/,  6 /*6550*/,  7 /*6551*/,  7 /*6552*/,  8 /*6553*/,
    7 /*6554*/,  8 /*6555*/,  8 /*6556*/,  9 /*6557*/,  7 /*6558*/,
    8 /*6559*/,  8 /*655a*/,  9 /*655b*/,  8 /*655c*/,  9 /*655d*/,
    9 /*655e*/,  10 /*655f*/, 6 /*6560*/,  7 /*6561*/,  7 /*6562*/,
    8 /*6563*/,  7 /*6564*/,  8 /*6565*/,  8 /*6566*/,  9 /*6567*/,
    7 /*6568*/,  8 /*6569*/,  8 /*656a*/,  9 /*656b*/,  8 /*656c*/,
    9 /*656d*/,  9 /*656e*/,  10 /*656f*/, 7 /*6570*/,  8 /*6571*/,
    8 /*6572*/,  9 /*6573*/,  8 /*6574*/,  9 /*6575*/,  9 /*6576*/,
    10 /*6577*/, 8 /*6578*/,  9 /*6579*/,  9 /*657a*/,  10 /*657b*/,
    9 /*657c*/,  10 /*657d*/, 10 /*657e*/, 11 /*657f*/, 5 /*6580*/,
    6 /*6581*/,  6 /*6582*/,  7 /*6583*/,  6 /*6584*/,  7 /*6585*/,
    7 /*6586*/,  8 /*6587*/,  6 /*6588*/,  7 /*6589*/,  7 /*658a*/,
    8 /*658b*/,  7 /*658c*/,  8 /*658d*/,  8 /*658e*/,  9 /*658f*/,
    6 /*6590*/,  7 /*6591*/,  7 /*6592*/,  8 /*6593*/,  7 /*6594*/,
    8 /*6595*/,  8 /*6596*/,  9 /*6597*/,  7 /*6598*/,  8 /*6599*/,
    8 /*659a*/,  9 /*659b*/,  8 /*659c*/,  9 /*659d*/,  9 /*659e*/,
    10 /*659f*/, 6 /*65a0*/,  7 /*65a1*/,  7 /*65a2*/,  8 /*65a3*/,
    7 /*65a4*/,  8 /*65a5*/,  8 /*65a6*/,  9 /*65a7*/,  7 /*65a8*/,
    8 /*65a9*/,  8 /*65aa*/,  9 /*65ab*/,  8 /*65ac*/,  9 /*65ad*/,
    9 /*65ae*/,  10 /*65af*/, 7 /*65b0*/,  8 /*65b1*/,  8 /*65b2*/,
    9 /*65b3*/,  8 /*65b4*/,  9 /*65b5*/,  9 /*65b6*/,  10 /*65b7*/,
    8 /*65b8*/,  9 /*65b9*/,  9 /*65ba*/,  10 /*65bb*/, 9 /*65bc*/,
    10 /*65bd*/, 10 /*65be*/, 11 /*65bf*/, 6 /*65c0*/,  7 /*65c1*/,
    7 /*65c2*/,  8 /*65c3*/,  7 /*65c4*/,  8 /*65c5*/,  8 /*65c6*/,
    9 /*65c7*/,  7 /*65c8*/,  8 /*65c9*/,  8 /*65ca*/,  9 /*65cb*/,
    8 /*65cc*/,  9 /*65cd*/,  9 /*65ce*/,  10 /*65cf*/, 7 /*65d0*/,
    8 /*65d1*/,  8 /*65d2*/,  9 /*65d3*/,  8 /*65d4*/,  9 /*65d5*/,
    9 /*65d6*/,  10 /*65d7*/, 8 /*65d8*/,  9 /*65d9*/,  9 /*65da*/,
    10 /*65db*/, 9 /*65dc*/,  10 /*65dd*/, 10 /*65de*/, 11 /*65df*/,
    7 /*65e0*/,  8 /*65e1*/,  8 /*65e2*/,  9 /*65e3*/,  8 /*65e4*/,
    9 /*65e5*/,  9 /*65e6*/,  10 /*65e7*/, 8 /*65e8*/,  9 /*65e9*/,
    9 /*65ea*/,  10 /*65eb*/, 9 /*65ec*/,  10 /*65ed*/, 10 /*65ee*/,
    11 /*65ef*/, 8 /*65f0*/,  9 /*65f1*/,  9 /*65f2*/,  10 /*65f3*/,
    9 /*65f4*/,  10 /*65f5*/, 10 /*65f6*/, 11 /*65f7*/, 9 /*65f8*/,
    10 /*65f9*/, 10 /*65fa*/, 11 /*65fb*/, 10 /*65fc*/, 11 /*65fd*/,
    11 /*65fe*/, 12 /*65ff*/, 4 /*6600*/,  5 /*6601*/,  5 /*6602*/,
    6 /*6603*/,  5 /*6604*/,  6 /*6605*/,  6 /*6606*/,  7 /*6607*/,
    5 /*6608*/,  6 /*6609*/,  6 /*660a*/,  7 /*660b*/,  6 /*660c*/,
    7 /*660d*/,  7 /*660e*/,  8 /*660f*/,  5 /*6610*/,  6 /*6611*/,
    6 /*6612*/,  7 /*6613*/,  6 /*6614*/,  7 /*6615*/,  7 /*6616*/,
    8 /*6617*/,  6 /*6618*/,  7 /*6619*/,  7 /*661a*/,  8 /*661b*/,
    7 /*661c*/,  8 /*661d*/,  8 /*661e*/,  9 /*661f*/,  5 /*6620*/,
    6 /*6621*/,  6 /*6622*/,  7 /*6623*/,  6 /*6624*/,  7 /*6625*/,
    7 /*6626*/,  8 /*6627*/,  6 /*6628*/,  7 /*6629*/,  7 /*662a*/,
    8 /*662b*/,  7 /*662c*/,  8 /*662d*/,  8 /*662e*/,  9 /*662f*/,
    6 /*6630*/,  7 /*6631*/,  7 /*6632*/,  8 /*6633*/,  7 /*6634*/,
    8 /*6635*/,  8 /*6636*/,  9 /*6637*/,  7 /*6638*/,  8 /*6639*/,
    8 /*663a*/,  9 /*663b*/,  8 /*663c*/,  9 /*663d*/,  9 /*663e*/,
    10 /*663f*/, 5 /*6640*/,  6 /*6641*/,  6 /*6642*/,  7 /*6643*/,
    6 /*6644*/,  7 /*6645*/,  7 /*6646*/,  8 /*6647*/,  6 /*6648*/,
    7 /*6649*/,  7 /*664a*/,  8 /*664b*/,  7 /*664c*/,  8 /*664d*/,
    8 /*664e*/,  9 /*664f*/,  6 /*6650*/,  7 /*6651*/,  7 /*6652*/,
    8 /*6653*/,  7 /*6654*/,  8 /*6655*/,  8 /*6656*/,  9 /*6657*/,
    7 /*6658*/,  8 /*6659*/,  8 /*665a*/,  9 /*665b*/,  8 /*665c*/,
    9 /*665d*/,  9 /*665e*/,  10 /*665f*/, 6 /*6660*/,  7 /*6661*/,
    7 /*6662*/,  8 /*6663*/,  7 /*6664*/,  8 /*6665*/,  8 /*6666*/,
    9 /*6667*/,  7 /*6668*/,  8 /*6669*/,  8 /*666a*/,  9 /*666b*/,
    8 /*666c*/,  9 /*666d*/,  9 /*666e*/,  10 /*666f*/, 7 /*6670*/,
    8 /*6671*/,  8 /*6672*/,  9 /*6673*/,  8 /*6674*/,  9 /*6675*/,
    9 /*6676*/,  10 /*6677*/, 8 /*6678*/,  9 /*6679*/,  9 /*667a*/,
    10 /*667b*/, 9 /*667c*/,  10 /*667d*/, 10 /*667e*/, 11 /*667f*/,
    5 /*6680*/,  6 /*6681*/,  6 /*6682*/,  7 /*6683*/,  6 /*6684*/,
    7 /*6685*/,  7 /*6686*/,  8 /*6687*/,  6 /*6688*/,  7 /*6689*/,
    7 /*668a*/,  8 /*668b*/,  7 /*668c*/,  8 /*668d*/,  8 /*668e*/,
    9 /*668f*/,  6 /*6690*/,  7 /*6691*/,  7 /*6692*/,  8 /*6693*/,
    7 /*6694*/,  8 /*6695*/,  8 /*6696*/,  9 /*6697*/,  7 /*6698*/,
    8 /*6699*/,  8 /*669a*/,  9 /*669b*/,  8 /*669c*/,  9 /*669d*/,
    9 /*669e*/,  10 /*669f*/, 6 /*66a0*/,  7 /*66a1*/,  7 /*66a2*/,
    8 /*66a3*/,  7 /*66a4*/,  8 /*66a5*/,  8 /*66a6*/,  9 /*66a7*/,
    7 /*66a8*/,  8 /*66a9*/,  8 /*66aa*/,  9 /*66ab*/,  8 /*66ac*/,
    9 /*66ad*/,  9 /*66ae*/,  10 /*66af*/, 7 /*66b0*/,  8 /*66b1*/,
    8 /*66b2*/,  9 /*66b3*/,  8 /*66b4*/,  9 /*66b5*/,  9 /*66b6*/,
    10 /*66b7*/, 8 /*66b8*/,  9 /*66b9*/,  9 /*66ba*/,  10 /*66bb*/,
    9 /*66bc*/,  10 /*66bd*/, 10 /*66be*/, 11 /*66bf*/, 6 /*66c0*/,
    7 /*66c1*/,  7 /*66c2*/,  8 /*66c3*/,  7 /*66c4*/,  8 /*66c5*/,
    8 /*66c6*/,  9 /*66c7*/,  7 /*66c8*/,  8 /*66c9*/,  8 /*66ca*/,
    9 /*66cb*/,  8 /*66cc*/,  9 /*66cd*/,  9 /*66ce*/,  10 /*66cf*/,
    7 /*66d0*/,  8 /*66d1*/,  8 /*66d2*/,  9 /*66d3*/,  8 /*66d4*/,
    9 /*66d5*/,  9 /*66d6*/,  10 /*66d7*/, 8 /*66d8*/,  9 /*66d9*/,
    9 /*66da*/,  10 /*66db*/, 9 /*66dc*/,  10 /*66dd*/, 10 /*66de*/,
    11 /*66df*/, 7 /*66e0*/,  8 /*66e1*/,  8 /*66e2*/,  9 /*66e3*/,
    8 /*66e4*/,  9 /*66e5*/,  9 /*66e6*/,  10 /*66e7*/, 8 /*66e8*/,
    9 /*66e9*/,  9 /*66ea*/,  10 /*66eb*/, 9 /*66ec*/,  10 /*66ed*/,
    10 /*66ee*/, 11 /*66ef*/, 8 /*66f0*/,  9 /*66f1*/,  9 /*66f2*/,
    10 /*66f3*/, 9 /*66f4*/,  10 /*66f5*/, 10 /*66f6*/, 11 /*66f7*/,
    9 /*66f8*/,  10 /*66f9*/, 10 /*66fa*/, 11 /*66fb*/, 10 /*66fc*/,
    11 /*66fd*/, 11 /*66fe*/, 12 /*66ff*/, 5 /*6700*/,  6 /*6701*/,
    6 /*6702*/,  7 /*6703*/,  6 /*6704*/,  7 /*6705*/,  7 /*6706*/,
    8 /*6707*/,  6 /*6708*/,  7 /*6709*/,  7 /*670a*/,  8 /*670b*/,
    7 /*670c*/,  8 /*670d*/,  8 /*670e*/,  9 /*670f*/,  6 /*6710*/,
    7 /*6711*/,  7 /*6712*/,  8 /*6713*/,  7 /*6714*/,  8 /*6715*/,
    8 /*6716*/,  9 /*6717*/,  7 /*6718*/,  8 /*6719*/,  8 /*671a*/,
    9 /*671b*/,  8 /*671c*/,  9 /*671d*/,  9 /*671e*/,  10 /*671f*/,
    6 /*6720*/,  7 /*6721*/,  7 /*6722*/,  8 /*6723*/,  7 /*6724*/,
    8 /*6725*/,  8 /*6726*/,  9 /*6727*/,  7 /*6728*/,  8 /*6729*/,
    8 /*672a*/,  9 /*672b*/,  8 /*672c*/,  9 /*672d*/,  9 /*672e*/,
    10 /*672f*/, 7 /*6730*/,  8 /*6731*/,  8 /*6732*/,  9 /*6733*/,
    8 /*6734*/,  9 /*6735*/,  9 /*6736*/,  10 /*6737*/, 8 /*6738*/,
    9 /*6739*/,  9 /*673a*/,  10 /*673b*/, 9 /*673c*/,  10 /*673d*/,
    10 /*673e*/, 11 /*673f*/, 6 /*6740*/,  7 /*6741*/,  7 /*6742*/,
    8 /*6743*/,  7 /*6744*/,  8 /*6745*/,  8 /*6746*/,  9 /*6747*/,
    7 /*6748*/,  8 /*6749*/,  8 /*674a*/,  9 /*674b*/,  8 /*674c*/,
    9 /*674d*/,  9 /*674e*/,  10 /*674f*/, 7 /*6750*/,  8 /*6751*/,
    8 /*6752*/,  9 /*6753*/,  8 /*6754*/,  9 /*6755*/,  9 /*6756*/,
    10 /*6757*/, 8 /*6758*/,  9 /*6759*/,  9 /*675a*/,  10 /*675b*/,
    9 /*675c*/,  10 /*675d*/, 10 /*675e*/, 11 /*675f*/, 7 /*6760*/,
    8 /*6761*/,  8 /*6762*/,  9 /*6763*/,  8 /*6764*/,  9 /*6765*/,
    9 /*6766*/,  10 /*6767*/, 8 /*6768*/,  9 /*6769*/,  9 /*676a*/,
    10 /*676b*/, 9 /*676c*/,  10 /*676d*/, 10 /*676e*/, 11 /*676f*/,
    8 /*6770*/,  9 /*6771*/,  9 /*6772*/,  10 /*6773*/, 9 /*6774*/,
    10 /*6775*/, 10 /*6776*/, 11 /*6777*/, 9 /*6778*/,  10 /*6779*/,
    10 /*677a*/, 11 /*677b*/, 10 /*677c*/, 11 /*677d*/, 11 /*677e*/,
    12 /*677f*/, 6 /*6780*/,  7 /*6781*/,  7 /*6782*/,  8 /*6783*/,
    7 /*6784*/,  8 /*6785*/,  8 /*6786*/,  9 /*6787*/,  7 /*6788*/,
    8 /*6789*/,  8 /*678a*/,  9 /*678b*/,  8 /*678c*/,  9 /*678d*/,
    9 /*678e*/,  10 /*678f*/, 7 /*6790*/,  8 /*6791*/,  8 /*6792*/,
    9 /*6793*/,  8 /*6794*/,  9 /*6795*/,  9 /*6796*/,  10 /*6797*/,
    8 /*6798*/,  9 /*6799*/,  9 /*679a*/,  10 /*679b*/, 9 /*679c*/,
    10 /*679d*/, 10 /*679e*/, 11 /*679f*/, 7 /*67a0*/,  8 /*67a1*/,
    8 /*67a2*/,  9 /*67a3*/,  8 /*67a4*/,  9 /*67a5*/,  9 /*67a6*/,
    10 /*67a7*/, 8 /*67a8*/,  9 /*67a9*/,  9 /*67aa*/,  10 /*67ab*/,
    9 /*67ac*/,  10 /*67ad*/, 10 /*67ae*/, 11 /*67af*/, 8 /*67b0*/,
    9 /*67b1*/,  9 /*67b2*/,  10 /*67b3*/, 9 /*67b4*/,  10 /*67b5*/,
    10 /*67b6*/, 11 /*67b7*/, 9 /*67b8*/,  10 /*67b9*/, 10 /*67ba*/,
    11 /*67bb*/, 10 /*67bc*/, 11 /*67bd*/, 11 /*67be*/, 12 /*67bf*/,
    7 /*67c0*/,  8 /*67c1*/,  8 /*67c2*/,  9 /*67c3*/,  8 /*67c4*/,
    9 /*67c5*/,  9 /*67c6*/,  10 /*67c7*/, 8 /*67c8*/,  9 /*67c9*/,
    9 /*67ca*/,  10 /*67cb*/, 9 /*67cc*/,  10 /*67cd*/, 10 /*67ce*/,
    11 /*67cf*/, 8 /*67d0*/,  9 /*67d1*/,  9 /*67d2*/,  10 /*67d3*/,
    9 /*67d4*/,  10 /*67d5*/, 10 /*67d6*/, 11 /*67d7*/, 9 /*67d8*/,
    10 /*67d9*/, 10 /*67da*/, 11 /*67db*/, 10 /*67dc*/, 11 /*67dd*/,
    11 /*67de*/, 12 /*67df*/, 8 /*67e0*/,  9 /*67e1*/,  9 /*67e2*/,
    10 /*67e3*/, 9 /*67e4*/,  10 /*67e5*/, 10 /*67e6*/, 11 /*67e7*/,
    9 /*67e8*/,  10 /*67e9*/, 10 /*67ea*/, 11 /*67eb*/, 10 /*67ec*/,
    11 /*67ed*/, 11 /*67ee*/, 12 /*67ef*/, 9 /*67f0*/,  10 /*67f1*/,
    10 /*67f2*/, 11 /*67f3*/, 10 /*67f4*/, 11 /*67f5*/, 11 /*67f6*/,
    12 /*67f7*/, 10 /*67f8*/, 11 /*67f9*/, 11 /*67fa*/, 12 /*67fb*/,
    11 /*67fc*/, 12 /*67fd*/, 12 /*67fe*/, 13 /*67ff*/, 3 /*6800*/,
    4 /*6801*/,  4 /*6802*/,  5 /*6803*/,  4 /*6804*/,  5 /*6805*/,
    5 /*6806*/,  6 /*6807*/,  4 /*6808*/,  5 /*6809*/,  5 /*680a*/,
    6 /*680b*/,  5 /*680c*/,  6 /*680d*/,  6 /*680e*/,  7 /*680f*/,
    4 /*6810*/,  5 /*6811*/,  5 /*6812*/,  6 /*6813*/,  5 /*6814*/,
    6 /*6815*/,  6 /*6816*/,  7 /*6817*/,  5 /*6818*/,  6 /*6819*/,
    6 /*681a*/,  7 /*681b*/,  6 /*681c*/,  7 /*681d*/,  7 /*681e*/,
    8 /*681f*/,  4 /*6820*/,  5 /*6821*/,  5 /*6822*/,  6 /*6823*/,
    5 /*6824*/,  6 /*6825*/,  6 /*6826*/,  7 /*6827*/,  5 /*6828*/,
    6 /*6829*/,  6 /*682a*/,  7 /*682b*/,  6 /*682c*/,  7 /*682d*/,
    7 /*682e*/,  8 /*682f*/,  5 /*6830*/,  6 /*6831*/,  6 /*6832*/,
    7 /*6833*/,  6 /*6834*/,  7 /*6835*/,  7 /*6836*/,  8 /*6837*/,
    6 /*6838*/,  7 /*6839*/,  7 /*683a*/,  8 /*683b*/,  7 /*683c*/,
    8 /*683d*/,  8 /*683e*/,  9 /*683f*/,  4 /*6840*/,  5 /*6841*/,
    5 /*6842*/,  6 /*6843*/,  5 /*6844*/,  6 /*6845*/,  6 /*6846*/,
    7 /*6847*/,  5 /*6848*/,  6 /*6849*/,  6 /*684a*/,  7 /*684b*/,
    6 /*684c*/,  7 /*684d*/,  7 /*684e*/,  8 /*684f*/,  5 /*6850*/,
    6 /*6851*/,  6 /*6852*/,  7 /*6853*/,  6 /*6854*/,  7 /*6855*/,
    7 /*6856*/,  8 /*6857*/,  6 /*6858*/,  7 /*6859*/,  7 /*685a*/,
    8 /*685b*/,  7 /*685c*/,  8 /*685d*/,  8 /*685e*/,  9 /*685f*/,
    5 /*6860*/,  6 /*6861*/,  6 /*6862*/,  7 /*6863*/,  6 /*6864*/,
    7 /*6865*/,  7 /*6866*/,  8 /*6867*/,  6 /*6868*/,  7 /*6869*/,
    7 /*686a*/,  8 /*686b*/,  7 /*686c*/,  8 /*686d*/,  8 /*686e*/,
    9 /*686f*/,  6 /*6870*/,  7 /*6871*/,  7 /*6872*/,  8 /*6873*/,
    7 /*6874*/,  8 /*6875*/,  8 /*6876*/,  9 /*6877*/,  7 /*6878*/,
    8 /*6879*/,  8 /*687a*/,  9 /*687b*/,  8 /*687c*/,  9 /*687d*/,
    9 /*687e*/,  10 /*687f*/, 4 /*6880*/,  5 /*6881*/,  5 /*6882*/,
    6 /*6883*/,  5 /*6884*/,  6 /*6885*/,  6 /*6886*/,  7 /*6887*/,
    5 /*6888*/,  6 /*6889*/,  6 /*688a*/,  7 /*688b*/,  6 /*688c*/,
    7 /*688d*/,  7 /*688e*/,  8 /*688f*/,  5 /*6890*/,  6 /*6891*/,
    6 /*6892*/,  7 /*6893*/,  6 /*6894*/,  7 /*6895*/,  7 /*6896*/,
    8 /*6897*/,  6 /*6898*/,  7 /*6899*/,  7 /*689a*/,  8 /*689b*/,
    7 /*689c*/,  8 /*689d*/,  8 /*689e*/,  9 /*689f*/,  5 /*68a0*/,
    6 /*68a1*/,  6 /*68a2*/,  7 /*68a3*/,  6 /*68a4*/,  7 /*68a5*/,
    7 /*68a6*/,  8 /*68a7*/,  6 /*68a8*/,  7 /*68a9*/,  7 /*68aa*/,
    8 /*68ab*/,  7 /*68ac*/,  8 /*68ad*/,  8 /*68ae*/,  9 /*68af*/,
    6 /*68b0*/,  7 /*68b1*/,  7 /*68b2*/,  8 /*68b3*/,  7 /*68b4*/,
    8 /*68b5*/,  8 /*68b6*/,  9 /*68b7*/,  7 /*68b8*/,  8 /*68b9*/,
    8 /*68ba*/,  9 /*68bb*/,  8 /*68bc*/,  9 /*68bd*/,  9 /*68be*/,
    10 /*68bf*/, 5 /*68c0*/,  6 /*68c1*/,  6 /*68c2*/,  7 /*68c3*/,
    6 /*68c4*/,  7 /*68c5*/,  7 /*68c6*/,  8 /*68c7*/,  6 /*68c8*/,
    7 /*68c9*/,  7 /*68ca*/,  8 /*68cb*/,  7 /*68cc*/,  8 /*68cd*/,
    8 /*68ce*/,  9 /*68cf*/,  6 /*68d0*/,  7 /*68d1*/,  7 /*68d2*/,
    8 /*68d3*/,  7 /*68d4*/,  8 /*68d5*/,  8 /*68d6*/,  9 /*68d7*/,
    7 /*68d8*/,  8 /*68d9*/,  8 /*68da*/,  9 /*68db*/,  8 /*68dc*/,
    9 /*68dd*/,  9 /*68de*/,  10 /*68df*/, 6 /*68e0*/,  7 /*68e1*/,
    7 /*68e2*/,  8 /*68e3*/,  7 /*68e4*/,  8 /*68e5*/,  8 /*68e6*/,
    9 /*68e7*/,  7 /*68e8*/,  8 /*68e9*/,  8 /*68ea*/,  9 /*68eb*/,
    8 /*68ec*/,  9 /*68ed*/,  9 /*68ee*/,  10 /*68ef*/, 7 /*68f0*/,
    8 /*68f1*/,  8 /*68f2*/,  9 /*68f3*/,  8 /*68f4*/,  9 /*68f5*/,
    9 /*68f6*/,  10 /*68f7*/, 8 /*68f8*/,  9 /*68f9*/,  9 /*68fa*/,
    10 /*68fb*/, 9 /*68fc*/,  10 /*68fd*/, 10 /*68fe*/, 11 /*68ff*/,
    4 /*6900*/,  5 /*6901*/,  5 /*6902*/,  6 /*6903*/,  5 /*6904*/,
    6 /*6905*/,  6 /*6906*/,  7 /*6907*/,  5 /*6908*/,  6 /*6909*/,
    6 /*690a*/,  7 /*690b*/,  6 /*690c*/,  7 /*690d*/,  7 /*690e*/,
    8 /*690f*/,  5 /*6910*/,  6 /*6911*/,  6 /*6912*/,  7 /*6913*/,
    6 /*6914*/,  7 /*6915*/,  7 /*6916*/,  8 /*6917*/,  6 /*6918*/,
    7 /*6919*/,  7 /*691a*/,  8 /*691b*/,  7 /*691c*/,  8 /*691d*/,
    8 /*691e*/,  9 /*691f*/,  5 /*6920*/,  6 /*6921*/,  6 /*6922*/,
    7 /*6923*/,  6 /*6924*/,  7 /*6925*/,  7 /*6926*/,  8 /*6927*/,
    6 /*6928*/,  7 /*6929*/,  7 /*692a*/,  8 /*692b*/,  7 /*692c*/,
    8 /*692d*/,  8 /*692e*/,  9 /*692f*/,  6 /*6930*/,  7 /*6931*/,
    7 /*6932*/,  8 /*6933*/,  7 /*6934*/,  8 /*6935*/,  8 /*6936*/,
    9 /*6937*/,  7 /*6938*/,  8 /*6939*/,  8 /*693a*/,  9 /*693b*/,
    8 /*693c*/,  9 /*693d*/,  9 /*693e*/,  10 /*693f*/, 5 /*6940*/,
    6 /*6941*/,  6 /*6942*/,  7 /*6943*/,  6 /*6944*/,  7 /*6945*/,
    7 /*6946*/,  8 /*6947*/,  6 /*6948*/,  7 /*6949*/,  7 /*694a*/,
    8 /*694b*/,  7 /*694c*/,  8 /*694d*/,  8 /*694e*/,  9 /*694f*/,
    6 /*6950*/,  7 /*6951*/,  7 /*6952*/,  8 /*6953*/,  7 /*6954*/,
    8 /*6955*/,  8 /*6956*/,  9 /*6957*/,  7 /*6958*/,  8 /*6959*/,
    8 /*695a*/,  9 /*695b*/,  8 /*695c*/,  9 /*695d*/,  9 /*695e*/,
    10 /*695f*/, 6 /*6960*/,  7 /*6961*/,  7 /*6962*/,  8 /*6963*/,
    7 /*6964*/,  8 /*6965*/,  8 /*6966*/,  9 /*6967*/,  7 /*6968*/,
    8 /*6969*/,  8 /*696a*/,  9 /*696b*/,  8 /*696c*/,  9 /*696d*/,
    9 /*696e*/,  10 /*696f*/, 7 /*6970*/,  8 /*6971*/,  8 /*6972*/,
    9 /*6973*/,  8 /*6974*/,  9 /*6975*/,  9 /*6976*/,  10 /*6977*/,
    8 /*6978*/,  9 /*6979*/,  9 /*697a*/,  10 /*697b*/, 9 /*697c*/,
    10 /*697d*/, 10 /*697e*/, 11 /*697f*/, 5 /*6980*/,  6 /*6981*/,
    6 /*6982*/,  7 /*6983*/,  6 /*6984*/,  7 /*6985*/,  7 /*6986*/,
    8 /*6987*/,  6 /*6988*/,  7 /*6989*/,  7 /*698a*/,  8 /*698b*/,
    7 /*698c*/,  8 /*698d*/,  8 /*698e*/,  9 /*698f*/,  6 /*6990*/,
    7 /*6991*/,  7 /*6992*/,  8 /*6993*/,  7 /*6994*/,  8 /*6995*/,
    8 /*6996*/,  9 /*6997*/,  7 /*6998*/,  8 /*6999*/,  8 /*699a*/,
    9 /*699b*/,  8 /*699c*/,  9 /*699d*/,  9 /*699e*/,  10 /*699f*/,
    6 /*69a0*/,  7 /*69a1*/,  7 /*69a2*/,  8 /*69a3*/,  7 /*69a4*/,
    8 /*69a5*/,  8 /*69a6*/,  9 /*69a7*/,  7 /*69a8*/,  8 /*69a9*/,
    8 /*69aa*/,  9 /*69ab*/,  8 /*69ac*/,  9 /*69ad*/,  9 /*69ae*/,
    10 /*69af*/, 7 /*69b0*/,  8 /*69b1*/,  8 /*69b2*/,  9 /*69b3*/,
    8 /*69b4*/,  9 /*69b5*/,  9 /*69b6*/,  10 /*69b7*/, 8 /*69b8*/,
    9 /*69b9*/,  9 /*69ba*/,  10 /*69bb*/, 9 /*69bc*/,  10 /*69bd*/,
    10 /*69be*/, 11 /*69bf*/, 6 /*69c0*/,  7 /*69c1*/,  7 /*69c2*/,
    8 /*69c3*/,  7 /*69c4*/,  8 /*69c5*/,  8 /*69c6*/,  9 /*69c7*/,
    7 /*69c8*/,  8 /*69c9*/,  8 /*69ca*/,  9 /*69cb*/,  8 /*69cc*/,
    9 /*69cd*/,  9 /*69ce*/,  10 /*69cf*/, 7 /*69d0*/,  8 /*69d1*/,
    8 /*69d2*/,  9 /*69d3*/,  8 /*69d4*/,  9 /*69d5*/,  9 /*69d6*/,
    10 /*69d7*/, 8 /*69d8*/,  9 /*69d9*/,  9 /*69da*/,  10 /*69db*/,
    9 /*69dc*/,  10 /*69dd*/, 10 /*69de*/, 11 /*69df*/, 7 /*69e0*/,
    8 /*69e1*/,  8 /*69e2*/,  9 /*69e3*/,  8 /*69e4*/,  9 /*69e5*/,
    9 /*69e6*/,  10 /*69e7*/, 8 /*69e8*/,  9 /*69e9*/,  9 /*69ea*/,
    10 /*69eb*/, 9 /*69ec*/,  10 /*69ed*/, 10 /*69ee*/, 11 /*69ef*/,
    8 /*69f0*/,  9 /*69f1*/,  9 /*69f2*/,  10 /*69f3*/, 9 /*69f4*/,
    10 /*69f5*/, 10 /*69f6*/, 11 /*69f7*/, 9 /*69f8*/,  10 /*69f9*/,
    10 /*69fa*/, 11 /*69fb*/, 10 /*69fc*/, 11 /*69fd*/, 11 /*69fe*/,
    12 /*69ff*/, 4 /*6a00*/,  5 /*6a01*/,  5 /*6a02*/,  6 /*6a03*/,
    5 /*6a04*/,  6 /*6a05*/,  6 /*6a06*/,  7 /*6a07*/,  5 /*6a08*/,
    6 /*6a09*/,  6 /*6a0a*/,  7 /*6a0b*/,  6 /*6a0c*/,  7 /*6a0d*/,
    7 /*6a0e*/,  8 /*6a0f*/,  5 /*6a10*/,  6 /*6a11*/,  6 /*6a12*/,
    7 /*6a13*/,  6 /*6a14*/,  7 /*6a15*/,  7 /*6a16*/,  8 /*6a17*/,
    6 /*6a18*/,  7 /*6a19*/,  7 /*6a1a*/,  8 /*6a1b*/,  7 /*6a1c*/,
    8 /*6a1d*/,  8 /*6a1e*/,  9 /*6a1f*/,  5 /*6a20*/,  6 /*6a21*/,
    6 /*6a22*/,  7 /*6a23*/,  6 /*6a24*/,  7 /*6a25*/,  7 /*6a26*/,
    8 /*6a27*/,  6 /*6a28*/,  7 /*6a29*/,  7 /*6a2a*/,  8 /*6a2b*/,
    7 /*6a2c*/,  8 /*6a2d*/,  8 /*6a2e*/,  9 /*6a2f*/,  6 /*6a30*/,
    7 /*6a31*/,  7 /*6a32*/,  8 /*6a33*/,  7 /*6a34*/,  8 /*6a35*/,
    8 /*6a36*/,  9 /*6a37*/,  7 /*6a38*/,  8 /*6a39*/,  8 /*6a3a*/,
    9 /*6a3b*/,  8 /*6a3c*/,  9 /*6a3d*/,  9 /*6a3e*/,  10 /*6a3f*/,
    5 /*6a40*/,  6 /*6a41*/,  6 /*6a42*/,  7 /*6a43*/,  6 /*6a44*/,
    7 /*6a45*/,  7 /*6a46*/,  8 /*6a47*/,  6 /*6a48*/,  7 /*6a49*/,
    7 /*6a4a*/,  8 /*6a4b*/,  7 /*6a4c*/,  8 /*6a4d*/,  8 /*6a4e*/,
    9 /*6a4f*/,  6 /*6a50*/,  7 /*6a51*/,  7 /*6a52*/,  8 /*6a53*/,
    7 /*6a54*/,  8 /*6a55*/,  8 /*6a56*/,  9 /*6a57*/,  7 /*6a58*/,
    8 /*6a59*/,  8 /*6a5a*/,  9 /*6a5b*/,  8 /*6a5c*/,  9 /*6a5d*/,
    9 /*6a5e*/,  10 /*6a5f*/, 6 /*6a60*/,  7 /*6a61*/,  7 /*6a62*/,
    8 /*6a63*/,  7 /*6a64*/,  8 /*6a65*/,  8 /*6a66*/,  9 /*6a67*/,
    7 /*6a68*/,  8 /*6a69*/,  8 /*6a6a*/,  9 /*6a6b*/,  8 /*6a6c*/,
    9 /*6a6d*/,  9 /*6a6e*/,  10 /*6a6f*/, 7 /*6a70*/,  8 /*6a71*/,
    8 /*6a72*/,  9 /*6a73*/,  8 /*6a74*/,  9 /*6a75*/,  9 /*6a76*/,
    10 /*6a77*/, 8 /*6a78*/,  9 /*6a79*/,  9 /*6a7a*/,  10 /*6a7b*/,
    9 /*6a7c*/,  10 /*6a7d*/, 10 /*6a7e*/, 11 /*6a7f*/, 5 /*6a80*/,
    6 /*6a81*/,  6 /*6a82*/,  7 /*6a83*/,  6 /*6a84*/,  7 /*6a85*/,
    7 /*6a86*/,  8 /*6a87*/,  6 /*6a88*/,  7 /*6a89*/,  7 /*6a8a*/,
    8 /*6a8b*/,  7 /*6a8c*/,  8 /*6a8d*/,  8 /*6a8e*/,  9 /*6a8f*/,
    6 /*6a90*/,  7 /*6a91*/,  7 /*6a92*/,  8 /*6a93*/,  7 /*6a94*/,
    8 /*6a95*/,  8 /*6a96*/,  9 /*6a97*/,  7 /*6a98*/,  8 /*6a99*/,
    8 /*6a9a*/,  9 /*6a9b*/,  8 /*6a9c*/,  9 /*6a9d*/,  9 /*6a9e*/,
    10 /*6a9f*/, 6 /*6aa0*/,  7 /*6aa1*/,  7 /*6aa2*/,  8 /*6aa3*/,
    7 /*6aa4*/,  8 /*6aa5*/,  8 /*6aa6*/,  9 /*6aa7*/,  7 /*6aa8*/,
    8 /*6aa9*/,  8 /*6aaa*/,  9 /*6aab*/,  8 /*6aac*/,  9 /*6aad*/,
    9 /*6aae*/,  10 /*6aaf*/, 7 /*6ab0*/,  8 /*6ab1*/,  8 /*6ab2*/,
    9 /*6ab3*/,  8 /*6ab4*/,  9 /*6ab5*/,  9 /*6ab6*/,  10 /*6ab7*/,
    8 /*6ab8*/,  9 /*6ab9*/,  9 /*6aba*/,  10 /*6abb*/, 9 /*6abc*/,
    10 /*6abd*/, 10 /*6abe*/, 11 /*6abf*/, 6 /*6ac0*/,  7 /*6ac1*/,
    7 /*6ac2*/,  8 /*6ac3*/,  7 /*6ac4*/,  8 /*6ac5*/,  8 /*6ac6*/,
    9 /*6ac7*/,  7 /*6ac8*/,  8 /*6ac9*/,  8 /*6aca*/,  9 /*6acb*/,
    8 /*6acc*/,  9 /*6acd*/,  9 /*6ace*/,  10 /*6acf*/, 7 /*6ad0*/,
    8 /*6ad1*/,  8 /*6ad2*/,  9 /*6ad3*/,  8 /*6ad4*/,  9 /*6ad5*/,
    9 /*6ad6*/,  10 /*6ad7*/, 8 /*6ad8*/,  9 /*6ad9*/,  9 /*6ada*/,
    10 /*6adb*/, 9 /*6adc*/,  10 /*6add*/, 10 /*6ade*/, 11 /*6adf*/,
    7 /*6ae0*/,  8 /*6ae1*/,  8 /*6ae2*/,  9 /*6ae3*/,  8 /*6ae4*/,
    9 /*6ae5*/,  9 /*6ae6*/,  10 /*6ae7*/, 8 /*6ae8*/,  9 /*6ae9*/,
    9 /*6aea*/,  10 /*6aeb*/, 9 /*6aec*/,  10 /*6aed*/, 10 /*6aee*/,
    11 /*6aef*/, 8 /*6af0*/,  9 /*6af1*/,  9 /*6af2*/,  10 /*6af3*/,
    9 /*6af4*/,  10 /*6af5*/, 10 /*6af6*/, 11 /*6af7*/, 9 /*6af8*/,
    10 /*6af9*/, 10 /*6afa*/, 11 /*6afb*/, 10 /*6afc*/, 11 /*6afd*/,
    11 /*6afe*/, 12 /*6aff*/, 5 /*6b00*/,  6 /*6b01*/,  6 /*6b02*/,
    7 /*6b03*/,  6 /*6b04*/,  7 /*6b05*/,  7 /*6b06*/,  8 /*6b07*/,
    6 /*6b08*/,  7 /*6b09*/,  7 /*6b0a*/,  8 /*6b0b*/,  7 /*6b0c*/,
    8 /*6b0d*/,  8 /*6b0e*/,  9 /*6b0f*/,  6 /*6b10*/,  7 /*6b11*/,
    7 /*6b12*/,  8 /*6b13*/,  7 /*6b14*/,  8 /*6b15*/,  8 /*6b16*/,
    9 /*6b17*/,  7 /*6b18*/,  8 /*6b19*/,  8 /*6b1a*/,  9 /*6b1b*/,
    8 /*6b1c*/,  9 /*6b1d*/,  9 /*6b1e*/,  10 /*6b1f*/, 6 /*6b20*/,
    7 /*6b21*/,  7 /*6b22*/,  8 /*6b23*/,  7 /*6b24*/,  8 /*6b25*/,
    8 /*6b26*/,  9 /*6b27*/,  7 /*6b28*/,  8 /*6b29*/,  8 /*6b2a*/,
    9 /*6b2b*/,  8 /*6b2c*/,  9 /*6b2d*/,  9 /*6b2e*/,  10 /*6b2f*/,
    7 /*6b30*/,  8 /*6b31*/,  8 /*6b32*/,  9 /*6b33*/,  8 /*6b34*/,
    9 /*6b35*/,  9 /*6b36*/,  10 /*6b37*/, 8 /*6b38*/,  9 /*6b39*/,
    9 /*6b3a*/,  10 /*6b3b*/, 9 /*6b3c*/,  10 /*6b3d*/, 10 /*6b3e*/,
    11 /*6b3f*/, 6 /*6b40*/,  7 /*6b41*/,  7 /*6b42*/,  8 /*6b43*/,
    7 /*6b44*/,  8 /*6b45*/,  8 /*6b46*/,  9 /*6b47*/,  7 /*6b48*/,
    8 /*6b49*/,  8 /*6b4a*/,  9 /*6b4b*/,  8 /*6b4c*/,  9 /*6b4d*/,
    9 /*6b4e*/,  10 /*6b4f*/, 7 /*6b50*/,  8 /*6b51*/,  8 /*6b52*/,
    9 /*6b53*/,  8 /*6b54*/,  9 /*6b55*/,  9 /*6b56*/,  10 /*6b57*/,
    8 /*6b58*/,  9 /*6b59*/,  9 /*6b5a*/,  10 /*6b5b*/, 9 /*6b5c*/,
    10 /*6b5d*/, 10 /*6b5e*/, 11 /*6b5f*/, 7 /*6b60*/,  8 /*6b61*/,
    8 /*6b62*/,  9 /*6b63*/,  8 /*6b64*/,  9 /*6b65*/,  9 /*6b66*/,
    10 /*6b67*/, 8 /*6b68*/,  9 /*6b69*/,  9 /*6b6a*/,  10 /*6b6b*/,
    9 /*6b6c*/,  10 /*6b6d*/, 10 /*6b6e*/, 11 /*6b6f*/, 8 /*6b70*/,
    9 /*6b71*/,  9 /*6b72*/,  10 /*6b73*/, 9 /*6b74*/,  10 /*6b75*/,
    10 /*6b76*/, 11 /*6b77*/, 9 /*6b78*/,  10 /*6b79*/, 10 /*6b7a*/,
    11 /*6b7b*/, 10 /*6b7c*/, 11 /*6b7d*/, 11 /*6b7e*/, 12 /*6b7f*/,
    6 /*6b80*/,  7 /*6b81*/,  7 /*6b82*/,  8 /*6b83*/,  7 /*6b84*/,
    8 /*6b85*/,  8 /*6b86*/,  9 /*6b87*/,  7 /*6b88*/,  8 /*6b89*/,
    8 /*6b8a*/,  9 /*6b8b*/,  8 /*6b8c*/,  9 /*6b8d*/,  9 /*6b8e*/,
    10 /*6b8f*/, 7 /*6b90*/,  8 /*6b91*/,  8 /*6b92*/,  9 /*6b93*/,
    8 /*6b94*/,  9 /*6b95*/,  9 /*6b96*/,  10 /*6b97*/, 8 /*6b98*/,
    9 /*6b99*/,  9 /*6b9a*/,  10 /*6b9b*/, 9 /*6b9c*/,  10 /*6b9d*/,
    10 /*6b9e*/, 11 /*6b9f*/, 7 /*6ba0*/,  8 /*6ba1*/,  8 /*6ba2*/,
    9 /*6ba3*/,  8 /*6ba4*/,  9 /*6ba5*/,  9 /*6ba6*/,  10 /*6ba7*/,
    8 /*6ba8*/,  9 /*6ba9*/,  9 /*6baa*/,  10 /*6bab*/, 9 /*6bac*/,
    10 /*6bad*/, 10 /*6bae*/, 11 /*6baf*/, 8 /*6bb0*/,  9 /*6bb1*/,
    9 /*6bb2*/,  10 /*6bb3*/, 9 /*6bb4*/,  10 /*6bb5*/, 10 /*6bb6*/,
    11 /*6bb7*/, 9 /*6bb8*/,  10 /*6bb9*/, 10 /*6bba*/, 11 /*6bbb*/,
    10 /*6bbc*/, 11 /*6bbd*/, 11 /*6bbe*/, 12 /*6bbf*/, 7 /*6bc0*/,
    8 /*6bc1*/,  8 /*6bc2*/,  9 /*6bc3*/,  8 /*6bc4*/,  9 /*6bc5*/,
    9 /*6bc6*/,  10 /*6bc7*/, 8 /*6bc8*/,  9 /*6bc9*/,  9 /*6bca*/,
    10 /*6bcb*/, 9 /*6bcc*/,  10 /*6bcd*/, 10 /*6bce*/, 11 /*6bcf*/,
    8 /*6bd0*/,  9 /*6bd1*/,  9 /*6bd2*/,  10 /*6bd3*/, 9 /*6bd4*/,
    10 /*6bd5*/, 10 /*6bd6*/, 11 /*6bd7*/, 9 /*6bd8*/,  10 /*6bd9*/,
    10 /*6bda*/, 11 /*6bdb*/, 10 /*6bdc*/, 11 /*6bdd*/, 11 /*6bde*/,
    12 /*6bdf*/, 8 /*6be0*/,  9 /*6be1*/,  9 /*6be2*/,  10 /*6be3*/,
    9 /*6be4*/,  10 /*6be5*/, 10 /*6be6*/, 11 /*6be7*/, 9 /*6be8*/,
    10 /*6be9*/, 10 /*6bea*/, 11 /*6beb*/, 10 /*6bec*/, 11 /*6bed*/,
    11 /*6bee*/, 12 /*6bef*/, 9 /*6bf0*/,  10 /*6bf1*/, 10 /*6bf2*/,
    11 /*6bf3*/, 10 /*6bf4*/, 11 /*6bf5*/, 11 /*6bf6*/, 12 /*6bf7*/,
    10 /*6bf8*/, 11 /*6bf9*/, 11 /*6bfa*/, 12 /*6bfb*/, 11 /*6bfc*/,
    12 /*6bfd*/, 12 /*6bfe*/, 13 /*6bff*/, 4 /*6c00*/,  5 /*6c01*/,
    5 /*6c02*/,  6 /*6c03*/,  5 /*6c04*/,  6 /*6c05*/,  6 /*6c06*/,
    7 /*6c07*/,  5 /*6c08*/,  6 /*6c09*/,  6 /*6c0a*/,  7 /*6c0b*/,
    6 /*6c0c*/,  7 /*6c0d*/,  7 /*6c0e*/,  8 /*6c0f*/,  5 /*6c10*/,
    6 /*6c11*/,  6 /*6c12*/,  7 /*6c13*/,  6 /*6c14*/,  7 /*6c15*/,
    7 /*6c16*/,  8 /*6c17*/,  6 /*6c18*/,  7 /*6c19*/,  7 /*6c1a*/,
    8 /*6c1b*/,  7 /*6c1c*/,  8 /*6c1d*/,  8 /*6c1e*/,  9 /*6c1f*/,
    5 /*6c20*/,  6 /*6c21*/,  6 /*6c22*/,  7 /*6c23*/,  6 /*6c24*/,
    7 /*6c25*/,  7 /*6c26*/,  8 /*6c27*/,  6 /*6c28*/,  7 /*6c29*/,
    7 /*6c2a*/,  8 /*6c2b*/,  7 /*6c2c*/,  8 /*6c2d*/,  8 /*6c2e*/,
    9 /*6c2f*/,  6 /*6c30*/,  7 /*6c31*/,  7 /*6c32*/,  8 /*6c33*/,
    7 /*6c34*/,  8 /*6c35*/,  8 /*6c36*/,  9 /*6c37*/,  7 /*6c38*/,
    8 /*6c39*/,  8 /*6c3a*/,  9 /*6c3b*/,  8 /*6c3c*/,  9 /*6c3d*/,
    9 /*6c3e*/,  10 /*6c3f*/, 5 /*6c40*/,  6 /*6c41*/,  6 /*6c42*/,
    7 /*6c43*/,  6 /*6c44*/,  7 /*6c45*/,  7 /*6c46*/,  8 /*6c47*/,
    6 /*6c48*/,  7 /*6c49*/,  7 /*6c4a*/,  8 /*6c4b*/,  7 /*6c4c*/,
    8 /*6c4d*/,  8 /*6c4e*/,  9 /*6c4f*/,  6 /*6c50*/,  7 /*6c51*/,
    7 /*6c52*/,  8 /*6c53*/,  7 /*6c54*/,  8 /*6c55*/,  8 /*6c56*/,
    9 /*6c57*/,  7 /*6c58*/,  8 /*6c59*/,  8 /*6c5a*/,  9 /*6c5b*/,
    8 /*6c5c*/,  9 /*6c5d*/,  9 /*6c5e*/,  10 /*6c5f*/, 6 /*6c60*/,
    7 /*6c61*/,  7 /*6c62*/,  8 /*6c63*/,  7 /*6c64*/,  8 /*6c65*/,
    8 /*6c66*/,  9 /*6c67*/,  7 /*6c68*/,  8 /*6c69*/,  8 /*6c6a*/,
    9 /*6c6b*/,  8 /*6c6c*/,  9 /*6c6d*/,  9 /*6c6e*/,  10 /*6c6f*/,
    7 /*6c70*/,  8 /*6c71*/,  8 /*6c72*/,  9 /*6c73*/,  8 /*6c74*/,
    9 /*6c75*/,  9 /*6c76*/,  10 /*6c77*/, 8 /*6c78*/,  9 /*6c79*/,
    9 /*6c7a*/,  10 /*6c7b*/, 9 /*6c7c*/,  10 /*6c7d*/, 10 /*6c7e*/,
    11 /*6c7f*/, 5 /*6c80*/,  6 /*6c81*/,  6 /*6c82*/,  7 /*6c83*/,
    6 /*6c84*/,  7 /*6c85*/,  7 /*6c86*/,  8 /*6c87*/,  6 /*6c88*/,
    7 /*6c89*/,  7 /*6c8a*/,  8 /*6c8b*/,  7 /*6c8c*/,  8 /*6c8d*/,
    8 /*6c8e*/,  9 /*6c8f*/,  6 /*6c90*/,  7 /*6c91*/,  7 /*6c92*/,
    8 /*6c93*/,  7 /*6c94*/,  8 /*6c95*/,  8 /*6c96*/,  9 /*6c97*/,
    7 /*6c98*/,  8 /*6c99*/,  8 /*6c9a*/,  9 /*6c9b*/,  8 /*6c9c*/,
    9 /*6c9d*/,  9 /*6c9e*/,  10 /*6c9f*/, 6 /*6ca0*/,  7 /*6ca1*/,
    7 /*6ca2*/,  8 /*6ca3*/,  7 /*6ca4*/,  8 /*6ca5*/,  8 /*6ca6*/,
    9 /*6ca7*/,  7 /*6ca8*/,  8 /*6ca9*/,  8 /*6caa*/,  9 /*6cab*/,
    8 /*6cac*/,  9 /*6cad*/,  9 /*6cae*/,  10 /*6caf*/, 7 /*6cb0*/,
    8 /*6cb1*/,  8 /*6cb2*/,  9 /*6cb3*/,  8 /*6cb4*/,  9 /*6cb5*/,
    9 /*6cb6*/,  10 /*6cb7*/, 8 /*6cb8*/,  9 /*6cb9*/,  9 /*6cba*/,
    10 /*6cbb*/, 9 /*6cbc*/,  10 /*6cbd*/, 10 /*6cbe*/, 11 /*6cbf*/,
    6 /*6cc0*/,  7 /*6cc1*/,  7 /*6cc2*/,  8 /*6cc3*/,  7 /*6cc4*/,
    8 /*6cc5*/,  8 /*6cc6*/,  9 /*6cc7*/,  7 /*6cc8*/,  8 /*6cc9*/,
    8 /*6cca*/,  9 /*6ccb*/,  8 /*6ccc*/,  9 /*6ccd*/,  9 /*6cce*/,
    10 /*6ccf*/, 7 /*6cd0*/,  8 /*6cd1*/,  8 /*6cd2*/,  9 /*6cd3*/,
    8 /*6cd4*/,  9 /*6cd5*/,  9 /*6cd6*/,  10 /*6cd7*/, 8 /*6cd8*/,
    9 /*6cd9*/,  9 /*6cda*/,  10 /*6cdb*/, 9 /*6cdc*/,  10 /*6cdd*/,
    10 /*6cde*/, 11 /*6cdf*/, 7 /*6ce0*/,  8 /*6ce1*/,  8 /*6ce2*/,
    9 /*6ce3*/,  8 /*6ce4*/,  9 /*6ce5*/,  9 /*6ce6*/,  10 /*6ce7*/,
    8 /*6ce8*/,  9 /*6ce9*/,  9 /*6cea*/,  10 /*6ceb*/, 9 /*6cec*/,
    10 /*6ced*/, 10 /*6cee*/, 11 /*6cef*/, 8 /*6cf0*/,  9 /*6cf1*/,
    9 /*6cf2*/,  10 /*6cf3*/, 9 /*6cf4*/,  10 /*6cf5*/, 10 /*6cf6*/,
    11 /*6cf7*/, 9 /*6cf8*/,  10 /*6cf9*/, 10 /*6cfa*/, 11 /*6cfb*/,
    10 /*6cfc*/, 11 /*6cfd*/, 11 /*6cfe*/, 12 /*6cff*/, 5 /*6d00*/,
    6 /*6d01*/,  6 /*6d02*/,  7 /*6d03*/,  6 /*6d04*/,  7 /*6d05*/,
    7 /*6d06*/,  8 /*6d07*/,  6 /*6d08*/,  7 /*6d09*/,  7 /*6d0a*/,
    8 /*6d0b*/,  7 /*6d0c*/,  8 /*6d0d*/,  8 /*6d0e*/,  9 /*6d0f*/,
    6 /*6d10*/,  7 /*6d11*/,  7 /*6d12*/,  8 /*6d13*/,  7 /*6d14*/,
    8 /*6d15*/,  8 /*6d16*/,  9 /*6d17*/,  7 /*6d18*/,  8 /*6d19*/,
    8 /*6d1a*/,  9 /*6d1b*/,  8 /*6d1c*/,  9 /*6d1d*/,  9 /*6d1e*/,
    10 /*6d1f*/, 6 /*6d20*/,  7 /*6d21*/,  7 /*6d22*/,  8 /*6d23*/,
    7 /*6d24*/,  8 /*6d25*/,  8 /*6d26*/,  9 /*6d27*/,  7 /*6d28*/,
    8 /*6d29*/,  8 /*6d2a*/,  9 /*6d2b*/,  8 /*6d2c*/,  9 /*6d2d*/,
    9 /*6d2e*/,  10 /*6d2f*/, 7 /*6d30*/,  8 /*6d31*/,  8 /*6d32*/,
    9 /*6d33*/,  8 /*6d34*/,  9 /*6d35*/,  9 /*6d36*/,  10 /*6d37*/,
    8 /*6d38*/,  9 /*6d39*/,  9 /*6d3a*/,  10 /*6d3b*/, 9 /*6d3c*/,
    10 /*6d3d*/, 10 /*6d3e*/, 11 /*6d3f*/, 6 /*6d40*/,  7 /*6d41*/,
    7 /*6d42*/,  8 /*6d43*/,  7 /*6d44*/,  8 /*6d45*/,  8 /*6d46*/,
    9 /*6d47*/,  7 /*6d48*/,  8 /*6d49*/,  8 /*6d4a*/,  9 /*6d4b*/,
    8 /*6d4c*/,  9 /*6d4d*/,  9 /*6d4e*/,  10 /*6d4f*/, 7 /*6d50*/,
    8 /*6d51*/,  8 /*6d52*/,  9 /*6d53*/,  8 /*6d54*/,  9 /*6d55*/,
    9 /*6d56*/,  10 /*6d57*/, 8 /*6d58*/,  9 /*6d59*/,  9 /*6d5a*/,
    10 /*6d5b*/, 9 /*6d5c*/,  10 /*6d5d*/, 10 /*6d5e*/, 11 /*6d5f*/,
    7 /*6d60*/,  8 /*6d61*/,  8 /*6d62*/,  9 /*6d63*/,  8 /*6d64*/,
    9 /*6d65*/,  9 /*6d66*/,  10 /*6d67*/, 8 /*6d68*/,  9 /*6d69*/,
    9 /*6d6a*/,  10 /*6d6b*/, 9 /*6d6c*/,  10 /*6d6d*/, 10 /*6d6e*/,
    11 /*6d6f*/, 8 /*6d70*/,  9 /*6d71*/,  9 /*6d72*/,  10 /*6d73*/,
    9 /*6d74*/,  10 /*6d75*/, 10 /*6d76*/, 11 /*6d77*/, 9 /*6d78*/,
    10 /*6d79*/, 10 /*6d7a*/, 11 /*6d7b*/, 10 /*6d7c*/, 11 /*6d7d*/,
    11 /*6d7e*/, 12 /*6d7f*/, 6 /*6d80*/,  7 /*6d81*/,  7 /*6d82*/,
    8 /*6d83*/,  7 /*6d84*/,  8 /*6d85*/,  8 /*6d86*/,  9 /*6d87*/,
    7 /*6d88*/,  8 /*6d89*/,  8 /*6d8a*/,  9 /*6d8b*/,  8 /*6d8c*/,
    9 /*6d8d*/,  9 /*6d8e*/,  10 /*6d8f*/, 7 /*6d90*/,  8 /*6d91*/,
    8 /*6d92*/,  9 /*6d93*/,  8 /*6d94*/,  9 /*6d95*/,  9 /*6d96*/,
    10 /*6d97*/, 8 /*6d98*/,  9 /*6d99*/,  9 /*6d9a*/,  10 /*6d9b*/,
    9 /*6d9c*/,  10 /*6d9d*/, 10 /*6d9e*/, 11 /*6d9f*/, 7 /*6da0*/,
    8 /*6da1*/,  8 /*6da2*/,  9 /*6da3*/,  8 /*6da4*/,  9 /*6da5*/,
    9 /*6da6*/,  10 /*6da7*/, 8 /*6da8*/,  9 /*6da9*/,  9 /*6daa*/,
    10 /*6dab*/, 9 /*6dac*/,  10 /*6dad*/, 10 /*6dae*/, 11 /*6daf*/,
    8 /*6db0*/,  9 /*6db1*/,  9 /*6db2*/,  10 /*6db3*/, 9 /*6db4*/,
    10 /*6db5*/, 10 /*6db6*/, 11 /*6db7*/, 9 /*6db8*/,  10 /*6db9*/,
    10 /*6dba*/, 11 /*6dbb*/, 10 /*6dbc*/, 11 /*6dbd*/, 11 /*6dbe*/,
    12 /*6dbf*/, 7 /*6dc0*/,  8 /*6dc1*/,  8 /*6dc2*/,  9 /*6dc3*/,
    8 /*6dc4*/,  9 /*6dc5*/,  9 /*6dc6*/,  10 /*6dc7*/, 8 /*6dc8*/,
    9 /*6dc9*/,  9 /*6dca*/,  10 /*6dcb*/, 9 /*6dcc*/,  10 /*6dcd*/,
    10 /*6dce*/, 11 /*6dcf*/, 8 /*6dd0*/,  9 /*6dd1*/,  9 /*6dd2*/,
    10 /*6dd3*/, 9 /*6dd4*/,  10 /*6dd5*/, 10 /*6dd6*/, 11 /*6dd7*/,
    9 /*6dd8*/,  10 /*6dd9*/, 10 /*6dda*/, 11 /*6ddb*/, 10 /*6ddc*/,
    11 /*6ddd*/, 11 /*6dde*/, 12 /*6ddf*/, 8 /*6de0*/,  9 /*6de1*/,
    9 /*6de2*/,  10 /*6de3*/, 9 /*6de4*/,  10 /*6de5*/, 10 /*6de6*/,
    11 /*6de7*/, 9 /*6de8*/,  10 /*6de9*/, 10 /*6dea*/, 11 /*6deb*/,
    10 /*6dec*/, 11 /*6ded*/, 11 /*6dee*/, 12 /*6def*/, 9 /*6df0*/,
    10 /*6df1*/, 10 /*6df2*/, 11 /*6df3*/, 10 /*6df4*/, 11 /*6df5*/,
    11 /*6df6*/, 12 /*6df7*/, 10 /*6df8*/, 11 /*6df9*/, 11 /*6dfa*/,
    12 /*6dfb*/, 11 /*6dfc*/, 12 /*6dfd*/, 12 /*6dfe*/, 13 /*6dff*/,
    5 /*6e00*/,  6 /*6e01*/,  6 /*6e02*/,  7 /*6e03*/,  6 /*6e04*/,
    7 /*6e05*/,  7 /*6e06*/,  8 /*6e07*/,  6 /*6e08*/,  7 /*6e09*/,
    7 /*6e0a*/,  8 /*6e0b*/,  7 /*6e0c*/,  8 /*6e0d*/,  8 /*6e0e*/,
    9 /*6e0f*/,  6 /*6e10*/,  7 /*6e11*/,  7 /*6e12*/,  8 /*6e13*/,
    7 /*6e14*/,  8 /*6e15*/,  8 /*6e16*/,  9 /*6e17*/,  7 /*6e18*/,
    8 /*6e19*/,  8 /*6e1a*/,  9 /*6e1b*/,  8 /*6e1c*/,  9 /*6e1d*/,
    9 /*6e1e*/,  10 /*6e1f*/, 6 /*6e20*/,  7 /*6e21*/,  7 /*6e22*/,
    8 /*6e23*/,  7 /*6e24*/,  8 /*6e25*/,  8 /*6e26*/,  9 /*6e27*/,
    7 /*6e28*/,  8 /*6e29*/,  8 /*6e2a*/,  9 /*6e2b*/,  8 /*6e2c*/,
    9 /*6e2d*/,  9 /*6e2e*/,  10 /*6e2f*/, 7 /*6e30*/,  8 /*6e31*/,
    8 /*6e32*/,  9 /*6e33*/,  8 /*6e34*/,  9 /*6e35*/,  9 /*6e36*/,
    10 /*6e37*/, 8 /*6e38*/,  9 /*6e39*/,  9 /*6e3a*/,  10 /*6e3b*/,
    9 /*6e3c*/,  10 /*6e3d*/, 10 /*6e3e*/, 11 /*6e3f*/, 6 /*6e40*/,
    7 /*6e41*/,  7 /*6e42*/,  8 /*6e43*/,  7 /*6e44*/,  8 /*6e45*/,
    8 /*6e46*/,  9 /*6e47*/,  7 /*6e48*/,  8 /*6e49*/,  8 /*6e4a*/,
    9 /*6e4b*/,  8 /*6e4c*/,  9 /*6e4d*/,  9 /*6e4e*/,  10 /*6e4f*/,
    7 /*6e50*/,  8 /*6e51*/,  8 /*6e52*/,  9 /*6e53*/,  8 /*6e54*/,
    9 /*6e55*/,  9 /*6e56*/,  10 /*6e57*/, 8 /*6e58*/,  9 /*6e59*/,
    9 /*6e5a*/,  10 /*6e5b*/, 9 /*6e5c*/,  10 /*6e5d*/, 10 /*6e5e*/,
    11 /*6e5f*/, 7 /*6e60*/,  8 /*6e61*/,  8 /*6e62*/,  9 /*6e63*/,
    8 /*6e64*/,  9 /*6e65*/,  9 /*6e66*/,  10 /*6e67*/, 8 /*6e68*/,
    9 /*6e69*/,  9 /*6e6a*/,  10 /*6e6b*/, 9 /*6e6c*/,  10 /*6e6d*/,
    10 /*6e6e*/, 11 /*6e6f*/, 8 /*6e70*/,  9 /*6e71*/,  9 /*6e72*/,
    10 /*6e73*/, 9 /*6e74*/,  10 /*6e75*/, 10 /*6e76*/, 11 /*6e77*/,
    9 /*6e78*/,  10 /*6e79*/, 10 /*6e7a*/, 11 /*6e7b*/, 10 /*6e7c*/,
    11 /*6e7d*/, 11 /*6e7e*/, 12 /*6e7f*/, 6 /*6e80*/,  7 /*6e81*/,
    7 /*6e82*/,  8 /*6e83*/,  7 /*6e84*/,  8 /*6e85*/,  8 /*6e86*/,
    9 /*6e87*/,  7 /*6e88*/,  8 /*6e89*/,  8 /*6e8a*/,  9 /*6e8b*/,
    8 /*6e8c*/,  9 /*6e8d*/,  9 /*6e8e*/,  10 /*6e8f*/, 7 /*6e90*/,
    8 /*6e91*/,  8 /*6e92*/,  9 /*6e93*/,  8 /*6e94*/,  9 /*6e95*/,
    9 /*6e96*/,  10 /*6e97*/, 8 /*6e98*/,  9 /*6e99*/,  9 /*6e9a*/,
    10 /*6e9b*/, 9 /*6e9c*/,  10 /*6e9d*/, 10 /*6e9e*/, 11 /*6e9f*/,
    7 /*6ea0*/,  8 /*6ea1*/,  8 /*6ea2*/,  9 /*6ea3*/,  8 /*6ea4*/,
    9 /*6ea5*/,  9 /*6ea6*/,  10 /*6ea7*/, 8 /*6ea8*/,  9 /*6ea9*/,
    9 /*6eaa*/,  10 /*6eab*/, 9 /*6eac*/,  10 /*6ead*/, 10 /*6eae*/,
    11 /*6eaf*/, 8 /*6eb0*/,  9 /*6eb1*/,  9 /*6eb2*/,  10 /*6eb3*/,
    9 /*6eb4*/,  10 /*6eb5*/, 10 /*6eb6*/, 11 /*6eb7*/, 9 /*6eb8*/,
    10 /*6eb9*/, 10 /*6eba*/, 11 /*6ebb*/, 10 /*6ebc*/, 11 /*6ebd*/,
    11 /*6ebe*/, 12 /*6ebf*/, 7 /*6ec0*/,  8 /*6ec1*/,  8 /*6ec2*/,
    9 /*6ec3*/,  8 /*6ec4*/,  9 /*6ec5*/,  9 /*6ec6*/,  10 /*6ec7*/,
    8 /*6ec8*/,  9 /*6ec9*/,  9 /*6eca*/,  10 /*6ecb*/, 9 /*6ecc*/,
    10 /*6ecd*/, 10 /*6ece*/, 11 /*6ecf*/, 8 /*6ed0*/,  9 /*6ed1*/,
    9 /*6ed2*/,  10 /*6ed3*/, 9 /*6ed4*/,  10 /*6ed5*/, 10 /*6ed6*/,
    11 /*6ed7*/, 9 /*6ed8*/,  10 /*6ed9*/, 10 /*6eda*/, 11 /*6edb*/,
    10 /*6edc*/, 11 /*6edd*/, 11 /*6ede*/, 12 /*6edf*/, 8 /*6ee0*/,
    9 /*6ee1*/,  9 /*6ee2*/,  10 /*6ee3*/, 9 /*6ee4*/,  10 /*6ee5*/,
    10 /*6ee6*/, 11 /*6ee7*/, 9 /*6ee8*/,  10 /*6ee9*/, 10 /*6eea*/,
    11 /*6eeb*/, 10 /*6eec*/, 11 /*6eed*/, 11 /*6eee*/, 12 /*6eef*/,
    9 /*6ef0*/,  10 /*6ef1*/, 10 /*6ef2*/, 11 /*6ef3*/, 10 /*6ef4*/,
    11 /*6ef5*/, 11 /*6ef6*/, 12 /*6ef7*/, 10 /*6ef8*/, 11 /*6ef9*/,
    11 /*6efa*/, 12 /*6efb*/, 11 /*6efc*/, 12 /*6efd*/, 12 /*6efe*/,
    13 /*6eff*/, 6 /*6f00*/,  7 /*6f01*/,  7 /*6f02*/,  8 /*6f03*/,
    7 /*6f04*/,  8 /*6f05*/,  8 /*6f06*/,  9 /*6f07*/,  7 /*6f08*/,
    8 /*6f09*/,  8 /*6f0a*/,  9 /*6f0b*/,  8 /*6f0c*/,  9 /*6f0d*/,
    9 /*6f0e*/,  10 /*6f0f*/, 7 /*6f10*/,  8 /*6f11*/,  8 /*6f12*/,
    9 /*6f13*/,  8 /*6f14*/,  9 /*6f15*/,  9 /*6f16*/,  10 /*6f17*/,
    8 /*6f18*/,  9 /*6f19*/,  9 /*6f1a*/,  10 /*6f1b*/, 9 /*6f1c*/,
    10 /*6f1d*/, 10 /*6f1e*/, 11 /*6f1f*/, 7 /*6f20*/,  8 /*6f21*/,
    8 /*6f22*/,  9 /*6f23*/,  8 /*6f24*/,  9 /*6f25*/,  9 /*6f26*/,
    10 /*6f27*/, 8 /*6f28*/,  9 /*6f29*/,  9 /*6f2a*/,  10 /*6f2b*/,
    9 /*6f2c*/,  10 /*6f2d*/, 10 /*6f2e*/, 11 /*6f2f*/, 8 /*6f30*/,
    9 /*6f31*/,  9 /*6f32*/,  10 /*6f33*/, 9 /*6f34*/,  10 /*6f35*/,
    10 /*6f36*/, 11 /*6f37*/, 9 /*6f38*/,  10 /*6f39*/, 10 /*6f3a*/,
    11 /*6f3b*/, 10 /*6f3c*/, 11 /*6f3d*/, 11 /*6f3e*/, 12 /*6f3f*/,
    7 /*6f40*/,  8 /*6f41*/,  8 /*6f42*/,  9 /*6f43*/,  8 /*6f44*/,
    9 /*6f45*/,  9 /*6f46*/,  10 /*6f47*/, 8 /*6f48*/,  9 /*6f49*/,
    9 /*6f4a*/,  10 /*6f4b*/, 9 /*6f4c*/,  10 /*6f4d*/, 10 /*6f4e*/,
    11 /*6f4f*/, 8 /*6f50*/,  9 /*6f51*/,  9 /*6f52*/,  10 /*6f53*/,
    9 /*6f54*/,  10 /*6f55*/, 10 /*6f56*/, 11 /*6f57*/, 9 /*6f58*/,
    10 /*6f59*/, 10 /*6f5a*/, 11 /*6f5b*/, 10 /*6f5c*/, 11 /*6f5d*/,
    11 /*6f5e*/, 12 /*6f5f*/, 8 /*6f60*/,  9 /*6f61*/,  9 /*6f62*/,
    10 /*6f63*/, 9 /*6f64*/,  10 /*6f65*/, 10 /*6f66*/, 11 /*6f67*/,
    9 /*6f68*/,  10 /*6f69*/, 10 /*6f6a*/, 11 /*6f6b*/, 10 /*6f6c*/,
    11 /*6f6d*/, 11 /*6f6e*/, 12 /*6f6f*/, 9 /*6f70*/,  10 /*6f71*/,
    10 /*6f72*/, 11 /*6f73*/, 10 /*6f74*/, 11 /*6f75*/, 11 /*6f76*/,
    12 /*6f77*/, 10 /*6f78*/, 11 /*6f79*/, 11 /*6f7a*/, 12 /*6f7b*/,
    11 /*6f7c*/, 12 /*6f7d*/, 12 /*6f7e*/, 13 /*6f7f*/, 7 /*6f80*/,
    8 /*6f81*/,  8 /*6f82*/,  9 /*6f83*/,  8 /*6f84*/,  9 /*6f85*/,
    9 /*6f86*/,  10 /*6f87*/, 8 /*6f88*/,  9 /*6f89*/,  9 /*6f8a*/,
    10 /*6f8b*/, 9 /*6f8c*/,  10 /*6f8d*/, 10 /*6f8e*/, 11 /*6f8f*/,
    8 /*6f90*/,  9 /*6f91*/,  9 /*6f92*/,  10 /*6f93*/, 9 /*6f94*/,
    10 /*6f95*/, 10 /*6f96*/, 11 /*6f97*/, 9 /*6f98*/,  10 /*6f99*/,
    10 /*6f9a*/, 11 /*6f9b*/, 10 /*6f9c*/, 11 /*6f9d*/, 11 /*6f9e*/,
    12 /*6f9f*/, 8 /*6fa0*/,  9 /*6fa1*/,  9 /*6fa2*/,  10 /*6fa3*/,
    9 /*6fa4*/,  10 /*6fa5*/, 10 /*6fa6*/, 11 /*6fa7*/, 9 /*6fa8*/,
    10 /*6fa9*/, 10 /*6faa*/, 11 /*6fab*/, 10 /*6fac*/, 11 /*6fad*/,
    11 /*6fae*/, 12 /*6faf*/, 9 /*6fb0*/,  10 /*6fb1*/, 10 /*6fb2*/,
    11 /*6fb3*/, 10 /*6fb4*/, 11 /*6fb5*/, 11 /*6fb6*/, 12 /*6fb7*/,
    10 /*6fb8*/, 11 /*6fb9*/, 11 /*6fba*/, 12 /*6fbb*/, 11 /*6fbc*/,
    12 /*6fbd*/, 12 /*6fbe*/, 13 /*6fbf*/, 8 /*6fc0*/,  9 /*6fc1*/,
    9 /*6fc2*/,  10 /*6fc3*/, 9 /*6fc4*/,  10 /*6fc5*/, 10 /*6fc6*/,
    11 /*6fc7*/, 9 /*6fc8*/,  10 /*6fc9*/, 10 /*6fca*/, 11 /*6fcb*/,
    10 /*6fcc*/, 11 /*6fcd*/, 11 /*6fce*/, 12 /*6fcf*/, 9 /*6fd0*/,
    10 /*6fd1*/, 10 /*6fd2*/, 11 /*6fd3*/, 10 /*6fd4*/, 11 /*6fd5*/,
    11 /*6fd6*/, 12 /*6fd7*/, 10 /*6fd8*/, 11 /*6fd9*/, 11 /*6fda*/,
    12 /*6fdb*/, 11 /*6fdc*/, 12 /*6fdd*/, 12 /*6fde*/, 13 /*6fdf*/,
    9 /*6fe0*/,  10 /*6fe1*/, 10 /*6fe2*/, 11 /*6fe3*/, 10 /*6fe4*/,
    11 /*6fe5*/, 11 /*6fe6*/, 12 /*6fe7*/, 10 /*6fe8*/, 11 /*6fe9*/,
    11 /*6fea*/, 12 /*6feb*/, 11 /*6fec*/, 12 /*6fed*/, 12 /*6fee*/,
    13 /*6fef*/, 10 /*6ff0*/, 11 /*6ff1*/, 11 /*6ff2*/, 12 /*6ff3*/,
    11 /*6ff4*/, 12 /*6ff5*/, 12 /*6ff6*/, 13 /*6ff7*/, 11 /*6ff8*/,
    12 /*6ff9*/, 12 /*6ffa*/, 13 /*6ffb*/, 12 /*6ffc*/, 13 /*6ffd*/,
    13 /*6ffe*/, 14 /*6fff*/, 3 /*7000*/,  4 /*7001*/,  4 /*7002*/,
    5 /*7003*/,  4 /*7004*/,  5 /*7005*/,  5 /*7006*/,  6 /*7007*/,
    4 /*7008*/,  5 /*7009*/,  5 /*700a*/,  6 /*700b*/,  5 /*700c*/,
    6 /*700d*/,  6 /*700e*/,  7 /*700f*/,  4 /*7010*/,  5 /*7011*/,
    5 /*7012*/,  6 /*7013*/,  5 /*7014*/,  6 /*7015*/,  6 /*7016*/,
    7 /*7017*/,  5 /*7018*/,  6 /*7019*/,  6 /*701a*/,  7 /*701b*/,
    6 /*701c*/,  7 /*701d*/,  7 /*701e*/,  8 /*701f*/,  4 /*7020*/,
    5 /*7021*/,  5 /*7022*/,  6 /*7023*/,  5 /*7024*/,  6 /*7025*/,
    6 /*7026*/,  7 /*7027*/,  5 /*7028*/,  6 /*7029*/,  6 /*702a*/,
    7 /*702b*/,  6 /*702c*/,  7 /*702d*/,  7 /*702e*/,  8 /*702f*/,
    5 /*7030*/,  6 /*7031*/,  6 /*7032*/,  7 /*7033*/,  6 /*7034*/,
    7 /*7035*/,  7 /*7036*/,  8 /*7037*/,  6 /*7038*/,  7 /*7039*/,
    7 /*703a*/,  8 /*703b*/,  7 /*703c*/,  8 /*703d*/,  8 /*703e*/,
    9 /*703f*/,  4 /*7040*/,  5 /*7041*/,  5 /*7042*/,  6 /*7043*/,
    5 /*7044*/,  6 /*7045*/,  6 /*7046*/,  7 /*7047*/,  5 /*7048*/,
    6 /*7049*/,  6 /*704a*/,  7 /*704b*/,  6 /*704c*/,  7 /*704d*/,
    7 /*704e*/,  8 /*704f*/,  5 /*7050*/,  6 /*7051*/,  6 /*7052*/,
    7 /*7053*/,  6 /*7054*/,  7 /*7055*/,  7 /*7056*/,  8 /*7057*/,
    6 /*7058*/,  7 /*7059*/,  7 /*705a*/,  8 /*705b*/,  7 /*705c*/,
    8 /*705d*/,  8 /*705e*/,  9 /*705f*/,  5 /*7060*/,  6 /*7061*/,
    6 /*7062*/,  7 /*7063*/,  6 /*7064*/,  7 /*7065*/,  7 /*7066*/,
    8 /*7067*/,  6 /*7068*/,  7 /*7069*/,  7 /*706a*/,  8 /*706b*/,
    7 /*706c*/,  8 /*706d*/,  8 /*706e*/,  9 /*706f*/,  6 /*7070*/,
    7 /*7071*/,  7 /*7072*/,  8 /*7073*/,  7 /*7074*/,  8 /*7075*/,
    8 /*7076*/,  9 /*7077*/,  7 /*7078*/,  8 /*7079*/,  8 /*707a*/,
    9 /*707b*/,  8 /*707c*/,  9 /*707d*/,  9 /*707e*/,  10 /*707f*/,
    4 /*7080*/,  5 /*7081*/,  5 /*7082*/,  6 /*7083*/,  5 /*7084*/,
    6 /*7085*/,  6 /*7086*/,  7 /*7087*/,  5 /*7088*/,  6 /*7089*/,
    6 /*708a*/,  7 /*708b*/,  6 /*708c*/,  7 /*708d*/,  7 /*708e*/,
    8 /*708f*/,  5 /*7090*/,  6 /*7091*/,  6 /*7092*/,  7 /*7093*/,
    6 /*7094*/,  7 /*7095*/,  7 /*7096*/,  8 /*7097*/,  6 /*7098*/,
    7 /*7099*/,  7 /*709a*/,  8 /*709b*/,  7 /*709c*/,  8 /*709d*/,
    8 /*709e*/,  9 /*709f*/,  5 /*70a0*/,  6 /*70a1*/,  6 /*70a2*/,
    7 /*70a3*/,  6 /*70a4*/,  7 /*70a5*/,  7 /*70a6*/,  8 /*70a7*/,
    6 /*70a8*/,  7 /*70a9*/,  7 /*70aa*/,  8 /*70ab*/,  7 /*70ac*/,
    8 /*70ad*/,  8 /*70ae*/,  9 /*70af*/,  6 /*70b0*/,  7 /*70b1*/,
    7 /*70b2*/,  8 /*70b3*/,  7 /*70b4*/,  8 /*70b5*/,  8 /*70b6*/,
    9 /*70b7*/,  7 /*70b8*/,  8 /*70b9*/,  8 /*70ba*/,  9 /*70bb*/,
    8 /*70bc*/,  9 /*70bd*/,  9 /*70be*/,  10 /*70bf*/, 5 /*70c0*/,
    6 /*70c1*/,  6 /*70c2*/,  7 /*70c3*/,  6 /*70c4*/,  7 /*70c5*/,
    7 /*70c6*/,  8 /*70c7*/,  6 /*70c8*/,  7 /*70c9*/,  7 /*70ca*/,
    8 /*70cb*/,  7 /*70cc*/,  8 /*70cd*/,  8 /*70ce*/,  9 /*70cf*/,
    6 /*70d0*/,  7 /*70d1*/,  7 /*70d2*/,  8 /*70d3*/,  7 /*70d4*/,
    8 /*70d5*/,  8 /*70d6*/,  9 /*70d7*/,  7 /*70d8*/,  8 /*70d9*/,
    8 /*70da*/,  9 /*70db*/,  8 /*70dc*/,  9 /*70dd*/,  9 /*70de*/,
    10 /*70df*/, 6 /*70e0*/,  7 /*70e1*/,  7 /*70e2*/,  8 /*70e3*/,
    7 /*70e4*/,  8 /*70e5*/,  8 /*70e6*/,  9 /*70e7*/,  7 /*70e8*/,
    8 /*70e9*/,  8 /*70ea*/,  9 /*70eb*/,  8 /*70ec*/,  9 /*70ed*/,
    9 /*70ee*/,  10 /*70ef*/, 7 /*70f0*/,  8 /*70f1*/,  8 /*70f2*/,
    9 /*70f3*/,  8 /*70f4*/,  9 /*70f5*/,  9 /*70f6*/,  10 /*70f7*/,
    8 /*70f8*/,  9 /*70f9*/,  9 /*70fa*/,  10 /*70fb*/, 9 /*70fc*/,
    10 /*70fd*/, 10 /*70fe*/, 11 /*70ff*/, 4 /*7100*/,  5 /*7101*/,
    5 /*7102*/,  6 /*7103*/,  5 /*7104*/,  6 /*7105*/,  6 /*7106*/,
    7 /*7107*/,  5 /*7108*/,  6 /*7109*/,  6 /*710a*/,  7 /*710b*/,
    6 /*710c*/,  7 /*710d*/,  7 /*710e*/,  8 /*710f*/,  5 /*7110*/,
    6 /*7111*/,  6 /*7112*/,  7 /*7113*/,  6 /*7114*/,  7 /*7115*/,
    7 /*7116*/,  8 /*7117*/,  6 /*7118*/,  7 /*7119*/,  7 /*711a*/,
    8 /*711b*/,  7 /*711c*/,  8 /*711d*/,  8 /*711e*/,  9 /*711f*/,
    5 /*7120*/,  6 /*7121*/,  6 /*7122*/,  7 /*7123*/,  6 /*7124*/,
    7 /*7125*/,  7 /*7126*/,  8 /*7127*/,  6 /*7128*/,  7 /*7129*/,
    7 /*712a*/,  8 /*712b*/,  7 /*712c*/,  8 /*712d*/,  8 /*712e*/,
    9 /*712f*/,  6 /*7130*/,  7 /*7131*/,  7 /*7132*/,  8 /*7133*/,
    7 /*7134*/,  8 /*7135*/,  8 /*7136*/,  9 /*7137*/,  7 /*7138*/,
    8 /*7139*/,  8 /*713a*/,  9 /*713b*/,  8 /*713c*/,  9 /*713d*/,
    9 /*713e*/,  10 /*713f*/, 5 /*7140*/,  6 /*7141*/,  6 /*7142*/,
    7 /*7143*/,  6 /*7144*/,  7 /*7145*/,  7 /*7146*/,  8 /*7147*/,
    6 /*7148*/,  7 /*7149*/,  7 /*714a*/,  8 /*714b*/,  7 /*714c*/,
    8 /*714d*/,  8 /*714e*/,  9 /*714f*/,  6 /*7150*/,  7 /*7151*/,
    7 /*7152*/,  8 /*7153*/,  7 /*7154*/,  8 /*7155*/,  8 /*7156*/,
    9 /*7157*/,  7 /*7158*/,  8 /*7159*/,  8 /*715a*/,  9 /*715b*/,
    8 /*715c*/,  9 /*715d*/,  9 /*715e*/,  10 /*715f*/, 6 /*7160*/,
    7 /*7161*/,  7 /*7162*/,  8 /*7163*/,  7 /*7164*/,  8 /*7165*/,
    8 /*7166*/,  9 /*7167*/,  7 /*7168*/,  8 /*7169*/,  8 /*716a*/,
    9 /*716b*/,  8 /*716c*/,  9 /*716d*/,  9 /*716e*/,  10 /*716f*/,
    7 /*7170*/,  8 /*7171*/,  8 /*7172*/,  9 /*7173*/,  8 /*7174*/,
    9 /*7175*/,  9 /*7176*/,  10 /*7177*/, 8 /*7178*/,  9 /*7179*/,
    9 /*717a*/,  10 /*717b*/, 9 /*717c*/,  10 /*717d*/, 10 /*717e*/,
    11 /*717f*/, 5 /*7180*/,  6 /*7181*/,  6 /*7182*/,  7 /*7183*/,
    6 /*7184*/,  7 /*7185*/,  7 /*7186*/,  8 /*7187*/,  6 /*7188*/,
    7 /*7189*/,  7 /*718a*/,  8 /*718b*/,  7 /*718c*/,  8 /*718d*/,
    8 /*718e*/,  9 /*718f*/,  6 /*7190*/,  7 /*7191*/,  7 /*7192*/,
    8 /*7193*/,  7 /*7194*/,  8 /*7195*/,  8 /*7196*/,  9 /*7197*/,
    7 /*7198*/,  8 /*7199*/,  8 /*719a*/,  9 /*719b*/,  8 /*719c*/,
    9 /*719d*/,  9 /*719e*/,  10 /*719f*/, 6 /*71a0*/,  7 /*71a1*/,
    7 /*71a2*/,  8 /*71a3*/,  7 /*71a4*/,  8 /*71a5*/,  8 /*71a6*/,
    9 /*71a7*/,  7 /*71a8*/,  8 /*71a9*/,  8 /*71aa*/,  9 /*71ab*/,
    8 /*71ac*/,  9 /*71ad*/,  9 /*71ae*/,  10 /*71af*/, 7 /*71b0*/,
    8 /*71b1*/,  8 /*71b2*/,  9 /*71b3*/,  8 /*71b4*/,  9 /*71b5*/,
    9 /*71b6*/,  10 /*71b7*/, 8 /*71b8*/,  9 /*71b9*/,  9 /*71ba*/,
    10 /*71bb*/, 9 /*71bc*/,  10 /*71bd*/, 10 /*71be*/, 11 /*71bf*/,
    6 /*71c0*/,  7 /*71c1*/,  7 /*71c2*/,  8 /*71c3*/,  7 /*71c4*/,
    8 /*71c5*/,  8 /*71c6*/,  9 /*71c7*/,  7 /*71c8*/,  8 /*71c9*/,
    8 /*71ca*/,  9 /*71cb*/,  8 /*71cc*/,  9 /*71cd*/,  9 /*71ce*/,
    10 /*71cf*/, 7 /*71d0*/,  8 /*71d1*/,  8 /*71d2*/,  9 /*71d3*/,
    8 /*71d4*/,  9 /*71d5*/,  9 /*71d6*/,  10 /*71d7*/, 8 /*71d8*/,
    9 /*71d9*/,  9 /*71da*/,  10 /*71db*/, 9 /*71dc*/,  10 /*71dd*/,
    10 /*71de*/, 11 /*71df*/, 7 /*71e0*/,  8 /*71e1*/,  8 /*71e2*/,
    9 /*71e3*/,  8 /*71e4*/,  9 /*71e5*/,  9 /*71e6*/,  10 /*71e7*/,
    8 /*71e8*/,  9 /*71e9*/,  9 /*71ea*/,  10 /*71eb*/, 9 /*71ec*/,
    10 /*71ed*/, 10 /*71ee*/, 11 /*71ef*/, 8 /*71f0*/,  9 /*71f1*/,
    9 /*71f2*/,  10 /*71f3*/, 9 /*71f4*/,  10 /*71f5*/, 10 /*71f6*/,
    11 /*71f7*/, 9 /*71f8*/,  10 /*71f9*/, 10 /*71fa*/, 11 /*71fb*/,
    10 /*71fc*/, 11 /*71fd*/, 11 /*71fe*/, 12 /*71ff*/, 4 /*7200*/,
    5 /*7201*/,  5 /*7202*/,  6 /*7203*/,  5 /*7204*/,  6 /*7205*/,
    6 /*7206*/,  7 /*7207*/,  5 /*7208*/,  6 /*7209*/,  6 /*720a*/,
    7 /*720b*/,  6 /*720c*/,  7 /*720d*/,  7 /*720e*/,  8 /*720f*/,
    5 /*7210*/,  6 /*7211*/,  6 /*7212*/,  7 /*7213*/,  6 /*7214*/,
    7 /*7215*/,  7 /*7216*/,  8 /*7217*/,  6 /*7218*/,  7 /*7219*/,
    7 /*721a*/,  8 /*721b*/,  7 /*721c*/,  8 /*721d*/,  8 /*721e*/,
    9 /*721f*/,  5 /*7220*/,  6 /*7221*/,  6 /*7222*/,  7 /*7223*/,
    6 /*7224*/,  7 /*7225*/,  7 /*7226*/,  8 /*7227*/,  6 /*7228*/,
    7 /*7229*/,  7 /*722a*/,  8 /*722b*/,  7 /*722c*/,  8 /*722d*/,
    8 /*722e*/,  9 /*722f*/,  6 /*7230*/,  7 /*7231*/,  7 /*7232*/,
    8 /*7233*/,  7 /*7234*/,  8 /*7235*/,  8 /*7236*/,  9 /*7237*/,
    7 /*7238*/,  8 /*7239*/,  8 /*723a*/,  9 /*723b*/,  8 /*723c*/,
    9 /*723d*/,  9 /*723e*/,  10 /*723f*/, 5 /*7240*/,  6 /*7241*/,
    6 /*7242*/,  7 /*7243*/,  6 /*7244*/,  7 /*7245*/,  7 /*7246*/,
    8 /*7247*/,  6 /*7248*/,  7 /*7249*/,  7 /*724a*/,  8 /*724b*/,
    7 /*724c*/,  8 /*724d*/,  8 /*724e*/,  9 /*724f*/,  6 /*7250*/,
    7 /*7251*/,  7 /*7252*/,  8 /*7253*/,  7 /*7254*/,  8 /*7255*/,
    8 /*7256*/,  9 /*7257*/,  7 /*7258*/,  8 /*7259*/,  8 /*725a*/,
    9 /*725b*/,  8 /*725c*/,  9 /*725d*/,  9 /*725e*/,  10 /*725f*/,
    6 /*7260*/,  7 /*7261*/,  7 /*7262*/,  8 /*7263*/,  7 /*7264*/,
    8 /*7265*/,  8 /*7266*/,  9 /*7267*/,  7 /*7268*/,  8 /*7269*/,
    8 /*726a*/,  9 /*726b*/,  8 /*726c*/,  9 /*726d*/,  9 /*726e*/,
    10 /*726f*/, 7 /*7270*/,  8 /*7271*/,  8 /*7272*/,  9 /*7273*/,
    8 /*7274*/,  9 /*7275*/,  9 /*7276*/,  10 /*7277*/, 8 /*7278*/,
    9 /*7279*/,  9 /*727a*/,  10 /*727b*/, 9 /*727c*/,  10 /*727d*/,
    10 /*727e*/, 11 /*727f*/, 5 /*7280*/,  6 /*7281*/,  6 /*7282*/,
    7 /*7283*/,  6 /*7284*/,  7 /*7285*/,  7 /*7286*/,  8 /*7287*/,
    6 /*7288*/,  7 /*7289*/,  7 /*728a*/,  8 /*728b*/,  7 /*728c*/,
    8 /*728d*/,  8 /*728e*/,  9 /*728f*/,  6 /*7290*/,  7 /*7291*/,
    7 /*7292*/,  8 /*7293*/,  7 /*7294*/,  8 /*7295*/,  8 /*7296*/,
    9 /*7297*/,  7 /*7298*/,  8 /*7299*/,  8 /*729a*/,  9 /*729b*/,
    8 /*729c*/,  9 /*729d*/,  9 /*729e*/,  10 /*729f*/, 6 /*72a0*/,
    7 /*72a1*/,  7 /*72a2*/,  8 /*72a3*/,  7 /*72a4*/,  8 /*72a5*/,
    8 /*72a6*/,  9 /*72a7*/,  7 /*72a8*/,  8 /*72a9*/,  8 /*72aa*/,
    9 /*72ab*/,  8 /*72ac*/,  9 /*72ad*/,  9 /*72ae*/,  10 /*72af*/,
    7 /*72b0*/,  8 /*72b1*/,  8 /*72b2*/,  9 /*72b3*/,  8 /*72b4*/,
    9 /*72b5*/,  9 /*72b6*/,  10 /*72b7*/, 8 /*72b8*/,  9 /*72b9*/,
    9 /*72ba*/,  10 /*72bb*/, 9 /*72bc*/,  10 /*72bd*/, 10 /*72be*/,
    11 /*72bf*/, 6 /*72c0*/,  7 /*72c1*/,  7 /*72c2*/,  8 /*72c3*/,
    7 /*72c4*/,  8 /*72c5*/,  8 /*72c6*/,  9 /*72c7*/,  7 /*72c8*/,
    8 /*72c9*/,  8 /*72ca*/,  9 /*72cb*/,  8 /*72cc*/,  9 /*72cd*/,
    9 /*72ce*/,  10 /*72cf*/, 7 /*72d0*/,  8 /*72d1*/,  8 /*72d2*/,
    9 /*72d3*/,  8 /*72d4*/,  9 /*72d5*/,  9 /*72d6*/,  10 /*72d7*/,
    8 /*72d8*/,  9 /*72d9*/,  9 /*72da*/,  10 /*72db*/, 9 /*72dc*/,
    10 /*72dd*/, 10 /*72de*/, 11 /*72df*/, 7 /*72e0*/,  8 /*72e1*/,
    8 /*72e2*/,  9 /*72e3*/,  8 /*72e4*/,  9 /*72e5*/,  9 /*72e6*/,
    10 /*72e7*/, 8 /*72e8*/,  9 /*72e9*/,  9 /*72ea*/,  10 /*72eb*/,
    9 /*72ec*/,  10 /*72ed*/, 10 /*72ee*/, 11 /*72ef*/, 8 /*72f0*/,
    9 /*72f1*/,  9 /*72f2*/,  10 /*72f3*/, 9 /*72f4*/,  10 /*72f5*/,
    10 /*72f6*/, 11 /*72f7*/, 9 /*72f8*/,  10 /*72f9*/, 10 /*72fa*/,
    11 /*72fb*/, 10 /*72fc*/, 11 /*72fd*/, 11 /*72fe*/, 12 /*72ff*/,
    5 /*7300*/,  6 /*7301*/,  6 /*7302*/,  7 /*7303*/,  6 /*7304*/,
    7 /*7305*/,  7 /*7306*/,  8 /*7307*/,  6 /*7308*/,  7 /*7309*/,
    7 /*730a*/,  8 /*730b*/,  7 /*730c*/,  8 /*730d*/,  8 /*730e*/,
    9 /*730f*/,  6 /*7310*/,  7 /*7311*/,  7 /*7312*/,  8 /*7313*/,
    7 /*7314*/,  8 /*7315*/,  8 /*7316*/,  9 /*7317*/,  7 /*7318*/,
    8 /*7319*/,  8 /*731a*/,  9 /*731b*/,  8 /*731c*/,  9 /*731d*/,
    9 /*731e*/,  10 /*731f*/, 6 /*7320*/,  7 /*7321*/,  7 /*7322*/,
    8 /*7323*/,  7 /*7324*/,  8 /*7325*/,  8 /*7326*/,  9 /*7327*/,
    7 /*7328*/,  8 /*7329*/,  8 /*732a*/,  9 /*732b*/,  8 /*732c*/,
    9 /*732d*/,  9 /*732e*/,  10 /*732f*/, 7 /*7330*/,  8 /*7331*/,
    8 /*7332*/,  9 /*7333*/,  8 /*7334*/,  9 /*7335*/,  9 /*7336*/,
    10 /*7337*/, 8 /*7338*/,  9 /*7339*/,  9 /*733a*/,  10 /*733b*/,
    9 /*733c*/,  10 /*733d*/, 10 /*733e*/, 11 /*733f*/, 6 /*7340*/,
    7 /*7341*/,  7 /*7342*/,  8 /*7343*/,  7 /*7344*/,  8 /*7345*/,
    8 /*7346*/,  9 /*7347*/,  7 /*7348*/,  8 /*7349*/,  8 /*734a*/,
    9 /*734b*/,  8 /*734c*/,  9 /*734d*/,  9 /*734e*/,  10 /*734f*/,
    7 /*7350*/,  8 /*7351*/,  8 /*7352*/,  9 /*7353*/,  8 /*7354*/,
    9 /*7355*/,  9 /*7356*/,  10 /*7357*/, 8 /*7358*/,  9 /*7359*/,
    9 /*735a*/,  10 /*735b*/, 9 /*735c*/,  10 /*735d*/, 10 /*735e*/,
    11 /*735f*/, 7 /*7360*/,  8 /*7361*/,  8 /*7362*/,  9 /*7363*/,
    8 /*7364*/,  9 /*7365*/,  9 /*7366*/,  10 /*7367*/, 8 /*7368*/,
    9 /*7369*/,  9 /*736a*/,  10 /*736b*/, 9 /*736c*/,  10 /*736d*/,
    10 /*736e*/, 11 /*736f*/, 8 /*7370*/,  9 /*7371*/,  9 /*7372*/,
    10 /*7373*/, 9 /*7374*/,  10 /*7375*/, 10 /*7376*/, 11 /*7377*/,
    9 /*7378*/,  10 /*7379*/, 10 /*737a*/, 11 /*737b*/, 10 /*737c*/,
    11 /*737d*/, 11 /*737e*/, 12 /*737f*/, 6 /*7380*/,  7 /*7381*/,
    7 /*7382*/,  8 /*7383*/,  7 /*7384*/,  8 /*7385*/,  8 /*7386*/,
    9 /*7387*/,  7 /*7388*/,  8 /*7389*/,  8 /*738a*/,  9 /*738b*/,
    8 /*738c*/,  9 /*738d*/,  9 /*738e*/,  10 /*738f*/, 7 /*7390*/,
    8 /*7391*/,  8 /*7392*/,  9 /*7393*/,  8 /*7394*/,  9 /*7395*/,
    9 /*7396*/,  10 /*7397*/, 8 /*7398*/,  9 /*7399*/,  9 /*739a*/,
    10 /*739b*/, 9 /*739c*/,  10 /*739d*/, 10 /*739e*/, 11 /*739f*/,
    7 /*73a0*/,  8 /*73a1*/,  8 /*73a2*/,  9 /*73a3*/,  8 /*73a4*/,
    9 /*73a5*/,  9 /*73a6*/,  10 /*73a7*/, 8 /*73a8*/,  9 /*73a9*/,
    9 /*73aa*/,  10 /*73ab*/, 9 /*73ac*/,  10 /*73ad*/, 10 /*73ae*/,
    11 /*73af*/, 8 /*73b0*/,  9 /*73b1*/,  9 /*73b2*/,  10 /*73b3*/,
    9 /*73b4*/,  10 /*73b5*/, 10 /*73b6*/, 11 /*73b7*/, 9 /*73b8*/,
    10 /*73b9*/, 10 /*73ba*/, 11 /*73bb*/, 10 /*73bc*/, 11 /*73bd*/,
    11 /*73be*/, 12 /*73bf*/, 7 /*73c0*/,  8 /*73c1*/,  8 /*73c2*/,
    9 /*73c3*/,  8 /*73c4*/,  9 /*73c5*/,  9 /*73c6*/,  10 /*73c7*/,
    8 /*73c8*/,  9 /*73c9*/,  9 /*73ca*/,  10 /*73cb*/, 9 /*73cc*/,
    10 /*73cd*/, 10 /*73ce*/, 11 /*73cf*/, 8 /*73d0*/,  9 /*73d1*/,
    9 /*73d2*/,  10 /*73d3*/, 9 /*73d4*/,  10 /*73d5*/, 10 /*73d6*/,
    11 /*73d7*/, 9 /*73d8*/,  10 /*73d9*/, 10 /*73da*/, 11 /*73db*/,
    10 /*73dc*/, 11 /*73dd*/, 11 /*73de*/, 12 /*73df*/, 8 /*73e0*/,
    9 /*73e1*/,  9 /*73e2*/,  10 /*73e3*/, 9 /*73e4*/,  10 /*73e5*/,
    10 /*73e6*/, 11 /*73e7*/, 9 /*73e8*/,  10 /*73e9*/, 10 /*73ea*/,
    11 /*73eb*/, 10 /*73ec*/, 11 /*73ed*/, 11 /*73ee*/, 12 /*73ef*/,
    9 /*73f0*/,  10 /*73f1*/, 10 /*73f2*/, 11 /*73f3*/, 10 /*73f4*/,
    11 /*73f5*/, 11 /*73f6*/, 12 /*73f7*/, 10 /*73f8*/, 11 /*73f9*/,
    11 /*73fa*/, 12 /*73fb*/, 11 /*73fc*/, 12 /*73fd*/, 12 /*73fe*/,
    13 /*73ff*/, 4 /*7400*/,  5 /*7401*/,  5 /*7402*/,  6 /*7403*/,
    5 /*7404*/,  6 /*7405*/,  6 /*7406*/,  7 /*7407*/,  5 /*7408*/,
    6 /*7409*/,  6 /*740a*/,  7 /*740b*/,  6 /*740c*/,  7 /*740d*/,
    7 /*740e*/,  8 /*740f*/,  5 /*7410*/,  6 /*7411*/,  6 /*7412*/,
    7 /*7413*/,  6 /*7414*/,  7 /*7415*/,  7 /*7416*/,  8 /*7417*/,
    6 /*7418*/,  7 /*7419*/,  7 /*741a*/,  8 /*741b*/,  7 /*741c*/,
    8 /*741d*/,  8 /*741e*/,  9 /*741f*/,  5 /*7420*/,  6 /*7421*/,
    6 /*7422*/,  7 /*7423*/,  6 /*7424*/,  7 /*7425*/,  7 /*7426*/,
    8 /*7427*/,  6 /*7428*/,  7 /*7429*/,  7 /*742a*/,  8 /*742b*/,
    7 /*742c*/,  8 /*742d*/,  8 /*742e*/,  9 /*742f*/,  6 /*7430*/,
    7 /*7431*/,  7 /*7432*/,  8 /*7433*/,  7 /*7434*/,  8 /*7435*/,
    8 /*7436*/,  9 /*7437*/,  7 /*7438*/,  8 /*7439*/,  8 /*743a*/,
    9 /*743b*/,  8 /*743c*/,  9 /*743d*/,  9 /*743e*/,  10 /*743f*/,
    5 /*7440*/,  6 /*7441*/,  6 /*7442*/,  7 /*7443*/,  6 /*7444*/,
    7 /*7445*/,  7 /*7446*/,  8 /*7447*/,  6 /*7448*/,  7 /*7449*/,
    7 /*744a*/,  8 /*744b*/,  7 /*744c*/,  8 /*744d*/,  8 /*744e*/,
    9 /*744f*/,  6 /*7450*/,  7 /*7451*/,  7 /*7452*/,  8 /*7453*/,
    7 /*7454*/,  8 /*7455*/,  8 /*7456*/,  9 /*7457*/,  7 /*7458*/,
    8 /*7459*/,  8 /*745a*/,  9 /*745b*/,  8 /*745c*/,  9 /*745d*/,
    9 /*745e*/,  10 /*745f*/, 6 /*7460*/,  7 /*7461*/,  7 /*7462*/,
    8 /*7463*/,  7 /*7464*/,  8 /*7465*/,  8 /*7466*/,  9 /*7467*/,
    7 /*7468*/,  8 /*7469*/,  8 /*746a*/,  9 /*746b*/,  8 /*746c*/,
    9 /*746d*/,  9 /*746e*/,  10 /*746f*/, 7 /*7470*/,  8 /*7471*/,
    8 /*7472*/,  9 /*7473*/,  8 /*7474*/,  9 /*7475*/,  9 /*7476*/,
    10 /*7477*/, 8 /*7478*/,  9 /*7479*/,  9 /*747a*/,  10 /*747b*/,
    9 /*747c*/,  10 /*747d*/, 10 /*747e*/, 11 /*747f*/, 5 /*7480*/,
    6 /*7481*/,  6 /*7482*/,  7 /*7483*/,  6 /*7484*/,  7 /*7485*/,
    7 /*7486*/,  8 /*7487*/,  6 /*7488*/,  7 /*7489*/,  7 /*748a*/,
    8 /*748b*/,  7 /*748c*/,  8 /*748d*/,  8 /*748e*/,  9 /*748f*/,
    6 /*7490*/,  7 /*7491*/,  7 /*7492*/,  8 /*7493*/,  7 /*7494*/,
    8 /*7495*/,  8 /*7496*/,  9 /*7497*/,  7 /*7498*/,  8 /*7499*/,
    8 /*749a*/,  9 /*749b*/,  8 /*749c*/,  9 /*749d*/,  9 /*749e*/,
    10 /*749f*/, 6 /*74a0*/,  7 /*74a1*/,  7 /*74a2*/,  8 /*74a3*/,
    7 /*74a4*/,  8 /*74a5*/,  8 /*74a6*/,  9 /*74a7*/,  7 /*74a8*/,
    8 /*74a9*/,  8 /*74aa*/,  9 /*74ab*/,  8 /*74ac*/,  9 /*74ad*/,
    9 /*74ae*/,  10 /*74af*/, 7 /*74b0*/,  8 /*74b1*/,  8 /*74b2*/,
    9 /*74b3*/,  8 /*74b4*/,  9 /*74b5*/,  9 /*74b6*/,  10 /*74b7*/,
    8 /*74b8*/,  9 /*74b9*/,  9 /*74ba*/,  10 /*74bb*/, 9 /*74bc*/,
    10 /*74bd*/, 10 /*74be*/, 11 /*74bf*/, 6 /*74c0*/,  7 /*74c1*/,
    7 /*74c2*/,  8 /*74c3*/,  7 /*74c4*/,  8 /*74c5*/,  8 /*74c6*/,
    9 /*74c7*/,  7 /*74c8*/,  8 /*74c9*/,  8 /*74ca*/,  9 /*74cb*/,
    8 /*74cc*/,  9 /*74cd*/,  9 /*74ce*/,  10 /*74cf*/, 7 /*74d0*/,
    8 /*74d1*/,  8 /*74d2*/,  9 /*74d3*/,  8 /*74d4*/,  9 /*74d5*/,
    9 /*74d6*/,  10 /*74d7*/, 8 /*74d8*/,  9 /*74d9*/,  9 /*74da*/,
    10 /*74db*/, 9 /*74dc*/,  10 /*74dd*/, 10 /*74de*/, 11 /*74df*/,
    7 /*74e0*/,  8 /*74e1*/,  8 /*74e2*/,  9 /*74e3*/,  8 /*74e4*/,
    9 /*74e5*/,  9 /*74e6*/,  10 /*74e7*/, 8 /*74e8*/,  9 /*74e9*/,
    9 /*74ea*/,  10 /*74eb*/, 9 /*74ec*/,  10 /*74ed*/, 10 /*74ee*/,
    11 /*74ef*/, 8 /*74f0*/,  9 /*74f1*/,  9 /*74f2*/,  10 /*74f3*/,
    9 /*74f4*/,  10 /*74f5*/, 10 /*74f6*/, 11 /*74f7*/, 9 /*74f8*/,
    10 /*74f9*/, 10 /*74fa*/, 11 /*74fb*/, 10 /*74fc*/, 11 /*74fd*/,
    11 /*74fe*/, 12 /*74ff*/, 5 /*7500*/,  6 /*7501*/,  6 /*7502*/,
    7 /*7503*/,  6 /*7504*/,  7 /*7505*/,  7 /*7506*/,  8 /*7507*/,
    6 /*7508*/,  7 /*7509*/,  7 /*750a*/,  8 /*750b*/,  7 /*750c*/,
    8 /*750d*/,  8 /*750e*/,  9 /*750f*/,  6 /*7510*/,  7 /*7511*/,
    7 /*7512*/,  8 /*7513*/,  7 /*7514*/,  8 /*7515*/,  8 /*7516*/,
    9 /*7517*/,  7 /*7518*/,  8 /*7519*/,  8 /*751a*/,  9 /*751b*/,
    8 /*751c*/,  9 /*751d*/,  9 /*751e*/,  10 /*751f*/, 6 /*7520*/,
    7 /*7521*/,  7 /*7522*/,  8 /*7523*/,  7 /*7524*/,  8 /*7525*/,
    8 /*7526*/,  9 /*7527*/,  7 /*7528*/,  8 /*7529*/,  8 /*752a*/,
    9 /*752b*/,  8 /*752c*/,  9 /*752d*/,  9 /*752e*/,  10 /*752f*/,
    7 /*7530*/,  8 /*7531*/,  8 /*7532*/,  9 /*7533*/,  8 /*7534*/,
    9 /*7535*/,  9 /*7536*/,  10 /*7537*/, 8 /*7538*/,  9 /*7539*/,
    9 /*753a*/,  10 /*753b*/, 9 /*753c*/,  10 /*753d*/, 10 /*753e*/,
    11 /*753f*/, 6 /*7540*/,  7 /*7541*/,  7 /*7542*/,  8 /*7543*/,
    7 /*7544*/,  8 /*7545*/,  8 /*7546*/,  9 /*7547*/,  7 /*7548*/,
    8 /*7549*/,  8 /*754a*/,  9 /*754b*/,  8 /*754c*/,  9 /*754d*/,
    9 /*754e*/,  10 /*754f*/, 7 /*7550*/,  8 /*7551*/,  8 /*7552*/,
    9 /*7553*/,  8 /*7554*/,  9 /*7555*/,  9 /*7556*/,  10 /*7557*/,
    8 /*7558*/,  9 /*7559*/,  9 /*755a*/,  10 /*755b*/, 9 /*755c*/,
    10 /*755d*/, 10 /*755e*/, 11 /*755f*/, 7 /*7560*/,  8 /*7561*/,
    8 /*7562*/,  9 /*7563*/,  8 /*7564*/,  9 /*7565*/,  9 /*7566*/,
    10 /*7567*/, 8 /*7568*/,  9 /*7569*/,  9 /*756a*/,  10 /*756b*/,
    9 /*756c*/,  10 /*756d*/, 10 /*756e*/, 11 /*756f*/, 8 /*7570*/,
    9 /*7571*/,  9 /*7572*/,  10 /*7573*/, 9 /*7574*/,  10 /*7575*/,
    10 /*7576*/, 11 /*7577*/, 9 /*7578*/,  10 /*7579*/, 10 /*757a*/,
    11 /*757b*/, 10 /*757c*/, 11 /*757d*/, 11 /*757e*/, 12 /*757f*/,
    6 /*7580*/,  7 /*7581*/,  7 /*7582*/,  8 /*7583*/,  7 /*7584*/,
    8 /*7585*/,  8 /*7586*/,  9 /*7587*/,  7 /*7588*/,  8 /*7589*/,
    8 /*758a*/,  9 /*758b*/,  8 /*758c*/,  9 /*758d*/,  9 /*758e*/,
    10 /*758f*/, 7 /*7590*/,  8 /*7591*/,  8 /*7592*/,  9 /*7593*/,
    8 /*7594*/,  9 /*7595*/,  9 /*7596*/,  10 /*7597*/, 8 /*7598*/,
    9 /*7599*/,  9 /*759a*/,  10 /*759b*/, 9 /*759c*/,  10 /*759d*/,
    10 /*759e*/, 11 /*759f*/, 7 /*75a0*/,  8 /*75a1*/,  8 /*75a2*/,
    9 /*75a3*/,  8 /*75a4*/,  9 /*75a5*/,  9 /*75a6*/,  10 /*75a7*/,
    8 /*75a8*/,  9 /*75a9*/,  9 /*75aa*/,  10 /*75ab*/, 9 /*75ac*/,
    10 /*75ad*/, 10 /*75ae*/, 11 /*75af*/, 8 /*75b0*/,  9 /*75b1*/,
    9 /*75b2*/,  10 /*75b3*/, 9 /*75b4*/,  10 /*75b5*/, 10 /*75b6*/,
    11 /*75b7*/, 9 /*75b8*/,  10 /*75b9*/, 10 /*75ba*/, 11 /*75bb*/,
    10 /*75bc*/, 11 /*75bd*/, 11 /*75be*/, 12 /*75bf*/, 7 /*75c0*/,
    8 /*75c1*/,  8 /*75c2*/,  9 /*75c3*/,  8 /*75c4*/,  9 /*75c5*/,
    9 /*75c6*/,  10 /*75c7*/, 8 /*75c8*/,  9 /*75c9*/,  9 /*75ca*/,
    10 /*75cb*/, 9 /*75cc*/,  10 /*75cd*/, 10 /*75ce*/, 11 /*75cf*/,
    8 /*75d0*/,  9 /*75d1*/,  9 /*75d2*/,  10 /*75d3*/, 9 /*75d4*/,
    10 /*75d5*/, 10 /*75d6*/, 11 /*75d7*/, 9 /*75d8*/,  10 /*75d9*/,
    10 /*75da*/, 11 /*75db*/, 10 /*75dc*/, 11 /*75dd*/, 11 /*75de*/,
    12 /*75df*/, 8 /*75e0*/,  9 /*75e1*/,  9 /*75e2*/,  10 /*75e3*/,
    9 /*75e4*/,  10 /*75e5*/, 10 /*75e6*/, 11 /*75e7*/, 9 /*75e8*/,
    10 /*75e9*/, 10 /*75ea*/, 11 /*75eb*/, 10 /*75ec*/, 11 /*75ed*/,
    11 /*75ee*/, 12 /*75ef*/, 9 /*75f0*/,  10 /*75f1*/, 10 /*75f2*/,
    11 /*75f3*/, 10 /*75f4*/, 11 /*75f5*/, 11 /*75f6*/, 12 /*75f7*/,
    10 /*75f8*/, 11 /*75f9*/, 11 /*75fa*/, 12 /*75fb*/, 11 /*75fc*/,
    12 /*75fd*/, 12 /*75fe*/, 13 /*75ff*/, 5 /*7600*/,  6 /*7601*/,
    6 /*7602*/,  7 /*7603*/,  6 /*7604*/,  7 /*7605*/,  7 /*7606*/,
    8 /*7607*/,  6 /*7608*/,  7 /*7609*/,  7 /*760a*/,  8 /*760b*/,
    7 /*760c*/,  8 /*760d*/,  8 /*760e*/,  9 /*760f*/,  6 /*7610*/,
    7 /*7611*/,  7 /*7612*/,  8 /*7613*/,  7 /*7614*/,  8 /*7615*/,
    8 /*7616*/,  9 /*7617*/,  7 /*7618*/,  8 /*7619*/,  8 /*761a*/,
    9 /*761b*/,  8 /*761c*/,  9 /*761d*/,  9 /*761e*/,  10 /*761f*/,
    6 /*7620*/,  7 /*7621*/,  7 /*7622*/,  8 /*7623*/,  7 /*7624*/,
    8 /*7625*/,  8 /*7626*/,  9 /*7627*/,  7 /*7628*/,  8 /*7629*/,
    8 /*762a*/,  9 /*762b*/,  8 /*762c*/,  9 /*762d*/,  9 /*762e*/,
    10 /*762f*/, 7 /*7630*/,  8 /*7631*/,  8 /*7632*/,  9 /*7633*/,
    8 /*7634*/,  9 /*7635*/,  9 /*7636*/,  10 /*7637*/, 8 /*7638*/,
    9 /*7639*/,  9 /*763a*/,  10 /*763b*/, 9 /*763c*/,  10 /*763d*/,
    10 /*763e*/, 11 /*763f*/, 6 /*7640*/,  7 /*7641*/,  7 /*7642*/,
    8 /*7643*/,  7 /*7644*/,  8 /*7645*/,  8 /*7646*/,  9 /*7647*/,
    7 /*7648*/,  8 /*7649*/,  8 /*764a*/,  9 /*764b*/,  8 /*764c*/,
    9 /*764d*/,  9 /*764e*/,  10 /*764f*/, 7 /*7650*/,  8 /*7651*/,
    8 /*7652*/,  9 /*7653*/,  8 /*7654*/,  9 /*7655*/,  9 /*7656*/,
    10 /*7657*/, 8 /*7658*/,  9 /*7659*/,  9 /*765a*/,  10 /*765b*/,
    9 /*765c*/,  10 /*765d*/, 10 /*765e*/, 11 /*765f*/, 7 /*7660*/,
    8 /*7661*/,  8 /*7662*/,  9 /*7663*/,  8 /*7664*/,  9 /*7665*/,
    9 /*7666*/,  10 /*7667*/, 8 /*7668*/,  9 /*7669*/,  9 /*766a*/,
    10 /*766b*/, 9 /*766c*/,  10 /*766d*/, 10 /*766e*/, 11 /*766f*/,
    8 /*7670*/,  9 /*7671*/,  9 /*7672*/,  10 /*7673*/, 9 /*7674*/,
    10 /*7675*/, 10 /*7676*/, 11 /*7677*/, 9 /*7678*/,  10 /*7679*/,
    10 /*767a*/, 11 /*767b*/, 10 /*767c*/, 11 /*767d*/, 11 /*767e*/,
    12 /*767f*/, 6 /*7680*/,  7 /*7681*/,  7 /*7682*/,  8 /*7683*/,
    7 /*7684*/,  8 /*7685*/,  8 /*7686*/,  9 /*7687*/,  7 /*7688*/,
    8 /*7689*/,  8 /*768a*/,  9 /*768b*/,  8 /*768c*/,  9 /*768d*/,
    9 /*768e*/,  10 /*768f*/, 7 /*7690*/,  8 /*7691*/,  8 /*7692*/,
    9 /*7693*/,  8 /*7694*/,  9 /*7695*/,  9 /*7696*/,  10 /*7697*/,
    8 /*7698*/,  9 /*7699*/,  9 /*769a*/,  10 /*769b*/, 9 /*769c*/,
    10 /*769d*/, 10 /*769e*/, 11 /*769f*/, 7 /*76a0*/,  8 /*76a1*/,
    8 /*76a2*/,  9 /*76a3*/,  8 /*76a4*/,  9 /*76a5*/,  9 /*76a6*/,
    10 /*76a7*/, 8 /*76a8*/,  9 /*76a9*/,  9 /*76aa*/,  10 /*76ab*/,
    9 /*76ac*/,  10 /*76ad*/, 10 /*76ae*/, 11 /*76af*/, 8 /*76b0*/,
    9 /*76b1*/,  9 /*76b2*/,  10 /*76b3*/, 9 /*76b4*/,  10 /*76b5*/,
    10 /*76b6*/, 11 /*76b7*/, 9 /*76b8*/,  10 /*76b9*/, 10 /*76ba*/,
    11 /*76bb*/, 10 /*76bc*/, 11 /*76bd*/, 11 /*76be*/, 12 /*76bf*/,
    7 /*76c0*/,  8 /*76c1*/,  8 /*76c2*/,  9 /*76c3*/,  8 /*76c4*/,
    9 /*76c5*/,  9 /*76c6*/,  10 /*76c7*/, 8 /*76c8*/,  9 /*76c9*/,
    9 /*76ca*/,  10 /*76cb*/, 9 /*76cc*/,  10 /*76cd*/, 10 /*76ce*/,
    11 /*76cf*/, 8 /*76d0*/,  9 /*76d1*/,  9 /*76d2*/,  10 /*76d3*/,
    9 /*76d4*/,  10 /*76d5*/, 10 /*76d6*/, 11 /*76d7*/, 9 /*76d8*/,
    10 /*76d9*/, 10 /*76da*/, 11 /*76db*/, 10 /*76dc*/, 11 /*76dd*/,
    11 /*76de*/, 12 /*76df*/, 8 /*76e0*/,  9 /*76e1*/,  9 /*76e2*/,
    10 /*76e3*/, 9 /*76e4*/,  10 /*76e5*/, 10 /*76e6*/, 11 /*76e7*/,
    9 /*76e8*/,  10 /*76e9*/, 10 /*76ea*/, 11 /*76eb*/, 10 /*76ec*/,
    11 /*76ed*/, 11 /*76ee*/, 12 /*76ef*/, 9 /*76f0*/,  10 /*76f1*/,
    10 /*76f2*/, 11 /*76f3*/, 10 /*76f4*/, 11 /*76f5*/, 11 /*76f6*/,
    12 /*76f7*/, 10 /*76f8*/, 11 /*76f9*/, 11 /*76fa*/, 12 /*76fb*/,
    11 /*76fc*/, 12 /*76fd*/, 12 /*76fe*/, 13 /*76ff*/, 6 /*7700*/,
    7 /*7701*/,  7 /*7702*/,  8 /*7703*/,  7 /*7704*/,  8 /*7705*/,
    8 /*7706*/,  9 /*7707*/,  7 /*7708*/,  8 /*7709*/,  8 /*770a*/,
    9 /*770b*/,  8 /*770c*/,  9 /*770d*/,  9 /*770e*/,  10 /*770f*/,
    7 /*7710*/,  8 /*7711*/,  8 /*7712*/,  9 /*7713*/,  8 /*7714*/,
    9 /*7715*/,  9 /*7716*/,  10 /*7717*/, 8 /*7718*/,  9 /*7719*/,
    9 /*771a*/,  10 /*771b*/, 9 /*771c*/,  10 /*771d*/, 10 /*771e*/,
    11 /*771f*/, 7 /*7720*/,  8 /*7721*/,  8 /*7722*/,  9 /*7723*/,
    8 /*7724*/,  9 /*7725*/,  9 /*7726*/,  10 /*7727*/, 8 /*7728*/,
    9 /*7729*/,  9 /*772a*/,  10 /*772b*/, 9 /*772c*/,  10 /*772d*/,
    10 /*772e*/, 11 /*772f*/, 8 /*7730*/,  9 /*7731*/,  9 /*7732*/,
    10 /*7733*/, 9 /*7734*/,  10 /*7735*/, 10 /*7736*/, 11 /*7737*/,
    9 /*7738*/,  10 /*7739*/, 10 /*773a*/, 11 /*773b*/, 10 /*773c*/,
    11 /*773d*/, 11 /*773e*/, 12 /*773f*/, 7 /*7740*/,  8 /*7741*/,
    8 /*7742*/,  9 /*7743*/,  8 /*7744*/,  9 /*7745*/,  9 /*7746*/,
    10 /*7747*/, 8 /*7748*/,  9 /*7749*/,  9 /*774a*/,  10 /*774b*/,
    9 /*774c*/,  10 /*774d*/, 10 /*774e*/, 11 /*774f*/, 8 /*7750*/,
    9 /*7751*/,  9 /*7752*/,  10 /*7753*/, 9 /*7754*/,  10 /*7755*/,
    10 /*7756*/, 11 /*7757*/, 9 /*7758*/,  10 /*7759*/, 10 /*775a*/,
    11 /*775b*/, 10 /*775c*/, 11 /*775d*/, 11 /*775e*/, 12 /*775f*/,
    8 /*7760*/,  9 /*7761*/,  9 /*7762*/,  10 /*7763*/, 9 /*7764*/,
    10 /*7765*/, 10 /*7766*/, 11 /*7767*/, 9 /*7768*/,  10 /*7769*/,
    10 /*776a*/, 11 /*776b*/, 10 /*776c*/, 11 /*776d*/, 11 /*776e*/,
    12 /*776f*/, 9 /*7770*/,  10 /*7771*/, 10 /*7772*/, 11 /*7773*/,
    10 /*7774*/, 11 /*7775*/, 11 /*7776*/, 12 /*7777*/, 10 /*7778*/,
    11 /*7779*/, 11 /*777a*/, 12 /*777b*/, 11 /*777c*/, 12 /*777d*/,
    12 /*777e*/, 13 /*777f*/, 7 /*7780*/,  8 /*7781*/,  8 /*7782*/,
    9 /*7783*/,  8 /*7784*/,  9 /*7785*/,  9 /*7786*/,  10 /*7787*/,
    8 /*7788*/,  9 /*7789*/,  9 /*778a*/,  10 /*778b*/, 9 /*778c*/,
    10 /*778d*/, 10 /*778e*/, 11 /*778f*/, 8 /*7790*/,  9 /*7791*/,
    9 /*7792*/,  10 /*7793*/, 9 /*7794*/,  10 /*7795*/, 10 /*7796*/,
    11 /*7797*/, 9 /*7798*/,  10 /*7799*/, 10 /*779a*/, 11 /*779b*/,
    10 /*779c*/, 11 /*779d*/, 11 /*779e*/, 12 /*779f*/, 8 /*77a0*/,
    9 /*77a1*/,  9 /*77a2*/,  10 /*77a3*/, 9 /*77a4*/,  10 /*77a5*/,
    10 /*77a6*/, 11 /*77a7*/, 9 /*77a8*/,  10 /*77a9*/, 10 /*77aa*/,
    11 /*77ab*/, 10 /*77ac*/, 11 /*77ad*/, 11 /*77ae*/, 12 /*77af*/,
    9 /*77b0*/,  10 /*77b1*/, 10 /*77b2*/, 11 /*77b3*/, 10 /*77b4*/,
    11 /*77b5*/, 11 /*77b6*/, 12 /*77b7*/, 10 /*77b8*/, 11 /*77b9*/,
    11 /*77ba*/, 12 /*77bb*/, 11 /*77bc*/, 12 /*77bd*/, 12 /*77be*/,
    13 /*77bf*/, 8 /*77c0*/,  9 /*77c1*/,  9 /*77c2*/,  10 /*77c3*/,
    9 /*77c4*/,  10 /*77c5*/, 10 /*77c6*/, 11 /*77c7*/, 9 /*77c8*/,
    10 /*77c9*/, 10 /*77ca*/, 11 /*77cb*/, 10 /*77cc*/, 11 /*77cd*/,
    11 /*77ce*/, 12 /*77cf*/, 9 /*77d0*/,  10 /*77d1*/, 10 /*77d2*/,
    11 /*77d3*/, 10 /*77d4*/, 11 /*77d5*/, 11 /*77d6*/, 12 /*77d7*/,
    10 /*77d8*/, 11 /*77d9*/, 11 /*77da*/, 12 /*77db*/, 11 /*77dc*/,
    12 /*77dd*/, 12 /*77de*/, 13 /*77df*/, 9 /*77e0*/,  10 /*77e1*/,
    10 /*77e2*/, 11 /*77e3*/, 10 /*77e4*/, 11 /*77e5*/, 11 /*77e6*/,
    12 /*77e7*/, 10 /*77e8*/, 11 /*77e9*/, 11 /*77ea*/, 12 /*77eb*/,
    11 /*77ec*/, 12 /*77ed*/, 12 /*77ee*/, 13 /*77ef*/, 10 /*77f0*/,
    11 /*77f1*/, 11 /*77f2*/, 12 /*77f3*/, 11 /*77f4*/, 12 /*77f5*/,
    12 /*77f6*/, 13 /*77f7*/, 11 /*77f8*/, 12 /*77f9*/, 12 /*77fa*/,
    13 /*77fb*/, 12 /*77fc*/, 13 /*77fd*/, 13 /*77fe*/, 14 /*77ff*/,
    4 /*7800*/,  5 /*7801*/,  5 /*7802*/,  6 /*7803*/,  5 /*7804*/,
    6 /*7805*/,  6 /*7806*/,  7 /*7807*/,  5 /*7808*/,  6 /*7809*/,
    6 /*780a*/,  7 /*780b*/,  6 /*780c*/,  7 /*780d*/,  7 /*780e*/,
    8 /*780f*/,  5 /*7810*/,  6 /*7811*/,  6 /*7812*/,  7 /*7813*/,
    6 /*7814*/,  7 /*7815*/,  7 /*7816*/,  8 /*7817*/,  6 /*7818*/,
    7 /*7819*/,  7 /*781a*/,  8 /*781b*/,  7 /*781c*/,  8 /*781d*/,
    8 /*781e*/,  9 /*781f*/,  5 /*7820*/,  6 /*7821*/,  6 /*7822*/,
    7 /*7823*/,  6 /*7824*/,  7 /*7825*/,  7 /*7826*/,  8 /*7827*/,
    6 /*7828*/,  7 /*7829*/,  7 /*782a*/,  8 /*782b*/,  7 /*782c*/,
    8 /*782d*/,  8 /*782e*/,  9 /*782f*/,  6 /*7830*/,  7 /*7831*/,
    7 /*7832*/,  8 /*7833*/,  7 /*7834*/,  8 /*7835*/,  8 /*7836*/,
    9 /*7837*/,  7 /*7838*/,  8 /*7839*/,  8 /*783a*/,  9 /*783b*/,
    8 /*783c*/,  9 /*783d*/,  9 /*783e*/,  10 /*783f*/, 5 /*7840*/,
    6 /*7841*/,  6 /*7842*/,  7 /*7843*/,  6 /*7844*/,  7 /*7845*/,
    7 /*7846*/,  8 /*7847*/,  6 /*7848*/,  7 /*7849*/,  7 /*784a*/,
    8 /*784b*/,  7 /*784c*/,  8 /*784d*/,  8 /*784e*/,  9 /*784f*/,
    6 /*7850*/,  7 /*7851*/,  7 /*7852*/,  8 /*7853*/,  7 /*7854*/,
    8 /*7855*/,  8 /*7856*/,  9 /*7857*/,  7 /*7858*/,  8 /*7859*/,
    8 /*785a*/,  9 /*785b*/,  8 /*785c*/,  9 /*785d*/,  9 /*785e*/,
    10 /*785f*/, 6 /*7860*/,  7 /*7861*/,  7 /*7862*/,  8 /*7863*/,
    7 /*7864*/,  8 /*7865*/,  8 /*7866*/,  9 /*7867*/,  7 /*7868*/,
    8 /*7869*/,  8 /*786a*/,  9 /*786b*/,  8 /*786c*/,  9 /*786d*/,
    9 /*786e*/,  10 /*786f*/, 7 /*7870*/,  8 /*7871*/,  8 /*7872*/,
    9 /*7873*/,  8 /*7874*/,  9 /*7875*/,  9 /*7876*/,  10 /*7877*/,
    8 /*7878*/,  9 /*7879*/,  9 /*787a*/,  10 /*787b*/, 9 /*787c*/,
    10 /*787d*/, 10 /*787e*/, 11 /*787f*/, 5 /*7880*/,  6 /*7881*/,
    6 /*7882*/,  7 /*7883*/,  6 /*7884*/,  7 /*7885*/,  7 /*7886*/,
    8 /*7887*/,  6 /*7888*/,  7 /*7889*/,  7 /*788a*/,  8 /*788b*/,
    7 /*788c*/,  8 /*788d*/,  8 /*788e*/,  9 /*788f*/,  6 /*7890*/,
    7 /*7891*/,  7 /*7892*/,  8 /*7893*/,  7 /*7894*/,  8 /*7895*/,
    8 /*7896*/,  9 /*7897*/,  7 /*7898*/,  8 /*7899*/,  8 /*789a*/,
    9 /*789b*/,  8 /*789c*/,  9 /*789d*/,  9 /*789e*/,  10 /*789f*/,
    6 /*78a0*/,  7 /*78a1*/,  7 /*78a2*/,  8 /*78a3*/,  7 /*78a4*/,
    8 /*78a5*/,  8 /*78a6*/,  9 /*78a7*/,  7 /*78a8*/,  8 /*78a9*/,
    8 /*78aa*/,  9 /*78ab*/,  8 /*78ac*/,  9 /*78ad*/,  9 /*78ae*/,
    10 /*78af*/, 7 /*78b0*/,  8 /*78b1*/,  8 /*78b2*/,  9 /*78b3*/,
    8 /*78b4*/,  9 /*78b5*/,  9 /*78b6*/,  10 /*78b7*/, 8 /*78b8*/,
    9 /*78b9*/,  9 /*78ba*/,  10 /*78bb*/, 9 /*78bc*/,  10 /*78bd*/,
    10 /*78be*/, 11 /*78bf*/, 6 /*78c0*/,  7 /*78c1*/,  7 /*78c2*/,
    8 /*78c3*/,  7 /*78c4*/,  8 /*78c5*/,  8 /*78c6*/,  9 /*78c7*/,
    7 /*78c8*/,  8 /*78c9*/,  8 /*78ca*/,  9 /*78cb*/,  8 /*78cc*/,
    9 /*78cd*/,  9 /*78ce*/,  10 /*78cf*/, 7 /*78d0*/,  8 /*78d1*/,
    8 /*78d2*/,  9 /*78d3*/,  8 /*78d4*/,  9 /*78d5*/,  9 /*78d6*/,
    10 /*78d7*/, 8 /*78d8*/,  9 /*78d9*/,  9 /*78da*/,  10 /*78db*/,
    9 /*78dc*/,  10 /*78dd*/, 10 /*78de*/, 11 /*78df*/, 7 /*78e0*/,
    8 /*78e1*/,  8 /*78e2*/,  9 /*78e3*/,  8 /*78e4*/,  9 /*78e5*/,
    9 /*78e6*/,  10 /*78e7*/, 8 /*78e8*/,  9 /*78e9*/,  9 /*78ea*/,
    10 /*78eb*/, 9 /*78ec*/,  10 /*78ed*/, 10 /*78ee*/, 11 /*78ef*/,
    8 /*78f0*/,  9 /*78f1*/,  9 /*78f2*/,  10 /*78f3*/, 9 /*78f4*/,
    10 /*78f5*/, 10 /*78f6*/, 11 /*78f7*/, 9 /*78f8*/,  10 /*78f9*/,
    10 /*78fa*/, 11 /*78fb*/, 10 /*78fc*/, 11 /*78fd*/, 11 /*78fe*/,
    12 /*78ff*/, 5 /*7900*/,  6 /*7901*/,  6 /*7902*/,  7 /*7903*/,
    6 /*7904*/,  7 /*7905*/,  7 /*7906*/,  8 /*7907*/,  6 /*7908*/,
    7 /*7909*/,  7 /*790a*/,  8 /*790b*/,  7 /*790c*/,  8 /*790d*/,
    8 /*790e*/,  9 /*790f*/,  6 /*7910*/,  7 /*7911*/,  7 /*7912*/,
    8 /*7913*/,  7 /*7914*/,  8 /*7915*/,  8 /*7916*/,  9 /*7917*/,
    7 /*7918*/,  8 /*7919*/,  8 /*791a*/,  9 /*791b*/,  8 /*791c*/,
    9 /*791d*/,  9 /*791e*/,  10 /*791f*/, 6 /*7920*/,  7 /*7921*/,
    7 /*7922*/,  8 /*7923*/,  7 /*7924*/,  8 /*7925*/,  8 /*7926*/,
    9 /*7927*/,  7 /*7928*/,  8 /*7929*/,  8 /*792a*/,  9 /*792b*/,
    8 /*792c*/,  9 /*792d*/,  9 /*792e*/,  10 /*792f*/, 7 /*7930*/,
    8 /*7931*/,  8 /*7932*/,  9 /*7933*/,  8 /*7934*/,  9 /*7935*/,
    9 /*7936*/,  10 /*7937*/, 8 /*7938*/,  9 /*7939*/,  9 /*793a*/,
    10 /*793b*/, 9 /*793c*/,  10 /*793d*/, 10 /*793e*/, 11 /*793f*/,
    6 /*7940*/,  7 /*7941*/,  7 /*7942*/,  8 /*7943*/,  7 /*7944*/,
    8 /*7945*/,  8 /*7946*/,  9 /*7947*/,  7 /*7948*/,  8 /*7949*/,
    8 /*794a*/,  9 /*794b*/,  8 /*794c*/,  9 /*794d*/,  9 /*794e*/,
    10 /*794f*/, 7 /*7950*/,  8 /*7951*/,  8 /*7952*/,  9 /*7953*/,
    8 /*7954*/,  9 /*7955*/,  9 /*7956*/,  10 /*7957*/, 8 /*7958*/,
    9 /*7959*/,  9 /*795a*/,  10 /*795b*/, 9 /*795c*/,  10 /*795d*/,
    10 /*795e*/, 11 /*795f*/, 7 /*7960*/,  8 /*7961*/,  8 /*7962*/,
    9 /*7963*/,  8 /*7964*/,  9 /*7965*/,  9 /*7966*/,  10 /*7967*/,
    8 /*7968*/,  9 /*7969*/,  9 /*796a*/,  10 /*796b*/, 9 /*796c*/,
    10 /*796d*/, 10 /*796e*/, 11 /*796f*/, 8 /*7970*/,  9 /*7971*/,
    9 /*7972*/,  10 /*7973*/, 9 /*7974*/,  10 /*7975*/, 10 /*7976*/,
    11 /*7977*/, 9 /*7978*/,  10 /*7979*/, 10 /*797a*/, 11 /*797b*/,
    10 /*797c*/, 11 /*797d*/, 11 /*797e*/, 12 /*797f*/, 6 /*7980*/,
    7 /*7981*/,  7 /*7982*/,  8 /*7983*/,  7 /*7984*/,  8 /*7985*/,
    8 /*7986*/,  9 /*7987*/,  7 /*7988*/,  8 /*7989*/,  8 /*798a*/,
    9 /*798b*/,  8 /*798c*/,  9 /*798d*/,  9 /*798e*/,  10 /*798f*/,
    7 /*7990*/,  8 /*7991*/,  8 /*7992*/,  9 /*7993*/,  8 /*7994*/,
    9 /*7995*/,  9 /*7996*/,  10 /*7997*/, 8 /*7998*/,  9 /*7999*/,
    9 /*799a*/,  10 /*799b*/, 9 /*799c*/,  10 /*799d*/, 10 /*799e*/,
    11 /*799f*/, 7 /*79a0*/,  8 /*79a1*/,  8 /*79a2*/,  9 /*79a3*/,
    8 /*79a4*/,  9 /*79a5*/,  9 /*79a6*/,  10 /*79a7*/, 8 /*79a8*/,
    9 /*79a9*/,  9 /*79aa*/,  10 /*79ab*/, 9 /*79ac*/,  10 /*79ad*/,
    10 /*79ae*/, 11 /*79af*/, 8 /*79b0*/,  9 /*79b1*/,  9 /*79b2*/,
    10 /*79b3*/, 9 /*79b4*/,  10 /*79b5*/, 10 /*79b6*/, 11 /*79b7*/,
    9 /*79b8*/,  10 /*79b9*/, 10 /*79ba*/, 11 /*79bb*/, 10 /*79bc*/,
    11 /*79bd*/, 11 /*79be*/, 12 /*79bf*/, 7 /*79c0*/,  8 /*79c1*/,
    8 /*79c2*/,  9 /*79c3*/,  8 /*79c4*/,  9 /*79c5*/,  9 /*79c6*/,
    10 /*79c7*/, 8 /*79c8*/,  9 /*79c9*/,  9 /*79ca*/,  10 /*79cb*/,
    9 /*79cc*/,  10 /*79cd*/, 10 /*79ce*/, 11 /*79cf*/, 8 /*79d0*/,
    9 /*79d1*/,  9 /*79d2*/,  10 /*79d3*/, 9 /*79d4*/,  10 /*79d5*/,
    10 /*79d6*/, 11 /*79d7*/, 9 /*79d8*/,  10 /*79d9*/, 10 /*79da*/,
    11 /*79db*/, 10 /*79dc*/, 11 /*79dd*/, 11 /*79de*/, 12 /*79df*/,
    8 /*79e0*/,  9 /*79e1*/,  9 /*79e2*/,  10 /*79e3*/, 9 /*79e4*/,
    10 /*79e5*/, 10 /*79e6*/, 11 /*79e7*/, 9 /*79e8*/,  10 /*79e9*/,
    10 /*79ea*/, 11 /*79eb*/, 10 /*79ec*/, 11 /*79ed*/, 11 /*79ee*/,
    12 /*79ef*/, 9 /*79f0*/,  10 /*79f1*/, 10 /*79f2*/, 11 /*79f3*/,
    10 /*79f4*/, 11 /*79f5*/, 11 /*79f6*/, 12 /*79f7*/, 10 /*79f8*/,
    11 /*79f9*/, 11 /*79fa*/, 12 /*79fb*/, 11 /*79fc*/, 12 /*79fd*/,
    12 /*79fe*/, 13 /*79ff*/, 5 /*7a00*/,  6 /*7a01*/,  6 /*7a02*/,
    7 /*7a03*/,  6 /*7a04*/,  7 /*7a05*/,  7 /*7a06*/,  8 /*7a07*/,
    6 /*7a08*/,  7 /*7a09*/,  7 /*7a0a*/,  8 /*7a0b*/,  7 /*7a0c*/,
    8 /*7a0d*/,  8 /*7a0e*/,  9 /*7a0f*/,  6 /*7a10*/,  7 /*7a11*/,
    7 /*7a12*/,  8 /*7a13*/,  7 /*7a14*/,  8 /*7a15*/,  8 /*7a16*/,
    9 /*7a17*/,  7 /*7a18*/,  8 /*7a19*/,  8 /*7a1a*/,  9 /*7a1b*/,
    8 /*7a1c*/,  9 /*7a1d*/,  9 /*7a1e*/,  10 /*7a1f*/, 6 /*7a20*/,
    7 /*7a21*/,  7 /*7a22*/,  8 /*7a23*/,  7 /*7a24*/,  8 /*7a25*/,
    8 /*7a26*/,  9 /*7a27*/,  7 /*7a28*/,  8 /*7a29*/,  8 /*7a2a*/,
    9 /*7a2b*/,  8 /*7a2c*/,  9 /*7a2d*/,  9 /*7a2e*/,  10 /*7a2f*/,
    7 /*7a30*/,  8 /*7a31*/,  8 /*7a32*/,  9 /*7a33*/,  8 /*7a34*/,
    9 /*7a35*/,  9 /*7a36*/,  10 /*7a37*/, 8 /*7a38*/,  9 /*7a39*/,
    9 /*7a3a*/,  10 /*7a3b*/, 9 /*7a3c*/,  10 /*7a3d*/, 10 /*7a3e*/,
    11 /*7a3f*/, 6 /*7a40*/,  7 /*7a41*/,  7 /*7a42*/,  8 /*7a43*/,
    7 /*7a44*/,  8 /*7a45*/,  8 /*7a46*/,  9 /*7a47*/,  7 /*7a48*/,
    8 /*7a49*/,  8 /*7a4a*/,  9 /*7a4b*/,  8 /*7a4c*/,  9 /*7a4d*/,
    9 /*7a4e*/,  10 /*7a4f*/, 7 /*7a50*/,  8 /*7a51*/,  8 /*7a52*/,
    9 /*7a53*/,  8 /*7a54*/,  9 /*7a55*/,  9 /*7a56*/,  10 /*7a57*/,
    8 /*7a58*/,  9 /*7a59*/,  9 /*7a5a*/,  10 /*7a5b*/, 9 /*7a5c*/,
    10 /*7a5d*/, 10 /*7a5e*/, 11 /*7a5f*/, 7 /*7a60*/,  8 /*7a61*/,
    8 /*7a62*/,  9 /*7a63*/,  8 /*7a64*/,  9 /*7a65*/,  9 /*7a66*/,
    10 /*7a67*/, 8 /*7a68*/,  9 /*7a69*/,  9 /*7a6a*/,  10 /*7a6b*/,
    9 /*7a6c*/,  10 /*7a6d*/, 10 /*7a6e*/, 11 /*7a6f*/, 8 /*7a70*/,
    9 /*7a71*/,  9 /*7a72*/,  10 /*7a73*/, 9 /*7a74*/,  10 /*7a75*/,
    10 /*7a76*/, 11 /*7a77*/, 9 /*7a78*/,  10 /*7a79*/, 10 /*7a7a*/,
    11 /*7a7b*/, 10 /*7a7c*/, 11 /*7a7d*/, 11 /*7a7e*/, 12 /*7a7f*/,
    6 /*7a80*/,  7 /*7a81*/,  7 /*7a82*/,  8 /*7a83*/,  7 /*7a84*/,
    8 /*7a85*/,  8 /*7a86*/,  9 /*7a87*/,  7 /*7a88*/,  8 /*7a89*/,
    8 /*7a8a*/,  9 /*7a8b*/,  8 /*7a8c*/,  9 /*7a8d*/,  9 /*7a8e*/,
    10 /*7a8f*/, 7 /*7a90*/,  8 /*7a91*/,  8 /*7a92*/,  9 /*7a93*/,
    8 /*7a94*/,  9 /*7a95*/,  9 /*7a96*/,  10 /*7a97*/, 8 /*7a98*/,
    9 /*7a99*/,  9 /*7a9a*/,  10 /*7a9b*/, 9 /*7a9c*/,  10 /*7a9d*/,
    10 /*7a9e*/, 11 /*7a9f*/, 7 /*7aa0*/,  8 /*7aa1*/,  8 /*7aa2*/,
    9 /*7aa3*/,  8 /*7aa4*/,  9 /*7aa5*/,  9 /*7aa6*/,  10 /*7aa7*/,
    8 /*7aa8*/,  9 /*7aa9*/,  9 /*7aaa*/,  10 /*7aab*/, 9 /*7aac*/,
    10 /*7aad*/, 10 /*7aae*/, 11 /*7aaf*/, 8 /*7ab0*/,  9 /*7ab1*/,
    9 /*7ab2*/,  10 /*7ab3*/, 9 /*7ab4*/,  10 /*7ab5*/, 10 /*7ab6*/,
    11 /*7ab7*/, 9 /*7ab8*/,  10 /*7ab9*/, 10 /*7aba*/, 11 /*7abb*/,
    10 /*7abc*/, 11 /*7abd*/, 11 /*7abe*/, 12 /*7abf*/, 7 /*7ac0*/,
    8 /*7ac1*/,  8 /*7ac2*/,  9 /*7ac3*/,  8 /*7ac4*/,  9 /*7ac5*/,
    9 /*7ac6*/,  10 /*7ac7*/, 8 /*7ac8*/,  9 /*7ac9*/,  9 /*7aca*/,
    10 /*7acb*/, 9 /*7acc*/,  10 /*7acd*/, 10 /*7ace*/, 11 /*7acf*/,
    8 /*7ad0*/,  9 /*7ad1*/,  9 /*7ad2*/,  10 /*7ad3*/, 9 /*7ad4*/,
    10 /*7ad5*/, 10 /*7ad6*/, 11 /*7ad7*/, 9 /*7ad8*/,  10 /*7ad9*/,
    10 /*7ada*/, 11 /*7adb*/, 10 /*7adc*/, 11 /*7add*/, 11 /*7ade*/,
    12 /*7adf*/, 8 /*7ae0*/,  9 /*7ae1*/,  9 /*7ae2*/,  10 /*7ae3*/,
    9 /*7ae4*/,  10 /*7ae5*/, 10 /*7ae6*/, 11 /*7ae7*/, 9 /*7ae8*/,
    10 /*7ae9*/, 10 /*7aea*/, 11 /*7aeb*/, 10 /*7aec*/, 11 /*7aed*/,
    11 /*7aee*/, 12 /*7aef*/, 9 /*7af0*/,  10 /*7af1*/, 10 /*7af2*/,
    11 /*7af3*/, 10 /*7af4*/, 11 /*7af5*/, 11 /*7af6*/, 12 /*7af7*/,
    10 /*7af8*/, 11 /*7af9*/, 11 /*7afa*/, 12 /*7afb*/, 11 /*7afc*/,
    12 /*7afd*/, 12 /*7afe*/, 13 /*7aff*/, 6 /*7b00*/,  7 /*7b01*/,
    7 /*7b02*/,  8 /*7b03*/,  7 /*7b04*/,  8 /*7b05*/,  8 /*7b06*/,
    9 /*7b07*/,  7 /*7b08*/,  8 /*7b09*/,  8 /*7b0a*/,  9 /*7b0b*/,
    8 /*7b0c*/,  9 /*7b0d*/,  9 /*7b0e*/,  10 /*7b0f*/, 7 /*7b10*/,
    8 /*7b11*/,  8 /*7b12*/,  9 /*7b13*/,  8 /*7b14*/,  9 /*7b15*/,
    9 /*7b16*/,  10 /*7b17*/, 8 /*7b18*/,  9 /*7b19*/,  9 /*7b1a*/,
    10 /*7b1b*/, 9 /*7b1c*/,  10 /*7b1d*/, 10 /*7b1e*/, 11 /*7b1f*/,
    7 /*7b20*/,  8 /*7b21*/,  8 /*7b22*/,  9 /*7b23*/,  8 /*7b24*/,
    9 /*7b25*/,  9 /*7b26*/,  10 /*7b27*/, 8 /*7b28*/,  9 /*7b29*/,
    9 /*7b2a*/,  10 /*7b2b*/, 9 /*7b2c*/,  10 /*7b2d*/, 10 /*7b2e*/,
    11 /*7b2f*/, 8 /*7b30*/,  9 /*7b31*/,  9 /*7b32*/,  10 /*7b33*/,
    9 /*7b34*/,  10 /*7b35*/, 10 /*7b36*/, 11 /*7b37*/, 9 /*7b38*/,
    10 /*7b39*/, 10 /*7b3a*/, 11 /*7b3b*/, 10 /*7b3c*/, 11 /*7b3d*/,
    11 /*7b3e*/, 12 /*7b3f*/, 7 /*7b40*/,  8 /*7b41*/,  8 /*7b42*/,
    9 /*7b43*/,  8 /*7b44*/,  9 /*7b45*/,  9 /*7b46*/,  10 /*7b47*/,
    8 /*7b48*/,  9 /*7b49*/,  9 /*7b4a*/,  10 /*7b4b*/, 9 /*7b4c*/,
    10 /*7b4d*/, 10 /*7b4e*/, 11 /*7b4f*/, 8 /*7b50*/,  9 /*7b51*/,
    9 /*7b52*/,  10 /*7b53*/, 9 /*7b54*/,  10 /*7b55*/, 10 /*7b56*/,
    11 /*7b57*/, 9 /*7b58*/,  10 /*7b59*/, 10 /*7b5a*/, 11 /*7b5b*/,
    10 /*7b5c*/, 11 /*7b5d*/, 11 /*7b5e*/, 12 /*7b5f*/, 8 /*7b60*/,
    9 /*7b61*/,  9 /*7b62*/,  10 /*7b63*/, 9 /*7b64*/,  10 /*7b65*/,
    10 /*7b66*/, 11 /*7b67*/, 9 /*7b68*/,  10 /*7b69*/, 10 /*7b6a*/,
    11 /*7b6b*/, 10 /*7b6c*/, 11 /*7b6d*/, 11 /*7b6e*/, 12 /*7b6f*/,
    9 /*7b70*/,  10 /*7b71*/, 10 /*7b72*/, 11 /*7b73*/, 10 /*7b74*/,
    11 /*7b75*/, 11 /*7b76*/, 12 /*7b77*/, 10 /*7b78*/, 11 /*7b79*/,
    11 /*7b7a*/, 12 /*7b7b*/, 11 /*7b7c*/, 12 /*7b7d*/, 12 /*7b7e*/,
    13 /*7b7f*/, 7 /*7b80*/,  8 /*7b81*/,  8 /*7b82*/,  9 /*7b83*/,
    8 /*7b84*/,  9 /*7b85*/,  9 /*7b86*/,  10 /*7b87*/, 8 /*7b88*/,
    9 /*7b89*/,  9 /*7b8a*/,  10 /*7b8b*/, 9 /*7b8c*/,  10 /*7b8d*/,
    10 /*7b8e*/, 11 /*7b8f*/, 8 /*7b90*/,  9 /*7b91*/,  9 /*7b92*/,
    10 /*7b93*/, 9 /*7b94*/,  10 /*7b95*/, 10 /*7b96*/, 11 /*7b97*/,
    9 /*7b98*/,  10 /*7b99*/, 10 /*7b9a*/, 11 /*7b9b*/, 10 /*7b9c*/,
    11 /*7b9d*/, 11 /*7b9e*/, 12 /*7b9f*/, 8 /*7ba0*/,  9 /*7ba1*/,
    9 /*7ba2*/,  10 /*7ba3*/, 9 /*7ba4*/,  10 /*7ba5*/, 10 /*7ba6*/,
    11 /*7ba7*/, 9 /*7ba8*/,  10 /*7ba9*/, 10 /*7baa*/, 11 /*7bab*/,
    10 /*7bac*/, 11 /*7bad*/, 11 /*7bae*/, 12 /*7baf*/, 9 /*7bb0*/,
    10 /*7bb1*/, 10 /*7bb2*/, 11 /*7bb3*/, 10 /*7bb4*/, 11 /*7bb5*/,
    11 /*7bb6*/, 12 /*7bb7*/, 10 /*7bb8*/, 11 /*7bb9*/, 11 /*7bba*/,
    12 /*7bbb*/, 11 /*7bbc*/, 12 /*7bbd*/, 12 /*7bbe*/, 13 /*7bbf*/,
    8 /*7bc0*/,  9 /*7bc1*/,  9 /*7bc2*/,  10 /*7bc3*/, 9 /*7bc4*/,
    10 /*7bc5*/, 10 /*7bc6*/, 11 /*7bc7*/, 9 /*7bc8*/,  10 /*7bc9*/,
    10 /*7bca*/, 11 /*7bcb*/, 10 /*7bcc*/, 11 /*7bcd*/, 11 /*7bce*/,
    12 /*7bcf*/, 9 /*7bd0*/,  10 /*7bd1*/, 10 /*7bd2*/, 11 /*7bd3*/,
    10 /*7bd4*/, 11 /*7bd5*/, 11 /*7bd6*/, 12 /*7bd7*/, 10 /*7bd8*/,
    11 /*7bd9*/, 11 /*7bda*/, 12 /*7bdb*/, 11 /*7bdc*/, 12 /*7bdd*/,
    12 /*7bde*/, 13 /*7bdf*/, 9 /*7be0*/,  10 /*7be1*/, 10 /*7be2*/,
    11 /*7be3*/, 10 /*7be4*/, 11 /*7be5*/, 11 /*7be6*/, 12 /*7be7*/,
    10 /*7be8*/, 11 /*7be9*/, 11 /*7bea*/, 12 /*7beb*/, 11 /*7bec*/,
    12 /*7bed*/, 12 /*7bee*/, 13 /*7bef*/, 10 /*7bf0*/, 11 /*7bf1*/,
    11 /*7bf2*/, 12 /*7bf3*/, 11 /*7bf4*/, 12 /*7bf5*/, 12 /*7bf6*/,
    13 /*7bf7*/, 11 /*7bf8*/, 12 /*7bf9*/, 12 /*7bfa*/, 13 /*7bfb*/,
    12 /*7bfc*/, 13 /*7bfd*/, 13 /*7bfe*/, 14 /*7bff*/, 5 /*7c00*/,
    6 /*7c01*/,  6 /*7c02*/,  7 /*7c03*/,  6 /*7c04*/,  7 /*7c05*/,
    7 /*7c06*/,  8 /*7c07*/,  6 /*7c08*/,  7 /*7c09*/,  7 /*7c0a*/,
    8 /*7c0b*/,  7 /*7c0c*/,  8 /*7c0d*/,  8 /*7c0e*/,  9 /*7c0f*/,
    6 /*7c10*/,  7 /*7c11*/,  7 /*7c12*/,  8 /*7c13*/,  7 /*7c14*/,
    8 /*7c15*/,  8 /*7c16*/,  9 /*7c17*/,  7 /*7c18*/,  8 /*7c19*/,
    8 /*7c1a*/,  9 /*7c1b*/,  8 /*7c1c*/,  9 /*7c1d*/,  9 /*7c1e*/,
    10 /*7c1f*/, 6 /*7c20*/,  7 /*7c21*/,  7 /*7c22*/,  8 /*7c23*/,
    7 /*7c24*/,  8 /*7c25*/,  8 /*7c26*/,  9 /*7c27*/,  7 /*7c28*/,
    8 /*7c29*/,  8 /*7c2a*/,  9 /*7c2b*/,  8 /*7c2c*/,  9 /*7c2d*/,
    9 /*7c2e*/,  10 /*7c2f*/, 7 /*7c30*/,  8 /*7c31*/,  8 /*7c32*/,
    9 /*7c33*/,  8 /*7c34*/,  9 /*7c35*/,  9 /*7c36*/,  10 /*7c37*/,
    8 /*7c38*/,  9 /*7c39*/,  9 /*7c3a*/,  10 /*7c3b*/, 9 /*7c3c*/,
    10 /*7c3d*/, 10 /*7c3e*/, 11 /*7c3f*/, 6 /*7c40*/,  7 /*7c41*/,
    7 /*7c42*/,  8 /*7c43*/,  7 /*7c44*/,  8 /*7c45*/,  8 /*7c46*/,
    9 /*7c47*/,  7 /*7c48*/,  8 /*7c49*/,  8 /*7c4a*/,  9 /*7c4b*/,
    8 /*7c4c*/,  9 /*7c4d*/,  9 /*7c4e*/,  10 /*7c4f*/, 7 /*7c50*/,
    8 /*7c51*/,  8 /*7c52*/,  9 /*7c53*/,  8 /*7c54*/,  9 /*7c55*/,
    9 /*7c56*/,  10 /*7c57*/, 8 /*7c58*/,  9 /*7c59*/,  9 /*7c5a*/,
    10 /*7c5b*/, 9 /*7c5c*/,  10 /*7c5d*/, 10 /*7c5e*/, 11 /*7c5f*/,
    7 /*7c60*/,  8 /*7c61*/,  8 /*7c62*/,  9 /*7c63*/,  8 /*7c64*/,
    9 /*7c65*/,  9 /*7c66*/,  10 /*7c67*/, 8 /*7c68*/,  9 /*7c69*/,
    9 /*7c6a*/,  10 /*7c6b*/, 9 /*7c6c*/,  10 /*7c6d*/, 10 /*7c6e*/,
    11 /*7c6f*/, 8 /*7c70*/,  9 /*7c71*/,  9 /*7c72*/,  10 /*7c73*/,
    9 /*7c74*/,  10 /*7c75*/, 10 /*7c76*/, 11 /*7c77*/, 9 /*7c78*/,
    10 /*7c79*/, 10 /*7c7a*/, 11 /*7c7b*/, 10 /*7c7c*/, 11 /*7c7d*/,
    11 /*7c7e*/, 12 /*7c7f*/, 6 /*7c80*/,  7 /*7c81*/,  7 /*7c82*/,
    8 /*7c83*/,  7 /*7c84*/,  8 /*7c85*/,  8 /*7c86*/,  9 /*7c87*/,
    7 /*7c88*/,  8 /*7c89*/,  8 /*7c8a*/,  9 /*7c8b*/,  8 /*7c8c*/,
    9 /*7c8d*/,  9 /*7c8e*/,  10 /*7c8f*/, 7 /*7c90*/,  8 /*7c91*/,
    8 /*7c92*/,  9 /*7c93*/,  8 /*7c94*/,  9 /*7c95*/,  9 /*7c96*/,
    10 /*7c97*/, 8 /*7c98*/,  9 /*7c99*/,  9 /*7c9a*/,  10 /*7c9b*/,
    9 /*7c9c*/,  10 /*7c9d*/, 10 /*7c9e*/, 11 /*7c9f*/, 7 /*7ca0*/,
    8 /*7ca1*/,  8 /*7ca2*/,  9 /*7ca3*/,  8 /*7ca4*/,  9 /*7ca5*/,
    9 /*7ca6*/,  10 /*7ca7*/, 8 /*7ca8*/,  9 /*7ca9*/,  9 /*7caa*/,
    10 /*7cab*/, 9 /*7cac*/,  10 /*7cad*/, 10 /*7cae*/, 11 /*7caf*/,
    8 /*7cb0*/,  9 /*7cb1*/,  9 /*7cb2*/,  10 /*7cb3*/, 9 /*7cb4*/,
    10 /*7cb5*/, 10 /*7cb6*/, 11 /*7cb7*/, 9 /*7cb8*/,  10 /*7cb9*/,
    10 /*7cba*/, 11 /*7cbb*/, 10 /*7cbc*/, 11 /*7cbd*/, 11 /*7cbe*/,
    12 /*7cbf*/, 7 /*7cc0*/,  8 /*7cc1*/,  8 /*7cc2*/,  9 /*7cc3*/,
    8 /*7cc4*/,  9 /*7cc5*/,  9 /*7cc6*/,  10 /*7cc7*/, 8 /*7cc8*/,
    9 /*7cc9*/,  9 /*7cca*/,  10 /*7ccb*/, 9 /*7ccc*/,  10 /*7ccd*/,
    10 /*7cce*/, 11 /*7ccf*/, 8 /*7cd0*/,  9 /*7cd1*/,  9 /*7cd2*/,
    10 /*7cd3*/, 9 /*7cd4*/,  10 /*7cd5*/, 10 /*7cd6*/, 11 /*7cd7*/,
    9 /*7cd8*/,  10 /*7cd9*/, 10 /*7cda*/, 11 /*7cdb*/, 10 /*7cdc*/,
    11 /*7cdd*/, 11 /*7cde*/, 12 /*7cdf*/, 8 /*7ce0*/,  9 /*7ce1*/,
    9 /*7ce2*/,  10 /*7ce3*/, 9 /*7ce4*/,  10 /*7ce5*/, 10 /*7ce6*/,
    11 /*7ce7*/, 9 /*7ce8*/,  10 /*7ce9*/, 10 /*7cea*/, 11 /*7ceb*/,
    10 /*7cec*/, 11 /*7ced*/, 11 /*7cee*/, 12 /*7cef*/, 9 /*7cf0*/,
    10 /*7cf1*/, 10 /*7cf2*/, 11 /*7cf3*/, 10 /*7cf4*/, 11 /*7cf5*/,
    11 /*7cf6*/, 12 /*7cf7*/, 10 /*7cf8*/, 11 /*7cf9*/, 11 /*7cfa*/,
    12 /*7cfb*/, 11 /*7cfc*/, 12 /*7cfd*/, 12 /*7cfe*/, 13 /*7cff*/,
    6 /*7d00*/,  7 /*7d01*/,  7 /*7d02*/,  8 /*7d03*/,  7 /*7d04*/,
    8 /*7d05*/,  8 /*7d06*/,  9 /*7d07*/,  7 /*7d08*/,  8 /*7d09*/,
    8 /*7d0a*/,  9 /*7d0b*/,  8 /*7d0c*/,  9 /*7d0d*/,  9 /*7d0e*/,
    10 /*7d0f*/, 7 /*7d10*/,  8 /*7d11*/,  8 /*7d12*/,  9 /*7d13*/,
    8 /*7d14*/,  9 /*7d15*/,  9 /*7d16*/,  10 /*7d17*/, 8 /*7d18*/,
    9 /*7d19*/,  9 /*7d1a*/,  10 /*7d1b*/, 9 /*7d1c*/,  10 /*7d1d*/,
    10 /*7d1e*/, 11 /*7d1f*/, 7 /*7d20*/,  8 /*7d21*/,  8 /*7d22*/,
    9 /*7d23*/,  8 /*7d24*/,  9 /*7d25*/,  9 /*7d26*/,  10 /*7d27*/,
    8 /*7d28*/,  9 /*7d29*/,  9 /*7d2a*/,  10 /*7d2b*/, 9 /*7d2c*/,
    10 /*7d2d*/, 10 /*7d2e*/, 11 /*7d2f*/, 8 /*7d30*/,  9 /*7d31*/,
    9 /*7d32*/,  10 /*7d33*/, 9 /*7d34*/,  10 /*7d35*/, 10 /*7d36*/,
    11 /*7d37*/, 9 /*7d38*/,  10 /*7d39*/, 10 /*7d3a*/, 11 /*7d3b*/,
    10 /*7d3c*/, 11 /*7d3d*/, 11 /*7d3e*/, 12 /*7d3f*/, 7 /*7d40*/,
    8 /*7d41*/,  8 /*7d42*/,  9 /*7d43*/,  8 /*7d44*/,  9 /*7d45*/,
    9 /*7d46*/,  10 /*7d47*/, 8 /*7d48*/,  9 /*7d49*/,  9 /*7d4a*/,
    10 /*7d4b*/, 9 /*7d4c*/,  10 /*7d4d*/, 10 /*7d4e*/, 11 /*7d4f*/,
    8 /*7d50*/,  9 /*7d51*/,  9 /*7d52*/,  10 /*7d53*/, 9 /*7d54*/,
    10 /*7d55*/, 10 /*7d56*/, 11 /*7d57*/, 9 /*7d58*/,  10 /*7d59*/,
    10 /*7d5a*/, 11 /*7d5b*/, 10 /*7d5c*/, 11 /*7d5d*/, 11 /*7d5e*/,
    12 /*7d5f*/, 8 /*7d60*/,  9 /*7d61*/,  9 /*7d62*/,  10 /*7d63*/,
    9 /*7d64*/,  10 /*7d65*/, 10 /*7d66*/, 11 /*7d67*/, 9 /*7d68*/,
    10 /*7d69*/, 10 /*7d6a*/, 11 /*7d6b*/, 10 /*7d6c*/, 11 /*7d6d*/,
    11 /*7d6e*/, 12 /*7d6f*/, 9 /*7d70*/,  10 /*7d71*/, 10 /*7d72*/,
    11 /*7d73*/, 10 /*7d74*/, 11 /*7d75*/, 11 /*7d76*/, 12 /*7d77*/,
    10 /*7d78*/, 11 /*7d79*/, 11 /*7d7a*/, 12 /*7d7b*/, 11 /*7d7c*/,
    12 /*7d7d*/, 12 /*7d7e*/, 13 /*7d7f*/, 7 /*7d80*/,  8 /*7d81*/,
    8 /*7d82*/,  9 /*7d83*/,  8 /*7d84*/,  9 /*7d85*/,  9 /*7d86*/,
    10 /*7d87*/, 8 /*7d88*/,  9 /*7d89*/,  9 /*7d8a*/,  10 /*7d8b*/,
    9 /*7d8c*/,  10 /*7d8d*/, 10 /*7d8e*/, 11 /*7d8f*/, 8 /*7d90*/,
    9 /*7d91*/,  9 /*7d92*/,  10 /*7d93*/, 9 /*7d94*/,  10 /*7d95*/,
    10 /*7d96*/, 11 /*7d97*/, 9 /*7d98*/,  10 /*7d99*/, 10 /*7d9a*/,
    11 /*7d9b*/, 10 /*7d9c*/, 11 /*7d9d*/, 11 /*7d9e*/, 12 /*7d9f*/,
    8 /*7da0*/,  9 /*7da1*/,  9 /*7da2*/,  10 /*7da3*/, 9 /*7da4*/,
    10 /*7da5*/, 10 /*7da6*/, 11 /*7da7*/, 9 /*7da8*/,  10 /*7da9*/,
    10 /*7daa*/, 11 /*7dab*/, 10 /*7dac*/, 11 /*7dad*/, 11 /*7dae*/,
    12 /*7daf*/, 9 /*7db0*/,  10 /*7db1*/, 10 /*7db2*/, 11 /*7db3*/,
    10 /*7db4*/, 11 /*7db5*/, 11 /*7db6*/, 12 /*7db7*/, 10 /*7db8*/,
    11 /*7db9*/, 11 /*7dba*/, 12 /*7dbb*/, 11 /*7dbc*/, 12 /*7dbd*/,
    12 /*7dbe*/, 13 /*7dbf*/, 8 /*7dc0*/,  9 /*7dc1*/,  9 /*7dc2*/,
    10 /*7dc3*/, 9 /*7dc4*/,  10 /*7dc5*/, 10 /*7dc6*/, 11 /*7dc7*/,
    9 /*7dc8*/,  10 /*7dc9*/, 10 /*7dca*/, 11 /*7dcb*/, 10 /*7dcc*/,
    11 /*7dcd*/, 11 /*7dce*/, 12 /*7dcf*/, 9 /*7dd0*/,  10 /*7dd1*/,
    10 /*7dd2*/, 11 /*7dd3*/, 10 /*7dd4*/, 11 /*7dd5*/, 11 /*7dd6*/,
    12 /*7dd7*/, 10 /*7dd8*/, 11 /*7dd9*/, 11 /*7dda*/, 12 /*7ddb*/,
    11 /*7ddc*/, 12 /*7ddd*/, 12 /*7dde*/, 13 /*7ddf*/, 9 /*7de0*/,
    10 /*7de1*/, 10 /*7de2*/, 11 /*7de3*/, 10 /*7de4*/, 11 /*7de5*/,
    11 /*7de6*/, 12 /*7de7*/, 10 /*7de8*/, 11 /*7de9*/, 11 /*7dea*/,
    12 /*7deb*/, 11 /*7dec*/, 12 /*7ded*/, 12 /*7dee*/, 13 /*7def*/,
    10 /*7df0*/, 11 /*7df1*/, 11 /*7df2*/, 12 /*7df3*/, 11 /*7df4*/,
    12 /*7df5*/, 12 /*7df6*/, 13 /*7df7*/, 11 /*7df8*/, 12 /*7df9*/,
    12 /*7dfa*/, 13 /*7dfb*/, 12 /*7dfc*/, 13 /*7dfd*/, 13 /*7dfe*/,
    14 /*7dff*/, 6 /*7e00*/,  7 /*7e01*/,  7 /*7e02*/,  8 /*7e03*/,
    7 /*7e04*/,  8 /*7e05*/,  8 /*7e06*/,  9 /*7e07*/,  7 /*7e08*/,
    8 /*7e09*/,  8 /*7e0a*/,  9 /*7e0b*/,  8 /*7e0c*/,  9 /*7e0d*/,
    9 /*7e0e*/,  10 /*7e0f*/, 7 /*7e10*/,  8 /*7e11*/,  8 /*7e12*/,
    9 /*7e13*/,  8 /*7e14*/,  9 /*7e15*/,  9 /*7e16*/,  10 /*7e17*/,
    8 /*7e18*/,  9 /*7e19*/,  9 /*7e1a*/,  10 /*7e1b*/, 9 /*7e1c*/,
    10 /*7e1d*/, 10 /*7e1e*/, 11 /*7e1f*/, 7 /*7e20*/,  8 /*7e21*/,
    8 /*7e22*/,  9 /*7e23*/,  8 /*7e24*/,  9 /*7e25*/,  9 /*7e26*/,
    10 /*7e27*/, 8 /*7e28*/,  9 /*7e29*/,  9 /*7e2a*/,  10 /*7e2b*/,
    9 /*7e2c*/,  10 /*7e2d*/, 10 /*7e2e*/, 11 /*7e2f*/, 8 /*7e30*/,
    9 /*7e31*/,  9 /*7e32*/,  10 /*7e33*/, 9 /*7e34*/,  10 /*7e35*/,
    10 /*7e36*/, 11 /*7e37*/, 9 /*7e38*/,  10 /*7e39*/, 10 /*7e3a*/,
    11 /*7e3b*/, 10 /*7e3c*/, 11 /*7e3d*/, 11 /*7e3e*/, 12 /*7e3f*/,
    7 /*7e40*/,  8 /*7e41*/,  8 /*7e42*/,  9 /*7e43*/,  8 /*7e44*/,
    9 /*7e45*/,  9 /*7e46*/,  10 /*7e47*/, 8 /*7e48*/,  9 /*7e49*/,
    9 /*7e4a*/,  10 /*7e4b*/, 9 /*7e4c*/,  10 /*7e4d*/, 10 /*7e4e*/,
    11 /*7e4f*/, 8 /*7e50*/,  9 /*7e51*/,  9 /*7e52*/,  10 /*7e53*/,
    9 /*7e54*/,  10 /*7e55*/, 10 /*7e56*/, 11 /*7e57*/, 9 /*7e58*/,
    10 /*7e59*/, 10 /*7e5a*/, 11 /*7e5b*/, 10 /*7e5c*/, 11 /*7e5d*/,
    11 /*7e5e*/, 12 /*7e5f*/, 8 /*7e60*/,  9 /*7e61*/,  9 /*7e62*/,
    10 /*7e63*/, 9 /*7e64*/,  10 /*7e65*/, 10 /*7e66*/, 11 /*7e67*/,
    9 /*7e68*/,  10 /*7e69*/, 10 /*7e6a*/, 11 /*7e6b*/, 10 /*7e6c*/,
    11 /*7e6d*/, 11 /*7e6e*/, 12 /*7e6f*/, 9 /*7e70*/,  10 /*7e71*/,
    10 /*7e72*/, 11 /*7e73*/, 10 /*7e74*/, 11 /*7e75*/, 11 /*7e76*/,
    12 /*7e77*/, 10 /*7e78*/, 11 /*7e79*/, 11 /*7e7a*/, 12 /*7e7b*/,
    11 /*7e7c*/, 12 /*7e7d*/, 12 /*7e7e*/, 13 /*7e7f*/, 7 /*7e80*/,
    8 /*7e81*/,  8 /*7e82*/,  9 /*7e83*/,  8 /*7e84*/,  9 /*7e85*/,
    9 /*7e86*/,  10 /*7e87*/, 8 /*7e88*/,  9 /*7e89*/,  9 /*7e8a*/,
    10 /*7e8b*/, 9 /*7e8c*/,  10 /*7e8d*/, 10 /*7e8e*/, 11 /*7e8f*/,
    8 /*7e90*/,  9 /*7e91*/,  9 /*7e92*/,  10 /*7e93*/, 9 /*7e94*/,
    10 /*7e95*/, 10 /*7e96*/, 11 /*7e97*/, 9 /*7e98*/,  10 /*7e99*/,
    10 /*7e9a*/, 11 /*7e9b*/, 10 /*7e9c*/, 11 /*7e9d*/, 11 /*7e9e*/,
    12 /*7e9f*/, 8 /*7ea0*/,  9 /*7ea1*/,  9 /*7ea2*/,  10 /*7ea3*/,
    9 /*7ea4*/,  10 /*7ea5*/, 10 /*7ea6*/, 11 /*7ea7*/, 9 /*7ea8*/,
    10 /*7ea9*/, 10 /*7eaa*/, 11 /*7eab*/, 10 /*7eac*/, 11 /*7ead*/,
    11 /*7eae*/, 12 /*7eaf*/, 9 /*7eb0*/,  10 /*7eb1*/, 10 /*7eb2*/,
    11 /*7eb3*/, 10 /*7eb4*/, 11 /*7eb5*/, 11 /*7eb6*/, 12 /*7eb7*/,
    10 /*7eb8*/, 11 /*7eb9*/, 11 /*7eba*/, 12 /*7ebb*/, 11 /*7ebc*/,
    12 /*7ebd*/, 12 /*7ebe*/, 13 /*7ebf*/, 8 /*7ec0*/,  9 /*7ec1*/,
    9 /*7ec2*/,  10 /*7ec3*/, 9 /*7ec4*/,  10 /*7ec5*/, 10 /*7ec6*/,
    11 /*7ec7*/, 9 /*7ec8*/,  10 /*7ec9*/, 10 /*7eca*/, 11 /*7ecb*/,
    10 /*7ecc*/, 11 /*7ecd*/, 11 /*7ece*/, 12 /*7ecf*/, 9 /*7ed0*/,
    10 /*7ed1*/, 10 /*7ed2*/, 11 /*7ed3*/, 10 /*7ed4*/, 11 /*7ed5*/,
    11 /*7ed6*/, 12 /*7ed7*/, 10 /*7ed8*/, 11 /*7ed9*/, 11 /*7eda*/,
    12 /*7edb*/, 11 /*7edc*/, 12 /*7edd*/, 12 /*7ede*/, 13 /*7edf*/,
    9 /*7ee0*/,  10 /*7ee1*/, 10 /*7ee2*/, 11 /*7ee3*/, 10 /*7ee4*/,
    11 /*7ee5*/, 11 /*7ee6*/, 12 /*7ee7*/, 10 /*7ee8*/, 11 /*7ee9*/,
    11 /*7eea*/, 12 /*7eeb*/, 11 /*7eec*/, 12 /*7eed*/, 12 /*7eee*/,
    13 /*7eef*/, 10 /*7ef0*/, 11 /*7ef1*/, 11 /*7ef2*/, 12 /*7ef3*/,
    11 /*7ef4*/, 12 /*7ef5*/, 12 /*7ef6*/, 13 /*7ef7*/, 11 /*7ef8*/,
    12 /*7ef9*/, 12 /*7efa*/, 13 /*7efb*/, 12 /*7efc*/, 13 /*7efd*/,
    13 /*7efe*/, 14 /*7eff*/, 7 /*7f00*/,  8 /*7f01*/,  8 /*7f02*/,
    9 /*7f03*/,  8 /*7f04*/,  9 /*7f05*/,  9 /*7f06*/,  10 /*7f07*/,
    8 /*7f08*/,  9 /*7f09*/,  9 /*7f0a*/,  10 /*7f0b*/, 9 /*7f0c*/,
    10 /*7f0d*/, 10 /*7f0e*/, 11 /*7f0f*/, 8 /*7f10*/,  9 /*7f11*/,
    9 /*7f12*/,  10 /*7f13*/, 9 /*7f14*/,  10 /*7f15*/, 10 /*7f16*/,
    11 /*7f17*/, 9 /*7f18*/,  10 /*7f19*/, 10 /*7f1a*/, 11 /*7f1b*/,
    10 /*7f1c*/, 11 /*7f1d*/, 11 /*7f1e*/, 12 /*7f1f*/, 8 /*7f20*/,
    9 /*7f21*/,  9 /*7f22*/,  10 /*7f23*/, 9 /*7f24*/,  10 /*7f25*/,
    10 /*7f26*/, 11 /*7f27*/, 9 /*7f28*/,  10 /*7f29*/, 10 /*7f2a*/,
    11 /*7f2b*/, 10 /*7f2c*/, 11 /*7f2d*/, 11 /*7f2e*/, 12 /*7f2f*/,
    9 /*7f30*/,  10 /*7f31*/, 10 /*7f32*/, 11 /*7f33*/, 10 /*7f34*/,
    11 /*7f35*/, 11 /*7f36*/, 12 /*7f37*/, 10 /*7f38*/, 11 /*7f39*/,
    11 /*7f3a*/, 12 /*7f3b*/, 11 /*7f3c*/, 12 /*7f3d*/, 12 /*7f3e*/,
    13 /*7f3f*/, 8 /*7f40*/,  9 /*7f41*/,  9 /*7f42*/,  10 /*7f43*/,
    9 /*7f44*/,  10 /*7f45*/, 10 /*7f46*/, 11 /*7f47*/, 9 /*7f48*/,
    10 /*7f49*/, 10 /*7f4a*/, 11 /*7f4b*/, 10 /*7f4c*/, 11 /*7f4d*/,
    11 /*7f4e*/, 12 /*7f4f*/, 9 /*7f50*/,  10 /*7f51*/, 10 /*7f52*/,
    11 /*7f53*/, 10 /*7f54*/, 11 /*7f55*/, 11 /*7f56*/, 12 /*7f57*/,
    10 /*7f58*/, 11 /*7f59*/, 11 /*7f5a*/, 12 /*7f5b*/, 11 /*7f5c*/,
    12 /*7f5d*/, 12 /*7f5e*/, 13 /*7f5f*/, 9 /*7f60*/,  10 /*7f61*/,
    10 /*7f62*/, 11 /*7f63*/, 10 /*7f64*/, 11 /*7f65*/, 11 /*7f66*/,
    12 /*7f67*/, 10 /*7f68*/, 11 /*7f69*/, 11 /*7f6a*/, 12 /*7f6b*/,
    11 /*7f6c*/, 12 /*7f6d*/, 12 /*7f6e*/, 13 /*7f6f*/, 10 /*7f70*/,
    11 /*7f71*/, 11 /*7f72*/, 12 /*7f73*/, 11 /*7f74*/, 12 /*7f75*/,
    12 /*7f76*/, 13 /*7f77*/, 11 /*7f78*/, 12 /*7f79*/, 12 /*7f7a*/,
    13 /*7f7b*/, 12 /*7f7c*/, 13 /*7f7d*/, 13 /*7f7e*/, 14 /*7f7f*/,
    8 /*7f80*/,  9 /*7f81*/,  9 /*7f82*/,  10 /*7f83*/, 9 /*7f84*/,
    10 /*7f85*/, 10 /*7f86*/, 11 /*7f87*/, 9 /*7f88*/,  10 /*7f89*/,
    10 /*7f8a*/, 11 /*7f8b*/, 10 /*7f8c*/, 11 /*7f8d*/, 11 /*7f8e*/,
    12 /*7f8f*/, 9 /*7f90*/,  10 /*7f91*/, 10 /*7f92*/, 11 /*7f93*/,
    10 /*7f94*/, 11 /*7f95*/, 11 /*7f96*/, 12 /*7f97*/, 10 /*7f98*/,
    11 /*7f99*/, 11 /*7f9a*/, 12 /*7f9b*/, 11 /*7f9c*/, 12 /*7f9d*/,
    12 /*7f9e*/, 13 /*7f9f*/, 9 /*7fa0*/,  10 /*7fa1*/, 10 /*7fa2*/,
    11 /*7fa3*/, 10 /*7fa4*/, 11 /*7fa5*/, 11 /*7fa6*/, 12 /*7fa7*/,
    10 /*7fa8*/, 11 /*7fa9*/, 11 /*7faa*/, 12 /*7fab*/, 11 /*7fac*/,
    12 /*7fad*/, 12 /*7fae*/, 13 /*7faf*/, 10 /*7fb0*/, 11 /*7fb1*/,
    11 /*7fb2*/, 12 /*7fb3*/, 11 /*7fb4*/, 12 /*7fb5*/, 12 /*7fb6*/,
    13 /*7fb7*/, 11 /*7fb8*/, 12 /*7fb9*/, 12 /*7fba*/, 13 /*7fbb*/,
    12 /*7fbc*/, 13 /*7fbd*/, 13 /*7fbe*/, 14 /*7fbf*/, 9 /*7fc0*/,
    10 /*7fc1*/, 10 /*7fc2*/, 11 /*7fc3*/, 10 /*7fc4*/, 11 /*7fc5*/,
    11 /*7fc6*/, 12 /*7fc7*/, 10 /*7fc8*/, 11 /*7fc9*/, 11 /*7fca*/,
    12 /*7fcb*/, 11 /*7fcc*/, 12 /*7fcd*/, 12 /*7fce*/, 13 /*7fcf*/,
    10 /*7fd0*/, 11 /*7fd1*/, 11 /*7fd2*/, 12 /*7fd3*/, 11 /*7fd4*/,
    12 /*7fd5*/, 12 /*7fd6*/, 13 /*7fd7*/, 11 /*7fd8*/, 12 /*7fd9*/,
    12 /*7fda*/, 13 /*7fdb*/, 12 /*7fdc*/, 13 /*7fdd*/, 13 /*7fde*/,
    14 /*7fdf*/, 10 /*7fe0*/, 11 /*7fe1*/, 11 /*7fe2*/, 12 /*7fe3*/,
    11 /*7fe4*/, 12 /*7fe5*/, 12 /*7fe6*/, 13 /*7fe7*/, 11 /*7fe8*/,
    12 /*7fe9*/, 12 /*7fea*/, 13 /*7feb*/, 12 /*7fec*/, 13 /*7fed*/,
    13 /*7fee*/, 14 /*7fef*/, 11 /*7ff0*/, 12 /*7ff1*/, 12 /*7ff2*/,
    13 /*7ff3*/, 12 /*7ff4*/, 13 /*7ff5*/, 13 /*7ff6*/, 14 /*7ff7*/,
    12 /*7ff8*/, 13 /*7ff9*/, 13 /*7ffa*/, 14 /*7ffb*/, 13 /*7ffc*/,
    14 /*7ffd*/, 14 /*7ffe*/, 15 /*7fff*/, 1 /*8000*/,  2 /*8001*/,
    2 /*8002*/,  3 /*8003*/,  2 /*8004*/,  3 /*8005*/,  3 /*8006*/,
    4 /*8007*/,  2 /*8008*/,  3 /*8009*/,  3 /*800a*/,  4 /*800b*/,
    3 /*800c*/,  4 /*800d*/,  4 /*800e*/,  5 /*800f*/,  2 /*8010*/,
    3 /*8011*/,  3 /*8012*/,  4 /*8013*/,  3 /*8014*/,  4 /*8015*/,
    4 /*8016*/,  5 /*8017*/,  3 /*8018*/,  4 /*8019*/,  4 /*801a*/,
    5 /*801b*/,  4 /*801c*/,  5 /*801d*/,  5 /*801e*/,  6 /*801f*/,
    2 /*8020*/,  3 /*8021*/,  3 /*8022*/,  4 /*8023*/,  3 /*8024*/,
    4 /*8025*/,  4 /*8026*/,  5 /*8027*/,  3 /*8028*/,  4 /*8029*/,
    4 /*802a*/,  5 /*802b*/,  4 /*802c*/,  5 /*802d*/,  5 /*802e*/,
    6 /*802f*/,  3 /*8030*/,  4 /*8031*/,  4 /*8032*/,  5 /*8033*/,
    4 /*8034*/,  5 /*8035*/,  5 /*8036*/,  6 /*8037*/,  4 /*8038*/,
    5 /*8039*/,  5 /*803a*/,  6 /*803b*/,  5 /*803c*/,  6 /*803d*/,
    6 /*803e*/,  7 /*803f*/,  2 /*8040*/,  3 /*8041*/,  3 /*8042*/,
    4 /*8043*/,  3 /*8044*/,  4 /*8045*/,  4 /*8046*/,  5 /*8047*/,
    3 /*8048*/,  4 /*8049*/,  4 /*804a*/,  5 /*804b*/,  4 /*804c*/,
    5 /*804d*/,  5 /*804e*/,  6 /*804f*/,  3 /*8050*/,  4 /*8051*/,
    4 /*8052*/,  5 /*8053*/,  4 /*8054*/,  5 /*8055*/,  5 /*8056*/,
    6 /*8057*/,  4 /*8058*/,  5 /*8059*/,  5 /*805a*/,  6 /*805b*/,
    5 /*805c*/,  6 /*805d*/,  6 /*805e*/,  7 /*805f*/,  3 /*8060*/,
    4 /*8061*/,  4 /*8062*/,  5 /*8063*/,  4 /*8064*/,  5 /*8065*/,
    5 /*8066*/,  6 /*8067*/,  4 /*8068*/,  5 /*8069*/,  5 /*806a*/,
    6 /*806b*/,  5 /*806c*/,  6 /*806d*/,  6 /*806e*/,  7 /*806f*/,
    4 /*8070*/,  5 /*8071*/,  5 /*8072*/,  6 /*8073*/,  5 /*8074*/,
    6 /*8075*/,  6 /*8076*/,  7 /*8077*/,  5 /*8078*/,  6 /*8079*/,
    6 /*807a*/,  7 /*807b*/,  6 /*807c*/,  7 /*807d*/,  7 /*807e*/,
    8 /*807f*/,  2 /*8080*/,  3 /*8081*/,  3 /*8082*/,  4 /*8083*/,
    3 /*8084*/,  4 /*8085*/,  4 /*8086*/,  5 /*8087*/,  3 /*8088*/,
    4 /*8089*/,  4 /*808a*/,  5 /*808b*/,  4 /*808c*/,  5 /*808d*/,
    5 /*808e*/,  6 /*808f*/,  3 /*8090*/,  4 /*8091*/,  4 /*8092*/,
    5 /*8093*/,  4 /*8094*/,  5 /*8095*/,  5 /*8096*/,  6 /*8097*/,
    4 /*8098*/,  5 /*8099*/,  5 /*809a*/,  6 /*809b*/,  5 /*809c*/,
    6 /*809d*/,  6 /*809e*/,  7 /*809f*/,  3 /*80a0*/,  4 /*80a1*/,
    4 /*80a2*/,  5 /*80a3*/,  4 /*80a4*/,  5 /*80a5*/,  5 /*80a6*/,
    6 /*80a7*/,  4 /*80a8*/,  5 /*80a9*/,  5 /*80aa*/,  6 /*80ab*/,
    5 /*80ac*/,  6 /*80ad*/,  6 /*80ae*/,  7 /*80af*/,  4 /*80b0*/,
    5 /*80b1*/,  5 /*80b2*/,  6 /*80b3*/,  5 /*80b4*/,  6 /*80b5*/,
    6 /*80b6*/,  7 /*80b7*/,  5 /*80b8*/,  6 /*80b9*/,  6 /*80ba*/,
    7 /*80bb*/,  6 /*80bc*/,  7 /*80bd*/,  7 /*80be*/,  8 /*80bf*/,
    3 /*80c0*/,  4 /*80c1*/,  4 /*80c2*/,  5 /*80c3*/,  4 /*80c4*/,
    5 /*80c5*/,  5 /*80c6*/,  6 /*80c7*/,  4 /*80c8*/,  5 /*80c9*/,
    5 /*80ca*/,  6 /*80cb*/,  5 /*80cc*/,  6 /*80cd*/,  6 /*80ce*/,
    7 /*80cf*/,  4 /*80d0*/,  5 /*80d1*/,  5 /*80d2*/,  6 /*80d3*/,
    5 /*80d4*/,  6 /*80d5*/,  6 /*80d6*/,  7 /*80d7*/,  5 /*80d8*/,
    6 /*80d9*/,  6 /*80da*/,  7 /*80db*/,  6 /*80dc*/,  7 /*80dd*/,
    7 /*80de*/,  8 /*80df*/,  4 /*80e0*/,  5 /*80e1*/,  5 /*80e2*/,
    6 /*80e3*/,  5 /*80e4*/,  6 /*80e5*/,  6 /*80e6*/,  7 /*80e7*/,
    5 /*80e8*/,  6 /*80e9*/,  6 /*80ea*/,  7 /*80eb*/,  6 /*80ec*/,
    7 /*80ed*/,  7 /*80ee*/,  8 /*80ef*/,  5 /*80f0*/,  6 /*80f1*/,
    6 /*80f2*/,  7 /*80f3*/,  6 /*80f4*/,  7 /*80f5*/,  7 /*80f6*/,
    8 /*80f7*/,  6 /*80f8*/,  7 /*80f9*/,  7 /*80fa*/,  8 /*80fb*/,
    7 /*80fc*/,  8 /*80fd*/,  8 /*80fe*/,  9 /*80ff*/,  2 /*8100*/,
    3 /*8101*/,  3 /*8102*/,  4 /*8103*/,  3 /*8104*/,  4 /*8105*/,
    4 /*8106*/,  5 /*8107*/,  3 /*8108*/,  4 /*8109*/,  4 /*810a*/,
    5 /*810b*/,  4 /*810c*/,  5 /*810d*/,  5 /*810e*/,  6 /*810f*/,
    3 /*8110*/,  4 /*8111*/,  4 /*8112*/,  5 /*8113*/,  4 /*8114*/,
    5 /*8115*/,  5 /*8116*/,  6 /*8117*/,  4 /*8118*/,  5 /*8119*/,
    5 /*811a*/,  6 /*811b*/,  5 /*811c*/,  6 /*811d*/,  6 /*811e*/,
    7 /*811f*/,  3 /*8120*/,  4 /*8121*/,  4 /*8122*/,  5 /*8123*/,
    4 /*8124*/,  5 /*8125*/,  5 /*8126*/,  6 /*8127*/,  4 /*8128*/,
    5 /*8129*/,  5 /*812a*/,  6 /*812b*/,  5 /*812c*/,  6 /*812d*/,
    6 /*812e*/,  7 /*812f*/,  4 /*8130*/,  5 /*8131*/,  5 /*8132*/,
    6 /*8133*/,  5 /*8134*/,  6 /*8135*/,  6 /*8136*/,  7 /*8137*/,
    5 /*8138*/,  6 /*8139*/,  6 /*813a*/,  7 /*813b*/,  6 /*813c*/,
    7 /*813d*/,  7 /*813e*/,  8 /*813f*/,  3 /*8140*/,  4 /*8141*/,
    4 /*8142*/,  5 /*8143*/,  4 /*8144*/,  5 /*8145*/,  5 /*8146*/,
    6 /*8147*/,  4 /*8148*/,  5 /*8149*/,  5 /*814a*/,  6 /*814b*/,
    5 /*814c*/,  6 /*814d*/,  6 /*814e*/,  7 /*814f*/,  4 /*8150*/,
    5 /*8151*/,  5 /*8152*/,  6 /*8153*/,  5 /*8154*/,  6 /*8155*/,
    6 /*8156*/,  7 /*8157*/,  5 /*8158*/,  6 /*8159*/,  6 /*815a*/,
    7 /*815b*/,  6 /*815c*/,  7 /*815d*/,  7 /*815e*/,  8 /*815f*/,
    4 /*8160*/,  5 /*8161*/,  5 /*8162*/,  6 /*8163*/,  5 /*8164*/,
    6 /*8165*/,  6 /*8166*/,  7 /*8167*/,  5 /*8168*/,  6 /*8169*/,
    6 /*816a*/,  7 /*816b*/,  6 /*816c*/,  7 /*816d*/,  7 /*816e*/,
    8 /*816f*/,  5 /*8170*/,  6 /*8171*/,  6 /*8172*/,  7 /*8173*/,
    6 /*8174*/,  7 /*8175*/,  7 /*8176*/,  8 /*8177*/,  6 /*8178*/,
    7 /*8179*/,  7 /*817a*/,  8 /*817b*/,  7 /*817c*/,  8 /*817d*/,
    8 /*817e*/,  9 /*817f*/,  3 /*8180*/,  4 /*8181*/,  4 /*8182*/,
    5 /*8183*/,  4 /*8184*/,  5 /*8185*/,  5 /*8186*/,  6 /*8187*/,
    4 /*8188*/,  5 /*8189*/,  5 /*818a*/,  6 /*818b*/,  5 /*818c*/,
    6 /*818d*/,  6 /*818e*/,  7 /*818f*/,  4 /*8190*/,  5 /*8191*/,
    5 /*8192*/,  6 /*8193*/,  5 /*8194*/,  6 /*8195*/,  6 /*8196*/,
    7 /*8197*/,  5 /*8198*/,  6 /*8199*/,  6 /*819a*/,  7 /*819b*/,
    6 /*819c*/,  7 /*819d*/,  7 /*819e*/,  8 /*819f*/,  4 /*81a0*/,
    5 /*81a1*/,  5 /*81a2*/,  6 /*81a3*/,  5 /*81a4*/,  6 /*81a5*/,
    6 /*81a6*/,  7 /*81a7*/,  5 /*81a8*/,  6 /*81a9*/,  6 /*81aa*/,
    7 /*81ab*/,  6 /*81ac*/,  7 /*81ad*/,  7 /*81ae*/,  8 /*81af*/,
    5 /*81b0*/,  6 /*81b1*/,  6 /*81b2*/,  7 /*81b3*/,  6 /*81b4*/,
    7 /*81b5*/,  7 /*81b6*/,  8 /*81b7*/,  6 /*81b8*/,  7 /*81b9*/,
    7 /*81ba*/,  8 /*81bb*/,  7 /*81bc*/,  8 /*81bd*/,  8 /*81be*/,
    9 /*81bf*/,  4 /*81c0*/,  5 /*81c1*/,  5 /*81c2*/,  6 /*81c3*/,
    5 /*81c4*/,  6 /*81c5*/,  6 /*81c6*/,  7 /*81c7*/,  5 /*81c8*/,
    6 /*81c9*/,  6 /*81ca*/,  7 /*81cb*/,  6 /*81cc*/,  7 /*81cd*/,
    7 /*81ce*/,  8 /*81cf*/,  5 /*81d0*/,  6 /*81d1*/,  6 /*81d2*/,
    7 /*81d3*/,  6 /*81d4*/,  7 /*81d5*/,  7 /*81d6*/,  8 /*81d7*/,
    6 /*81d8*/,  7 /*81d9*/,  7 /*81da*/,  8 /*81db*/,  7 /*81dc*/,
    8 /*81dd*/,  8 /*81de*/,  9 /*81df*/,  5 /*81e0*/,  6 /*81e1*/,
    6 /*81e2*/,  7 /*81e3*/,  6 /*81e4*/,  7 /*81e5*/,  7 /*81e6*/,
    8 /*81e7*/,  6 /*81e8*/,  7 /*81e9*/,  7 /*81ea*/,  8 /*81eb*/,
    7 /*81ec*/,  8 /*81ed*/,  8 /*81ee*/,  9 /*81ef*/,  6 /*81f0*/,
    7 /*81f1*/,  7 /*81f2*/,  8 /*81f3*/,  7 /*81f4*/,  8 /*81f5*/,
    8 /*81f6*/,  9 /*81f7*/,  7 /*81f8*/,  8 /*81f9*/,  8 /*81fa*/,
    9 /*81fb*/,  8 /*81fc*/,  9 /*81fd*/,  9 /*81fe*/,  10 /*81ff*/,
    2 /*8200*/,  3 /*8201*/,  3 /*8202*/,  4 /*8203*/,  3 /*8204*/,
    4 /*8205*/,  4 /*8206*/,  5 /*8207*/,  3 /*8208*/,  4 /*8209*/,
    4 /*820a*/,  5 /*820b*/,  4 /*820c*/,  5 /*820d*/,  5 /*820e*/,
    6 /*820f*/,  3 /*8210*/,  4 /*8211*/,  4 /*8212*/,  5 /*8213*/,
    4 /*8214*/,  5 /*8215*/,  5 /*8216*/,  6 /*8217*/,  4 /*8218*/,
    5 /*8219*/,  5 /*821a*/,  6 /*821b*/,  5 /*821c*/,  6 /*821d*/,
    6 /*821e*/,  7 /*821f*/,  3 /*8220*/,  4 /*8221*/,  4 /*8222*/,
    5 /*8223*/,  4 /*8224*/,  5 /*8225*/,  5 /*8226*/,  6 /*8227*/,
    4 /*8228*/,  5 /*8229*/,  5 /*822a*/,  6 /*822b*/,  5 /*822c*/,
    6 /*822d*/,  6 /*822e*/,  7 /*822f*/,  4 /*8230*/,  5 /*8231*/,
    5 /*8232*/,  6 /*8233*/,  5 /*8234*/,  6 /*8235*/,  6 /*8236*/,
    7 /*8237*/,  5 /*8238*/,  6 /*8239*/,  6 /*823a*/,  7 /*823b*/,
    6 /*823c*/,  7 /*823d*/,  7 /*823e*/,  8 /*823f*/,  3 /*8240*/,
    4 /*8241*/,  4 /*8242*/,  5 /*8243*/,  4 /*8244*/,  5 /*8245*/,
    5 /*8246*/,  6 /*8247*/,  4 /*8248*/,  5 /*8249*/,  5 /*824a*/,
    6 /*824b*/,  5 /*824c*/,  6 /*824d*/,  6 /*824e*/,  7 /*824f*/,
    4 /*8250*/,  5 /*8251*/,  5 /*8252*/,  6 /*8253*/,  5 /*8254*/,
    6 /*8255*/,  6 /*8256*/,  7 /*8257*/,  5 /*8258*/,  6 /*8259*/,
    6 /*825a*/,  7 /*825b*/,  6 /*825c*/,  7 /*825d*/,  7 /*825e*/,
    8 /*825f*/,  4 /*8260*/,  5 /*8261*/,  5 /*8262*/,  6 /*8263*/,
    5 /*8264*/,  6 /*8265*/,  6 /*8266*/,  7 /*8267*/,  5 /*8268*/,
    6 /*8269*/,  6 /*826a*/,  7 /*826b*/,  6 /*826c*/,  7 /*826d*/,
    7 /*826e*/,  8 /*826f*/,  5 /*8270*/,  6 /*8271*/,  6 /*8272*/,
    7 /*8273*/,  6 /*8274*/,  7 /*8275*/,  7 /*8276*/,  8 /*8277*/,
    6 /*8278*/,  7 /*8279*/,  7 /*827a*/,  8 /*827b*/,  7 /*827c*/,
    8 /*827d*/,  8 /*827e*/,  9 /*827f*/,  3 /*8280*/,  4 /*8281*/,
    4 /*8282*/,  5 /*8283*/,  4 /*8284*/,  5 /*8285*/,  5 /*8286*/,
    6 /*8287*/,  4 /*8288*/,  5 /*8289*/,  5 /*828a*/,  6 /*828b*/,
    5 /*828c*/,  6 /*828d*/,  6 /*828e*/,  7 /*828f*/,  4 /*8290*/,
    5 /*8291*/,  5 /*8292*/,  6 /*8293*/,  5 /*8294*/,  6 /*8295*/,
    6 /*8296*/,  7 /*8297*/,  5 /*8298*/,  6 /*8299*/,  6 /*829a*/,
    7 /*829b*/,  6 /*829c*/,  7 /*829d*/,  7 /*829e*/,  8 /*829f*/,
    4 /*82a0*/,  5 /*82a1*/,  5 /*82a2*/,  6 /*82a3*/,  5 /*82a4*/,
    6 /*82a5*/,  6 /*82a6*/,  7 /*82a7*/,  5 /*82a8*/,  6 /*82a9*/,
    6 /*82aa*/,  7 /*82ab*/,  6 /*82ac*/,  7 /*82ad*/,  7 /*82ae*/,
    8 /*82af*/,  5 /*82b0*/,  6 /*82b1*/,  6 /*82b2*/,  7 /*82b3*/,
    6 /*82b4*/,  7 /*82b5*/,  7 /*82b6*/,  8 /*82b7*/,  6 /*82b8*/,
    7 /*82b9*/,  7 /*82ba*/,  8 /*82bb*/,  7 /*82bc*/,  8 /*82bd*/,
    8 /*82be*/,  9 /*82bf*/,  4 /*82c0*/,  5 /*82c1*/,  5 /*82c2*/,
    6 /*82c3*/,  5 /*82c4*/,  6 /*82c5*/,  6 /*82c6*/,  7 /*82c7*/,
    5 /*82c8*/,  6 /*82c9*/,  6 /*82ca*/,  7 /*82cb*/,  6 /*82cc*/,
    7 /*82cd*/,  7 /*82ce*/,  8 /*82cf*/,  5 /*82d0*/,  6 /*82d1*/,
    6 /*82d2*/,  7 /*82d3*/,  6 /*82d4*/,  7 /*82d5*/,  7 /*82d6*/,
    8 /*82d7*/,  6 /*82d8*/,  7 /*82d9*/,  7 /*82da*/,  8 /*82db*/,
    7 /*82dc*/,  8 /*82dd*/,  8 /*82de*/,  9 /*82df*/,  5 /*82e0*/,
    6 /*82e1*/,  6 /*82e2*/,  7 /*82e3*/,  6 /*82e4*/,  7 /*82e5*/,
    7 /*82e6*/,  8 /*82e7*/,  6 /*82e8*/,  7 /*82e9*/,  7 /*82ea*/,
    8 /*82eb*/,  7 /*82ec*/,  8 /*82ed*/,  8 /*82ee*/,  9 /*82ef*/,
    6 /*82f0*/,  7 /*82f1*/,  7 /*82f2*/,  8 /*82f3*/,  7 /*82f4*/,
    8 /*82f5*/,  8 /*82f6*/,  9 /*82f7*/,  7 /*82f8*/,  8 /*82f9*/,
    8 /*82fa*/,  9 /*82fb*/,  8 /*82fc*/,  9 /*82fd*/,  9 /*82fe*/,
    10 /*82ff*/, 3 /*8300*/,  4 /*8301*/,  4 /*8302*/,  5 /*8303*/,
    4 /*8304*/,  5 /*8305*/,  5 /*8306*/,  6 /*8307*/,  4 /*8308*/,
    5 /*8309*/,  5 /*830a*/,  6 /*830b*/,  5 /*830c*/,  6 /*830d*/,
    6 /*830e*/,  7 /*830f*/,  4 /*8310*/,  5 /*8311*/,  5 /*8312*/,
    6 /*8313*/,  5 /*8314*/,  6 /*8315*/,  6 /*8316*/,  7 /*8317*/,
    5 /*8318*/,  6 /*8319*/,  6 /*831a*/,  7 /*831b*/,  6 /*831c*/,
    7 /*831d*/,  7 /*831e*/,  8 /*831f*/,  4 /*8320*/,  5 /*8321*/,
    5 /*8322*/,  6 /*8323*/,  5 /*8324*/,  6 /*8325*/,  6 /*8326*/,
    7 /*8327*/,  5 /*8328*/,  6 /*8329*/,  6 /*832a*/,  7 /*832b*/,
    6 /*832c*/,  7 /*832d*/,  7 /*832e*/,  8 /*832f*/,  5 /*8330*/,
    6 /*8331*/,  6 /*8332*/,  7 /*8333*/,  6 /*8334*/,  7 /*8335*/,
    7 /*8336*/,  8 /*8337*/,  6 /*8338*/,  7 /*8339*/,  7 /*833a*/,
    8 /*833b*/,  7 /*833c*/,  8 /*833d*/,  8 /*833e*/,  9 /*833f*/,
    4 /*8340*/,  5 /*8341*/,  5 /*8342*/,  6 /*8343*/,  5 /*8344*/,
    6 /*8345*/,  6 /*8346*/,  7 /*8347*/,  5 /*8348*/,  6 /*8349*/,
    6 /*834a*/,  7 /*834b*/,  6 /*834c*/,  7 /*834d*/,  7 /*834e*/,
    8 /*834f*/,  5 /*8350*/,  6 /*8351*/,  6 /*8352*/,  7 /*8353*/,
    6 /*8354*/,  7 /*8355*/,  7 /*8356*/,  8 /*8357*/,  6 /*8358*/,
    7 /*8359*/,  7 /*835a*/,  8 /*835b*/,  7 /*835c*/,  8 /*835d*/,
    8 /*835e*/,  9 /*835f*/,  5 /*8360*/,  6 /*8361*/,  6 /*8362*/,
    7 /*8363*/,  6 /*8364*/,  7 /*8365*/,  7 /*8366*/,  8 /*8367*/,
    6 /*8368*/,  7 /*8369*/,  7 /*836a*/,  8 /*836b*/,  7 /*836c*/,
    8 /*836d*/,  8 /*836e*/,  9 /*836f*/,  6 /*8370*/,  7 /*8371*/,
    7 /*8372*/,  8 /*8373*/,  7 /*8374*/,  8 /*8375*/,  8 /*8376*/,
    9 /*8377*/,  7 /*8378*/,  8 /*8379*/,  8 /*837a*/,  9 /*837b*/,
    8 /*837c*/,  9 /*837d*/,  9 /*837e*/,  10 /*837f*/, 4 /*8380*/,
    5 /*8381*/,  5 /*8382*/,  6 /*8383*/,  5 /*8384*/,  6 /*8385*/,
    6 /*8386*/,  7 /*8387*/,  5 /*8388*/,  6 /*8389*/,  6 /*838a*/,
    7 /*838b*/,  6 /*838c*/,  7 /*838d*/,  7 /*838e*/,  8 /*838f*/,
    5 /*8390*/,  6 /*8391*/,  6 /*8392*/,  7 /*8393*/,  6 /*8394*/,
    7 /*8395*/,  7 /*8396*/,  8 /*8397*/,  6 /*8398*/,  7 /*8399*/,
    7 /*839a*/,  8 /*839b*/,  7 /*839c*/,  8 /*839d*/,  8 /*839e*/,
    9 /*839f*/,  5 /*83a0*/,  6 /*83a1*/,  6 /*83a2*/,  7 /*83a3*/,
    6 /*83a4*/,  7 /*83a5*/,  7 /*83a6*/,  8 /*83a7*/,  6 /*83a8*/,
    7 /*83a9*/,  7 /*83aa*/,  8 /*83ab*/,  7 /*83ac*/,  8 /*83ad*/,
    8 /*83ae*/,  9 /*83af*/,  6 /*83b0*/,  7 /*83b1*/,  7 /*83b2*/,
    8 /*83b3*/,  7 /*83b4*/,  8 /*83b5*/,  8 /*83b6*/,  9 /*83b7*/,
    7 /*83b8*/,  8 /*83b9*/,  8 /*83ba*/,  9 /*83bb*/,  8 /*83bc*/,
    9 /*83bd*/,  9 /*83be*/,  10 /*83bf*/, 5 /*83c0*/,  6 /*83c1*/,
    6 /*83c2*/,  7 /*83c3*/,  6 /*83c4*/,  7 /*83c5*/,  7 /*83c6*/,
    8 /*83c7*/,  6 /*83c8*/,  7 /*83c9*/,  7 /*83ca*/,  8 /*83cb*/,
    7 /*83cc*/,  8 /*83cd*/,  8 /*83ce*/,  9 /*83cf*/,  6 /*83d0*/,
    7 /*83d1*/,  7 /*83d2*/,  8 /*83d3*/,  7 /*83d4*/,  8 /*83d5*/,
    8 /*83d6*/,  9 /*83d7*/,  7 /*83d8*/,  8 /*83d9*/,  8 /*83da*/,
    9 /*83db*/,  8 /*83dc*/,  9 /*83dd*/,  9 /*83de*/,  10 /*83df*/,
    6 /*83e0*/,  7 /*83e1*/,  7 /*83e2*/,  8 /*83e3*/,  7 /*83e4*/,
    8 /*83e5*/,  8 /*83e6*/,  9 /*83e7*/,  7 /*83e8*/,  8 /*83e9*/,
    8 /*83ea*/,  9 /*83eb*/,  8 /*83ec*/,  9 /*83ed*/,  9 /*83ee*/,
    10 /*83ef*/, 7 /*83f0*/,  8 /*83f1*/,  8 /*83f2*/,  9 /*83f3*/,
    8 /*83f4*/,  9 /*83f5*/,  9 /*83f6*/,  10 /*83f7*/, 8 /*83f8*/,
    9 /*83f9*/,  9 /*83fa*/,  10 /*83fb*/, 9 /*83fc*/,  10 /*83fd*/,
    10 /*83fe*/, 11 /*83ff*/, 2 /*8400*/,  3 /*8401*/,  3 /*8402*/,
    4 /*8403*/,  3 /*8404*/,  4 /*8405*/,  4 /*8406*/,  5 /*8407*/,
    3 /*8408*/,  4 /*8409*/,  4 /*840a*/,  5 /*840b*/,  4 /*840c*/,
    5 /*840d*/,  5 /*840e*/,  6 /*840f*/,  3 /*8410*/,  4 /*8411*/,
    4 /*8412*/,  5 /*8413*/,  4 /*8414*/,  5 /*8415*/,  5 /*8416*/,
    6 /*8417*/,  4 /*8418*/,  5 /*8419*/,  5 /*841a*/,  6 /*841b*/,
    5 /*841c*/,  6 /*841d*/,  6 /*841e*/,  7 /*841f*/,  3 /*8420*/,
    4 /*8421*/,  4 /*8422*/,  5 /*8423*/,  4 /*8424*/,  5 /*8425*/,
    5 /*8426*/,  6 /*8427*/,  4 /*8428*/,  5 /*8429*/,  5 /*842a*/,
    6 /*842b*/,  5 /*842c*/,  6 /*842d*/,  6 /*842e*/,  7 /*842f*/,
    4 /*8430*/,  5 /*8431*/,  5 /*8432*/,  6 /*8433*/,  5 /*8434*/,
    6 /*8435*/,  6 /*8436*/,  7 /*8437*/,  5 /*8438*/,  6 /*8439*/,
    6 /*843a*/,  7 /*843b*/,  6 /*843c*/,  7 /*843d*/,  7 /*843e*/,
    8 /*843f*/,  3 /*8440*/,  4 /*8441*/,  4 /*8442*/,  5 /*8443*/,
    4 /*8444*/,  5 /*8445*/,  5 /*8446*/,  6 /*8447*/,  4 /*8448*/,
    5 /*8449*/,  5 /*844a*/,  6 /*844b*/,  5 /*844c*/,  6 /*844d*/,
    6 /*844e*/,  7 /*844f*/,  4 /*8450*/,  5 /*8451*/,  5 /*8452*/,
    6 /*8453*/,  5 /*8454*/,  6 /*8455*/,  6 /*8456*/,  7 /*8457*/,
    5 /*8458*/,  6 /*8459*/,  6 /*845a*/,  7 /*845b*/,  6 /*845c*/,
    7 /*845d*/,  7 /*845e*/,  8 /*845f*/,  4 /*8460*/,  5 /*8461*/,
    5 /*8462*/,  6 /*8463*/,  5 /*8464*/,  6 /*8465*/,  6 /*8466*/,
    7 /*8467*/,  5 /*8468*/,  6 /*8469*/,  6 /*846a*/,  7 /*846b*/,
    6 /*846c*/,  7 /*846d*/,  7 /*846e*/,  8 /*846f*/,  5 /*8470*/,
    6 /*8471*/,  6 /*8472*/,  7 /*8473*/,  6 /*8474*/,  7 /*8475*/,
    7 /*8476*/,  8 /*8477*/,  6 /*8478*/,  7 /*8479*/,  7 /*847a*/,
    8 /*847b*/,  7 /*847c*/,  8 /*847d*/,  8 /*847e*/,  9 /*847f*/,
    3 /*8480*/,  4 /*8481*/,  4 /*8482*/,  5 /*8483*/,  4 /*8484*/,
    5 /*8485*/,  5 /*8486*/,  6 /*8487*/,  4 /*8488*/,  5 /*8489*/,
    5 /*848a*/,  6 /*848b*/,  5 /*848c*/,  6 /*848d*/,  6 /*848e*/,
    7 /*848f*/,  4 /*8490*/,  5 /*8491*/,  5 /*8492*/,  6 /*8493*/,
    5 /*8494*/,  6 /*8495*/,  6 /*8496*/,  7 /*8497*/,  5 /*8498*/,
    6 /*8499*/,  6 /*849a*/,  7 /*849b*/,  6 /*849c*/,  7 /*849d*/,
    7 /*849e*/,  8 /*849f*/,  4 /*84a0*/,  5 /*84a1*/,  5 /*84a2*/,
    6 /*84a3*/,  5 /*84a4*/,  6 /*84a5*/,  6 /*84a6*/,  7 /*84a7*/,
    5 /*84a8*/,  6 /*84a9*/,  6 /*84aa*/,  7 /*84ab*/,  6 /*84ac*/,
    7 /*84ad*/,  7 /*84ae*/,  8 /*84af*/,  5 /*84b0*/,  6 /*84b1*/,
    6 /*84b2*/,  7 /*84b3*/,  6 /*84b4*/,  7 /*84b5*/,  7 /*84b6*/,
    8 /*84b7*/,  6 /*84b8*/,  7 /*84b9*/,  7 /*84ba*/,  8 /*84bb*/,
    7 /*84bc*/,  8 /*84bd*/,  8 /*84be*/,  9 /*84bf*/,  4 /*84c0*/,
    5 /*84c1*/,  5 /*84c2*/,  6 /*84c3*/,  5 /*84c4*/,  6 /*84c5*/,
    6 /*84c6*/,  7 /*84c7*/,  5 /*84c8*/,  6 /*84c9*/,  6 /*84ca*/,
    7 /*84cb*/,  6 /*84cc*/,  7 /*84cd*/,  7 /*84ce*/,  8 /*84cf*/,
    5 /*84d0*/,  6 /*84d1*/,  6 /*84d2*/,  7 /*84d3*/,  6 /*84d4*/,
    7 /*84d5*/,  7 /*84d6*/,  8 /*84d7*/,  6 /*84d8*/,  7 /*84d9*/,
    7 /*84da*/,  8 /*84db*/,  7 /*84dc*/,  8 /*84dd*/,  8 /*84de*/,
    9 /*84df*/,  5 /*84e0*/,  6 /*84e1*/,  6 /*84e2*/,  7 /*84e3*/,
    6 /*84e4*/,  7 /*84e5*/,  7 /*84e6*/,  8 /*84e7*/,  6 /*84e8*/,
    7 /*84e9*/,  7 /*84ea*/,  8 /*84eb*/,  7 /*84ec*/,  8 /*84ed*/,
    8 /*84ee*/,  9 /*84ef*/,  6 /*84f0*/,  7 /*84f1*/,  7 /*84f2*/,
    8 /*84f3*/,  7 /*84f4*/,  8 /*84f5*/,  8 /*84f6*/,  9 /*84f7*/,
    7 /*84f8*/,  8 /*84f9*/,  8 /*84fa*/,  9 /*84fb*/,  8 /*84fc*/,
    9 /*84fd*/,  9 /*84fe*/,  10 /*84ff*/, 3 /*8500*/,  4 /*8501*/,
    4 /*8502*/,  5 /*8503*/,  4 /*8504*/,  5 /*8505*/,  5 /*8506*/,
    6 /*8507*/,  4 /*8508*/,  5 /*8509*/,  5 /*850a*/,  6 /*850b*/,
    5 /*850c*/,  6 /*850d*/,  6 /*850e*/,  7 /*850f*/,  4 /*8510*/,
    5 /*8511*/,  5 /*8512*/,  6 /*8513*/,  5 /*8514*/,  6 /*8515*/,
    6 /*8516*/,  7 /*8517*/,  5 /*8518*/,  6 /*8519*/,  6 /*851a*/,
    7 /*851b*/,  6 /*851c*/,  7 /*851d*/,  7 /*851e*/,  8 /*851f*/,
    4 /*8520*/,  5 /*8521*/,  5 /*8522*/,  6 /*8523*/,  5 /*8524*/,
    6 /*8525*/,  6 /*8526*/,  7 /*8527*/,  5 /*8528*/,  6 /*8529*/,
    6 /*852a*/,  7 /*852b*/,  6 /*852c*/,  7 /*852d*/,  7 /*852e*/,
    8 /*852f*/,  5 /*8530*/,  6 /*8531*/,  6 /*8532*/,  7 /*8533*/,
    6 /*8534*/,  7 /*8535*/,  7 /*8536*/,  8 /*8537*/,  6 /*8538*/,
    7 /*8539*/,  7 /*853a*/,  8 /*853b*/,  7 /*853c*/,  8 /*853d*/,
    8 /*853e*/,  9 /*853f*/,  4 /*8540*/,  5 /*8541*/,  5 /*8542*/,
    6 /*8543*/,  5 /*8544*/,  6 /*8545*/,  6 /*8546*/,  7 /*8547*/,
    5 /*8548*/,  6 /*8549*/,  6 /*854a*/,  7 /*854b*/,  6 /*854c*/,
    7 /*854d*/,  7 /*854e*/,  8 /*854f*/,  5 /*8550*/,  6 /*8551*/,
    6 /*8552*/,  7 /*8553*/,  6 /*8554*/,  7 /*8555*/,  7 /*8556*/,
    8 /*8557*/,  6 /*8558*/,  7 /*8559*/,  7 /*855a*/,  8 /*855b*/,
    7 /*855c*/,  8 /*855d*/,  8 /*855e*/,  9 /*855f*/,  5 /*8560*/,
    6 /*8561*/,  6 /*8562*/,  7 /*8563*/,  6 /*8564*/,  7 /*8565*/,
    7 /*8566*/,  8 /*8567*/,  6 /*8568*/,  7 /*8569*/,  7 /*856a*/,
    8 /*856b*/,  7 /*856c*/,  8 /*856d*/,  8 /*856e*/,  9 /*856f*/,
    6 /*8570*/,  7 /*8571*/,  7 /*8572*/,  8 /*8573*/,  7 /*8574*/,
    8 /*8575*/,  8 /*8576*/,  9 /*8577*/,  7 /*8578*/,  8 /*8579*/,
    8 /*857a*/,  9 /*857b*/,  8 /*857c*/,  9 /*857d*/,  9 /*857e*/,
    10 /*857f*/, 4 /*8580*/,  5 /*8581*/,  5 /*8582*/,  6 /*8583*/,
    5 /*8584*/,  6 /*8585*/,  6 /*8586*/,  7 /*8587*/,  5 /*8588*/,
    6 /*8589*/,  6 /*858a*/,  7 /*858b*/,  6 /*858c*/,  7 /*858d*/,
    7 /*858e*/,  8 /*858f*/,  5 /*8590*/,  6 /*8591*/,  6 /*8592*/,
    7 /*8593*/,  6 /*8594*/,  7 /*8595*/,  7 /*8596*/,  8 /*8597*/,
    6 /*8598*/,  7 /*8599*/,  7 /*859a*/,  8 /*859b*/,  7 /*859c*/,
    8 /*859d*/,  8 /*859e*/,  9 /*859f*/,  5 /*85a0*/,  6 /*85a1*/,
    6 /*85a2*/,  7 /*85a3*/,  6 /*85a4*/,  7 /*85a5*/,  7 /*85a6*/,
    8 /*85a7*/,  6 /*85a8*/,  7 /*85a9*/,  7 /*85aa*/,  8 /*85ab*/,
    7 /*85ac*/,  8 /*85ad*/,  8 /*85ae*/,  9 /*85af*/,  6 /*85b0*/,
    7 /*85b1*/,  7 /*85b2*/,  8 /*85b3*/,  7 /*85b4*/,  8 /*85b5*/,
    8 /*85b6*/,  9 /*85b7*/,  7 /*85b8*/,  8 /*85b9*/,  8 /*85ba*/,
    9 /*85bb*/,  8 /*85bc*/,  9 /*85bd*/,  9 /*85be*/,  10 /*85bf*/,
    5 /*85c0*/,  6 /*85c1*/,  6 /*85c2*/,  7 /*85c3*/,  6 /*85c4*/,
    7 /*85c5*/,  7 /*85c6*/,  8 /*85c7*/,  6 /*85c8*/,  7 /*85c9*/,
    7 /*85ca*/,  8 /*85cb*/,  7 /*85cc*/,  8 /*85cd*/,  8 /*85ce*/,
    9 /*85cf*/,  6 /*85d0*/,  7 /*85d1*/,  7 /*85d2*/,  8 /*85d3*/,
    7 /*85d4*/,  8 /*85d5*/,  8 /*85d6*/,  9 /*85d7*/,  7 /*85d8*/,
    8 /*85d9*/,  8 /*85da*/,  9 /*85db*/,  8 /*85dc*/,  9 /*85dd*/,
    9 /*85de*/,  10 /*85df*/, 6 /*85e0*/,  7 /*85e1*/,  7 /*85e2*/,
    8 /*85e3*/,  7 /*85e4*/,  8 /*85e5*/,  8 /*85e6*/,  9 /*85e7*/,
    7 /*85e8*/,  8 /*85e9*/,  8 /*85ea*/,  9 /*85eb*/,  8 /*85ec*/,
    9 /*85ed*/,  9 /*85ee*/,  10 /*85ef*/, 7 /*85f0*/,  8 /*85f1*/,
    8 /*85f2*/,  9 /*85f3*/,  8 /*85f4*/,  9 /*85f5*/,  9 /*85f6*/,
    10 /*85f7*/, 8 /*85f8*/,  9 /*85f9*/,  9 /*85fa*/,  10 /*85fb*/,
    9 /*85fc*/,  10 /*85fd*/, 10 /*85fe*/, 11 /*85ff*/, 3 /*8600*/,
    4 /*8601*/,  4 /*8602*/,  5 /*8603*/,  4 /*8604*/,  5 /*8605*/,
    5 /*8606*/,  6 /*8607*/,  4 /*8608*/,  5 /*8609*/,  5 /*860a*/,
    6 /*860b*/,  5 /*860c*/,  6 /*860d*/,  6 /*860e*/,  7 /*860f*/,
    4 /*8610*/,  5 /*8611*/,  5 /*8612*/,  6 /*8613*/,  5 /*8614*/,
    6 /*8615*/,  6 /*8616*/,  7 /*8617*/,  5 /*8618*/,  6 /*8619*/,
    6 /*861a*/,  7 /*861b*/,  6 /*861c*/,  7 /*861d*/,  7 /*861e*/,
    8 /*861f*/,  4 /*8620*/,  5 /*8621*/,  5 /*8622*/,  6 /*8623*/,
    5 /*8624*/,  6 /*8625*/,  6 /*8626*/,  7 /*8627*/,  5 /*8628*/,
    6 /*8629*/,  6 /*862a*/,  7 /*862b*/,  6 /*862c*/,  7 /*862d*/,
    7 /*862e*/,  8 /*862f*/,  5 /*8630*/,  6 /*8631*/,  6 /*8632*/,
    7 /*8633*/,  6 /*8634*/,  7 /*8635*/,  7 /*8636*/,  8 /*8637*/,
    6 /*8638*/,  7 /*8639*/,  7 /*863a*/,  8 /*863b*/,  7 /*863c*/,
    8 /*863d*/,  8 /*863e*/,  9 /*863f*/,  4 /*8640*/,  5 /*8641*/,
    5 /*8642*/,  6 /*8643*/,  5 /*8644*/,  6 /*8645*/,  6 /*8646*/,
    7 /*8647*/,  5 /*8648*/,  6 /*8649*/,  6 /*864a*/,  7 /*864b*/,
    6 /*864c*/,  7 /*864d*/,  7 /*864e*/,  8 /*864f*/,  5 /*8650*/,
    6 /*8651*/,  6 /*8652*/,  7 /*8653*/,  6 /*8654*/,  7 /*8655*/,
    7 /*8656*/,  8 /*8657*/,  6 /*8658*/,  7 /*8659*/,  7 /*865a*/,
    8 /*865b*/,  7 /*865c*/,  8 /*865d*/,  8 /*865e*/,  9 /*865f*/,
    5 /*8660*/,  6 /*8661*/,  6 /*8662*/,  7 /*8663*/,  6 /*8664*/,
    7 /*8665*/,  7 /*8666*/,  8 /*8667*/,  6 /*8668*/,  7 /*8669*/,
    7 /*866a*/,  8 /*866b*/,  7 /*866c*/,  8 /*866d*/,  8 /*866e*/,
    9 /*866f*/,  6 /*8670*/,  7 /*8671*/,  7 /*8672*/,  8 /*8673*/,
    7 /*8674*/,  8 /*8675*/,  8 /*8676*/,  9 /*8677*/,  7 /*8678*/,
    8 /*8679*/,  8 /*867a*/,  9 /*867b*/,  8 /*867c*/,  9 /*867d*/,
    9 /*867e*/,  10 /*867f*/, 4 /*8680*/,  5 /*8681*/,  5 /*8682*/,
    6 /*8683*/,  5 /*8684*/,  6 /*8685*/,  6 /*8686*/,  7 /*8687*/,
    5 /*8688*/,  6 /*8689*/,  6 /*868a*/,  7 /*868b*/,  6 /*868c*/,
    7 /*868d*/,  7 /*868e*/,  8 /*868f*/,  5 /*8690*/,  6 /*8691*/,
    6 /*8692*/,  7 /*8693*/,  6 /*8694*/,  7 /*8695*/,  7 /*8696*/,
    8 /*8697*/,  6 /*8698*/,  7 /*8699*/,  7 /*869a*/,  8 /*869b*/,
    7 /*869c*/,  8 /*869d*/,  8 /*869e*/,  9 /*869f*/,  5 /*86a0*/,
    6 /*86a1*/,  6 /*86a2*/,  7 /*86a3*/,  6 /*86a4*/,  7 /*86a5*/,
    7 /*86a6*/,  8 /*86a7*/,  6 /*86a8*/,  7 /*86a9*/,  7 /*86aa*/,
    8 /*86ab*/,  7 /*86ac*/,  8 /*86ad*/,  8 /*86ae*/,  9 /*86af*/,
    6 /*86b0*/,  7 /*86b1*/,  7 /*86b2*/,  8 /*86b3*/,  7 /*86b4*/,
    8 /*86b5*/,  8 /*86b6*/,  9 /*86b7*/,  7 /*86b8*/,  8 /*86b9*/,
    8 /*86ba*/,  9 /*86bb*/,  8 /*86bc*/,  9 /*86bd*/,  9 /*86be*/,
    10 /*86bf*/, 5 /*86c0*/,  6 /*86c1*/,  6 /*86c2*/,  7 /*86c3*/,
    6 /*86c4*/,  7 /*86c5*/,  7 /*86c6*/,  8 /*86c7*/,  6 /*86c8*/,
    7 /*86c9*/,  7 /*86ca*/,  8 /*86cb*/,  7 /*86cc*/,  8 /*86cd*/,
    8 /*86ce*/,  9 /*86cf*/,  6 /*86d0*/,  7 /*86d1*/,  7 /*86d2*/,
    8 /*86d3*/,  7 /*86d4*/,  8 /*86d5*/,  8 /*86d6*/,  9 /*86d7*/,
    7 /*86d8*/,  8 /*86d9*/,  8 /*86da*/,  9 /*86db*/,  8 /*86dc*/,
    9 /*86dd*/,  9 /*86de*/,  10 /*86df*/, 6 /*86e0*/,  7 /*86e1*/,
    7 /*86e2*/,  8 /*86e3*/,  7 /*86e4*/,  8 /*86e5*/,  8 /*86e6*/,
    9 /*86e7*/,  7 /*86e8*/,  8 /*86e9*/,  8 /*86ea*/,  9 /*86eb*/,
    8 /*86ec*/,  9 /*86ed*/,  9 /*86ee*/,  10 /*86ef*/, 7 /*86f0*/,
    8 /*86f1*/,  8 /*86f2*/,  9 /*86f3*/,  8 /*86f4*/,  9 /*86f5*/,
    9 /*86f6*/,  10 /*86f7*/, 8 /*86f8*/,  9 /*86f9*/,  9 /*86fa*/,
    10 /*86fb*/, 9 /*86fc*/,  10 /*86fd*/, 10 /*86fe*/, 11 /*86ff*/,
    4 /*8700*/,  5 /*8701*/,  5 /*8702*/,  6 /*8703*/,  5 /*8704*/,
    6 /*8705*/,  6 /*8706*/,  7 /*8707*/,  5 /*8708*/,  6 /*8709*/,
    6 /*870a*/,  7 /*870b*/,  6 /*870c*/,  7 /*870d*/,  7 /*870e*/,
    8 /*870f*/,  5 /*8710*/,  6 /*8711*/,  6 /*8712*/,  7 /*8713*/,
    6 /*8714*/,  7 /*8715*/,  7 /*8716*/,  8 /*8717*/,  6 /*8718*/,
    7 /*8719*/,  7 /*871a*/,  8 /*871b*/,  7 /*871c*/,  8 /*871d*/,
    8 /*871e*/,  9 /*871f*/,  5 /*8720*/,  6 /*8721*/,  6 /*8722*/,
    7 /*8723*/,  6 /*8724*/,  7 /*8725*/,  7 /*8726*/,  8 /*8727*/,
    6 /*8728*/,  7 /*8729*/,  7 /*872a*/,  8 /*872b*/,  7 /*872c*/,
    8 /*872d*/,  8 /*872e*/,  9 /*872f*/,  6 /*8730*/,  7 /*8731*/,
    7 /*8732*/,  8 /*8733*/,  7 /*8734*/,  8 /*8735*/,  8 /*8736*/,
    9 /*8737*/,  7 /*8738*/,  8 /*8739*/,  8 /*873a*/,  9 /*873b*/,
    8 /*873c*/,  9 /*873d*/,  9 /*873e*/,  10 /*873f*/, 5 /*8740*/,
    6 /*8741*/,  6 /*8742*/,  7 /*8743*/,  6 /*8744*/,  7 /*8745*/,
    7 /*8746*/,  8 /*8747*/,  6 /*8748*/,  7 /*8749*/,  7 /*874a*/,
    8 /*874b*/,  7 /*874c*/,  8 /*874d*/,  8 /*874e*/,  9 /*874f*/,
    6 /*8750*/,  7 /*8751*/,  7 /*8752*/,  8 /*8753*/,  7 /*8754*/,
    8 /*8755*/,  8 /*8756*/,  9 /*8757*/,  7 /*8758*/,  8 /*8759*/,
    8 /*875a*/,  9 /*875b*/,  8 /*875c*/,  9 /*875d*/,  9 /*875e*/,
    10 /*875f*/, 6 /*8760*/,  7 /*8761*/,  7 /*8762*/,  8 /*8763*/,
    7 /*8764*/,  8 /*8765*/,  8 /*8766*/,  9 /*8767*/,  7 /*8768*/,
    8 /*8769*/,  8 /*876a*/,  9 /*876b*/,  8 /*876c*/,  9 /*876d*/,
    9 /*876e*/,  10 /*876f*/, 7 /*8770*/,  8 /*8771*/,  8 /*8772*/,
    9 /*8773*/,  8 /*8774*/,  9 /*8775*/,  9 /*8776*/,  10 /*8777*/,
    8 /*8778*/,  9 /*8779*/,  9 /*877a*/,  10 /*877b*/, 9 /*877c*/,
    10 /*877d*/, 10 /*877e*/, 11 /*877f*/, 5 /*8780*/,  6 /*8781*/,
    6 /*8782*/,  7 /*8783*/,  6 /*8784*/,  7 /*8785*/,  7 /*8786*/,
    8 /*8787*/,  6 /*8788*/,  7 /*8789*/,  7 /*878a*/,  8 /*878b*/,
    7 /*878c*/,  8 /*878d*/,  8 /*878e*/,  9 /*878f*/,  6 /*8790*/,
    7 /*8791*/,  7 /*8792*/,  8 /*8793*/,  7 /*8794*/,  8 /*8795*/,
    8 /*8796*/,  9 /*8797*/,  7 /*8798*/,  8 /*8799*/,  8 /*879a*/,
    9 /*879b*/,  8 /*879c*/,  9 /*879d*/,  9 /*879e*/,  10 /*879f*/,
    6 /*87a0*/,  7 /*87a1*/,  7 /*87a2*/,  8 /*87a3*/,  7 /*87a4*/,
    8 /*87a5*/,  8 /*87a6*/,  9 /*87a7*/,  7 /*87a8*/,  8 /*87a9*/,
    8 /*87aa*/,  9 /*87ab*/,  8 /*87ac*/,  9 /*87ad*/,  9 /*87ae*/,
    10 /*87af*/, 7 /*87b0*/,  8 /*87b1*/,  8 /*87b2*/,  9 /*87b3*/,
    8 /*87b4*/,  9 /*87b5*/,  9 /*87b6*/,  10 /*87b7*/, 8 /*87b8*/,
    9 /*87b9*/,  9 /*87ba*/,  10 /*87bb*/, 9 /*87bc*/,  10 /*87bd*/,
    10 /*87be*/, 11 /*87bf*/, 6 /*87c0*/,  7 /*87c1*/,  7 /*87c2*/,
    8 /*87c3*/,  7 /*87c4*/,  8 /*87c5*/,  8 /*87c6*/,  9 /*87c7*/,
    7 /*87c8*/,  8 /*87c9*/,  8 /*87ca*/,  9 /*87cb*/,  8 /*87cc*/,
    9 /*87cd*/,  9 /*87ce*/,  10 /*87cf*/, 7 /*87d0*/,  8 /*87d1*/,
    8 /*87d2*/,  9 /*87d3*/,  8 /*87d4*/,  9 /*87d5*/,  9 /*87d6*/,
    10 /*87d7*/, 8 /*87d8*/,  9 /*87d9*/,  9 /*87da*/,  10 /*87db*/,
    9 /*87dc*/,  10 /*87dd*/, 10 /*87de*/, 11 /*87df*/, 7 /*87e0*/,
    8 /*87e1*/,  8 /*87e2*/,  9 /*87e3*/,  8 /*87e4*/,  9 /*87e5*/,
    9 /*87e6*/,  10 /*87e7*/, 8 /*87e8*/,  9 /*87e9*/,  9 /*87ea*/,
    10 /*87eb*/, 9 /*87ec*/,  10 /*87ed*/, 10 /*87ee*/, 11 /*87ef*/,
    8 /*87f0*/,  9 /*87f1*/,  9 /*87f2*/,  10 /*87f3*/, 9 /*87f4*/,
    10 /*87f5*/, 10 /*87f6*/, 11 /*87f7*/, 9 /*87f8*/,  10 /*87f9*/,
    10 /*87fa*/, 11 /*87fb*/, 10 /*87fc*/, 11 /*87fd*/, 11 /*87fe*/,
    12 /*87ff*/, 2 /*8800*/,  3 /*8801*/,  3 /*8802*/,  4 /*8803*/,
    3 /*8804*/,  4 /*8805*/,  4 /*8806*/,  5 /*8807*/,  3 /*8808*/,
    4 /*8809*/,  4 /*880a*/,  5 /*880b*/,  4 /*880c*/,  5 /*880d*/,
    5 /*880e*/,  6 /*880f*/,  3 /*8810*/,  4 /*8811*/,  4 /*8812*/,
    5 /*8813*/,  4 /*8814*/,  5 /*8815*/,  5 /*8816*/,  6 /*8817*/,
    4 /*8818*/,  5 /*8819*/,  5 /*881a*/,  6 /*881b*/,  5 /*881c*/,
    6 /*881d*/,  6 /*881e*/,  7 /*881f*/,  3 /*8820*/,  4 /*8821*/,
    4 /*8822*/,  5 /*8823*/,  4 /*8824*/,  5 /*8825*/,  5 /*8826*/,
    6 /*8827*/,  4 /*8828*/,  5 /*8829*/,  5 /*882a*/,  6 /*882b*/,
    5 /*882c*/,  6 /*882d*/,  6 /*882e*/,  7 /*882f*/,  4 /*8830*/,
    5 /*8831*/,  5 /*8832*/,  6 /*8833*/,  5 /*8834*/,  6 /*8835*/,
    6 /*8836*/,  7 /*8837*/,  5 /*8838*/,  6 /*8839*/,  6 /*883a*/,
    7 /*883b*/,  6 /*883c*/,  7 /*883d*/,  7 /*883e*/,  8 /*883f*/,
    3 /*8840*/,  4 /*8841*/,  4 /*8842*/,  5 /*8843*/,  4 /*8844*/,
    5 /*8845*/,  5 /*8846*/,  6 /*8847*/,  4 /*8848*/,  5 /*8849*/,
    5 /*884a*/,  6 /*884b*/,  5 /*884c*/,  6 /*884d*/,  6 /*884e*/,
    7 /*884f*/,  4 /*8850*/,  5 /*8851*/,  5 /*8852*/,  6 /*8853*/,
    5 /*8854*/,  6 /*8855*/,  6 /*8856*/,  7 /*8857*/,  5 /*8858*/,
    6 /*8859*/,  6 /*885a*/,  7 /*885b*/,  6 /*885c*/,  7 /*885d*/,
    7 /*885e*/,  8 /*885f*/,  4 /*8860*/,  5 /*8861*/,  5 /*8862*/,
    6 /*8863*/,  5 /*8864*/,  6 /*8865*/,  6 /*8866*/,  7 /*8867*/,
    5 /*8868*/,  6 /*8869*/,  6 /*886a*/,  7 /*886b*/,  6 /*886c*/,
    7 /*886d*/,  7 /*886e*/,  8 /*886f*/,  5 /*8870*/,  6 /*8871*/,
    6 /*8872*/,  7 /*8873*/,  6 /*8874*/,  7 /*8875*/,  7 /*8876*/,
    8 /*8877*/,  6 /*8878*/,  7 /*8879*/,  7 /*887a*/,  8 /*887b*/,
    7 /*887c*/,  8 /*887d*/,  8 /*887e*/,  9 /*887f*/,  3 /*8880*/,
    4 /*8881*/,  4 /*8882*/,  5 /*8883*/,  4 /*8884*/,  5 /*8885*/,
    5 /*8886*/,  6 /*8887*/,  4 /*8888*/,  5 /*8889*/,  5 /*888a*/,
    6 /*888b*/,  5 /*888c*/,  6 /*888d*/,  6 /*888e*/,  7 /*888f*/,
    4 /*8890*/,  5 /*8891*/,  5 /*8892*/,  6 /*8893*/,  5 /*8894*/,
    6 /*8895*/,  6 /*8896*/,  7 /*8897*/,  5 /*8898*/,  6 /*8899*/,
    6 /*889a*/,  7 /*889b*/,  6 /*889c*/,  7 /*889d*/,  7 /*889e*/,
    8 /*889f*/,  4 /*88a0*/,  5 /*88a1*/,  5 /*88a2*/,  6 /*88a3*/,
    5 /*88a4*/,  6 /*88a5*/,  6 /*88a6*/,  7 /*88a7*/,  5 /*88a8*/,
    6 /*88a9*/,  6 /*88aa*/,  7 /*88ab*/,  6 /*88ac*/,  7 /*88ad*/,
    7 /*88ae*/,  8 /*88af*/,  5 /*88b0*/,  6 /*88b1*/,  6 /*88b2*/,
    7 /*88b3*/,  6 /*88b4*/,  7 /*88b5*/,  7 /*88b6*/,  8 /*88b7*/,
    6 /*88b8*/,  7 /*88b9*/,  7 /*88ba*/,  8 /*88bb*/,  7 /*88bc*/,
    8 /*88bd*/,  8 /*88be*/,  9 /*88bf*/,  4 /*88c0*/,  5 /*88c1*/,
    5 /*88c2*/,  6 /*88c3*/,  5 /*88c4*/,  6 /*88c5*/,  6 /*88c6*/,
    7 /*88c7*/,  5 /*88c8*/,  6 /*88c9*/,  6 /*88ca*/,  7 /*88cb*/,
    6 /*88cc*/,  7 /*88cd*/,  7 /*88ce*/,  8 /*88cf*/,  5 /*88d0*/,
    6 /*88d1*/,  6 /*88d2*/,  7 /*88d3*/,  6 /*88d4*/,  7 /*88d5*/,
    7 /*88d6*/,  8 /*88d7*/,  6 /*88d8*/,  7 /*88d9*/,  7 /*88da*/,
    8 /*88db*/,  7 /*88dc*/,  8 /*88dd*/,  8 /*88de*/,  9 /*88df*/,
    5 /*88e0*/,  6 /*88e1*/,  6 /*88e2*/,  7 /*88e3*/,  6 /*88e4*/,
    7 /*88e5*/,  7 /*88e6*/,  8 /*88e7*/,  6 /*88e8*/,  7 /*88e9*/,
    7 /*88ea*/,  8 /*88eb*/,  7 /*88ec*/,  8 /*88ed*/,  8 /*88ee*/,
    9 /*88ef*/,  6 /*88f0*/,  7 /*88f1*/,  7 /*88f2*/,  8 /*88f3*/,
    7 /*88f4*/,  8 /*88f5*/,  8 /*88f6*/,  9 /*88f7*/,  7 /*88f8*/,
    8 /*88f9*/,  8 /*88fa*/,  9 /*88fb*/,  8 /*88fc*/,  9 /*88fd*/,
    9 /*88fe*/,  10 /*88ff*/, 3 /*8900*/,  4 /*8901*/,  4 /*8902*/,
    5 /*8903*/,  4 /*8904*/,  5 /*8905*/,  5 /*8906*/,  6 /*8907*/,
    4 /*8908*/,  5 /*8909*/,  5 /*890a*/,  6 /*890b*/,  5 /*890c*/,
    6 /*890d*/,  6 /*890e*/,  7 /*890f*/,  4 /*8910*/,  5 /*8911*/,
    5 /*8912*/,  6 /*8913*/,  5 /*8914*/,  6 /*8915*/,  6 /*8916*/,
    7 /*8917*/,  5 /*8918*/,  6 /*8919*/,  6 /*891a*/,  7 /*891b*/,
    6 /*891c*/,  7 /*891d*/,  7 /*891e*/,  8 /*891f*/,  4 /*8920*/,
    5 /*8921*/,  5 /*8922*/,  6 /*8923*/,  5 /*8924*/,  6 /*8925*/,
    6 /*8926*/,  7 /*8927*/,  5 /*8928*/,  6 /*8929*/,  6 /*892a*/,
    7 /*892b*/,  6 /*892c*/,  7 /*892d*/,  7 /*892e*/,  8 /*892f*/,
    5 /*8930*/,  6 /*8931*/,  6 /*8932*/,  7 /*8933*/,  6 /*8934*/,
    7 /*8935*/,  7 /*8936*/,  8 /*8937*/,  6 /*8938*/,  7 /*8939*/,
    7 /*893a*/,  8 /*893b*/,  7 /*893c*/,  8 /*893d*/,  8 /*893e*/,
    9 /*893f*/,  4 /*8940*/,  5 /*8941*/,  5 /*8942*/,  6 /*8943*/,
    5 /*8944*/,  6 /*8945*/,  6 /*8946*/,  7 /*8947*/,  5 /*8948*/,
    6 /*8949*/,  6 /*894a*/,  7 /*894b*/,  6 /*894c*/,  7 /*894d*/,
    7 /*894e*/,  8 /*894f*/,  5 /*8950*/,  6 /*8951*/,  6 /*8952*/,
    7 /*8953*/,  6 /*8954*/,  7 /*8955*/,  7 /*8956*/,  8 /*8957*/,
    6 /*8958*/,  7 /*8959*/,  7 /*895a*/,  8 /*895b*/,  7 /*895c*/,
    8 /*895d*/,  8 /*895e*/,  9 /*895f*/,  5 /*8960*/,  6 /*8961*/,
    6 /*8962*/,  7 /*8963*/,  6 /*8964*/,  7 /*8965*/,  7 /*8966*/,
    8 /*8967*/,  6 /*8968*/,  7 /*8969*/,  7 /*896a*/,  8 /*896b*/,
    7 /*896c*/,  8 /*896d*/,  8 /*896e*/,  9 /*896f*/,  6 /*8970*/,
    7 /*8971*/,  7 /*8972*/,  8 /*8973*/,  7 /*8974*/,  8 /*8975*/,
    8 /*8976*/,  9 /*8977*/,  7 /*8978*/,  8 /*8979*/,  8 /*897a*/,
    9 /*897b*/,  8 /*897c*/,  9 /*897d*/,  9 /*897e*/,  10 /*897f*/,
    4 /*8980*/,  5 /*8981*/,  5 /*8982*/,  6 /*8983*/,  5 /*8984*/,
    6 /*8985*/,  6 /*8986*/,  7 /*8987*/,  5 /*8988*/,  6 /*8989*/,
    6 /*898a*/,  7 /*898b*/,  6 /*898c*/,  7 /*898d*/,  7 /*898e*/,
    8 /*898f*/,  5 /*8990*/,  6 /*8991*/,  6 /*8992*/,  7 /*8993*/,
    6 /*8994*/,  7 /*8995*/,  7 /*8996*/,  8 /*8997*/,  6 /*8998*/,
    7 /*8999*/,  7 /*899a*/,  8 /*899b*/,  7 /*899c*/,  8 /*899d*/,
    8 /*899e*/,  9 /*899f*/,  5 /*89a0*/,  6 /*89a1*/,  6 /*89a2*/,
    7 /*89a3*/,  6 /*89a4*/,  7 /*89a5*/,  7 /*89a6*/,  8 /*89a7*/,
    6 /*89a8*/,  7 /*89a9*/,  7 /*89aa*/,  8 /*89ab*/,  7 /*89ac*/,
    8 /*89ad*/,  8 /*89ae*/,  9 /*89af*/,  6 /*89b0*/,  7 /*89b1*/,
    7 /*89b2*/,  8 /*89b3*/,  7 /*89b4*/,  8 /*89b5*/,  8 /*89b6*/,
    9 /*89b7*/,  7 /*89b8*/,  8 /*89b9*/,  8 /*89ba*/,  9 /*89bb*/,
    8 /*89bc*/,  9 /*89bd*/,  9 /*89be*/,  10 /*89bf*/, 5 /*89c0*/,
    6 /*89c1*/,  6 /*89c2*/,  7 /*89c3*/,  6 /*89c4*/,  7 /*89c5*/,
    7 /*89c6*/,  8 /*89c7*/,  6 /*89c8*/,  7 /*89c9*/,  7 /*89ca*/,
    8 /*89cb*/,  7 /*89cc*/,  8 /*89cd*/,  8 /*89ce*/,  9 /*89cf*/,
    6 /*89d0*/,  7 /*89d1*/,  7 /*89d2*/,  8 /*89d3*/,  7 /*89d4*/,
    8 /*89d5*/,  8 /*89d6*/,  9 /*89d7*/,  7 /*89d8*/,  8 /*89d9*/,
    8 /*89da*/,  9 /*89db*/,  8 /*89dc*/,  9 /*89dd*/,  9 /*89de*/,
    10 /*89df*/, 6 /*89e0*/,  7 /*89e1*/,  7 /*89e2*/,  8 /*89e3*/,
    7 /*89e4*/,  8 /*89e5*/,  8 /*89e6*/,  9 /*89e7*/,  7 /*89e8*/,
    8 /*89e9*/,  8 /*89ea*/,  9 /*89eb*/,  8 /*89ec*/,  9 /*89ed*/,
    9 /*89ee*/,  10 /*89ef*/, 7 /*89f0*/,  8 /*89f1*/,  8 /*89f2*/,
    9 /*89f3*/,  8 /*89f4*/,  9 /*89f5*/,  9 /*89f6*/,  10 /*89f7*/,
    8 /*89f8*/,  9 /*89f9*/,  9 /*89fa*/,  10 /*89fb*/, 9 /*89fc*/,
    10 /*89fd*/, 10 /*89fe*/, 11 /*89ff*/, 3 /*8a00*/,  4 /*8a01*/,
    4 /*8a02*/,  5 /*8a03*/,  4 /*8a04*/,  5 /*8a05*/,  5 /*8a06*/,
    6 /*8a07*/,  4 /*8a08*/,  5 /*8a09*/,  5 /*8a0a*/,  6 /*8a0b*/,
    5 /*8a0c*/,  6 /*8a0d*/,  6 /*8a0e*/,  7 /*8a0f*/,  4 /*8a10*/,
    5 /*8a11*/,  5 /*8a12*/,  6 /*8a13*/,  5 /*8a14*/,  6 /*8a15*/,
    6 /*8a16*/,  7 /*8a17*/,  5 /*8a18*/,  6 /*8a19*/,  6 /*8a1a*/,
    7 /*8a1b*/,  6 /*8a1c*/,  7 /*8a1d*/,  7 /*8a1e*/,  8 /*8a1f*/,
    4 /*8a20*/,  5 /*8a21*/,  5 /*8a22*/,  6 /*8a23*/,  5 /*8a24*/,
    6 /*8a25*/,  6 /*8a26*/,  7 /*8a27*/,  5 /*8a28*/,  6 /*8a29*/,
    6 /*8a2a*/,  7 /*8a2b*/,  6 /*8a2c*/,  7 /*8a2d*/,  7 /*8a2e*/,
    8 /*8a2f*/,  5 /*8a30*/,  6 /*8a31*/,  6 /*8a32*/,  7 /*8a33*/,
    6 /*8a34*/,  7 /*8a35*/,  7 /*8a36*/,  8 /*8a37*/,  6 /*8a38*/,
    7 /*8a39*/,  7 /*8a3a*/,  8 /*8a3b*/,  7 /*8a3c*/,  8 /*8a3d*/,
    8 /*8a3e*/,  9 /*8a3f*/,  4 /*8a40*/,  5 /*8a41*/,  5 /*8a42*/,
    6 /*8a43*/,  5 /*8a44*/,  6 /*8a45*/,  6 /*8a46*/,  7 /*8a47*/,
    5 /*8a48*/,  6 /*8a49*/,  6 /*8a4a*/,  7 /*8a4b*/,  6 /*8a4c*/,
    7 /*8a4d*/,  7 /*8a4e*/,  8 /*8a4f*/,  5 /*8a50*/,  6 /*8a51*/,
    6 /*8a52*/,  7 /*8a53*/,  6 /*8a54*/,  7 /*8a55*/,  7 /*8a56*/,
    8 /*8a57*/,  6 /*8a58*/,  7 /*8a59*/,  7 /*8a5a*/,  8 /*8a5b*/,
    7 /*8a5c*/,  8 /*8a5d*/,  8 /*8a5e*/,  9 /*8a5f*/,  5 /*8a60*/,
    6 /*8a61*/,  6 /*8a62*/,  7 /*8a63*/,  6 /*8a64*/,  7 /*8a65*/,
    7 /*8a66*/,  8 /*8a67*/,  6 /*8a68*/,  7 /*8a69*/,  7 /*8a6a*/,
    8 /*8a6b*/,  7 /*8a6c*/,  8 /*8a6d*/,  8 /*8a6e*/,  9 /*8a6f*/,
    6 /*8a70*/,  7 /*8a71*/,  7 /*8a72*/,  8 /*8a73*/,  7 /*8a74*/,
    8 /*8a75*/,  8 /*8a76*/,  9 /*8a77*/,  7 /*8a78*/,  8 /*8a79*/,
    8 /*8a7a*/,  9 /*8a7b*/,  8 /*8a7c*/,  9 /*8a7d*/,  9 /*8a7e*/,
    10 /*8a7f*/, 4 /*8a80*/,  5 /*8a81*/,  5 /*8a82*/,  6 /*8a83*/,
    5 /*8a84*/,  6 /*8a85*/,  6 /*8a86*/,  7 /*8a87*/,  5 /*8a88*/,
    6 /*8a89*/,  6 /*8a8a*/,  7 /*8a8b*/,  6 /*8a8c*/,  7 /*8a8d*/,
    7 /*8a8e*/,  8 /*8a8f*/,  5 /*8a90*/,  6 /*8a91*/,  6 /*8a92*/,
    7 /*8a93*/,  6 /*8a94*/,  7 /*8a95*/,  7 /*8a96*/,  8 /*8a97*/,
    6 /*8a98*/,  7 /*8a99*/,  7 /*8a9a*/,  8 /*8a9b*/,  7 /*8a9c*/,
    8 /*8a9d*/,  8 /*8a9e*/,  9 /*8a9f*/,  5 /*8aa0*/,  6 /*8aa1*/,
    6 /*8aa2*/,  7 /*8aa3*/,  6 /*8aa4*/,  7 /*8aa5*/,  7 /*8aa6*/,
    8 /*8aa7*/,  6 /*8aa8*/,  7 /*8aa9*/,  7 /*8aaa*/,  8 /*8aab*/,
    7 /*8aac*/,  8 /*8aad*/,  8 /*8aae*/,  9 /*8aaf*/,  6 /*8ab0*/,
    7 /*8ab1*/,  7 /*8ab2*/,  8 /*8ab3*/,  7 /*8ab4*/,  8 /*8ab5*/,
    8 /*8ab6*/,  9 /*8ab7*/,  7 /*8ab8*/,  8 /*8ab9*/,  8 /*8aba*/,
    9 /*8abb*/,  8 /*8abc*/,  9 /*8abd*/,  9 /*8abe*/,  10 /*8abf*/,
    5 /*8ac0*/,  6 /*8ac1*/,  6 /*8ac2*/,  7 /*8ac3*/,  6 /*8ac4*/,
    7 /*8ac5*/,  7 /*8ac6*/,  8 /*8ac7*/,  6 /*8ac8*/,  7 /*8ac9*/,
    7 /*8aca*/,  8 /*8acb*/,  7 /*8acc*/,  8 /*8acd*/,  8 /*8ace*/,
    9 /*8acf*/,  6 /*8ad0*/,  7 /*8ad1*/,  7 /*8ad2*/,  8 /*8ad3*/,
    7 /*8ad4*/,  8 /*8ad5*/,  8 /*8ad6*/,  9 /*8ad7*/,  7 /*8ad8*/,
    8 /*8ad9*/,  8 /*8ada*/,  9 /*8adb*/,  8 /*8adc*/,  9 /*8add*/,
    9 /*8ade*/,  10 /*8adf*/, 6 /*8ae0*/,  7 /*8ae1*/,  7 /*8ae2*/,
    8 /*8ae3*/,  7 /*8ae4*/,  8 /*8ae5*/,  8 /*8ae6*/,  9 /*8ae7*/,
    7 /*8ae8*/,  8 /*8ae9*/,  8 /*8aea*/,  9 /*8aeb*/,  8 /*8aec*/,
    9 /*8aed*/,  9 /*8aee*/,  10 /*8aef*/, 7 /*8af0*/,  8 /*8af1*/,
    8 /*8af2*/,  9 /*8af3*/,  8 /*8af4*/,  9 /*8af5*/,  9 /*8af6*/,
    10 /*8af7*/, 8 /*8af8*/,  9 /*8af9*/,  9 /*8afa*/,  10 /*8afb*/,
    9 /*8afc*/,  10 /*8afd*/, 10 /*8afe*/, 11 /*8aff*/, 4 /*8b00*/,
    5 /*8b01*/,  5 /*8b02*/,  6 /*8b03*/,  5 /*8b04*/,  6 /*8b05*/,
    6 /*8b06*/,  7 /*8b07*/,  5 /*8b08*/,  6 /*8b09*/,  6 /*8b0a*/,
    7 /*8b0b*/,  6 /*8b0c*/,  7 /*8b0d*/,  7 /*8b0e*/,  8 /*8b0f*/,
    5 /*8b10*/,  6 /*8b11*/,  6 /*8b12*/,  7 /*8b13*/,  6 /*8b14*/,
    7 /*8b15*/,  7 /*8b16*/,  8 /*8b17*/,  6 /*8b18*/,  7 /*8b19*/,
    7 /*8b1a*/,  8 /*8b1b*/,  7 /*8b1c*/,  8 /*8b1d*/,  8 /*8b1e*/,
    9 /*8b1f*/,  5 /*8b20*/,  6 /*8b21*/,  6 /*8b22*/,  7 /*8b23*/,
    6 /*8b24*/,  7 /*8b25*/,  7 /*8b26*/,  8 /*8b27*/,  6 /*8b28*/,
    7 /*8b29*/,  7 /*8b2a*/,  8 /*8b2b*/,  7 /*8b2c*/,  8 /*8b2d*/,
    8 /*8b2e*/,  9 /*8b2f*/,  6 /*8b30*/,  7 /*8b31*/,  7 /*8b32*/,
    8 /*8b33*/,  7 /*8b34*/,  8 /*8b35*/,  8 /*8b36*/,  9 /*8b37*/,
    7 /*8b38*/,  8 /*8b39*/,  8 /*8b3a*/,  9 /*8b3b*/,  8 /*8b3c*/,
    9 /*8b3d*/,  9 /*8b3e*/,  10 /*8b3f*/, 5 /*8b40*/,  6 /*8b41*/,
    6 /*8b42*/,  7 /*8b43*/,  6 /*8b44*/,  7 /*8b45*/,  7 /*8b46*/,
    8 /*8b47*/,  6 /*8b48*/,  7 /*8b49*/,  7 /*8b4a*/,  8 /*8b4b*/,
    7 /*8b4c*/,  8 /*8b4d*/,  8 /*8b4e*/,  9 /*8b4f*/,  6 /*8b50*/,
    7 /*8b51*/,  7 /*8b52*/,  8 /*8b53*/,  7 /*8b54*/,  8 /*8b55*/,
    8 /*8b56*/,  9 /*8b57*/,  7 /*8b58*/,  8 /*8b59*/,  8 /*8b5a*/,
    9 /*8b5b*/,  8 /*8b5c*/,  9 /*8b5d*/,  9 /*8b5e*/,  10 /*8b5f*/,
    6 /*8b60*/,  7 /*8b61*/,  7 /*8b62*/,  8 /*8b63*/,  7 /*8b64*/,
    8 /*8b65*/,  8 /*8b66*/,  9 /*8b67*/,  7 /*8b68*/,  8 /*8b69*/,
    8 /*8b6a*/,  9 /*8b6b*/,  8 /*8b6c*/,  9 /*8b6d*/,  9 /*8b6e*/,
    10 /*8b6f*/, 7 /*8b70*/,  8 /*8b71*/,  8 /*8b72*/,  9 /*8b73*/,
    8 /*8b74*/,  9 /*8b75*/,  9 /*8b76*/,  10 /*8b77*/, 8 /*8b78*/,
    9 /*8b79*/,  9 /*8b7a*/,  10 /*8b7b*/, 9 /*8b7c*/,  10 /*8b7d*/,
    10 /*8b7e*/, 11 /*8b7f*/, 5 /*8b80*/,  6 /*8b81*/,  6 /*8b82*/,
    7 /*8b83*/,  6 /*8b84*/,  7 /*8b85*/,  7 /*8b86*/,  8 /*8b87*/,
    6 /*8b88*/,  7 /*8b89*/,  7 /*8b8a*/,  8 /*8b8b*/,  7 /*8b8c*/,
    8 /*8b8d*/,  8 /*8b8e*/,  9 /*8b8f*/,  6 /*8b90*/,  7 /*8b91*/,
    7 /*8b92*/,  8 /*8b93*/,  7 /*8b94*/,  8 /*8b95*/,  8 /*8b96*/,
    9 /*8b97*/,  7 /*8b98*/,  8 /*8b99*/,  8 /*8b9a*/,  9 /*8b9b*/,
    8 /*8b9c*/,  9 /*8b9d*/,  9 /*8b9e*/,  10 /*8b9f*/, 6 /*8ba0*/,
    7 /*8ba1*/,  7 /*8ba2*/,  8 /*8ba3*/,  7 /*8ba4*/,  8 /*8ba5*/,
    8 /*8ba6*/,  9 /*8ba7*/,  7 /*8ba8*/,  8 /*8ba9*/,  8 /*8baa*/,
    9 /*8bab*/,  8 /*8bac*/,  9 /*8bad*/,  9 /*8bae*/,  10 /*8baf*/,
    7 /*8bb0*/,  8 /*8bb1*/,  8 /*8bb2*/,  9 /*8bb3*/,  8 /*8bb4*/,
    9 /*8bb5*/,  9 /*8bb6*/,  10 /*8bb7*/, 8 /*8bb8*/,  9 /*8bb9*/,
    9 /*8bba*/,  10 /*8bbb*/, 9 /*8bbc*/,  10 /*8bbd*/, 10 /*8bbe*/,
    11 /*8bbf*/, 6 /*8bc0*/,  7 /*8bc1*/,  7 /*8bc2*/,  8 /*8bc3*/,
    7 /*8bc4*/,  8 /*8bc5*/,  8 /*8bc6*/,  9 /*8bc7*/,  7 /*8bc8*/,
    8 /*8bc9*/,  8 /*8bca*/,  9 /*8bcb*/,  8 /*8bcc*/,  9 /*8bcd*/,
    9 /*8bce*/,  10 /*8bcf*/, 7 /*8bd0*/,  8 /*8bd1*/,  8 /*8bd2*/,
    9 /*8bd3*/,  8 /*8bd4*/,  9 /*8bd5*/,  9 /*8bd6*/,  10 /*8bd7*/,
    8 /*8bd8*/,  9 /*8bd9*/,  9 /*8bda*/,  10 /*8bdb*/, 9 /*8bdc*/,
    10 /*8bdd*/, 10 /*8bde*/, 11 /*8bdf*/, 7 /*8be0*/,  8 /*8be1*/,
    8 /*8be2*/,  9 /*8be3*/,  8 /*8be4*/,  9 /*8be5*/,  9 /*8be6*/,
    10 /*8be7*/, 8 /*8be8*/,  9 /*8be9*/,  9 /*8bea*/,  10 /*8beb*/,
    9 /*8bec*/,  10 /*8bed*/, 10 /*8bee*/, 11 /*8bef*/, 8 /*8bf0*/,
    9 /*8bf1*/,  9 /*8bf2*/,  10 /*8bf3*/, 9 /*8bf4*/,  10 /*8bf5*/,
    10 /*8bf6*/, 11 /*8bf7*/, 9 /*8bf8*/,  10 /*8bf9*/, 10 /*8bfa*/,
    11 /*8bfb*/, 10 /*8bfc*/, 11 /*8bfd*/, 11 /*8bfe*/, 12 /*8bff*/,
    3 /*8c00*/,  4 /*8c01*/,  4 /*8c02*/,  5 /*8c03*/,  4 /*8c04*/,
    5 /*8c05*/,  5 /*8c06*/,  6 /*8c07*/,  4 /*8c08*/,  5 /*8c09*/,
    5 /*8c0a*/,  6 /*8c0b*/,  5 /*8c0c*/,  6 /*8c0d*/,  6 /*8c0e*/,
    7 /*8c0f*/,  4 /*8c10*/,  5 /*8c11*/,  5 /*8c12*/,  6 /*8c13*/,
    5 /*8c14*/,  6 /*8c15*/,  6 /*8c16*/,  7 /*8c17*/,  5 /*8c18*/,
    6 /*8c19*/,  6 /*8c1a*/,  7 /*8c1b*/,  6 /*8c1c*/,  7 /*8c1d*/,
    7 /*8c1e*/,  8 /*8c1f*/,  4 /*8c20*/,  5 /*8c21*/,  5 /*8c22*/,
    6 /*8c23*/,  5 /*8c24*/,  6 /*8c25*/,  6 /*8c26*/,  7 /*8c27*/,
    5 /*8c28*/,  6 /*8c29*/,  6 /*8c2a*/,  7 /*8c2b*/,  6 /*8c2c*/,
    7 /*8c2d*/,  7 /*8c2e*/,  8 /*8c2f*/,  5 /*8c30*/,  6 /*8c31*/,
    6 /*8c32*/,  7 /*8c33*/,  6 /*8c34*/,  7 /*8c35*/,  7 /*8c36*/,
    8 /*8c37*/,  6 /*8c38*/,  7 /*8c39*/,  7 /*8c3a*/,  8 /*8c3b*/,
    7 /*8c3c*/,  8 /*8c3d*/,  8 /*8c3e*/,  9 /*8c3f*/,  4 /*8c40*/,
    5 /*8c41*/,  5 /*8c42*/,  6 /*8c43*/,  5 /*8c44*/,  6 /*8c45*/,
    6 /*8c46*/,  7 /*8c47*/,  5 /*8c48*/,  6 /*8c49*/,  6 /*8c4a*/,
    7 /*8c4b*/,  6 /*8c4c*/,  7 /*8c4d*/,  7 /*8c4e*/,  8 /*8c4f*/,
    5 /*8c50*/,  6 /*8c51*/,  6 /*8c52*/,  7 /*8c53*/,  6 /*8c54*/,
    7 /*8c55*/,  7 /*8c56*/,  8 /*8c57*/,  6 /*8c58*/,  7 /*8c59*/,
    7 /*8c5a*/,  8 /*8c5b*/,  7 /*8c5c*/,  8 /*8c5d*/,  8 /*8c5e*/,
    9 /*8c5f*/,  5 /*8c60*/,  6 /*8c61*/,  6 /*8c62*/,  7 /*8c63*/,
    6 /*8c64*/,  7 /*8c65*/,  7 /*8c66*/,  8 /*8c67*/,  6 /*8c68*/,
    7 /*8c69*/,  7 /*8c6a*/,  8 /*8c6b*/,  7 /*8c6c*/,  8 /*8c6d*/,
    8 /*8c6e*/,  9 /*8c6f*/,  6 /*8c70*/,  7 /*8c71*/,  7 /*8c72*/,
    8 /*8c73*/,  7 /*8c74*/,  8 /*8c75*/,  8 /*8c76*/,  9 /*8c77*/,
    7 /*8c78*/,  8 /*8c79*/,  8 /*8c7a*/,  9 /*8c7b*/,  8 /*8c7c*/,
    9 /*8c7d*/,  9 /*8c7e*/,  10 /*8c7f*/, 4 /*8c80*/,  5 /*8c81*/,
    5 /*8c82*/,  6 /*8c83*/,  5 /*8c84*/,  6 /*8c85*/,  6 /*8c86*/,
    7 /*8c87*/,  5 /*8c88*/,  6 /*8c89*/,  6 /*8c8a*/,  7 /*8c8b*/,
    6 /*8c8c*/,  7 /*8c8d*/,  7 /*8c8e*/,  8 /*8c8f*/,  5 /*8c90*/,
    6 /*8c91*/,  6 /*8c92*/,  7 /*8c93*/,  6 /*8c94*/,  7 /*8c95*/,
    7 /*8c96*/,  8 /*8c97*/,  6 /*8c98*/,  7 /*8c99*/,  7 /*8c9a*/,
    8 /*8c9b*/,  7 /*8c9c*/,  8 /*8c9d*/,  8 /*8c9e*/,  9 /*8c9f*/,
    5 /*8ca0*/,  6 /*8ca1*/,  6 /*8ca2*/,  7 /*8ca3*/,  6 /*8ca4*/,
    7 /*8ca5*/,  7 /*8ca6*/,  8 /*8ca7*/,  6 /*8ca8*/,  7 /*8ca9*/,
    7 /*8caa*/,  8 /*8cab*/,  7 /*8cac*/,  8 /*8cad*/,  8 /*8cae*/,
    9 /*8caf*/,  6 /*8cb0*/,  7 /*8cb1*/,  7 /*8cb2*/,  8 /*8cb3*/,
    7 /*8cb4*/,  8 /*8cb5*/,  8 /*8cb6*/,  9 /*8cb7*/,  7 /*8cb8*/,
    8 /*8cb9*/,  8 /*8cba*/,  9 /*8cbb*/,  8 /*8cbc*/,  9 /*8cbd*/,
    9 /*8cbe*/,  10 /*8cbf*/, 5 /*8cc0*/,  6 /*8cc1*/,  6 /*8cc2*/,
    7 /*8cc3*/,  6 /*8cc4*/,  7 /*8cc5*/,  7 /*8cc6*/,  8 /*8cc7*/,
    6 /*8cc8*/,  7 /*8cc9*/,  7 /*8cca*/,  8 /*8ccb*/,  7 /*8ccc*/,
    8 /*8ccd*/,  8 /*8cce*/,  9 /*8ccf*/,  6 /*8cd0*/,  7 /*8cd1*/,
    7 /*8cd2*/,  8 /*8cd3*/,  7 /*8cd4*/,  8 /*8cd5*/,  8 /*8cd6*/,
    9 /*8cd7*/,  7 /*8cd8*/,  8 /*8cd9*/,  8 /*8cda*/,  9 /*8cdb*/,
    8 /*8cdc*/,  9 /*8cdd*/,  9 /*8cde*/,  10 /*8cdf*/, 6 /*8ce0*/,
    7 /*8ce1*/,  7 /*8ce2*/,  8 /*8ce3*/,  7 /*8ce4*/,  8 /*8ce5*/,
    8 /*8ce6*/,  9 /*8ce7*/,  7 /*8ce8*/,  8 /*8ce9*/,  8 /*8cea*/,
    9 /*8ceb*/,  8 /*8cec*/,  9 /*8ced*/,  9 /*8cee*/,  10 /*8cef*/,
    7 /*8cf0*/,  8 /*8cf1*/,  8 /*8cf2*/,  9 /*8cf3*/,  8 /*8cf4*/,
    9 /*8cf5*/,  9 /*8cf6*/,  10 /*8cf7*/, 8 /*8cf8*/,  9 /*8cf9*/,
    9 /*8cfa*/,  10 /*8cfb*/, 9 /*8cfc*/,  10 /*8cfd*/, 10 /*8cfe*/,
    11 /*8cff*/, 4 /*8d00*/,  5 /*8d01*/,  5 /*8d02*/,  6 /*8d03*/,
    5 /*8d04*/,  6 /*8d05*/,  6 /*8d06*/,  7 /*8d07*/,  5 /*8d08*/,
    6 /*8d09*/,  6 /*8d0a*/,  7 /*8d0b*/,  6 /*8d0c*/,  7 /*8d0d*/,
    7 /*8d0e*/,  8 /*8d0f*/,  5 /*8d10*/,  6 /*8d11*/,  6 /*8d12*/,
    7 /*8d13*/,  6 /*8d14*/,  7 /*8d15*/,  7 /*8d16*/,  8 /*8d17*/,
    6 /*8d18*/,  7 /*8d19*/,  7 /*8d1a*/,  8 /*8d1b*/,  7 /*8d1c*/,
    8 /*8d1d*/,  8 /*8d1e*/,  9 /*8d1f*/,  5 /*8d20*/,  6 /*8d21*/,
    6 /*8d22*/,  7 /*8d23*/,  6 /*8d24*/,  7 /*8d25*/,  7 /*8d26*/,
    8 /*8d27*/,  6 /*8d28*/,  7 /*8d29*/,  7 /*8d2a*/,  8 /*8d2b*/,
    7 /*8d2c*/,  8 /*8d2d*/,  8 /*8d2e*/,  9 /*8d2f*/,  6 /*8d30*/,
    7 /*8d31*/,  7 /*8d32*/,  8 /*8d33*/,  7 /*8d34*/,  8 /*8d35*/,
    8 /*8d36*/,  9 /*8d37*/,  7 /*8d38*/,  8 /*8d39*/,  8 /*8d3a*/,
    9 /*8d3b*/,  8 /*8d3c*/,  9 /*8d3d*/,  9 /*8d3e*/,  10 /*8d3f*/,
    5 /*8d40*/,  6 /*8d41*/,  6 /*8d42*/,  7 /*8d43*/,  6 /*8d44*/,
    7 /*8d45*/,  7 /*8d46*/,  8 /*8d47*/,  6 /*8d48*/,  7 /*8d49*/,
    7 /*8d4a*/,  8 /*8d4b*/,  7 /*8d4c*/,  8 /*8d4d*/,  8 /*8d4e*/,
    9 /*8d4f*/,  6 /*8d50*/,  7 /*8d51*/,  7 /*8d52*/,  8 /*8d53*/,
    7 /*8d54*/,  8 /*8d55*/,  8 /*8d56*/,  9 /*8d57*/,  7 /*8d58*/,
    8 /*8d59*/,  8 /*8d5a*/,  9 /*8d5b*/,  8 /*8d5c*/,  9 /*8d5d*/,
    9 /*8d5e*/,  10 /*8d5f*/, 6 /*8d60*/,  7 /*8d61*/,  7 /*8d62*/,
    8 /*8d63*/,  7 /*8d64*/,  8 /*8d65*/,  8 /*8d66*/,  9 /*8d67*/,
    7 /*8d68*/,  8 /*8d69*/,  8 /*8d6a*/,  9 /*8d6b*/,  8 /*8d6c*/,
    9 /*8d6d*/,  9 /*8d6e*/,  10 /*8d6f*/, 7 /*8d70*/,  8 /*8d71*/,
    8 /*8d72*/,  9 /*8d73*/,  8 /*8d74*/,  9 /*8d75*/,  9 /*8d76*/,
    10 /*8d77*/, 8 /*8d78*/,  9 /*8d79*/,  9 /*8d7a*/,  10 /*8d7b*/,
    9 /*8d7c*/,  10 /*8d7d*/, 10 /*8d7e*/, 11 /*8d7f*/, 5 /*8d80*/,
    6 /*8d81*/,  6 /*8d82*/,  7 /*8d83*/,  6 /*8d84*/,  7 /*8d85*/,
    7 /*8d86*/,  8 /*8d87*/,  6 /*8d88*/,  7 /*8d89*/,  7 /*8d8a*/,
    8 /*8d8b*/,  7 /*8d8c*/,  8 /*8d8d*/,  8 /*8d8e*/,  9 /*8d8f*/,
    6 /*8d90*/,  7 /*8d91*/,  7 /*8d92*/,  8 /*8d93*/,  7 /*8d94*/,
    8 /*8d95*/,  8 /*8d96*/,  9 /*8d97*/,  7 /*8d98*/,  8 /*8d99*/,
    8 /*8d9a*/,  9 /*8d9b*/,  8 /*8d9c*/,  9 /*8d9d*/,  9 /*8d9e*/,
    10 /*8d9f*/, 6 /*8da0*/,  7 /*8da1*/,  7 /*8da2*/,  8 /*8da3*/,
    7 /*8da4*/,  8 /*8da5*/,  8 /*8da6*/,  9 /*8da7*/,  7 /*8da8*/,
    8 /*8da9*/,  8 /*8daa*/,  9 /*8dab*/,  8 /*8dac*/,  9 /*8dad*/,
    9 /*8dae*/,  10 /*8daf*/, 7 /*8db0*/,  8 /*8db1*/,  8 /*8db2*/,
    9 /*8db3*/,  8 /*8db4*/,  9 /*8db5*/,  9 /*8db6*/,  10 /*8db7*/,
    8 /*8db8*/,  9 /*8db9*/,  9 /*8dba*/,  10 /*8dbb*/, 9 /*8dbc*/,
    10 /*8dbd*/, 10 /*8dbe*/, 11 /*8dbf*/, 6 /*8dc0*/,  7 /*8dc1*/,
    7 /*8dc2*/,  8 /*8dc3*/,  7 /*8dc4*/,  8 /*8dc5*/,  8 /*8dc6*/,
    9 /*8dc7*/,  7 /*8dc8*/,  8 /*8dc9*/,  8 /*8dca*/,  9 /*8dcb*/,
    8 /*8dcc*/,  9 /*8dcd*/,  9 /*8dce*/,  10 /*8dcf*/, 7 /*8dd0*/,
    8 /*8dd1*/,  8 /*8dd2*/,  9 /*8dd3*/,  8 /*8dd4*/,  9 /*8dd5*/,
    9 /*8dd6*/,  10 /*8dd7*/, 8 /*8dd8*/,  9 /*8dd9*/,  9 /*8dda*/,
    10 /*8ddb*/, 9 /*8ddc*/,  10 /*8ddd*/, 10 /*8dde*/, 11 /*8ddf*/,
    7 /*8de0*/,  8 /*8de1*/,  8 /*8de2*/,  9 /*8de3*/,  8 /*8de4*/,
    9 /*8de5*/,  9 /*8de6*/,  10 /*8de7*/, 8 /*8de8*/,  9 /*8de9*/,
    9 /*8dea*/,  10 /*8deb*/, 9 /*8dec*/,  10 /*8ded*/, 10 /*8dee*/,
    11 /*8def*/, 8 /*8df0*/,  9 /*8df1*/,  9 /*8df2*/,  10 /*8df3*/,
    9 /*8df4*/,  10 /*8df5*/, 10 /*8df6*/, 11 /*8df7*/, 9 /*8df8*/,
    10 /*8df9*/, 10 /*8dfa*/, 11 /*8dfb*/, 10 /*8dfc*/, 11 /*8dfd*/,
    11 /*8dfe*/, 12 /*8dff*/, 4 /*8e00*/,  5 /*8e01*/,  5 /*8e02*/,
    6 /*8e03*/,  5 /*8e04*/,  6 /*8e05*/,  6 /*8e06*/,  7 /*8e07*/,
    5 /*8e08*/,  6 /*8e09*/,  6 /*8e0a*/,  7 /*8e0b*/,  6 /*8e0c*/,
    7 /*8e0d*/,  7 /*8e0e*/,  8 /*8e0f*/,  5 /*8e10*/,  6 /*8e11*/,
    6 /*8e12*/,  7 /*8e13*/,  6 /*8e14*/,  7 /*8e15*/,  7 /*8e16*/,
    8 /*8e17*/,  6 /*8e18*/,  7 /*8e19*/,  7 /*8e1a*/,  8 /*8e1b*/,
    7 /*8e1c*/,  8 /*8e1d*/,  8 /*8e1e*/,  9 /*8e1f*/,  5 /*8e20*/,
    6 /*8e21*/,  6 /*8e22*/,  7 /*8e23*/,  6 /*8e24*/,  7 /*8e25*/,
    7 /*8e26*/,  8 /*8e27*/,  6 /*8e28*/,  7 /*8e29*/,  7 /*8e2a*/,
    8 /*8e2b*/,  7 /*8e2c*/,  8 /*8e2d*/,  8 /*8e2e*/,  9 /*8e2f*/,
    6 /*8e30*/,  7 /*8e31*/,  7 /*8e32*/,  8 /*8e33*/,  7 /*8e34*/,
    8 /*8e35*/,  8 /*8e36*/,  9 /*8e37*/,  7 /*8e38*/,  8 /*8e39*/,
    8 /*8e3a*/,  9 /*8e3b*/,  8 /*8e3c*/,  9 /*8e3d*/,  9 /*8e3e*/,
    10 /*8e3f*/, 5 /*8e40*/,  6 /*8e41*/,  6 /*8e42*/,  7 /*8e43*/,
    6 /*8e44*/,  7 /*8e45*/,  7 /*8e46*/,  8 /*8e47*/,  6 /*8e48*/,
    7 /*8e49*/,  7 /*8e4a*/,  8 /*8e4b*/,  7 /*8e4c*/,  8 /*8e4d*/,
    8 /*8e4e*/,  9 /*8e4f*/,  6 /*8e50*/,  7 /*8e51*/,  7 /*8e52*/,
    8 /*8e53*/,  7 /*8e54*/,  8 /*8e55*/,  8 /*8e56*/,  9 /*8e57*/,
    7 /*8e58*/,  8 /*8e59*/,  8 /*8e5a*/,  9 /*8e5b*/,  8 /*8e5c*/,
    9 /*8e5d*/,  9 /*8e5e*/,  10 /*8e5f*/, 6 /*8e60*/,  7 /*8e61*/,
    7 /*8e62*/,  8 /*8e63*/,  7 /*8e64*/,  8 /*8e65*/,  8 /*8e66*/,
    9 /*8e67*/,  7 /*8e68*/,  8 /*8e69*/,  8 /*8e6a*/,  9 /*8e6b*/,
    8 /*8e6c*/,  9 /*8e6d*/,  9 /*8e6e*/,  10 /*8e6f*/, 7 /*8e70*/,
    8 /*8e71*/,  8 /*8e72*/,  9 /*8e73*/,  8 /*8e74*/,  9 /*8e75*/,
    9 /*8e76*/,  10 /*8e77*/, 8 /*8e78*/,  9 /*8e79*/,  9 /*8e7a*/,
    10 /*8e7b*/, 9 /*8e7c*/,  10 /*8e7d*/, 10 /*8e7e*/, 11 /*8e7f*/,
    5 /*8e80*/,  6 /*8e81*/,  6 /*8e82*/,  7 /*8e83*/,  6 /*8e84*/,
    7 /*8e85*/,  7 /*8e86*/,  8 /*8e87*/,  6 /*8e88*/,  7 /*8e89*/,
    7 /*8e8a*/,  8 /*8e8b*/,  7 /*8e8c*/,  8 /*8e8d*/,  8 /*8e8e*/,
    9 /*8e8f*/,  6 /*8e90*/,  7 /*8e91*/,  7 /*8e92*/,  8 /*8e93*/,
    7 /*8e94*/,  8 /*8e95*/,  8 /*8e96*/,  9 /*8e97*/,  7 /*8e98*/,
    8 /*8e99*/,  8 /*8e9a*/,  9 /*8e9b*/,  8 /*8e9c*/,  9 /*8e9d*/,
    9 /*8e9e*/,  10 /*8e9f*/, 6 /*8ea0*/,  7 /*8ea1*/,  7 /*8ea2*/,
    8 /*8ea3*/,  7 /*8ea4*/,  8 /*8ea5*/,  8 /*8ea6*/,  9 /*8ea7*/,
    7 /*8ea8*/,  8 /*8ea9*/,  8 /*8eaa*/,  9 /*8eab*/,  8 /*8eac*/,
    9 /*8ead*/,  9 /*8eae*/,  10 /*8eaf*/, 7 /*8eb0*/,  8 /*8eb1*/,
    8 /*8eb2*/,  9 /*8eb3*/,  8 /*8eb4*/,  9 /*8eb5*/,  9 /*8eb6*/,
    10 /*8eb7*/, 8 /*8eb8*/,  9 /*8eb9*/,  9 /*8eba*/,  10 /*8ebb*/,
    9 /*8ebc*/,  10 /*8ebd*/, 10 /*8ebe*/, 11 /*8ebf*/, 6 /*8ec0*/,
    7 /*8ec1*/,  7 /*8ec2*/,  8 /*8ec3*/,  7 /*8ec4*/,  8 /*8ec5*/,
    8 /*8ec6*/,  9 /*8ec7*/,  7 /*8ec8*/,  8 /*8ec9*/,  8 /*8eca*/,
    9 /*8ecb*/,  8 /*8ecc*/,  9 /*8ecd*/,  9 /*8ece*/,  10 /*8ecf*/,
    7 /*8ed0*/,  8 /*8ed1*/,  8 /*8ed2*/,  9 /*8ed3*/,  8 /*8ed4*/,
    9 /*8ed5*/,  9 /*8ed6*/,  10 /*8ed7*/, 8 /*8ed8*/,  9 /*8ed9*/,
    9 /*8eda*/,  10 /*8edb*/, 9 /*8edc*/,  10 /*8edd*/, 10 /*8ede*/,
    11 /*8edf*/, 7 /*8ee0*/,  8 /*8ee1*/,  8 /*8ee2*/,  9 /*8ee3*/,
    8 /*8ee4*/,  9 /*8ee5*/,  9 /*8ee6*/,  10 /*8ee7*/, 8 /*8ee8*/,
    9 /*8ee9*/,  9 /*8eea*/,  10 /*8eeb*/, 9 /*8eec*/,  10 /*8eed*/,
    10 /*8eee*/, 11 /*8eef*/, 8 /*8ef0*/,  9 /*8ef1*/,  9 /*8ef2*/,
    10 /*8ef3*/, 9 /*8ef4*/,  10 /*8ef5*/, 10 /*8ef6*/, 11 /*8ef7*/,
    9 /*8ef8*/,  10 /*8ef9*/, 10 /*8efa*/, 11 /*8efb*/, 10 /*8efc*/,
    11 /*8efd*/, 11 /*8efe*/, 12 /*8eff*/, 5 /*8f00*/,  6 /*8f01*/,
    6 /*8f02*/,  7 /*8f03*/,  6 /*8f04*/,  7 /*8f05*/,  7 /*8f06*/,
    8 /*8f07*/,  6 /*8f08*/,  7 /*8f09*/,  7 /*8f0a*/,  8 /*8f0b*/,
    7 /*8f0c*/,  8 /*8f0d*/,  8 /*8f0e*/,  9 /*8f0f*/,  6 /*8f10*/,
    7 /*8f11*/,  7 /*8f12*/,  8 /*8f13*/,  7 /*8f14*/,  8 /*8f15*/,
    8 /*8f16*/,  9 /*8f17*/,  7 /*8f18*/,  8 /*8f19*/,  8 /*8f1a*/,
    9 /*8f1b*/,  8 /*8f1c*/,  9 /*8f1d*/,  9 /*8f1e*/,  10 /*8f1f*/,
    6 /*8f20*/,  7 /*8f21*/,  7 /*8f22*/,  8 /*8f23*/,  7 /*8f24*/,
    8 /*8f25*/,  8 /*8f26*/,  9 /*8f27*/,  7 /*8f28*/,  8 /*8f29*/,
    8 /*8f2a*/,  9 /*8f2b*/,  8 /*8f2c*/,  9 /*8f2d*/,  9 /*8f2e*/,
    10 /*8f2f*/, 7 /*8f30*/,  8 /*8f31*/,  8 /*8f32*/,  9 /*8f33*/,
    8 /*8f34*/,  9 /*8f35*/,  9 /*8f36*/,  10 /*8f37*/, 8 /*8f38*/,
    9 /*8f39*/,  9 /*8f3a*/,  10 /*8f3b*/, 9 /*8f3c*/,  10 /*8f3d*/,
    10 /*8f3e*/, 11 /*8f3f*/, 6 /*8f40*/,  7 /*8f41*/,  7 /*8f42*/,
    8 /*8f43*/,  7 /*8f44*/,  8 /*8f45*/,  8 /*8f46*/,  9 /*8f47*/,
    7 /*8f48*/,  8 /*8f49*/,  8 /*8f4a*/,  9 /*8f4b*/,  8 /*8f4c*/,
    9 /*8f4d*/,  9 /*8f4e*/,  10 /*8f4f*/, 7 /*8f50*/,  8 /*8f51*/,
    8 /*8f52*/,  9 /*8f53*/,  8 /*8f54*/,  9 /*8f55*/,  9 /*8f56*/,
    10 /*8f57*/, 8 /*8f58*/,  9 /*8f59*/,  9 /*8f5a*/,  10 /*8f5b*/,
    9 /*8f5c*/,  10 /*8f5d*/, 10 /*8f5e*/, 11 /*8f5f*/, 7 /*8f60*/,
    8 /*8f61*/,  8 /*8f62*/,  9 /*8f63*/,  8 /*8f64*/,  9 /*8f65*/,
    9 /*8f66*/,  10 /*8f67*/, 8 /*8f68*/,  9 /*8f69*/,  9 /*8f6a*/,
    10 /*8f6b*/, 9 /*8f6c*/,  10 /*8f6d*/, 10 /*8f6e*/, 11 /*8f6f*/,
    8 /*8f70*/,  9 /*8f71*/,  9 /*8f72*/,  10 /*8f73*/, 9 /*8f74*/,
    10 /*8f75*/, 10 /*8f76*/, 11 /*8f77*/, 9 /*8f78*/,  10 /*8f79*/,
    10 /*8f7a*/, 11 /*8f7b*/, 10 /*8f7c*/, 11 /*8f7d*/, 11 /*8f7e*/,
    12 /*8f7f*/, 6 /*8f80*/,  7 /*8f81*/,  7 /*8f82*/,  8 /*8f83*/,
    7 /*8f84*/,  8 /*8f85*/,  8 /*8f86*/,  9 /*8f87*/,  7 /*8f88*/,
    8 /*8f89*/,  8 /*8f8a*/,  9 /*8f8b*/,  8 /*8f8c*/,  9 /*8f8d*/,
    9 /*8f8e*/,  10 /*8f8f*/, 7 /*8f90*/,  8 /*8f91*/,  8 /*8f92*/,
    9 /*8f93*/,  8 /*8f94*/,  9 /*8f95*/,  9 /*8f96*/,  10 /*8f97*/,
    8 /*8f98*/,  9 /*8f99*/,  9 /*8f9a*/,  10 /*8f9b*/, 9 /*8f9c*/,
    10 /*8f9d*/, 10 /*8f9e*/, 11 /*8f9f*/, 7 /*8fa0*/,  8 /*8fa1*/,
    8 /*8fa2*/,  9 /*8fa3*/,  8 /*8fa4*/,  9 /*8fa5*/,  9 /*8fa6*/,
    10 /*8fa7*/, 8 /*8fa8*/,  9 /*8fa9*/,  9 /*8faa*/,  10 /*8fab*/,
    9 /*8fac*/,  10 /*8fad*/, 10 /*8fae*/, 11 /*8faf*/, 8 /*8fb0*/,
    9 /*8fb1*/,  9 /*8fb2*/,  10 /*8fb3*/, 9 /*8fb4*/,  10 /*8fb5*/,
    10 /*8fb6*/, 11 /*8fb7*/, 9 /*8fb8*/,  10 /*8fb9*/, 10 /*8fba*/,
    11 /*8fbb*/, 10 /*8fbc*/, 11 /*8fbd*/, 11 /*8fbe*/, 12 /*8fbf*/,
    7 /*8fc0*/,  8 /*8fc1*/,  8 /*8fc2*/,  9 /*8fc3*/,  8 /*8fc4*/,
    9 /*8fc5*/,  9 /*8fc6*/,  10 /*8fc7*/, 8 /*8fc8*/,  9 /*8fc9*/,
    9 /*8fca*/,  10 /*8fcb*/, 9 /*8fcc*/,  10 /*8fcd*/, 10 /*8fce*/,
    11 /*8fcf*/, 8 /*8fd0*/,  9 /*8fd1*/,  9 /*8fd2*/,  10 /*8fd3*/,
    9 /*8fd4*/,  10 /*8fd5*/, 10 /*8fd6*/, 11 /*8fd7*/, 9 /*8fd8*/,
    10 /*8fd9*/, 10 /*8fda*/, 11 /*8fdb*/, 10 /*8fdc*/, 11 /*8fdd*/,
    11 /*8fde*/, 12 /*8fdf*/, 8 /*8fe0*/,  9 /*8fe1*/,  9 /*8fe2*/,
    10 /*8fe3*/, 9 /*8fe4*/,  10 /*8fe5*/, 10 /*8fe6*/, 11 /*8fe7*/,
    9 /*8fe8*/,  10 /*8fe9*/, 10 /*8fea*/, 11 /*8feb*/, 10 /*8fec*/,
    11 /*8fed*/, 11 /*8fee*/, 12 /*8fef*/, 9 /*8ff0*/,  10 /*8ff1*/,
    10 /*8ff2*/, 11 /*8ff3*/, 10 /*8ff4*/, 11 /*8ff5*/, 11 /*8ff6*/,
    12 /*8ff7*/, 10 /*8ff8*/, 11 /*8ff9*/, 11 /*8ffa*/, 12 /*8ffb*/,
    11 /*8ffc*/, 12 /*8ffd*/, 12 /*8ffe*/, 13 /*8fff*/, 2 /*9000*/,
    3 /*9001*/,  3 /*9002*/,  4 /*9003*/,  3 /*9004*/,  4 /*9005*/,
    4 /*9006*/,  5 /*9007*/,  3 /*9008*/,  4 /*9009*/,  4 /*900a*/,
    5 /*900b*/,  4 /*900c*/,  5 /*900d*/,  5 /*900e*/,  6 /*900f*/,
    3 /*9010*/,  4 /*9011*/,  4 /*9012*/,  5 /*9013*/,  4 /*9014*/,
    5 /*9015*/,  5 /*9016*/,  6 /*9017*/,  4 /*9018*/,  5 /*9019*/,
    5 /*901a*/,  6 /*901b*/,  5 /*901c*/,  6 /*901d*/,  6 /*901e*/,
    7 /*901f*/,  3 /*9020*/,  4 /*9021*/,  4 /*9022*/,  5 /*9023*/,
    4 /*9024*/,  5 /*9025*/,  5 /*9026*/,  6 /*9027*/,  4 /*9028*/,
    5 /*9029*/,  5 /*902a*/,  6 /*902b*/,  5 /*902c*/,  6 /*902d*/,
    6 /*902e*/,  7 /*902f*/,  4 /*9030*/,  5 /*9031*/,  5 /*9032*/,
    6 /*9033*/,  5 /*9034*/,  6 /*9035*/,  6 /*9036*/,  7 /*9037*/,
    5 /*9038*/,  6 /*9039*/,  6 /*903a*/,  7 /*903b*/,  6 /*903c*/,
    7 /*903d*/,  7 /*903e*/,  8 /*903f*/,  3 /*9040*/,  4 /*9041*/,
    4 /*9042*/,  5 /*9043*/,  4 /*9044*/,  5 /*9045*/,  5 /*9046*/,
    6 /*9047*/,  4 /*9048*/,  5 /*9049*/,  5 /*904a*/,  6 /*904b*/,
    5 /*904c*/,  6 /*904d*/,  6 /*904e*/,  7 /*904f*/,  4 /*9050*/,
    5 /*9051*/,  5 /*9052*/,  6 /*9053*/,  5 /*9054*/,  6 /*9055*/,
    6 /*9056*/,  7 /*9057*/,  5 /*9058*/,  6 /*9059*/,  6 /*905a*/,
    7 /*905b*/,  6 /*905c*/,  7 /*905d*/,  7 /*905e*/,  8 /*905f*/,
    4 /*9060*/,  5 /*9061*/,  5 /*9062*/,  6 /*9063*/,  5 /*9064*/,
    6 /*9065*/,  6 /*9066*/,  7 /*9067*/,  5 /*9068*/,  6 /*9069*/,
    6 /*906a*/,  7 /*906b*/,  6 /*906c*/,  7 /*906d*/,  7 /*906e*/,
    8 /*906f*/,  5 /*9070*/,  6 /*9071*/,  6 /*9072*/,  7 /*9073*/,
    6 /*9074*/,  7 /*9075*/,  7 /*9076*/,  8 /*9077*/,  6 /*9078*/,
    7 /*9079*/,  7 /*907a*/,  8 /*907b*/,  7 /*907c*/,  8 /*907d*/,
    8 /*907e*/,  9 /*907f*/,  3 /*9080*/,  4 /*9081*/,  4 /*9082*/,
    5 /*9083*/,  4 /*9084*/,  5 /*9085*/,  5 /*9086*/,  6 /*9087*/,
    4 /*9088*/,  5 /*9089*/,  5 /*908a*/,  6 /*908b*/,  5 /*908c*/,
    6 /*908d*/,  6 /*908e*/,  7 /*908f*/,  4 /*9090*/,  5 /*9091*/,
    5 /*9092*/,  6 /*9093*/,  5 /*9094*/,  6 /*9095*/,  6 /*9096*/,
    7 /*9097*/,  5 /*9098*/,  6 /*9099*/,  6 /*909a*/,  7 /*909b*/,
    6 /*909c*/,  7 /*909d*/,  7 /*909e*/,  8 /*909f*/,  4 /*90a0*/,
    5 /*90a1*/,  5 /*90a2*/,  6 /*90a3*/,  5 /*90a4*/,  6 /*90a5*/,
    6 /*90a6*/,  7 /*90a7*/,  5 /*90a8*/,  6 /*90a9*/,  6 /*90aa*/,
    7 /*90ab*/,  6 /*90ac*/,  7 /*90ad*/,  7 /*90ae*/,  8 /*90af*/,
    5 /*90b0*/,  6 /*90b1*/,  6 /*90b2*/,  7 /*90b3*/,  6 /*90b4*/,
    7 /*90b5*/,  7 /*90b6*/,  8 /*90b7*/,  6 /*90b8*/,  7 /*90b9*/,
    7 /*90ba*/,  8 /*90bb*/,  7 /*90bc*/,  8 /*90bd*/,  8 /*90be*/,
    9 /*90bf*/,  4 /*90c0*/,  5 /*90c1*/,  5 /*90c2*/,  6 /*90c3*/,
    5 /*90c4*/,  6 /*90c5*/,  6 /*90c6*/,  7 /*90c7*/,  5 /*90c8*/,
    6 /*90c9*/,  6 /*90ca*/,  7 /*90cb*/,  6 /*90cc*/,  7 /*90cd*/,
    7 /*90ce*/,  8 /*90cf*/,  5 /*90d0*/,  6 /*90d1*/,  6 /*90d2*/,
    7 /*90d3*/,  6 /*90d4*/,  7 /*90d5*/,  7 /*90d6*/,  8 /*90d7*/,
    6 /*90d8*/,  7 /*90d9*/,  7 /*90da*/,  8 /*90db*/,  7 /*90dc*/,
    8 /*90dd*/,  8 /*90de*/,  9 /*90df*/,  5 /*90e0*/,  6 /*90e1*/,
    6 /*90e2*/,  7 /*90e3*/,  6 /*90e4*/,  7 /*90e5*/,  7 /*90e6*/,
    8 /*90e7*/,  6 /*90e8*/,  7 /*90e9*/,  7 /*90ea*/,  8 /*90eb*/,
    7 /*90ec*/,  8 /*90ed*/,  8 /*90ee*/,  9 /*90ef*/,  6 /*90f0*/,
    7 /*90f1*/,  7 /*90f2*/,  8 /*90f3*/,  7 /*90f4*/,  8 /*90f5*/,
    8 /*90f6*/,  9 /*90f7*/,  7 /*90f8*/,  8 /*90f9*/,  8 /*90fa*/,
    9 /*90fb*/,  8 /*90fc*/,  9 /*90fd*/,  9 /*90fe*/,  10 /*90ff*/,
    3 /*9100*/,  4 /*9101*/,  4 /*9102*/,  5 /*9103*/,  4 /*9104*/,
    5 /*9105*/,  5 /*9106*/,  6 /*9107*/,  4 /*9108*/,  5 /*9109*/,
    5 /*910a*/,  6 /*910b*/,  5 /*910c*/,  6 /*910d*/,  6 /*910e*/,
    7 /*910f*/,  4 /*9110*/,  5 /*9111*/,  5 /*9112*/,  6 /*9113*/,
    5 /*9114*/,  6 /*9115*/,  6 /*9116*/,  7 /*9117*/,  5 /*9118*/,
    6 /*9119*/,  6 /*911a*/,  7 /*911b*/,  6 /*911c*/,  7 /*911d*/,
    7 /*911e*/,  8 /*911f*/,  4 /*9120*/,  5 /*9121*/,  5 /*9122*/,
    6 /*9123*/,  5 /*9124*/,  6 /*9125*/,  6 /*9126*/,  7 /*9127*/,
    5 /*9128*/,  6 /*9129*/,  6 /*912a*/,  7 /*912b*/,  6 /*912c*/,
    7 /*912d*/,  7 /*912e*/,  8 /*912f*/,  5 /*9130*/,  6 /*9131*/,
    6 /*9132*/,  7 /*9133*/,  6 /*9134*/,  7 /*9135*/,  7 /*9136*/,
    8 /*9137*/,  6 /*9138*/,  7 /*9139*/,  7 /*913a*/,  8 /*913b*/,
    7 /*913c*/,  8 /*913d*/,  8 /*913e*/,  9 /*913f*/,  4 /*9140*/,
    5 /*9141*/,  5 /*9142*/,  6 /*9143*/,  5 /*9144*/,  6 /*9145*/,
    6 /*9146*/,  7 /*9147*/,  5 /*9148*/,  6 /*9149*/,  6 /*914a*/,
    7 /*914b*/,  6 /*914c*/,  7 /*914d*/,  7 /*914e*/,  8 /*914f*/,
    5 /*9150*/,  6 /*9151*/,  6 /*9152*/,  7 /*9153*/,  6 /*9154*/,
    7 /*9155*/,  7 /*9156*/,  8 /*9157*/,  6 /*9158*/,  7 /*9159*/,
    7 /*915a*/,  8 /*915b*/,  7 /*915c*/,  8 /*915d*/,  8 /*915e*/,
    9 /*915f*/,  5 /*9160*/,  6 /*9161*/,  6 /*9162*/,  7 /*9163*/,
    6 /*9164*/,  7 /*9165*/,  7 /*9166*/,  8 /*9167*/,  6 /*9168*/,
    7 /*9169*/,  7 /*916a*/,  8 /*916b*/,  7 /*916c*/,  8 /*916d*/,
    8 /*916e*/,  9 /*916f*/,  6 /*9170*/,  7 /*9171*/,  7 /*9172*/,
    8 /*9173*/,  7 /*9174*/,  8 /*9175*/,  8 /*9176*/,  9 /*9177*/,
    7 /*9178*/,  8 /*9179*/,  8 /*917a*/,  9 /*917b*/,  8 /*917c*/,
    9 /*917d*/,  9 /*917e*/,  10 /*917f*/, 4 /*9180*/,  5 /*9181*/,
    5 /*9182*/,  6 /*9183*/,  5 /*9184*/,  6 /*9185*/,  6 /*9186*/,
    7 /*9187*/,  5 /*9188*/,  6 /*9189*/,  6 /*918a*/,  7 /*918b*/,
    6 /*918c*/,  7 /*918d*/,  7 /*918e*/,  8 /*918f*/,  5 /*9190*/,
    6 /*9191*/,  6 /*9192*/,  7 /*9193*/,  6 /*9194*/,  7 /*9195*/,
    7 /*9196*/,  8 /*9197*/,  6 /*9198*/,  7 /*9199*/,  7 /*919a*/,
    8 /*919b*/,  7 /*919c*/,  8 /*919d*/,  8 /*919e*/,  9 /*919f*/,
    5 /*91a0*/,  6 /*91a1*/,  6 /*91a2*/,  7 /*91a3*/,  6 /*91a4*/,
    7 /*91a5*/,  7 /*91a6*/,  8 /*91a7*/,  6 /*91a8*/,  7 /*91a9*/,
    7 /*91aa*/,  8 /*91ab*/,  7 /*91ac*/,  8 /*91ad*/,  8 /*91ae*/,
    9 /*91af*/,  6 /*91b0*/,  7 /*91b1*/,  7 /*91b2*/,  8 /*91b3*/,
    7 /*91b4*/,  8 /*91b5*/,  8 /*91b6*/,  9 /*91b7*/,  7 /*91b8*/,
    8 /*91b9*/,  8 /*91ba*/,  9 /*91bb*/,  8 /*91bc*/,  9 /*91bd*/,
    9 /*91be*/,  10 /*91bf*/, 5 /*91c0*/,  6 /*91c1*/,  6 /*91c2*/,
    7 /*91c3*/,  6 /*91c4*/,  7 /*91c5*/,  7 /*91c6*/,  8 /*91c7*/,
    6 /*91c8*/,  7 /*91c9*/,  7 /*91ca*/,  8 /*91cb*/,  7 /*91cc*/,
    8 /*91cd*/,  8 /*91ce*/,  9 /*91cf*/,  6 /*91d0*/,  7 /*91d1*/,
    7 /*91d2*/,  8 /*91d3*/,  7 /*91d4*/,  8 /*91d5*/,  8 /*91d6*/,
    9 /*91d7*/,  7 /*91d8*/,  8 /*91d9*/,  8 /*91da*/,  9 /*91db*/,
    8 /*91dc*/,  9 /*91dd*/,  9 /*91de*/,  10 /*91df*/, 6 /*91e0*/,
    7 /*91e1*/,  7 /*91e2*/,  8 /*91e3*/,  7 /*91e4*/,  8 /*91e5*/,
    8 /*91e6*/,  9 /*91e7*/,  7 /*91e8*/,  8 /*91e9*/,  8 /*91ea*/,
    9 /*91eb*/,  8 /*91ec*/,  9 /*91ed*/,  9 /*91ee*/,  10 /*91ef*/,
    7 /*91f0*/,  8 /*91f1*/,  8 /*91f2*/,  9 /*91f3*/,  8 /*91f4*/,
    9 /*91f5*/,  9 /*91f6*/,  10 /*91f7*/, 8 /*91f8*/,  9 /*91f9*/,
    9 /*91fa*/,  10 /*91fb*/, 9 /*91fc*/,  10 /*91fd*/, 10 /*91fe*/,
    11 /*91ff*/, 3 /*9200*/,  4 /*9201*/,  4 /*9202*/,  5 /*9203*/,
    4 /*9204*/,  5 /*9205*/,  5 /*9206*/,  6 /*9207*/,  4 /*9208*/,
    5 /*9209*/,  5 /*920a*/,  6 /*920b*/,  5 /*920c*/,  6 /*920d*/,
    6 /*920e*/,  7 /*920f*/,  4 /*9210*/,  5 /*9211*/,  5 /*9212*/,
    6 /*9213*/,  5 /*9214*/,  6 /*9215*/,  6 /*9216*/,  7 /*9217*/,
    5 /*9218*/,  6 /*9219*/,  6 /*921a*/,  7 /*921b*/,  6 /*921c*/,
    7 /*921d*/,  7 /*921e*/,  8 /*921f*/,  4 /*9220*/,  5 /*9221*/,
    5 /*9222*/,  6 /*9223*/,  5 /*9224*/,  6 /*9225*/,  6 /*9226*/,
    7 /*9227*/,  5 /*9228*/,  6 /*9229*/,  6 /*922a*/,  7 /*922b*/,
    6 /*922c*/,  7 /*922d*/,  7 /*922e*/,  8 /*922f*/,  5 /*9230*/,
    6 /*9231*/,  6 /*9232*/,  7 /*9233*/,  6 /*9234*/,  7 /*9235*/,
    7 /*9236*/,  8 /*9237*/,  6 /*9238*/,  7 /*9239*/,  7 /*923a*/,
    8 /*923b*/,  7 /*923c*/,  8 /*923d*/,  8 /*923e*/,  9 /*923f*/,
    4 /*9240*/,  5 /*9241*/,  5 /*9242*/,  6 /*9243*/,  5 /*9244*/,
    6 /*9245*/,  6 /*9246*/,  7 /*9247*/,  5 /*9248*/,  6 /*9249*/,
    6 /*924a*/,  7 /*924b*/,  6 /*924c*/,  7 /*924d*/,  7 /*924e*/,
    8 /*924f*/,  5 /*9250*/,  6 /*9251*/,  6 /*9252*/,  7 /*9253*/,
    6 /*9254*/,  7 /*9255*/,  7 /*9256*/,  8 /*9257*/,  6 /*9258*/,
    7 /*9259*/,  7 /*925a*/,  8 /*925b*/,  7 /*925c*/,  8 /*925d*/,
    8 /*925e*/,  9 /*925f*/,  5 /*9260*/,  6 /*9261*/,  6 /*9262*/,
    7 /*9263*/,  6 /*9264*/,  7 /*9265*/,  7 /*9266*/,  8 /*9267*/,
    6 /*9268*/,  7 /*9269*/,  7 /*926a*/,  8 /*926b*/,  7 /*926c*/,
    8 /*926d*/,  8 /*926e*/,  9 /*926f*/,  6 /*9270*/,  7 /*9271*/,
    7 /*9272*/,  8 /*9273*/,  7 /*9274*/,  8 /*9275*/,  8 /*9276*/,
    9 /*9277*/,  7 /*9278*/,  8 /*9279*/,  8 /*927a*/,  9 /*927b*/,
    8 /*927c*/,  9 /*927d*/,  9 /*927e*/,  10 /*927f*/, 4 /*9280*/,
    5 /*9281*/,  5 /*9282*/,  6 /*9283*/,  5 /*9284*/,  6 /*9285*/,
    6 /*9286*/,  7 /*9287*/,  5 /*9288*/,  6 /*9289*/,  6 /*928a*/,
    7 /*928b*/,  6 /*928c*/,  7 /*928d*/,  7 /*928e*/,  8 /*928f*/,
    5 /*9290*/,  6 /*9291*/,  6 /*9292*/,  7 /*9293*/,  6 /*9294*/,
    7 /*9295*/,  7 /*9296*/,  8 /*9297*/,  6 /*9298*/,  7 /*9299*/,
    7 /*929a*/,  8 /*929b*/,  7 /*929c*/,  8 /*929d*/,  8 /*929e*/,
    9 /*929f*/,  5 /*92a0*/,  6 /*92a1*/,  6 /*92a2*/,  7 /*92a3*/,
    6 /*92a4*/,  7 /*92a5*/,  7 /*92a6*/,  8 /*92a7*/,  6 /*92a8*/,
    7 /*92a9*/,  7 /*92aa*/,  8 /*92ab*/,  7 /*92ac*/,  8 /*92ad*/,
    8 /*92ae*/,  9 /*92af*/,  6 /*92b0*/,  7 /*92b1*/,  7 /*92b2*/,
    8 /*92b3*/,  7 /*92b4*/,  8 /*92b5*/,  8 /*92b6*/,  9 /*92b7*/,
    7 /*92b8*/,  8 /*92b9*/,  8 /*92ba*/,  9 /*92bb*/,  8 /*92bc*/,
    9 /*92bd*/,  9 /*92be*/,  10 /*92bf*/, 5 /*92c0*/,  6 /*92c1*/,
    6 /*92c2*/,  7 /*92c3*/,  6 /*92c4*/,  7 /*92c5*/,  7 /*92c6*/,
    8 /*92c7*/,  6 /*92c8*/,  7 /*92c9*/,  7 /*92ca*/,  8 /*92cb*/,
    7 /*92cc*/,  8 /*92cd*/,  8 /*92ce*/,  9 /*92cf*/,  6 /*92d0*/,
    7 /*92d1*/,  7 /*92d2*/,  8 /*92d3*/,  7 /*92d4*/,  8 /*92d5*/,
    8 /*92d6*/,  9 /*92d7*/,  7 /*92d8*/,  8 /*92d9*/,  8 /*92da*/,
    9 /*92db*/,  8 /*92dc*/,  9 /*92dd*/,  9 /*92de*/,  10 /*92df*/,
    6 /*92e0*/,  7 /*92e1*/,  7 /*92e2*/,  8 /*92e3*/,  7 /*92e4*/,
    8 /*92e5*/,  8 /*92e6*/,  9 /*92e7*/,  7 /*92e8*/,  8 /*92e9*/,
    8 /*92ea*/,  9 /*92eb*/,  8 /*92ec*/,  9 /*92ed*/,  9 /*92ee*/,
    10 /*92ef*/, 7 /*92f0*/,  8 /*92f1*/,  8 /*92f2*/,  9 /*92f3*/,
    8 /*92f4*/,  9 /*92f5*/,  9 /*92f6*/,  10 /*92f7*/, 8 /*92f8*/,
    9 /*92f9*/,  9 /*92fa*/,  10 /*92fb*/, 9 /*92fc*/,  10 /*92fd*/,
    10 /*92fe*/, 11 /*92ff*/, 4 /*9300*/,  5 /*9301*/,  5 /*9302*/,
    6 /*9303*/,  5 /*9304*/,  6 /*9305*/,  6 /*9306*/,  7 /*9307*/,
    5 /*9308*/,  6 /*9309*/,  6 /*930a*/,  7 /*930b*/,  6 /*930c*/,
    7 /*930d*/,  7 /*930e*/,  8 /*930f*/,  5 /*9310*/,  6 /*9311*/,
    6 /*9312*/,  7 /*9313*/,  6 /*9314*/,  7 /*9315*/,  7 /*9316*/,
    8 /*9317*/,  6 /*9318*/,  7 /*9319*/,  7 /*931a*/,  8 /*931b*/,
    7 /*931c*/,  8 /*931d*/,  8 /*931e*/,  9 /*931f*/,  5 /*9320*/,
    6 /*9321*/,  6 /*9322*/,  7 /*9323*/,  6 /*9324*/,  7 /*9325*/,
    7 /*9326*/,  8 /*9327*/,  6 /*9328*/,  7 /*9329*/,  7 /*932a*/,
    8 /*932b*/,  7 /*932c*/,  8 /*932d*/,  8 /*932e*/,  9 /*932f*/,
    6 /*9330*/,  7 /*9331*/,  7 /*9332*/,  8 /*9333*/,  7 /*9334*/,
    8 /*9335*/,  8 /*9336*/,  9 /*9337*/,  7 /*9338*/,  8 /*9339*/,
    8 /*933a*/,  9 /*933b*/,  8 /*933c*/,  9 /*933d*/,  9 /*933e*/,
    10 /*933f*/, 5 /*9340*/,  6 /*9341*/,  6 /*9342*/,  7 /*9343*/,
    6 /*9344*/,  7 /*9345*/,  7 /*9346*/,  8 /*9347*/,  6 /*9348*/,
    7 /*9349*/,  7 /*934a*/,  8 /*934b*/,  7 /*934c*/,  8 /*934d*/,
    8 /*934e*/,  9 /*934f*/,  6 /*9350*/,  7 /*9351*/,  7 /*9352*/,
    8 /*9353*/,  7 /*9354*/,  8 /*9355*/,  8 /*9356*/,  9 /*9357*/,
    7 /*9358*/,  8 /*9359*/,  8 /*935a*/,  9 /*935b*/,  8 /*935c*/,
    9 /*935d*/,  9 /*935e*/,  10 /*935f*/, 6 /*9360*/,  7 /*9361*/,
    7 /*9362*/,  8 /*9363*/,  7 /*9364*/,  8 /*9365*/,  8 /*9366*/,
    9 /*9367*/,  7 /*9368*/,  8 /*9369*/,  8 /*936a*/,  9 /*936b*/,
    8 /*936c*/,  9 /*936d*/,  9 /*936e*/,  10 /*936f*/, 7 /*9370*/,
    8 /*9371*/,  8 /*9372*/,  9 /*9373*/,  8 /*9374*/,  9 /*9375*/,
    9 /*9376*/,  10 /*9377*/, 8 /*9378*/,  9 /*9379*/,  9 /*937a*/,
    10 /*937b*/, 9 /*937c*/,  10 /*937d*/, 10 /*937e*/, 11 /*937f*/,
    5 /*9380*/,  6 /*9381*/,  6 /*9382*/,  7 /*9383*/,  6 /*9384*/,
    7 /*9385*/,  7 /*9386*/,  8 /*9387*/,  6 /*9388*/,  7 /*9389*/,
    7 /*938a*/,  8 /*938b*/,  7 /*938c*/,  8 /*938d*/,  8 /*938e*/,
    9 /*938f*/,  6 /*9390*/,  7 /*9391*/,  7 /*9392*/,  8 /*9393*/,
    7 /*9394*/,  8 /*9395*/,  8 /*9396*/,  9 /*9397*/,  7 /*9398*/,
    8 /*9399*/,  8 /*939a*/,  9 /*939b*/,  8 /*939c*/,  9 /*939d*/,
    9 /*939e*/,  10 /*939f*/, 6 /*93a0*/,  7 /*93a1*/,  7 /*93a2*/,
    8 /*93a3*/,  7 /*93a4*/,  8 /*93a5*/,  8 /*93a6*/,  9 /*93a7*/,
    7 /*93a8*/,  8 /*93a9*/,  8 /*93aa*/,  9 /*93ab*/,  8 /*93ac*/,
    9 /*93ad*/,  9 /*93ae*/,  10 /*93af*/, 7 /*93b0*/,  8 /*93b1*/,
    8 /*93b2*/,  9 /*93b3*/,  8 /*93b4*/,  9 /*93b5*/,  9 /*93b6*/,
    10 /*93b7*/, 8 /*93b8*/,  9 /*93b9*/,  9 /*93ba*/,  10 /*93bb*/,
    9 /*93bc*/,  10 /*93bd*/, 10 /*93be*/, 11 /*93bf*/, 6 /*93c0*/,
    7 /*93c1*/,  7 /*93c2*/,  8 /*93c3*/,  7 /*93c4*/,  8 /*93c5*/,
    8 /*93c6*/,  9 /*93c7*/,  7 /*93c8*/,  8 /*93c9*/,  8 /*93ca*/,
    9 /*93cb*/,  8 /*93cc*/,  9 /*93cd*/,  9 /*93ce*/,  10 /*93cf*/,
    7 /*93d0*/,  8 /*93d1*/,  8 /*93d2*/,  9 /*93d3*/,  8 /*93d4*/,
    9 /*93d5*/,  9 /*93d6*/,  10 /*93d7*/, 8 /*93d8*/,  9 /*93d9*/,
    9 /*93da*/,  10 /*93db*/, 9 /*93dc*/,  10 /*93dd*/, 10 /*93de*/,
    11 /*93df*/, 7 /*93e0*/,  8 /*93e1*/,  8 /*93e2*/,  9 /*93e3*/,
    8 /*93e4*/,  9 /*93e5*/,  9 /*93e6*/,  10 /*93e7*/, 8 /*93e8*/,
    9 /*93e9*/,  9 /*93ea*/,  10 /*93eb*/, 9 /*93ec*/,  10 /*93ed*/,
    10 /*93ee*/, 11 /*93ef*/, 8 /*93f0*/,  9 /*93f1*/,  9 /*93f2*/,
    10 /*93f3*/, 9 /*93f4*/,  10 /*93f5*/, 10 /*93f6*/, 11 /*93f7*/,
    9 /*93f8*/,  10 /*93f9*/, 10 /*93fa*/, 11 /*93fb*/, 10 /*93fc*/,
    11 /*93fd*/, 11 /*93fe*/, 12 /*93ff*/, 3 /*9400*/,  4 /*9401*/,
    4 /*9402*/,  5 /*9403*/,  4 /*9404*/,  5 /*9405*/,  5 /*9406*/,
    6 /*9407*/,  4 /*9408*/,  5 /*9409*/,  5 /*940a*/,  6 /*940b*/,
    5 /*940c*/,  6 /*940d*/,  6 /*940e*/,  7 /*940f*/,  4 /*9410*/,
    5 /*9411*/,  5 /*9412*/,  6 /*9413*/,  5 /*9414*/,  6 /*9415*/,
    6 /*9416*/,  7 /*9417*/,  5 /*9418*/,  6 /*9419*/,  6 /*941a*/,
    7 /*941b*/,  6 /*941c*/,  7 /*941d*/,  7 /*941e*/,  8 /*941f*/,
    4 /*9420*/,  5 /*9421*/,  5 /*9422*/,  6 /*9423*/,  5 /*9424*/,
    6 /*9425*/,  6 /*9426*/,  7 /*9427*/,  5 /*9428*/,  6 /*9429*/,
    6 /*942a*/,  7 /*942b*/,  6 /*942c*/,  7 /*942d*/,  7 /*942e*/,
    8 /*942f*/,  5 /*9430*/,  6 /*9431*/,  6 /*9432*/,  7 /*9433*/,
    6 /*9434*/,  7 /*9435*/,  7 /*9436*/,  8 /*9437*/,  6 /*9438*/,
    7 /*9439*/,  7 /*943a*/,  8 /*943b*/,  7 /*943c*/,  8 /*943d*/,
    8 /*943e*/,  9 /*943f*/,  4 /*9440*/,  5 /*9441*/,  5 /*9442*/,
    6 /*9443*/,  5 /*9444*/,  6 /*9445*/,  6 /*9446*/,  7 /*9447*/,
    5 /*9448*/,  6 /*9449*/,  6 /*944a*/,  7 /*944b*/,  6 /*944c*/,
    7 /*944d*/,  7 /*944e*/,  8 /*944f*/,  5 /*9450*/,  6 /*9451*/,
    6 /*9452*/,  7 /*9453*/,  6 /*9454*/,  7 /*9455*/,  7 /*9456*/,
    8 /*9457*/,  6 /*9458*/,  7 /*9459*/,  7 /*945a*/,  8 /*945b*/,
    7 /*945c*/,  8 /*945d*/,  8 /*945e*/,  9 /*945f*/,  5 /*9460*/,
    6 /*9461*/,  6 /*9462*/,  7 /*9463*/,  6 /*9464*/,  7 /*9465*/,
    7 /*9466*/,  8 /*9467*/,  6 /*9468*/,  7 /*9469*/,  7 /*946a*/,
    8 /*946b*/,  7 /*946c*/,  8 /*946d*/,  8 /*946e*/,  9 /*946f*/,
    6 /*9470*/,  7 /*9471*/,  7 /*9472*/,  8 /*9473*/,  7 /*9474*/,
    8 /*9475*/,  8 /*9476*/,  9 /*9477*/,  7 /*9478*/,  8 /*9479*/,
    8 /*947a*/,  9 /*947b*/,  8 /*947c*/,  9 /*947d*/,  9 /*947e*/,
    10 /*947f*/, 4 /*9480*/,  5 /*9481*/,  5 /*9482*/,  6 /*9483*/,
    5 /*9484*/,  6 /*9485*/,  6 /*9486*/,  7 /*9487*/,  5 /*9488*/,
    6 /*9489*/,  6 /*948a*/,  7 /*948b*/,  6 /*948c*/,  7 /*948d*/,
    7 /*948e*/,  8 /*948f*/,  5 /*9490*/,  6 /*9491*/,  6 /*9492*/,
    7 /*9493*/,  6 /*9494*/,  7 /*9495*/,  7 /*9496*/,  8 /*9497*/,
    6 /*9498*/,  7 /*9499*/,  7 /*949a*/,  8 /*949b*/,  7 /*949c*/,
    8 /*949d*/,  8 /*949e*/,  9 /*949f*/,  5 /*94a0*/,  6 /*94a1*/,
    6 /*94a2*/,  7 /*94a3*/,  6 /*94a4*/,  7 /*94a5*/,  7 /*94a6*/,
    8 /*94a7*/,  6 /*94a8*/,  7 /*94a9*/,  7 /*94aa*/,  8 /*94ab*/,
    7 /*94ac*/,  8 /*94ad*/,  8 /*94ae*/,  9 /*94af*/,  6 /*94b0*/,
    7 /*94b1*/,  7 /*94b2*/,  8 /*94b3*/,  7 /*94b4*/,  8 /*94b5*/,
    8 /*94b6*/,  9 /*94b7*/,  7 /*94b8*/,  8 /*94b9*/,  8 /*94ba*/,
    9 /*94bb*/,  8 /*94bc*/,  9 /*94bd*/,  9 /*94be*/,  10 /*94bf*/,
    5 /*94c0*/,  6 /*94c1*/,  6 /*94c2*/,  7 /*94c3*/,  6 /*94c4*/,
    7 /*94c5*/,  7 /*94c6*/,  8 /*94c7*/,  6 /*94c8*/,  7 /*94c9*/,
    7 /*94ca*/,  8 /*94cb*/,  7 /*94cc*/,  8 /*94cd*/,  8 /*94ce*/,
    9 /*94cf*/,  6 /*94d0*/,  7 /*94d1*/,  7 /*94d2*/,  8 /*94d3*/,
    7 /*94d4*/,  8 /*94d5*/,  8 /*94d6*/,  9 /*94d7*/,  7 /*94d8*/,
    8 /*94d9*/,  8 /*94da*/,  9 /*94db*/,  8 /*94dc*/,  9 /*94dd*/,
    9 /*94de*/,  10 /*94df*/, 6 /*94e0*/,  7 /*94e1*/,  7 /*94e2*/,
    8 /*94e3*/,  7 /*94e4*/,  8 /*94e5*/,  8 /*94e6*/,  9 /*94e7*/,
    7 /*94e8*/,  8 /*94e9*/,  8 /*94ea*/,  9 /*94eb*/,  8 /*94ec*/,
    9 /*94ed*/,  9 /*94ee*/,  10 /*94ef*/, 7 /*94f0*/,  8 /*94f1*/,
    8 /*94f2*/,  9 /*94f3*/,  8 /*94f4*/,  9 /*94f5*/,  9 /*94f6*/,
    10 /*94f7*/, 8 /*94f8*/,  9 /*94f9*/,  9 /*94fa*/,  10 /*94fb*/,
    9 /*94fc*/,  10 /*94fd*/, 10 /*94fe*/, 11 /*94ff*/, 4 /*9500*/,
    5 /*9501*/,  5 /*9502*/,  6 /*9503*/,  5 /*9504*/,  6 /*9505*/,
    6 /*9506*/,  7 /*9507*/,  5 /*9508*/,  6 /*9509*/,  6 /*950a*/,
    7 /*950b*/,  6 /*950c*/,  7 /*950d*/,  7 /*950e*/,  8 /*950f*/,
    5 /*9510*/,  6 /*9511*/,  6 /*9512*/,  7 /*9513*/,  6 /*9514*/,
    7 /*9515*/,  7 /*9516*/,  8 /*9517*/,  6 /*9518*/,  7 /*9519*/,
    7 /*951a*/,  8 /*951b*/,  7 /*951c*/,  8 /*951d*/,  8 /*951e*/,
    9 /*951f*/,  5 /*9520*/,  6 /*9521*/,  6 /*9522*/,  7 /*9523*/,
    6 /*9524*/,  7 /*9525*/,  7 /*9526*/,  8 /*9527*/,  6 /*9528*/,
    7 /*9529*/,  7 /*952a*/,  8 /*952b*/,  7 /*952c*/,  8 /*952d*/,
    8 /*952e*/,  9 /*952f*/,  6 /*9530*/,  7 /*9531*/,  7 /*9532*/,
    8 /*9533*/,  7 /*9534*/,  8 /*9535*/,  8 /*9536*/,  9 /*9537*/,
    7 /*9538*/,  8 /*9539*/,  8 /*953a*/,  9 /*953b*/,  8 /*953c*/,
    9 /*953d*/,  9 /*953e*/,  10 /*953f*/, 5 /*9540*/,  6 /*9541*/,
    6 /*9542*/,  7 /*9543*/,  6 /*9544*/,  7 /*9545*/,  7 /*9546*/,
    8 /*9547*/,  6 /*9548*/,  7 /*9549*/,  7 /*954a*/,  8 /*954b*/,
    7 /*954c*/,  8 /*954d*/,  8 /*954e*/,  9 /*954f*/,  6 /*9550*/,
    7 /*9551*/,  7 /*9552*/,  8 /*9553*/,  7 /*9554*/,  8 /*9555*/,
    8 /*9556*/,  9 /*9557*/,  7 /*9558*/,  8 /*9559*/,  8 /*955a*/,
    9 /*955b*/,  8 /*955c*/,  9 /*955d*/,  9 /*955e*/,  10 /*955f*/,
    6 /*9560*/,  7 /*9561*/,  7 /*9562*/,  8 /*9563*/,  7 /*9564*/,
    8 /*9565*/,  8 /*9566*/,  9 /*9567*/,  7 /*9568*/,  8 /*9569*/,
    8 /*956a*/,  9 /*956b*/,  8 /*956c*/,  9 /*956d*/,  9 /*956e*/,
    10 /*956f*/, 7 /*9570*/,  8 /*9571*/,  8 /*9572*/,  9 /*9573*/,
    8 /*9574*/,  9 /*9575*/,  9 /*9576*/,  10 /*9577*/, 8 /*9578*/,
    9 /*9579*/,  9 /*957a*/,  10 /*957b*/, 9 /*957c*/,  10 /*957d*/,
    10 /*957e*/, 11 /*957f*/, 5 /*9580*/,  6 /*9581*/,  6 /*9582*/,
    7 /*9583*/,  6 /*9584*/,  7 /*9585*/,  7 /*9586*/,  8 /*9587*/,
    6 /*9588*/,  7 /*9589*/,  7 /*958a*/,  8 /*958b*/,  7 /*958c*/,
    8 /*958d*/,  8 /*958e*/,  9 /*958f*/,  6 /*9590*/,  7 /*9591*/,
    7 /*9592*/,  8 /*9593*/,  7 /*9594*/,  8 /*9595*/,  8 /*9596*/,
    9 /*9597*/,  7 /*9598*/,  8 /*9599*/,  8 /*959a*/,  9 /*959b*/,
    8 /*959c*/,  9 /*959d*/,  9 /*959e*/,  10 /*959f*/, 6 /*95a0*/,
    7 /*95a1*/,  7 /*95a2*/,  8 /*95a3*/,  7 /*95a4*/,  8 /*95a5*/,
    8 /*95a6*/,  9 /*95a7*/,  7 /*95a8*/,  8 /*95a9*/,  8 /*95aa*/,
    9 /*95ab*/,  8 /*95ac*/,  9 /*95ad*/,  9 /*95ae*/,  10 /*95af*/,
    7 /*95b0*/,  8 /*95b1*/,  8 /*95b2*/,  9 /*95b3*/,  8 /*95b4*/,
    9 /*95b5*/,  9 /*95b6*/,  10 /*95b7*/, 8 /*95b8*/,  9 /*95b9*/,
    9 /*95ba*/,  10 /*95bb*/, 9 /*95bc*/,  10 /*95bd*/, 10 /*95be*/,
    11 /*95bf*/, 6 /*95c0*/,  7 /*95c1*/,  7 /*95c2*/,  8 /*95c3*/,
    7 /*95c4*/,  8 /*95c5*/,  8 /*95c6*/,  9 /*95c7*/,  7 /*95c8*/,
    8 /*95c9*/,  8 /*95ca*/,  9 /*95cb*/,  8 /*95cc*/,  9 /*95cd*/,
    9 /*95ce*/,  10 /*95cf*/, 7 /*95d0*/,  8 /*95d1*/,  8 /*95d2*/,
    9 /*95d3*/,  8 /*95d4*/,  9 /*95d5*/,  9 /*95d6*/,  10 /*95d7*/,
    8 /*95d8*/,  9 /*95d9*/,  9 /*95da*/,  10 /*95db*/, 9 /*95dc*/,
    10 /*95dd*/, 10 /*95de*/, 11 /*95df*/, 7 /*95e0*/,  8 /*95e1*/,
    8 /*95e2*/,  9 /*95e3*/,  8 /*95e4*/,  9 /*95e5*/,  9 /*95e6*/,
    10 /*95e7*/, 8 /*95e8*/,  9 /*95e9*/,  9 /*95ea*/,  10 /*95eb*/,
    9 /*95ec*/,  10 /*95ed*/, 10 /*95ee*/, 11 /*95ef*/, 8 /*95f0*/,
    9 /*95f1*/,  9 /*95f2*/,  10 /*95f3*/, 9 /*95f4*/,  10 /*95f5*/,
    10 /*95f6*/, 11 /*95f7*/, 9 /*95f8*/,  10 /*95f9*/, 10 /*95fa*/,
    11 /*95fb*/, 10 /*95fc*/, 11 /*95fd*/, 11 /*95fe*/, 12 /*95ff*/,
    4 /*9600*/,  5 /*9601*/,  5 /*9602*/,  6 /*9603*/,  5 /*9604*/,
    6 /*9605*/,  6 /*9606*/,  7 /*9607*/,  5 /*9608*/,  6 /*9609*/,
    6 /*960a*/,  7 /*960b*/,  6 /*960c*/,  7 /*960d*/,  7 /*960e*/,
    8 /*960f*/,  5 /*9610*/,  6 /*9611*/,  6 /*9612*/,  7 /*9613*/,
    6 /*9614*/,  7 /*9615*/,  7 /*9616*/,  8 /*9617*/,  6 /*9618*/,
    7 /*9619*/,  7 /*961a*/,  8 /*961b*/,  7 /*961c*/,  8 /*961d*/,
    8 /*961e*/,  9 /*961f*/,  5 /*9620*/,  6 /*9621*/,  6 /*9622*/,
    7 /*9623*/,  6 /*9624*/,  7 /*9625*/,  7 /*9626*/,  8 /*9627*/,
    6 /*9628*/,  7 /*9629*/,  7 /*962a*/,  8 /*962b*/,  7 /*962c*/,
    8 /*962d*/,  8 /*962e*/,  9 /*962f*/,  6 /*9630*/,  7 /*9631*/,
    7 /*9632*/,  8 /*9633*/,  7 /*9634*/,  8 /*9635*/,  8 /*9636*/,
    9 /*9637*/,  7 /*9638*/,  8 /*9639*/,  8 /*963a*/,  9 /*963b*/,
    8 /*963c*/,  9 /*963d*/,  9 /*963e*/,  10 /*963f*/, 5 /*9640*/,
    6 /*9641*/,  6 /*9642*/,  7 /*9643*/,  6 /*9644*/,  7 /*9645*/,
    7 /*9646*/,  8 /*9647*/,  6 /*9648*/,  7 /*9649*/,  7 /*964a*/,
    8 /*964b*/,  7 /*964c*/,  8 /*964d*/,  8 /*964e*/,  9 /*964f*/,
    6 /*9650*/,  7 /*9651*/,  7 /*9652*/,  8 /*9653*/,  7 /*9654*/,
    8 /*9655*/,  8 /*9656*/,  9 /*9657*/,  7 /*9658*/,  8 /*9659*/,
    8 /*965a*/,  9 /*965b*/,  8 /*965c*/,  9 /*965d*/,  9 /*965e*/,
    10 /*965f*/, 6 /*9660*/,  7 /*9661*/,  7 /*9662*/,  8 /*9663*/,
    7 /*9664*/,  8 /*9665*/,  8 /*9666*/,  9 /*9667*/,  7 /*9668*/,
    8 /*9669*/,  8 /*966a*/,  9 /*966b*/,  8 /*966c*/,  9 /*966d*/,
    9 /*966e*/,  10 /*966f*/, 7 /*9670*/,  8 /*9671*/,  8 /*9672*/,
    9 /*9673*/,  8 /*9674*/,  9 /*9675*/,  9 /*9676*/,  10 /*9677*/,
    8 /*9678*/,  9 /*9679*/,  9 /*967a*/,  10 /*967b*/, 9 /*967c*/,
    10 /*967d*/, 10 /*967e*/, 11 /*967f*/, 5 /*9680*/,  6 /*9681*/,
    6 /*9682*/,  7 /*9683*/,  6 /*9684*/,  7 /*9685*/,  7 /*9686*/,
    8 /*9687*/,  6 /*9688*/,  7 /*9689*/,  7 /*968a*/,  8 /*968b*/,
    7 /*968c*/,  8 /*968d*/,  8 /*968e*/,  9 /*968f*/,  6 /*9690*/,
    7 /*9691*/,  7 /*9692*/,  8 /*9693*/,  7 /*9694*/,  8 /*9695*/,
    8 /*9696*/,  9 /*9697*/,  7 /*9698*/,  8 /*9699*/,  8 /*969a*/,
    9 /*969b*/,  8 /*969c*/,  9 /*969d*/,  9 /*969e*/,  10 /*969f*/,
    6 /*96a0*/,  7 /*96a1*/,  7 /*96a2*/,  8 /*96a3*/,  7 /*96a4*/,
    8 /*96a5*/,  8 /*96a6*/,  9 /*96a7*/,  7 /*96a8*/,  8 /*96a9*/,
    8 /*96aa*/,  9 /*96ab*/,  8 /*96ac*/,  9 /*96ad*/,  9 /*96ae*/,
    10 /*96af*/, 7 /*96b0*/,  8 /*96b1*/,  8 /*96b2*/,  9 /*96b3*/,
    8 /*96b4*/,  9 /*96b5*/,  9 /*96b6*/,  10 /*96b7*/, 8 /*96b8*/,
    9 /*96b9*/,  9 /*96ba*/,  10 /*96bb*/, 9 /*96bc*/,  10 /*96bd*/,
    10 /*96be*/, 11 /*96bf*/, 6 /*96c0*/,  7 /*96c1*/,  7 /*96c2*/,
    8 /*96c3*/,  7 /*96c4*/,  8 /*96c5*/,  8 /*96c6*/,  9 /*96c7*/,
    7 /*96c8*/,  8 /*96c9*/,  8 /*96ca*/,  9 /*96cb*/,  8 /*96cc*/,
    9 /*96cd*/,  9 /*96ce*/,  10 /*96cf*/, 7 /*96d0*/,  8 /*96d1*/,
    8 /*96d2*/,  9 /*96d3*/,  8 /*96d4*/,  9 /*96d5*/,  9 /*96d6*/,
    10 /*96d7*/, 8 /*96d8*/,  9 /*96d9*/,  9 /*96da*/,  10 /*96db*/,
    9 /*96dc*/,  10 /*96dd*/, 10 /*96de*/, 11 /*96df*/, 7 /*96e0*/,
    8 /*96e1*/,  8 /*96e2*/,  9 /*96e3*/,  8 /*96e4*/,  9 /*96e5*/,
    9 /*96e6*/,  10 /*96e7*/, 8 /*96e8*/,  9 /*96e9*/,  9 /*96ea*/,
    10 /*96eb*/, 9 /*96ec*/,  10 /*96ed*/, 10 /*96ee*/, 11 /*96ef*/,
    8 /*96f0*/,  9 /*96f1*/,  9 /*96f2*/,  10 /*96f3*/, 9 /*96f4*/,
    10 /*96f5*/, 10 /*96f6*/, 11 /*96f7*/, 9 /*96f8*/,  10 /*96f9*/,
    10 /*96fa*/, 11 /*96fb*/, 10 /*96fc*/, 11 /*96fd*/, 11 /*96fe*/,
    12 /*96ff*/, 5 /*9700*/,  6 /*9701*/,  6 /*9702*/,  7 /*9703*/,
    6 /*9704*/,  7 /*9705*/,  7 /*9706*/,  8 /*9707*/,  6 /*9708*/,
    7 /*9709*/,  7 /*970a*/,  8 /*970b*/,  7 /*970c*/,  8 /*970d*/,
    8 /*970e*/,  9 /*970f*/,  6 /*9710*/,  7 /*9711*/,  7 /*9712*/,
    8 /*9713*/,  7 /*9714*/,  8 /*9715*/,  8 /*9716*/,  9 /*9717*/,
    7 /*9718*/,  8 /*9719*/,  8 /*971a*/,  9 /*971b*/,  8 /*971c*/,
    9 /*971d*/,  9 /*971e*/,  10 /*971f*/, 6 /*9720*/,  7 /*9721*/,
    7 /*9722*/,  8 /*9723*/,  7 /*9724*/,  8 /*9725*/,  8 /*9726*/,
    9 /*9727*/,  7 /*9728*/,  8 /*9729*/,  8 /*972a*/,  9 /*972b*/,
    8 /*972c*/,  9 /*972d*/,  9 /*972e*/,  10 /*972f*/, 7 /*9730*/,
    8 /*9731*/,  8 /*9732*/,  9 /*9733*/,  8 /*9734*/,  9 /*9735*/,
    9 /*9736*/,  10 /*9737*/, 8 /*9738*/,  9 /*9739*/,  9 /*973a*/,
    10 /*973b*/, 9 /*973c*/,  10 /*973d*/, 10 /*973e*/, 11 /*973f*/,
    6 /*9740*/,  7 /*9741*/,  7 /*9742*/,  8 /*9743*/,  7 /*9744*/,
    8 /*9745*/,  8 /*9746*/,  9 /*9747*/,  7 /*9748*/,  8 /*9749*/,
    8 /*974a*/,  9 /*974b*/,  8 /*974c*/,  9 /*974d*/,  9 /*974e*/,
    10 /*974f*/, 7 /*9750*/,  8 /*9751*/,  8 /*9752*/,  9 /*9753*/,
    8 /*9754*/,  9 /*9755*/,  9 /*9756*/,  10 /*9757*/, 8 /*9758*/,
    9 /*9759*/,  9 /*975a*/,  10 /*975b*/, 9 /*975c*/,  10 /*975d*/,
    10 /*975e*/, 11 /*975f*/, 7 /*9760*/,  8 /*9761*/,  8 /*9762*/,
    9 /*9763*/,  8 /*9764*/,  9 /*9765*/,  9 /*9766*/,  10 /*9767*/,
    8 /*9768*/,  9 /*9769*/,  9 /*976a*/,  10 /*976b*/, 9 /*976c*/,
    10 /*976d*/, 10 /*976e*/, 11 /*976f*/, 8 /*9770*/,  9 /*9771*/,
    9 /*9772*/,  10 /*9773*/, 9 /*9774*/,  10 /*9775*/, 10 /*9776*/,
    11 /*9777*/, 9 /*9778*/,  10 /*9779*/, 10 /*977a*/, 11 /*977b*/,
    10 /*977c*/, 11 /*977d*/, 11 /*977e*/, 12 /*977f*/, 6 /*9780*/,
    7 /*9781*/,  7 /*9782*/,  8 /*9783*/,  7 /*9784*/,  8 /*9785*/,
    8 /*9786*/,  9 /*9787*/,  7 /*9788*/,  8 /*9789*/,  8 /*978a*/,
    9 /*978b*/,  8 /*978c*/,  9 /*978d*/,  9 /*978e*/,  10 /*978f*/,
    7 /*9790*/,  8 /*9791*/,  8 /*9792*/,  9 /*9793*/,  8 /*9794*/,
    9 /*9795*/,  9 /*9796*/,  10 /*9797*/, 8 /*9798*/,  9 /*9799*/,
    9 /*979a*/,  10 /*979b*/, 9 /*979c*/,  10 /*979d*/, 10 /*979e*/,
    11 /*979f*/, 7 /*97a0*/,  8 /*97a1*/,  8 /*97a2*/,  9 /*97a3*/,
    8 /*97a4*/,  9 /*97a5*/,  9 /*97a6*/,  10 /*97a7*/, 8 /*97a8*/,
    9 /*97a9*/,  9 /*97aa*/,  10 /*97ab*/, 9 /*97ac*/,  10 /*97ad*/,
    10 /*97ae*/, 11 /*97af*/, 8 /*97b0*/,  9 /*97b1*/,  9 /*97b2*/,
    10 /*97b3*/, 9 /*97b4*/,  10 /*97b5*/, 10 /*97b6*/, 11 /*97b7*/,
    9 /*97b8*/,  10 /*97b9*/, 10 /*97ba*/, 11 /*97bb*/, 10 /*97bc*/,
    11 /*97bd*/, 11 /*97be*/, 12 /*97bf*/, 7 /*97c0*/,  8 /*97c1*/,
    8 /*97c2*/,  9 /*97c3*/,  8 /*97c4*/,  9 /*97c5*/,  9 /*97c6*/,
    10 /*97c7*/, 8 /*97c8*/,  9 /*97c9*/,  9 /*97ca*/,  10 /*97cb*/,
    9 /*97cc*/,  10 /*97cd*/, 10 /*97ce*/, 11 /*97cf*/, 8 /*97d0*/,
    9 /*97d1*/,  9 /*97d2*/,  10 /*97d3*/, 9 /*97d4*/,  10 /*97d5*/,
    10 /*97d6*/, 11 /*97d7*/, 9 /*97d8*/,  10 /*97d9*/, 10 /*97da*/,
    11 /*97db*/, 10 /*97dc*/, 11 /*97dd*/, 11 /*97de*/, 12 /*97df*/,
    8 /*97e0*/,  9 /*97e1*/,  9 /*97e2*/,  10 /*97e3*/, 9 /*97e4*/,
    10 /*97e5*/, 10 /*97e6*/, 11 /*97e7*/, 9 /*97e8*/,  10 /*97e9*/,
    10 /*97ea*/, 11 /*97eb*/, 10 /*97ec*/, 11 /*97ed*/, 11 /*97ee*/,
    12 /*97ef*/, 9 /*97f0*/,  10 /*97f1*/, 10 /*97f2*/, 11 /*97f3*/,
    10 /*97f4*/, 11 /*97f5*/, 11 /*97f6*/, 12 /*97f7*/, 10 /*97f8*/,
    11 /*97f9*/, 11 /*97fa*/, 12 /*97fb*/, 11 /*97fc*/, 12 /*97fd*/,
    12 /*97fe*/, 13 /*97ff*/, 3 /*9800*/,  4 /*9801*/,  4 /*9802*/,
    5 /*9803*/,  4 /*9804*/,  5 /*9805*/,  5 /*9806*/,  6 /*9807*/,
    4 /*9808*/,  5 /*9809*/,  5 /*980a*/,  6 /*980b*/,  5 /*980c*/,
    6 /*980d*/,  6 /*980e*/,  7 /*980f*/,  4 /*9810*/,  5 /*9811*/,
    5 /*9812*/,  6 /*9813*/,  5 /*9814*/,  6 /*9815*/,  6 /*9816*/,
    7 /*9817*/,  5 /*9818*/,  6 /*9819*/,  6 /*981a*/,  7 /*981b*/,
    6 /*981c*/,  7 /*981d*/,  7 /*981e*/,  8 /*981f*/,  4 /*9820*/,
    5 /*9821*/,  5 /*9822*/,  6 /*9823*/,  5 /*9824*/,  6 /*9825*/,
    6 /*9826*/,  7 /*9827*/,  5 /*9828*/,  6 /*9829*/,  6 /*982a*/,
    7 /*982b*/,  6 /*982c*/,  7 /*982d*/,  7 /*982e*/,  8 /*982f*/,
    5 /*9830*/,  6 /*9831*/,  6 /*9832*/,  7 /*9833*/,  6 /*9834*/,
    7 /*9835*/,  7 /*9836*/,  8 /*9837*/,  6 /*9838*/,  7 /*9839*/,
    7 /*983a*/,  8 /*983b*/,  7 /*983c*/,  8 /*983d*/,  8 /*983e*/,
    9 /*983f*/,  4 /*9840*/,  5 /*9841*/,  5 /*9842*/,  6 /*9843*/,
    5 /*9844*/,  6 /*9845*/,  6 /*9846*/,  7 /*9847*/,  5 /*9848*/,
    6 /*9849*/,  6 /*984a*/,  7 /*984b*/,  6 /*984c*/,  7 /*984d*/,
    7 /*984e*/,  8 /*984f*/,  5 /*9850*/,  6 /*9851*/,  6 /*9852*/,
    7 /*9853*/,  6 /*9854*/,  7 /*9855*/,  7 /*9856*/,  8 /*9857*/,
    6 /*9858*/,  7 /*9859*/,  7 /*985a*/,  8 /*985b*/,  7 /*985c*/,
    8 /*985d*/,  8 /*985e*/,  9 /*985f*/,  5 /*9860*/,  6 /*9861*/,
    6 /*9862*/,  7 /*9863*/,  6 /*9864*/,  7 /*9865*/,  7 /*9866*/,
    8 /*9867*/,  6 /*9868*/,  7 /*9869*/,  7 /*986a*/,  8 /*986b*/,
    7 /*986c*/,  8 /*986d*/,  8 /*986e*/,  9 /*986f*/,  6 /*9870*/,
    7 /*9871*/,  7 /*9872*/,  8 /*9873*/,  7 /*9874*/,  8 /*9875*/,
    8 /*9876*/,  9 /*9877*/,  7 /*9878*/,  8 /*9879*/,  8 /*987a*/,
    9 /*987b*/,  8 /*987c*/,  9 /*987d*/,  9 /*987e*/,  10 /*987f*/,
    4 /*9880*/,  5 /*9881*/,  5 /*9882*/,  6 /*9883*/,  5 /*9884*/,
    6 /*9885*/,  6 /*9886*/,  7 /*9887*/,  5 /*9888*/,  6 /*9889*/,
    6 /*988a*/,  7 /*988b*/,  6 /*988c*/,  7 /*988d*/,  7 /*988e*/,
    8 /*988f*/,  5 /*9890*/,  6 /*9891*/,  6 /*9892*/,  7 /*9893*/,
    6 /*9894*/,  7 /*9895*/,  7 /*9896*/,  8 /*9897*/,  6 /*9898*/,
    7 /*9899*/,  7 /*989a*/,  8 /*989b*/,  7 /*989c*/,  8 /*989d*/,
    8 /*989e*/,  9 /*989f*/,  5 /*98a0*/,  6 /*98a1*/,  6 /*98a2*/,
    7 /*98a3*/,  6 /*98a4*/,  7 /*98a5*/,  7 /*98a6*/,  8 /*98a7*/,
    6 /*98a8*/,  7 /*98a9*/,  7 /*98aa*/,  8 /*98ab*/,  7 /*98ac*/,
    8 /*98ad*/,  8 /*98ae*/,  9 /*98af*/,  6 /*98b0*/,  7 /*98b1*/,
    7 /*98b2*/,  8 /*98b3*/,  7 /*98b4*/,  8 /*98b5*/,  8 /*98b6*/,
    9 /*98b7*/,  7 /*98b8*/,  8 /*98b9*/,  8 /*98ba*/,  9 /*98bb*/,
    8 /*98bc*/,  9 /*98bd*/,  9 /*98be*/,  10 /*98bf*/, 5 /*98c0*/,
    6 /*98c1*/,  6 /*98c2*/,  7 /*98c3*/,  6 /*98c4*/,  7 /*98c5*/,
    7 /*98c6*/,  8 /*98c7*/,  6 /*98c8*/,  7 /*98c9*/,  7 /*98ca*/,
    8 /*98cb*/,  7 /*98cc*/,  8 /*98cd*/,  8 /*98ce*/,  9 /*98cf*/,
    6 /*98d0*/,  7 /*98d1*/,  7 /*98d2*/,  8 /*98d3*/,  7 /*98d4*/,
    8 /*98d5*/,  8 /*98d6*/,  9 /*98d7*/,  7 /*98d8*/,  8 /*98d9*/,
    8 /*98da*/,  9 /*98db*/,  8 /*98dc*/,  9 /*98dd*/,  9 /*98de*/,
    10 /*98df*/, 6 /*98e0*/,  7 /*98e1*/,  7 /*98e2*/,  8 /*98e3*/,
    7 /*98e4*/,  8 /*98e5*/,  8 /*98e6*/,  9 /*98e7*/,  7 /*98e8*/,
    8 /*98e9*/,  8 /*98ea*/,  9 /*98eb*/,  8 /*98ec*/,  9 /*98ed*/,
    9 /*98ee*/,  10 /*98ef*/, 7 /*98f0*/,  8 /*98f1*/,  8 /*98f2*/,
    9 /*98f3*/,  8 /*98f4*/,  9 /*98f5*/,  9 /*98f6*/,  10 /*98f7*/,
    8 /*98f8*/,  9 /*98f9*/,  9 /*98fa*/,  10 /*98fb*/, 9 /*98fc*/,
    10 /*98fd*/, 10 /*98fe*/, 11 /*98ff*/, 4 /*9900*/,  5 /*9901*/,
    5 /*9902*/,  6 /*9903*/,  5 /*9904*/,  6 /*9905*/,  6 /*9906*/,
    7 /*9907*/,  5 /*9908*/,  6 /*9909*/,  6 /*990a*/,  7 /*990b*/,
    6 /*990c*/,  7 /*990d*/,  7 /*990e*/,  8 /*990f*/,  5 /*9910*/,
    6 /*9911*/,  6 /*9912*/,  7 /*9913*/,  6 /*9914*/,  7 /*9915*/,
    7 /*9916*/,  8 /*9917*/,  6 /*9918*/,  7 /*9919*/,  7 /*991a*/,
    8 /*991b*/,  7 /*991c*/,  8 /*991d*/,  8 /*991e*/,  9 /*991f*/,
    5 /*9920*/,  6 /*9921*/,  6 /*9922*/,  7 /*9923*/,  6 /*9924*/,
    7 /*9925*/,  7 /*9926*/,  8 /*9927*/,  6 /*9928*/,  7 /*9929*/,
    7 /*992a*/,  8 /*992b*/,  7 /*992c*/,  8 /*992d*/,  8 /*992e*/,
    9 /*992f*/,  6 /*9930*/,  7 /*9931*/,  7 /*9932*/,  8 /*9933*/,
    7 /*9934*/,  8 /*9935*/,  8 /*9936*/,  9 /*9937*/,  7 /*9938*/,
    8 /*9939*/,  8 /*993a*/,  9 /*993b*/,  8 /*993c*/,  9 /*993d*/,
    9 /*993e*/,  10 /*993f*/, 5 /*9940*/,  6 /*9941*/,  6 /*9942*/,
    7 /*9943*/,  6 /*9944*/,  7 /*9945*/,  7 /*9946*/,  8 /*9947*/,
    6 /*9948*/,  7 /*9949*/,  7 /*994a*/,  8 /*994b*/,  7 /*994c*/,
    8 /*994d*/,  8 /*994e*/,  9 /*994f*/,  6 /*9950*/,  7 /*9951*/,
    7 /*9952*/,  8 /*9953*/,  7 /*9954*/,  8 /*9955*/,  8 /*9956*/,
    9 /*9957*/,  7 /*9958*/,  8 /*9959*/,  8 /*995a*/,  9 /*995b*/,
    8 /*995c*/,  9 /*995d*/,  9 /*995e*/,  10 /*995f*/, 6 /*9960*/,
    7 /*9961*/,  7 /*9962*/,  8 /*9963*/,  7 /*9964*/,  8 /*9965*/,
    8 /*9966*/,  9 /*9967*/,  7 /*9968*/,  8 /*9969*/,  8 /*996a*/,
    9 /*996b*/,  8 /*996c*/,  9 /*996d*/,  9 /*996e*/,  10 /*996f*/,
    7 /*9970*/,  8 /*9971*/,  8 /*9972*/,  9 /*9973*/,  8 /*9974*/,
    9 /*9975*/,  9 /*9976*/,  10 /*9977*/, 8 /*9978*/,  9 /*9979*/,
    9 /*997a*/,  10 /*997b*/, 9 /*997c*/,  10 /*997d*/, 10 /*997e*/,
    11 /*997f*/, 5 /*9980*/,  6 /*9981*/,  6 /*9982*/,  7 /*9983*/,
    6 /*9984*/,  7 /*9985*/,  7 /*9986*/,  8 /*9987*/,  6 /*9988*/,
    7 /*9989*/,  7 /*998a*/,  8 /*998b*/,  7 /*998c*/,  8 /*998d*/,
    8 /*998e*/,  9 /*998f*/,  6 /*9990*/,  7 /*9991*/,  7 /*9992*/,
    8 /*9993*/,  7 /*9994*/,  8 /*9995*/,  8 /*9996*/,  9 /*9997*/,
    7 /*9998*/,  8 /*9999*/,  8 /*999a*/,  9 /*999b*/,  8 /*999c*/,
    9 /*999d*/,  9 /*999e*/,  10 /*999f*/, 6 /*99a0*/,  7 /*99a1*/,
    7 /*99a2*/,  8 /*99a3*/,  7 /*99a4*/,  8 /*99a5*/,  8 /*99a6*/,
    9 /*99a7*/,  7 /*99a8*/,  8 /*99a9*/,  8 /*99aa*/,  9 /*99ab*/,
    8 /*99ac*/,  9 /*99ad*/,  9 /*99ae*/,  10 /*99af*/, 7 /*99b0*/,
    8 /*99b1*/,  8 /*99b2*/,  9 /*99b3*/,  8 /*99b4*/,  9 /*99b5*/,
    9 /*99b6*/,  10 /*99b7*/, 8 /*99b8*/,  9 /*99b9*/,  9 /*99ba*/,
    10 /*99bb*/, 9 /*99bc*/,  10 /*99bd*/, 10 /*99be*/, 11 /*99bf*/,
    6 /*99c0*/,  7 /*99c1*/,  7 /*99c2*/,  8 /*99c3*/,  7 /*99c4*/,
    8 /*99c5*/,  8 /*99c6*/,  9 /*99c7*/,  7 /*99c8*/,  8 /*99c9*/,
    8 /*99ca*/,  9 /*99cb*/,  8 /*99cc*/,  9 /*99cd*/,  9 /*99ce*/,
    10 /*99cf*/, 7 /*99d0*/,  8 /*99d1*/,  8 /*99d2*/,  9 /*99d3*/,
    8 /*99d4*/,  9 /*99d5*/,  9 /*99d6*/,  10 /*99d7*/, 8 /*99d8*/,
    9 /*99d9*/,  9 /*99da*/,  10 /*99db*/, 9 /*99dc*/,  10 /*99dd*/,
    10 /*99de*/, 11 /*99df*/, 7 /*99e0*/,  8 /*99e1*/,  8 /*99e2*/,
    9 /*99e3*/,  8 /*99e4*/,  9 /*99e5*/,  9 /*99e6*/,  10 /*99e7*/,
    8 /*99e8*/,  9 /*99e9*/,  9 /*99ea*/,  10 /*99eb*/, 9 /*99ec*/,
    10 /*99ed*/, 10 /*99ee*/, 11 /*99ef*/, 8 /*99f0*/,  9 /*99f1*/,
    9 /*99f2*/,  10 /*99f3*/, 9 /*99f4*/,  10 /*99f5*/, 10 /*99f6*/,
    11 /*99f7*/, 9 /*99f8*/,  10 /*99f9*/, 10 /*99fa*/, 11 /*99fb*/,
    10 /*99fc*/, 11 /*99fd*/, 11 /*99fe*/, 12 /*99ff*/, 4 /*9a00*/,
    5 /*9a01*/,  5 /*9a02*/,  6 /*9a03*/,  5 /*9a04*/,  6 /*9a05*/,
    6 /*9a06*/,  7 /*9a07*/,  5 /*9a08*/,  6 /*9a09*/,  6 /*9a0a*/,
    7 /*9a0b*/,  6 /*9a0c*/,  7 /*9a0d*/,  7 /*9a0e*/,  8 /*9a0f*/,
    5 /*9a10*/,  6 /*9a11*/,  6 /*9a12*/,  7 /*9a13*/,  6 /*9a14*/,
    7 /*9a15*/,  7 /*9a16*/,  8 /*9a17*/,  6 /*9a18*/,  7 /*9a19*/,
    7 /*9a1a*/,  8 /*9a1b*/,  7 /*9a1c*/,  8 /*9a1d*/,  8 /*9a1e*/,
    9 /*9a1f*/,  5 /*9a20*/,  6 /*9a21*/,  6 /*9a22*/,  7 /*9a23*/,
    6 /*9a24*/,  7 /*9a25*/,  7 /*9a26*/,  8 /*9a27*/,  6 /*9a28*/,
    7 /*9a29*/,  7 /*9a2a*/,  8 /*9a2b*/,  7 /*9a2c*/,  8 /*9a2d*/,
    8 /*9a2e*/,  9 /*9a2f*/,  6 /*9a30*/,  7 /*9a31*/,  7 /*9a32*/,
    8 /*9a33*/,  7 /*9a34*/,  8 /*9a35*/,  8 /*9a36*/,  9 /*9a37*/,
    7 /*9a38*/,  8 /*9a39*/,  8 /*9a3a*/,  9 /*9a3b*/,  8 /*9a3c*/,
    9 /*9a3d*/,  9 /*9a3e*/,  10 /*9a3f*/, 5 /*9a40*/,  6 /*9a41*/,
    6 /*9a42*/,  7 /*9a43*/,  6 /*9a44*/,  7 /*9a45*/,  7 /*9a46*/,
    8 /*9a47*/,  6 /*9a48*/,  7 /*9a49*/,  7 /*9a4a*/,  8 /*9a4b*/,
    7 /*9a4c*/,  8 /*9a4d*/,  8 /*9a4e*/,  9 /*9a4f*/,  6 /*9a50*/,
    7 /*9a51*/,  7 /*9a52*/,  8 /*9a53*/,  7 /*9a54*/,  8 /*9a55*/,
    8 /*9a56*/,  9 /*9a57*/,  7 /*9a58*/,  8 /*9a59*/,  8 /*9a5a*/,
    9 /*9a5b*/,  8 /*9a5c*/,  9 /*9a5d*/,  9 /*9a5e*/,  10 /*9a5f*/,
    6 /*9a60*/,  7 /*9a61*/,  7 /*9a62*/,  8 /*9a63*/,  7 /*9a64*/,
    8 /*9a65*/,  8 /*9a66*/,  9 /*9a67*/,  7 /*9a68*/,  8 /*9a69*/,
    8 /*9a6a*/,  9 /*9a6b*/,  8 /*9a6c*/,  9 /*9a6d*/,  9 /*9a6e*/,
    10 /*9a6f*/, 7 /*9a70*/,  8 /*9a71*/,  8 /*9a72*/,  9 /*9a73*/,
    8 /*9a74*/,  9 /*9a75*/,  9 /*9a76*/,  10 /*9a77*/, 8 /*9a78*/,
    9 /*9a79*/,  9 /*9a7a*/,  10 /*9a7b*/, 9 /*9a7c*/,  10 /*9a7d*/,
    10 /*9a7e*/, 11 /*9a7f*/, 5 /*9a80*/,  6 /*9a81*/,  6 /*9a82*/,
    7 /*9a83*/,  6 /*9a84*/,  7 /*9a85*/,  7 /*9a86*/,  8 /*9a87*/,
    6 /*9a88*/,  7 /*9a89*/,  7 /*9a8a*/,  8 /*9a8b*/,  7 /*9a8c*/,
    8 /*9a8d*/,  8 /*9a8e*/,  9 /*9a8f*/,  6 /*9a90*/,  7 /*9a91*/,
    7 /*9a92*/,  8 /*9a93*/,  7 /*9a94*/,  8 /*9a95*/,  8 /*9a96*/,
    9 /*9a97*/,  7 /*9a98*/,  8 /*9a99*/,  8 /*9a9a*/,  9 /*9a9b*/,
    8 /*9a9c*/,  9 /*9a9d*/,  9 /*9a9e*/,  10 /*9a9f*/, 6 /*9aa0*/,
    7 /*9aa1*/,  7 /*9aa2*/,  8 /*9aa3*/,  7 /*9aa4*/,  8 /*9aa5*/,
    8 /*9aa6*/,  9 /*9aa7*/,  7 /*9aa8*/,  8 /*9aa9*/,  8 /*9aaa*/,
    9 /*9aab*/,  8 /*9aac*/,  9 /*9aad*/,  9 /*9aae*/,  10 /*9aaf*/,
    7 /*9ab0*/,  8 /*9ab1*/,  8 /*9ab2*/,  9 /*9ab3*/,  8 /*9ab4*/,
    9 /*9ab5*/,  9 /*9ab6*/,  10 /*9ab7*/, 8 /*9ab8*/,  9 /*9ab9*/,
    9 /*9aba*/,  10 /*9abb*/, 9 /*9abc*/,  10 /*9abd*/, 10 /*9abe*/,
    11 /*9abf*/, 6 /*9ac0*/,  7 /*9ac1*/,  7 /*9ac2*/,  8 /*9ac3*/,
    7 /*9ac4*/,  8 /*9ac5*/,  8 /*9ac6*/,  9 /*9ac7*/,  7 /*9ac8*/,
    8 /*9ac9*/,  8 /*9aca*/,  9 /*9acb*/,  8 /*9acc*/,  9 /*9acd*/,
    9 /*9ace*/,  10 /*9acf*/, 7 /*9ad0*/,  8 /*9ad1*/,  8 /*9ad2*/,
    9 /*9ad3*/,  8 /*9ad4*/,  9 /*9ad5*/,  9 /*9ad6*/,  10 /*9ad7*/,
    8 /*9ad8*/,  9 /*9ad9*/,  9 /*9ada*/,  10 /*9adb*/, 9 /*9adc*/,
    10 /*9add*/, 10 /*9ade*/, 11 /*9adf*/, 7 /*9ae0*/,  8 /*9ae1*/,
    8 /*9ae2*/,  9 /*9ae3*/,  8 /*9ae4*/,  9 /*9ae5*/,  9 /*9ae6*/,
    10 /*9ae7*/, 8 /*9ae8*/,  9 /*9ae9*/,  9 /*9aea*/,  10 /*9aeb*/,
    9 /*9aec*/,  10 /*9aed*/, 10 /*9aee*/, 11 /*9aef*/, 8 /*9af0*/,
    9 /*9af1*/,  9 /*9af2*/,  10 /*9af3*/, 9 /*9af4*/,  10 /*9af5*/,
    10 /*9af6*/, 11 /*9af7*/, 9 /*9af8*/,  10 /*9af9*/, 10 /*9afa*/,
    11 /*9afb*/, 10 /*9afc*/, 11 /*9afd*/, 11 /*9afe*/, 12 /*9aff*/,
    5 /*9b00*/,  6 /*9b01*/,  6 /*9b02*/,  7 /*9b03*/,  6 /*9b04*/,
    7 /*9b05*/,  7 /*9b06*/,  8 /*9b07*/,  6 /*9b08*/,  7 /*9b09*/,
    7 /*9b0a*/,  8 /*9b0b*/,  7 /*9b0c*/,  8 /*9b0d*/,  8 /*9b0e*/,
    9 /*9b0f*/,  6 /*9b10*/,  7 /*9b11*/,  7 /*9b12*/,  8 /*9b13*/,
    7 /*9b14*/,  8 /*9b15*/,  8 /*9b16*/,  9 /*9b17*/,  7 /*9b18*/,
    8 /*9b19*/,  8 /*9b1a*/,  9 /*9b1b*/,  8 /*9b1c*/,  9 /*9b1d*/,
    9 /*9b1e*/,  10 /*9b1f*/, 6 /*9b20*/,  7 /*9b21*/,  7 /*9b22*/,
    8 /*9b23*/,  7 /*9b24*/,  8 /*9b25*/,  8 /*9b26*/,  9 /*9b27*/,
    7 /*9b28*/,  8 /*9b29*/,  8 /*9b2a*/,  9 /*9b2b*/,  8 /*9b2c*/,
    9 /*9b2d*/,  9 /*9b2e*/,  10 /*9b2f*/, 7 /*9b30*/,  8 /*9b31*/,
    8 /*9b32*/,  9 /*9b33*/,  8 /*9b34*/,  9 /*9b35*/,  9 /*9b36*/,
    10 /*9b37*/, 8 /*9b38*/,  9 /*9b39*/,  9 /*9b3a*/,  10 /*9b3b*/,
    9 /*9b3c*/,  10 /*9b3d*/, 10 /*9b3e*/, 11 /*9b3f*/, 6 /*9b40*/,
    7 /*9b41*/,  7 /*9b42*/,  8 /*9b43*/,  7 /*9b44*/,  8 /*9b45*/,
    8 /*9b46*/,  9 /*9b47*/,  7 /*9b48*/,  8 /*9b49*/,  8 /*9b4a*/,
    9 /*9b4b*/,  8 /*9b4c*/,  9 /*9b4d*/,  9 /*9b4e*/,  10 /*9b4f*/,
    7 /*9b50*/,  8 /*9b51*/,  8 /*9b52*/,  9 /*9b53*/,  8 /*9b54*/,
    9 /*9b55*/,  9 /*9b56*/,  10 /*9b57*/, 8 /*9b58*/,  9 /*9b59*/,
    9 /*9b5a*/,  10 /*9b5b*/, 9 /*9b5c*/,  10 /*9b5d*/, 10 /*9b5e*/,
    11 /*9b5f*/, 7 /*9b60*/,  8 /*9b61*/,  8 /*9b62*/,  9 /*9b63*/,
    8 /*9b64*/,  9 /*9b65*/,  9 /*9b66*/,  10 /*9b67*/, 8 /*9b68*/,
    9 /*9b69*/,  9 /*9b6a*/,  10 /*9b6b*/, 9 /*9b6c*/,  10 /*9b6d*/,
    10 /*9b6e*/, 11 /*9b6f*/, 8 /*9b70*/,  9 /*9b71*/,  9 /*9b72*/,
    10 /*9b73*/, 9 /*9b74*/,  10 /*9b75*/, 10 /*9b76*/, 11 /*9b77*/,
    9 /*9b78*/,  10 /*9b79*/, 10 /*9b7a*/, 11 /*9b7b*/, 10 /*9b7c*/,
    11 /*9b7d*/, 11 /*9b7e*/, 12 /*9b7f*/, 6 /*9b80*/,  7 /*9b81*/,
    7 /*9b82*/,  8 /*9b83*/,  7 /*9b84*/,  8 /*9b85*/,  8 /*9b86*/,
    9 /*9b87*/,  7 /*9b88*/,  8 /*9b89*/,  8 /*9b8a*/,  9 /*9b8b*/,
    8 /*9b8c*/,  9 /*9b8d*/,  9 /*9b8e*/,  10 /*9b8f*/, 7 /*9b90*/,
    8 /*9b91*/,  8 /*9b92*/,  9 /*9b93*/,  8 /*9b94*/,  9 /*9b95*/,
    9 /*9b96*/,  10 /*9b97*/, 8 /*9b98*/,  9 /*9b99*/,  9 /*9b9a*/,
    10 /*9b9b*/, 9 /*9b9c*/,  10 /*9b9d*/, 10 /*9b9e*/, 11 /*9b9f*/,
    7 /*9ba0*/,  8 /*9ba1*/,  8 /*9ba2*/,  9 /*9ba3*/,  8 /*9ba4*/,
    9 /*9ba5*/,  9 /*9ba6*/,  10 /*9ba7*/, 8 /*9ba8*/,  9 /*9ba9*/,
    9 /*9baa*/,  10 /*9bab*/, 9 /*9bac*/,  10 /*9bad*/, 10 /*9bae*/,
    11 /*9baf*/, 8 /*9bb0*/,  9 /*9bb1*/,  9 /*9bb2*/,  10 /*9bb3*/,
    9 /*9bb4*/,  10 /*9bb5*/, 10 /*9bb6*/, 11 /*9bb7*/, 9 /*9bb8*/,
    10 /*9bb9*/, 10 /*9bba*/, 11 /*9bbb*/, 10 /*9bbc*/, 11 /*9bbd*/,
    11 /*9bbe*/, 12 /*9bbf*/, 7 /*9bc0*/,  8 /*9bc1*/,  8 /*9bc2*/,
    9 /*9bc3*/,  8 /*9bc4*/,  9 /*9bc5*/,  9 /*9bc6*/,  10 /*9bc7*/,
    8 /*9bc8*/,  9 /*9bc9*/,  9 /*9bca*/,  10 /*9bcb*/, 9 /*9bcc*/,
    10 /*9bcd*/, 10 /*9bce*/, 11 /*9bcf*/, 8 /*9bd0*/,  9 /*9bd1*/,
    9 /*9bd2*/,  10 /*9bd3*/, 9 /*9bd4*/,  10 /*9bd5*/, 10 /*9bd6*/,
    11 /*9bd7*/, 9 /*9bd8*/,  10 /*9bd9*/, 10 /*9bda*/, 11 /*9bdb*/,
    10 /*9bdc*/, 11 /*9bdd*/, 11 /*9bde*/, 12 /*9bdf*/, 8 /*9be0*/,
    9 /*9be1*/,  9 /*9be2*/,  10 /*9be3*/, 9 /*9be4*/,  10 /*9be5*/,
    10 /*9be6*/, 11 /*9be7*/, 9 /*9be8*/,  10 /*9be9*/, 10 /*9bea*/,
    11 /*9beb*/, 10 /*9bec*/, 11 /*9bed*/, 11 /*9bee*/, 12 /*9bef*/,
    9 /*9bf0*/,  10 /*9bf1*/, 10 /*9bf2*/, 11 /*9bf3*/, 10 /*9bf4*/,
    11 /*9bf5*/, 11 /*9bf6*/, 12 /*9bf7*/, 10 /*9bf8*/, 11 /*9bf9*/,
    11 /*9bfa*/, 12 /*9bfb*/, 11 /*9bfc*/, 12 /*9bfd*/, 12 /*9bfe*/,
    13 /*9bff*/, 4 /*9c00*/,  5 /*9c01*/,  5 /*9c02*/,  6 /*9c03*/,
    5 /*9c04*/,  6 /*9c05*/,  6 /*9c06*/,  7 /*9c07*/,  5 /*9c08*/,
    6 /*9c09*/,  6 /*9c0a*/,  7 /*9c0b*/,  6 /*9c0c*/,  7 /*9c0d*/,
    7 /*9c0e*/,  8 /*9c0f*/,  5 /*9c10*/,  6 /*9c11*/,  6 /*9c12*/,
    7 /*9c13*/,  6 /*9c14*/,  7 /*9c15*/,  7 /*9c16*/,  8 /*9c17*/,
    6 /*9c18*/,  7 /*9c19*/,  7 /*9c1a*/,  8 /*9c1b*/,  7 /*9c1c*/,
    8 /*9c1d*/,  8 /*9c1e*/,  9 /*9c1f*/,  5 /*9c20*/,  6 /*9c21*/,
    6 /*9c22*/,  7 /*9c23*/,  6 /*9c24*/,  7 /*9c25*/,  7 /*9c26*/,
    8 /*9c27*/,  6 /*9c28*/,  7 /*9c29*/,  7 /*9c2a*/,  8 /*9c2b*/,
    7 /*9c2c*/,  8 /*9c2d*/,  8 /*9c2e*/,  9 /*9c2f*/,  6 /*9c30*/,
    7 /*9c31*/,  7 /*9c32*/,  8 /*9c33*/,  7 /*9c34*/,  8 /*9c35*/,
    8 /*9c36*/,  9 /*9c37*/,  7 /*9c38*/,  8 /*9c39*/,  8 /*9c3a*/,
    9 /*9c3b*/,  8 /*9c3c*/,  9 /*9c3d*/,  9 /*9c3e*/,  10 /*9c3f*/,
    5 /*9c40*/,  6 /*9c41*/,  6 /*9c42*/,  7 /*9c43*/,  6 /*9c44*/,
    7 /*9c45*/,  7 /*9c46*/,  8 /*9c47*/,  6 /*9c48*/,  7 /*9c49*/,
    7 /*9c4a*/,  8 /*9c4b*/,  7 /*9c4c*/,  8 /*9c4d*/,  8 /*9c4e*/,
    9 /*9c4f*/,  6 /*9c50*/,  7 /*9c51*/,  7 /*9c52*/,  8 /*9c53*/,
    7 /*9c54*/,  8 /*9c55*/,  8 /*9c56*/,  9 /*9c57*/,  7 /*9c58*/,
    8 /*9c59*/,  8 /*9c5a*/,  9 /*9c5b*/,  8 /*9c5c*/,  9 /*9c5d*/,
    9 /*9c5e*/,  10 /*9c5f*/, 6 /*9c60*/,  7 /*9c61*/,  7 /*9c62*/,
    8 /*9c63*/,  7 /*9c64*/,  8 /*9c65*/,  8 /*9c66*/,  9 /*9c67*/,
    7 /*9c68*/,  8 /*9c69*/,  8 /*9c6a*/,  9 /*9c6b*/,  8 /*9c6c*/,
    9 /*9c6d*/,  9 /*9c6e*/,  10 /*9c6f*/, 7 /*9c70*/,  8 /*9c71*/,
    8 /*9c72*/,  9 /*9c73*/,  8 /*9c74*/,  9 /*9c75*/,  9 /*9c76*/,
    10 /*9c77*/, 8 /*9c78*/,  9 /*9c79*/,  9 /*9c7a*/,  10 /*9c7b*/,
    9 /*9c7c*/,  10 /*9c7d*/, 10 /*9c7e*/, 11 /*9c7f*/, 5 /*9c80*/,
    6 /*9c81*/,  6 /*9c82*/,  7 /*9c83*/,  6 /*9c84*/,  7 /*9c85*/,
    7 /*9c86*/,  8 /*9c87*/,  6 /*9c88*/,  7 /*9c89*/,  7 /*9c8a*/,
    8 /*9c8b*/,  7 /*9c8c*/,  8 /*9c8d*/,  8 /*9c8e*/,  9 /*9c8f*/,
    6 /*9c90*/,  7 /*9c91*/,  7 /*9c92*/,  8 /*9c93*/,  7 /*9c94*/,
    8 /*9c95*/,  8 /*9c96*/,  9 /*9c97*/,  7 /*9c98*/,  8 /*9c99*/,
    8 /*9c9a*/,  9 /*9c9b*/,  8 /*9c9c*/,  9 /*9c9d*/,  9 /*9c9e*/,
    10 /*9c9f*/, 6 /*9ca0*/,  7 /*9ca1*/,  7 /*9ca2*/,  8 /*9ca3*/,
    7 /*9ca4*/,  8 /*9ca5*/,  8 /*9ca6*/,  9 /*9ca7*/,  7 /*9ca8*/,
    8 /*9ca9*/,  8 /*9caa*/,  9 /*9cab*/,  8 /*9cac*/,  9 /*9cad*/,
    9 /*9cae*/,  10 /*9caf*/, 7 /*9cb0*/,  8 /*9cb1*/,  8 /*9cb2*/,
    9 /*9cb3*/,  8 /*9cb4*/,  9 /*9cb5*/,  9 /*9cb6*/,  10 /*9cb7*/,
    8 /*9cb8*/,  9 /*9cb9*/,  9 /*9cba*/,  10 /*9cbb*/, 9 /*9cbc*/,
    10 /*9cbd*/, 10 /*9cbe*/, 11 /*9cbf*/, 6 /*9cc0*/,  7 /*9cc1*/,
    7 /*9cc2*/,  8 /*9cc3*/,  7 /*9cc4*/,  8 /*9cc5*/,  8 /*9cc6*/,
    9 /*9cc7*/,  7 /*9cc8*/,  8 /*9cc9*/,  8 /*9cca*/,  9 /*9ccb*/,
    8 /*9ccc*/,  9 /*9ccd*/,  9 /*9cce*/,  10 /*9ccf*/, 7 /*9cd0*/,
    8 /*9cd1*/,  8 /*9cd2*/,  9 /*9cd3*/,  8 /*9cd4*/,  9 /*9cd5*/,
    9 /*9cd6*/,  10 /*9cd7*/, 8 /*9cd8*/,  9 /*9cd9*/,  9 /*9cda*/,
    10 /*9cdb*/, 9 /*9cdc*/,  10 /*9cdd*/, 10 /*9cde*/, 11 /*9cdf*/,
    7 /*9ce0*/,  8 /*9ce1*/,  8 /*9ce2*/,  9 /*9ce3*/,  8 /*9ce4*/,
    9 /*9ce5*/,  9 /*9ce6*/,  10 /*9ce7*/, 8 /*9ce8*/,  9 /*9ce9*/,
    9 /*9cea*/,  10 /*9ceb*/, 9 /*9cec*/,  10 /*9ced*/, 10 /*9cee*/,
    11 /*9cef*/, 8 /*9cf0*/,  9 /*9cf1*/,  9 /*9cf2*/,  10 /*9cf3*/,
    9 /*9cf4*/,  10 /*9cf5*/, 10 /*9cf6*/, 11 /*9cf7*/, 9 /*9cf8*/,
    10 /*9cf9*/, 10 /*9cfa*/, 11 /*9cfb*/, 10 /*9cfc*/, 11 /*9cfd*/,
    11 /*9cfe*/, 12 /*9cff*/, 5 /*9d00*/,  6 /*9d01*/,  6 /*9d02*/,
    7 /*9d03*/,  6 /*9d04*/,  7 /*9d05*/,  7 /*9d06*/,  8 /*9d07*/,
    6 /*9d08*/,  7 /*9d09*/,  7 /*9d0a*/,  8 /*9d0b*/,  7 /*9d0c*/,
    8 /*9d0d*/,  8 /*9d0e*/,  9 /*9d0f*/,  6 /*9d10*/,  7 /*9d11*/,
    7 /*9d12*/,  8 /*9d13*/,  7 /*9d14*/,  8 /*9d15*/,  8 /*9d16*/,
    9 /*9d17*/,  7 /*9d18*/,  8 /*9d19*/,  8 /*9d1a*/,  9 /*9d1b*/,
    8 /*9d1c*/,  9 /*9d1d*/,  9 /*9d1e*/,  10 /*9d1f*/, 6 /*9d20*/,
    7 /*9d21*/,  7 /*9d22*/,  8 /*9d23*/,  7 /*9d24*/,  8 /*9d25*/,
    8 /*9d26*/,  9 /*9d27*/,  7 /*9d28*/,  8 /*9d29*/,  8 /*9d2a*/,
    9 /*9d2b*/,  8 /*9d2c*/,  9 /*9d2d*/,  9 /*9d2e*/,  10 /*9d2f*/,
    7 /*9d30*/,  8 /*9d31*/,  8 /*9d32*/,  9 /*9d33*/,  8 /*9d34*/,
    9 /*9d35*/,  9 /*9d36*/,  10 /*9d37*/, 8 /*9d38*/,  9 /*9d39*/,
    9 /*9d3a*/,  10 /*9d3b*/, 9 /*9d3c*/,  10 /*9d3d*/, 10 /*9d3e*/,
    11 /*9d3f*/, 6 /*9d40*/,  7 /*9d41*/,  7 /*9d42*/,  8 /*9d43*/,
    7 /*9d44*/,  8 /*9d45*/,  8 /*9d46*/,  9 /*9d47*/,  7 /*9d48*/,
    8 /*9d49*/,  8 /*9d4a*/,  9 /*9d4b*/,  8 /*9d4c*/,  9 /*9d4d*/,
    9 /*9d4e*/,  10 /*9d4f*/, 7 /*9d50*/,  8 /*9d51*/,  8 /*9d52*/,
    9 /*9d53*/,  8 /*9d54*/,  9 /*9d55*/,  9 /*9d56*/,  10 /*9d57*/,
    8 /*9d58*/,  9 /*9d59*/,  9 /*9d5a*/,  10 /*9d5b*/, 9 /*9d5c*/,
    10 /*9d5d*/, 10 /*9d5e*/, 11 /*9d5f*/, 7 /*9d60*/,  8 /*9d61*/,
    8 /*9d62*/,  9 /*9d63*/,  8 /*9d64*/,  9 /*9d65*/,  9 /*9d66*/,
    10 /*9d67*/, 8 /*9d68*/,  9 /*9d69*/,  9 /*9d6a*/,  10 /*9d6b*/,
    9 /*9d6c*/,  10 /*9d6d*/, 10 /*9d6e*/, 11 /*9d6f*/, 8 /*9d70*/,
    9 /*9d71*/,  9 /*9d72*/,  10 /*9d73*/, 9 /*9d74*/,  10 /*9d75*/,
    10 /*9d76*/, 11 /*9d77*/, 9 /*9d78*/,  10 /*9d79*/, 10 /*9d7a*/,
    11 /*9d7b*/, 10 /*9d7c*/, 11 /*9d7d*/, 11 /*9d7e*/, 12 /*9d7f*/,
    6 /*9d80*/,  7 /*9d81*/,  7 /*9d82*/,  8 /*9d83*/,  7 /*9d84*/,
    8 /*9d85*/,  8 /*9d86*/,  9 /*9d87*/,  7 /*9d88*/,  8 /*9d89*/,
    8 /*9d8a*/,  9 /*9d8b*/,  8 /*9d8c*/,  9 /*9d8d*/,  9 /*9d8e*/,
    10 /*9d8f*/, 7 /*9d90*/,  8 /*9d91*/,  8 /*9d92*/,  9 /*9d93*/,
    8 /*9d94*/,  9 /*9d95*/,  9 /*9d96*/,  10 /*9d97*/, 8 /*9d98*/,
    9 /*9d99*/,  9 /*9d9a*/,  10 /*9d9b*/, 9 /*9d9c*/,  10 /*9d9d*/,
    10 /*9d9e*/, 11 /*9d9f*/, 7 /*9da0*/,  8 /*9da1*/,  8 /*9da2*/,
    9 /*9da3*/,  8 /*9da4*/,  9 /*9da5*/,  9 /*9da6*/,  10 /*9da7*/,
    8 /*9da8*/,  9 /*9da9*/,  9 /*9daa*/,  10 /*9dab*/, 9 /*9dac*/,
    10 /*9dad*/, 10 /*9dae*/, 11 /*9daf*/, 8 /*9db0*/,  9 /*9db1*/,
    9 /*9db2*/,  10 /*9db3*/, 9 /*9db4*/,  10 /*9db5*/, 10 /*9db6*/,
    11 /*9db7*/, 9 /*9db8*/,  10 /*9db9*/, 10 /*9dba*/, 11 /*9dbb*/,
    10 /*9dbc*/, 11 /*9dbd*/, 11 /*9dbe*/, 12 /*9dbf*/, 7 /*9dc0*/,
    8 /*9dc1*/,  8 /*9dc2*/,  9 /*9dc3*/,  8 /*9dc4*/,  9 /*9dc5*/,
    9 /*9dc6*/,  10 /*9dc7*/, 8 /*9dc8*/,  9 /*9dc9*/,  9 /*9dca*/,
    10 /*9dcb*/, 9 /*9dcc*/,  10 /*9dcd*/, 10 /*9dce*/, 11 /*9dcf*/,
    8 /*9dd0*/,  9 /*9dd1*/,  9 /*9dd2*/,  10 /*9dd3*/, 9 /*9dd4*/,
    10 /*9dd5*/, 10 /*9dd6*/, 11 /*9dd7*/, 9 /*9dd8*/,  10 /*9dd9*/,
    10 /*9dda*/, 11 /*9ddb*/, 10 /*9ddc*/, 11 /*9ddd*/, 11 /*9dde*/,
    12 /*9ddf*/, 8 /*9de0*/,  9 /*9de1*/,  9 /*9de2*/,  10 /*9de3*/,
    9 /*9de4*/,  10 /*9de5*/, 10 /*9de6*/, 11 /*9de7*/, 9 /*9de8*/,
    10 /*9de9*/, 10 /*9dea*/, 11 /*9deb*/, 10 /*9dec*/, 11 /*9ded*/,
    11 /*9dee*/, 12 /*9def*/, 9 /*9df0*/,  10 /*9df1*/, 10 /*9df2*/,
    11 /*9df3*/, 10 /*9df4*/, 11 /*9df5*/, 11 /*9df6*/, 12 /*9df7*/,
    10 /*9df8*/, 11 /*9df9*/, 11 /*9dfa*/, 12 /*9dfb*/, 11 /*9dfc*/,
    12 /*9dfd*/, 12 /*9dfe*/, 13 /*9dff*/, 5 /*9e00*/,  6 /*9e01*/,
    6 /*9e02*/,  7 /*9e03*/,  6 /*9e04*/,  7 /*9e05*/,  7 /*9e06*/,
    8 /*9e07*/,  6 /*9e08*/,  7 /*9e09*/,  7 /*9e0a*/,  8 /*9e0b*/,
    7 /*9e0c*/,  8 /*9e0d*/,  8 /*9e0e*/,  9 /*9e0f*/,  6 /*9e10*/,
    7 /*9e11*/,  7 /*9e12*/,  8 /*9e13*/,  7 /*9e14*/,  8 /*9e15*/,
    8 /*9e16*/,  9 /*9e17*/,  7 /*9e18*/,  8 /*9e19*/,  8 /*9e1a*/,
    9 /*9e1b*/,  8 /*9e1c*/,  9 /*9e1d*/,  9 /*9e1e*/,  10 /*9e1f*/,
    6 /*9e20*/,  7 /*9e21*/,  7 /*9e22*/,  8 /*9e23*/,  7 /*9e24*/,
    8 /*9e25*/,  8 /*9e26*/,  9 /*9e27*/,  7 /*9e28*/,  8 /*9e29*/,
    8 /*9e2a*/,  9 /*9e2b*/,  8 /*9e2c*/,  9 /*9e2d*/,  9 /*9e2e*/,
    10 /*9e2f*/, 7 /*9e30*/,  8 /*9e31*/,  8 /*9e32*/,  9 /*9e33*/,
    8 /*9e34*/,  9 /*9e35*/,  9 /*9e36*/,  10 /*9e37*/, 8 /*9e38*/,
    9 /*9e39*/,  9 /*9e3a*/,  10 /*9e3b*/, 9 /*9e3c*/,  10 /*9e3d*/,
    10 /*9e3e*/, 11 /*9e3f*/, 6 /*9e40*/,  7 /*9e41*/,  7 /*9e42*/,
    8 /*9e43*/,  7 /*9e44*/,  8 /*9e45*/,  8 /*9e46*/,  9 /*9e47*/,
    7 /*9e48*/,  8 /*9e49*/,  8 /*9e4a*/,  9 /*9e4b*/,  8 /*9e4c*/,
    9 /*9e4d*/,  9 /*9e4e*/,  10 /*9e4f*/, 7 /*9e50*/,  8 /*9e51*/,
    8 /*9e52*/,  9 /*9e53*/,  8 /*9e54*/,  9 /*9e55*/,  9 /*9e56*/,
    10 /*9e57*/, 8 /*9e58*/,  9 /*9e59*/,  9 /*9e5a*/,  10 /*9e5b*/,
    9 /*9e5c*/,  10 /*9e5d*/, 10 /*9e5e*/, 11 /*9e5f*/, 7 /*9e60*/,
    8 /*9e61*/,  8 /*9e62*/,  9 /*9e63*/,  8 /*9e64*/,  9 /*9e65*/,
    9 /*9e66*/,  10 /*9e67*/, 8 /*9e68*/,  9 /*9e69*/,  9 /*9e6a*/,
    10 /*9e6b*/, 9 /*9e6c*/,  10 /*9e6d*/, 10 /*9e6e*/, 11 /*9e6f*/,
    8 /*9e70*/,  9 /*9e71*/,  9 /*9e72*/,  10 /*9e73*/, 9 /*9e74*/,
    10 /*9e75*/, 10 /*9e76*/, 11 /*9e77*/, 9 /*9e78*/,  10 /*9e79*/,
    10 /*9e7a*/, 11 /*9e7b*/, 10 /*9e7c*/, 11 /*9e7d*/, 11 /*9e7e*/,
    12 /*9e7f*/, 6 /*9e80*/,  7 /*9e81*/,  7 /*9e82*/,  8 /*9e83*/,
    7 /*9e84*/,  8 /*9e85*/,  8 /*9e86*/,  9 /*9e87*/,  7 /*9e88*/,
    8 /*9e89*/,  8 /*9e8a*/,  9 /*9e8b*/,  8 /*9e8c*/,  9 /*9e8d*/,
    9 /*9e8e*/,  10 /*9e8f*/, 7 /*9e90*/,  8 /*9e91*/,  8 /*9e92*/,
    9 /*9e93*/,  8 /*9e94*/,  9 /*9e95*/,  9 /*9e96*/,  10 /*9e97*/,
    8 /*9e98*/,  9 /*9e99*/,  9 /*9e9a*/,  10 /*9e9b*/, 9 /*9e9c*/,
    10 /*9e9d*/, 10 /*9e9e*/, 11 /*9e9f*/, 7 /*9ea0*/,  8 /*9ea1*/,
    8 /*9ea2*/,  9 /*9ea3*/,  8 /*9ea4*/,  9 /*9ea5*/,  9 /*9ea6*/,
    10 /*9ea7*/, 8 /*9ea8*/,  9 /*9ea9*/,  9 /*9eaa*/,  10 /*9eab*/,
    9 /*9eac*/,  10 /*9ead*/, 10 /*9eae*/, 11 /*9eaf*/, 8 /*9eb0*/,
    9 /*9eb1*/,  9 /*9eb2*/,  10 /*9eb3*/, 9 /*9eb4*/,  10 /*9eb5*/,
    10 /*9eb6*/, 11 /*9eb7*/, 9 /*9eb8*/,  10 /*9eb9*/, 10 /*9eba*/,
    11 /*9ebb*/, 10 /*9ebc*/, 11 /*9ebd*/, 11 /*9ebe*/, 12 /*9ebf*/,
    7 /*9ec0*/,  8 /*9ec1*/,  8 /*9ec2*/,  9 /*9ec3*/,  8 /*9ec4*/,
    9 /*9ec5*/,  9 /*9ec6*/,  10 /*9ec7*/, 8 /*9ec8*/,  9 /*9ec9*/,
    9 /*9eca*/,  10 /*9ecb*/, 9 /*9ecc*/,  10 /*9ecd*/, 10 /*9ece*/,
    11 /*9ecf*/, 8 /*9ed0*/,  9 /*9ed1*/,  9 /*9ed2*/,  10 /*9ed3*/,
    9 /*9ed4*/,  10 /*9ed5*/, 10 /*9ed6*/, 11 /*9ed7*/, 9 /*9ed8*/,
    10 /*9ed9*/, 10 /*9eda*/, 11 /*9edb*/, 10 /*9edc*/, 11 /*9edd*/,
    11 /*9ede*/, 12 /*9edf*/, 8 /*9ee0*/,  9 /*9ee1*/,  9 /*9ee2*/,
    10 /*9ee3*/, 9 /*9ee4*/,  10 /*9ee5*/, 10 /*9ee6*/, 11 /*9ee7*/,
    9 /*9ee8*/,  10 /*9ee9*/, 10 /*9eea*/, 11 /*9eeb*/, 10 /*9eec*/,
    11 /*9eed*/, 11 /*9eee*/, 12 /*9eef*/, 9 /*9ef0*/,  10 /*9ef1*/,
    10 /*9ef2*/, 11 /*9ef3*/, 10 /*9ef4*/, 11 /*9ef5*/, 11 /*9ef6*/,
    12 /*9ef7*/, 10 /*9ef8*/, 11 /*9ef9*/, 11 /*9efa*/, 12 /*9efb*/,
    11 /*9efc*/, 12 /*9efd*/, 12 /*9efe*/, 13 /*9eff*/, 6 /*9f00*/,
    7 /*9f01*/,  7 /*9f02*/,  8 /*9f03*/,  7 /*9f04*/,  8 /*9f05*/,
    8 /*9f06*/,  9 /*9f07*/,  7 /*9f08*/,  8 /*9f09*/,  8 /*9f0a*/,
    9 /*9f0b*/,  8 /*9f0c*/,  9 /*9f0d*/,  9 /*9f0e*/,  10 /*9f0f*/,
    7 /*9f10*/,  8 /*9f11*/,  8 /*9f12*/,  9 /*9f13*/,  8 /*9f14*/,
    9 /*9f15*/,  9 /*9f16*/,  10 /*9f17*/, 8 /*9f18*/,  9 /*9f19*/,
    9 /*9f1a*/,  10 /*9f1b*/, 9 /*9f1c*/,  10 /*9f1d*/, 10 /*9f1e*/,
    11 /*9f1f*/, 7 /*9f20*/,  8 /*9f21*/,  8 /*9f22*/,  9 /*9f23*/,
    8 /*9f24*/,  9 /*9f25*/,  9 /*9f26*/,  10 /*9f27*/, 8 /*9f28*/,
    9 /*9f29*/,  9 /*9f2a*/,  10 /*9f2b*/, 9 /*9f2c*/,  10 /*9f2d*/,
    10 /*9f2e*/, 11 /*9f2f*/, 8 /*9f30*/,  9 /*9f31*/,  9 /*9f32*/,
    10 /*9f33*/, 9 /*9f34*/,  10 /*9f35*/, 10 /*9f36*/, 11 /*9f37*/,
    9 /*9f38*/,  10 /*9f39*/, 10 /*9f3a*/, 11 /*9f3b*/, 10 /*9f3c*/,
    11 /*9f3d*/, 11 /*9f3e*/, 12 /*9f3f*/, 7 /*9f40*/,  8 /*9f41*/,
    8 /*9f42*/,  9 /*9f43*/,  8 /*9f44*/,  9 /*9f45*/,  9 /*9f46*/,
    10 /*9f47*/, 8 /*9f48*/,  9 /*9f49*/,  9 /*9f4a*/,  10 /*9f4b*/,
    9 /*9f4c*/,  10 /*9f4d*/, 10 /*9f4e*/, 11 /*9f4f*/, 8 /*9f50*/,
    9 /*9f51*/,  9 /*9f52*/,  10 /*9f53*/, 9 /*9f54*/,  10 /*9f55*/,
    10 /*9f56*/, 11 /*9f57*/, 9 /*9f58*/,  10 /*9f59*/, 10 /*9f5a*/,
    11 /*9f5b*/, 10 /*9f5c*/, 11 /*9f5d*/, 11 /*9f5e*/, 12 /*9f5f*/,
    8 /*9f60*/,  9 /*9f61*/,  9 /*9f62*/,  10 /*9f63*/, 9 /*9f64*/,
    10 /*9f65*/, 10 /*9f66*/, 11 /*9f67*/, 9 /*9f68*/,  10 /*9f69*/,
    10 /*9f6a*/, 11 /*9f6b*/, 10 /*9f6c*/, 11 /*9f6d*/, 11 /*9f6e*/,
    12 /*9f6f*/, 9 /*9f70*/,  10 /*9f71*/, 10 /*9f72*/, 11 /*9f73*/,
    10 /*9f74*/, 11 /*9f75*/, 11 /*9f76*/, 12 /*9f77*/, 10 /*9f78*/,
    11 /*9f79*/, 11 /*9f7a*/, 12 /*9f7b*/, 11 /*9f7c*/, 12 /*9f7d*/,
    12 /*9f7e*/, 13 /*9f7f*/, 7 /*9f80*/,  8 /*9f81*/,  8 /*9f82*/,
    9 /*9f83*/,  8 /*9f84*/,  9 /*9f85*/,  9 /*9f86*/,  10 /*9f87*/,
    8 /*9f88*/,  9 /*9f89*/,  9 /*9f8a*/,  10 /*9f8b*/, 9 /*9f8c*/,
    10 /*9f8d*/, 10 /*9f8e*/, 11 /*9f8f*/, 8 /*9f90*/,  9 /*9f91*/,
    9 /*9f92*/,  10 /*9f93*/, 9 /*9f94*/,  10 /*9f95*/, 10 /*9f96*/,
    11 /*9f97*/, 9 /*9f98*/,  10 /*9f99*/, 10 /*9f9a*/, 11 /*9f9b*/,
    10 /*9f9c*/, 11 /*9f9d*/, 11 /*9f9e*/, 12 /*9f9f*/, 8 /*9fa0*/,
    9 /*9fa1*/,  9 /*9fa2*/,  10 /*9fa3*/, 9 /*9fa4*/,  10 /*9fa5*/,
    10 /*9fa6*/, 11 /*9fa7*/, 9 /*9fa8*/,  10 /*9fa9*/, 10 /*9faa*/,
    11 /*9fab*/, 10 /*9fac*/, 11 /*9fad*/, 11 /*9fae*/, 12 /*9faf*/,
    9 /*9fb0*/,  10 /*9fb1*/, 10 /*9fb2*/, 11 /*9fb3*/, 10 /*9fb4*/,
    11 /*9fb5*/, 11 /*9fb6*/, 12 /*9fb7*/, 10 /*9fb8*/, 11 /*9fb9*/,
    11 /*9fba*/, 12 /*9fbb*/, 11 /*9fbc*/, 12 /*9fbd*/, 12 /*9fbe*/,
    13 /*9fbf*/, 8 /*9fc0*/,  9 /*9fc1*/,  9 /*9fc2*/,  10 /*9fc3*/,
    9 /*9fc4*/,  10 /*9fc5*/, 10 /*9fc6*/, 11 /*9fc7*/, 9 /*9fc8*/,
    10 /*9fc9*/, 10 /*9fca*/, 11 /*9fcb*/, 10 /*9fcc*/, 11 /*9fcd*/,
    11 /*9fce*/, 12 /*9fcf*/, 9 /*9fd0*/,  10 /*9fd1*/, 10 /*9fd2*/,
    11 /*9fd3*/, 10 /*9fd4*/, 11 /*9fd5*/, 11 /*9fd6*/, 12 /*9fd7*/,
    10 /*9fd8*/, 11 /*9fd9*/, 11 /*9fda*/, 12 /*9fdb*/, 11 /*9fdc*/,
    12 /*9fdd*/, 12 /*9fde*/, 13 /*9fdf*/, 9 /*9fe0*/,  10 /*9fe1*/,
    10 /*9fe2*/, 11 /*9fe3*/, 10 /*9fe4*/, 11 /*9fe5*/, 11 /*9fe6*/,
    12 /*9fe7*/, 10 /*9fe8*/, 11 /*9fe9*/, 11 /*9fea*/, 12 /*9feb*/,
    11 /*9fec*/, 12 /*9fed*/, 12 /*9fee*/, 13 /*9fef*/, 10 /*9ff0*/,
    11 /*9ff1*/, 11 /*9ff2*/, 12 /*9ff3*/, 11 /*9ff4*/, 12 /*9ff5*/,
    12 /*9ff6*/, 13 /*9ff7*/, 11 /*9ff8*/, 12 /*9ff9*/, 12 /*9ffa*/,
    13 /*9ffb*/, 12 /*9ffc*/, 13 /*9ffd*/, 13 /*9ffe*/, 14 /*9fff*/,
    2 /*a000*/,  3 /*a001*/,  3 /*a002*/,  4 /*a003*/,  3 /*a004*/,
    4 /*a005*/,  4 /*a006*/,  5 /*a007*/,  3 /*a008*/,  4 /*a009*/,
    4 /*a00a*/,  5 /*a00b*/,  4 /*a00c*/,  5 /*a00d*/,  5 /*a00e*/,
    6 /*a00f*/,  3 /*a010*/,  4 /*a011*/,  4 /*a012*/,  5 /*a013*/,
    4 /*a014*/,  5 /*a015*/,  5 /*a016*/,  6 /*a017*/,  4 /*a018*/,
    5 /*a019*/,  5 /*a01a*/,  6 /*a01b*/,  5 /*a01c*/,  6 /*a01d*/,
    6 /*a01e*/,  7 /*a01f*/,  3 /*a020*/,  4 /*a021*/,  4 /*a022*/,
    5 /*a023*/,  4 /*a024*/,  5 /*a025*/,  5 /*a026*/,  6 /*a027*/,
    4 /*a028*/,  5 /*a029*/,  5 /*a02a*/,  6 /*a02b*/,  5 /*a02c*/,
    6 /*a02d*/,  6 /*a02e*/,  7 /*a02f*/,  4 /*a030*/,  5 /*a031*/,
    5 /*a032*/,  6 /*a033*/,  5 /*a034*/,  6 /*a035*/,  6 /*a036*/,
    7 /*a037*/,  5 /*a038*/,  6 /*a039*/,  6 /*a03a*/,  7 /*a03b*/,
    6 /*a03c*/,  7 /*a03d*/,  7 /*a03e*/,  8 /*a03f*/,  3 /*a040*/,
    4 /*a041*/,  4 /*a042*/,  5 /*a043*/,  4 /*a044*/,  5 /*a045*/,
    5 /*a046*/,  6 /*a047*/,  4 /*a048*/,  5 /*a049*/,  5 /*a04a*/,
    6 /*a04b*/,  5 /*a04c*/,  6 /*a04d*/,  6 /*a04e*/,  7 /*a04f*/,
    4 /*a050*/,  5 /*a051*/,  5 /*a052*/,  6 /*a053*/,  5 /*a054*/,
    6 /*a055*/,  6 /*a056*/,  7 /*a057*/,  5 /*a058*/,  6 /*a059*/,
    6 /*a05a*/,  7 /*a05b*/,  6 /*a05c*/,  7 /*a05d*/,  7 /*a05e*/,
    8 /*a05f*/,  4 /*a060*/,  5 /*a061*/,  5 /*a062*/,  6 /*a063*/,
    5 /*a064*/,  6 /*a065*/,  6 /*a066*/,  7 /*a067*/,  5 /*a068*/,
    6 /*a069*/,  6 /*a06a*/,  7 /*a06b*/,  6 /*a06c*/,  7 /*a06d*/,
    7 /*a06e*/,  8 /*a06f*/,  5 /*a070*/,  6 /*a071*/,  6 /*a072*/,
    7 /*a073*/,  6 /*a074*/,  7 /*a075*/,  7 /*a076*/,  8 /*a077*/,
    6 /*a078*/,  7 /*a079*/,  7 /*a07a*/,  8 /*a07b*/,  7 /*a07c*/,
    8 /*a07d*/,  8 /*a07e*/,  9 /*a07f*/,  3 /*a080*/,  4 /*a081*/,
    4 /*a082*/,  5 /*a083*/,  4 /*a084*/,  5 /*a085*/,  5 /*a086*/,
    6 /*a087*/,  4 /*a088*/,  5 /*a089*/,  5 /*a08a*/,  6 /*a08b*/,
    5 /*a08c*/,  6 /*a08d*/,  6 /*a08e*/,  7 /*a08f*/,  4 /*a090*/,
    5 /*a091*/,  5 /*a092*/,  6 /*a093*/,  5 /*a094*/,  6 /*a095*/,
    6 /*a096*/,  7 /*a097*/,  5 /*a098*/,  6 /*a099*/,  6 /*a09a*/,
    7 /*a09b*/,  6 /*a09c*/,  7 /*a09d*/,  7 /*a09e*/,  8 /*a09f*/,
    4 /*a0a0*/,  5 /*a0a1*/,  5 /*a0a2*/,  6 /*a0a3*/,  5 /*a0a4*/,
    6 /*a0a5*/,  6 /*a0a6*/,  7 /*a0a7*/,  5 /*a0a8*/,  6 /*a0a9*/,
    6 /*a0aa*/,  7 /*a0ab*/,  6 /*a0ac*/,  7 /*a0ad*/,  7 /*a0ae*/,
    8 /*a0af*/,  5 /*a0b0*/,  6 /*a0b1*/,  6 /*a0b2*/,  7 /*a0b3*/,
    6 /*a0b4*/,  7 /*a0b5*/,  7 /*a0b6*/,  8 /*a0b7*/,  6 /*a0b8*/,
    7 /*a0b9*/,  7 /*a0ba*/,  8 /*a0bb*/,  7 /*a0bc*/,  8 /*a0bd*/,
    8 /*a0be*/,  9 /*a0bf*/,  4 /*a0c0*/,  5 /*a0c1*/,  5 /*a0c2*/,
    6 /*a0c3*/,  5 /*a0c4*/,  6 /*a0c5*/,  6 /*a0c6*/,  7 /*a0c7*/,
    5 /*a0c8*/,  6 /*a0c9*/,  6 /*a0ca*/,  7 /*a0cb*/,  6 /*a0cc*/,
    7 /*a0cd*/,  7 /*a0ce*/,  8 /*a0cf*/,  5 /*a0d0*/,  6 /*a0d1*/,
    6 /*a0d2*/,  7 /*a0d3*/,  6 /*a0d4*/,  7 /*a0d5*/,  7 /*a0d6*/,
    8 /*a0d7*/,  6 /*a0d8*/,  7 /*a0d9*/,  7 /*a0da*/,  8 /*a0db*/,
    7 /*a0dc*/,  8 /*a0dd*/,  8 /*a0de*/,  9 /*a0df*/,  5 /*a0e0*/,
    6 /*a0e1*/,  6 /*a0e2*/,  7 /*a0e3*/,  6 /*a0e4*/,  7 /*a0e5*/,
    7 /*a0e6*/,  8 /*a0e7*/,  6 /*a0e8*/,  7 /*a0e9*/,  7 /*a0ea*/,
    8 /*a0eb*/,  7 /*a0ec*/,  8 /*a0ed*/,  8 /*a0ee*/,  9 /*a0ef*/,
    6 /*a0f0*/,  7 /*a0f1*/,  7 /*a0f2*/,  8 /*a0f3*/,  7 /*a0f4*/,
    8 /*a0f5*/,  8 /*a0f6*/,  9 /*a0f7*/,  7 /*a0f8*/,  8 /*a0f9*/,
    8 /*a0fa*/,  9 /*a0fb*/,  8 /*a0fc*/,  9 /*a0fd*/,  9 /*a0fe*/,
    10 /*a0ff*/, 3 /*a100*/,  4 /*a101*/,  4 /*a102*/,  5 /*a103*/,
    4 /*a104*/,  5 /*a105*/,  5 /*a106*/,  6 /*a107*/,  4 /*a108*/,
    5 /*a109*/,  5 /*a10a*/,  6 /*a10b*/,  5 /*a10c*/,  6 /*a10d*/,
    6 /*a10e*/,  7 /*a10f*/,  4 /*a110*/,  5 /*a111*/,  5 /*a112*/,
    6 /*a113*/,  5 /*a114*/,  6 /*a115*/,  6 /*a116*/,  7 /*a117*/,
    5 /*a118*/,  6 /*a119*/,  6 /*a11a*/,  7 /*a11b*/,  6 /*a11c*/,
    7 /*a11d*/,  7 /*a11e*/,  8 /*a11f*/,  4 /*a120*/,  5 /*a121*/,
    5 /*a122*/,  6 /*a123*/,  5 /*a124*/,  6 /*a125*/,  6 /*a126*/,
    7 /*a127*/,  5 /*a128*/,  6 /*a129*/,  6 /*a12a*/,  7 /*a12b*/,
    6 /*a12c*/,  7 /*a12d*/,  7 /*a12e*/,  8 /*a12f*/,  5 /*a130*/,
    6 /*a131*/,  6 /*a132*/,  7 /*a133*/,  6 /*a134*/,  7 /*a135*/,
    7 /*a136*/,  8 /*a137*/,  6 /*a138*/,  7 /*a139*/,  7 /*a13a*/,
    8 /*a13b*/,  7 /*a13c*/,  8 /*a13d*/,  8 /*a13e*/,  9 /*a13f*/,
    4 /*a140*/,  5 /*a141*/,  5 /*a142*/,  6 /*a143*/,  5 /*a144*/,
    6 /*a145*/,  6 /*a146*/,  7 /*a147*/,  5 /*a148*/,  6 /*a149*/,
    6 /*a14a*/,  7 /*a14b*/,  6 /*a14c*/,  7 /*a14d*/,  7 /*a14e*/,
    8 /*a14f*/,  5 /*a150*/,  6 /*a151*/,  6 /*a152*/,  7 /*a153*/,
    6 /*a154*/,  7 /*a155*/,  7 /*a156*/,  8 /*a157*/,  6 /*a158*/,
    7 /*a159*/,  7 /*a15a*/,  8 /*a15b*/,  7 /*a15c*/,  8 /*a15d*/,
    8 /*a15e*/,  9 /*a15f*/,  5 /*a160*/,  6 /*a161*/,  6 /*a162*/,
    7 /*a163*/,  6 /*a164*/,  7 /*a165*/,  7 /*a166*/,  8 /*a167*/,
    6 /*a168*/,  7 /*a169*/,  7 /*a16a*/,  8 /*a16b*/,  7 /*a16c*/,
    8 /*a16d*/,  8 /*a16e*/,  9 /*a16f*/,  6 /*a170*/,  7 /*a171*/,
    7 /*a172*/,  8 /*a173*/,  7 /*a174*/,  8 /*a175*/,  8 /*a176*/,
    9 /*a177*/,  7 /*a178*/,  8 /*a179*/,  8 /*a17a*/,  9 /*a17b*/,
    8 /*a17c*/,  9 /*a17d*/,  9 /*a17e*/,  10 /*a17f*/, 4 /*a180*/,
    5 /*a181*/,  5 /*a182*/,  6 /*a183*/,  5 /*a184*/,  6 /*a185*/,
    6 /*a186*/,  7 /*a187*/,  5 /*a188*/,  6 /*a189*/,  6 /*a18a*/,
    7 /*a18b*/,  6 /*a18c*/,  7 /*a18d*/,  7 /*a18e*/,  8 /*a18f*/,
    5 /*a190*/,  6 /*a191*/,  6 /*a192*/,  7 /*a193*/,  6 /*a194*/,
    7 /*a195*/,  7 /*a196*/,  8 /*a197*/,  6 /*a198*/,  7 /*a199*/,
    7 /*a19a*/,  8 /*a19b*/,  7 /*a19c*/,  8 /*a19d*/,  8 /*a19e*/,
    9 /*a19f*/,  5 /*a1a0*/,  6 /*a1a1*/,  6 /*a1a2*/,  7 /*a1a3*/,
    6 /*a1a4*/,  7 /*a1a5*/,  7 /*a1a6*/,  8 /*a1a7*/,  6 /*a1a8*/,
    7 /*a1a9*/,  7 /*a1aa*/,  8 /*a1ab*/,  7 /*a1ac*/,  8 /*a1ad*/,
    8 /*a1ae*/,  9 /*a1af*/,  6 /*a1b0*/,  7 /*a1b1*/,  7 /*a1b2*/,
    8 /*a1b3*/,  7 /*a1b4*/,  8 /*a1b5*/,  8 /*a1b6*/,  9 /*a1b7*/,
    7 /*a1b8*/,  8 /*a1b9*/,  8 /*a1ba*/,  9 /*a1bb*/,  8 /*a1bc*/,
    9 /*a1bd*/,  9 /*a1be*/,  10 /*a1bf*/, 5 /*a1c0*/,  6 /*a1c1*/,
    6 /*a1c2*/,  7 /*a1c3*/,  6 /*a1c4*/,  7 /*a1c5*/,  7 /*a1c6*/,
    8 /*a1c7*/,  6 /*a1c8*/,  7 /*a1c9*/,  7 /*a1ca*/,  8 /*a1cb*/,
    7 /*a1cc*/,  8 /*a1cd*/,  8 /*a1ce*/,  9 /*a1cf*/,  6 /*a1d0*/,
    7 /*a1d1*/,  7 /*a1d2*/,  8 /*a1d3*/,  7 /*a1d4*/,  8 /*a1d5*/,
    8 /*a1d6*/,  9 /*a1d7*/,  7 /*a1d8*/,  8 /*a1d9*/,  8 /*a1da*/,
    9 /*a1db*/,  8 /*a1dc*/,  9 /*a1dd*/,  9 /*a1de*/,  10 /*a1df*/,
    6 /*a1e0*/,  7 /*a1e1*/,  7 /*a1e2*/,  8 /*a1e3*/,  7 /*a1e4*/,
    8 /*a1e5*/,  8 /*a1e6*/,  9 /*a1e7*/,  7 /*a1e8*/,  8 /*a1e9*/,
    8 /*a1ea*/,  9 /*a1eb*/,  8 /*a1ec*/,  9 /*a1ed*/,  9 /*a1ee*/,
    10 /*a1ef*/, 7 /*a1f0*/,  8 /*a1f1*/,  8 /*a1f2*/,  9 /*a1f3*/,
    8 /*a1f4*/,  9 /*a1f5*/,  9 /*a1f6*/,  10 /*a1f7*/, 8 /*a1f8*/,
    9 /*a1f9*/,  9 /*a1fa*/,  10 /*a1fb*/, 9 /*a1fc*/,  10 /*a1fd*/,
    10 /*a1fe*/, 11 /*a1ff*/, 3 /*a200*/,  4 /*a201*/,  4 /*a202*/,
    5 /*a203*/,  4 /*a204*/,  5 /*a205*/,  5 /*a206*/,  6 /*a207*/,
    4 /*a208*/,  5 /*a209*/,  5 /*a20a*/,  6 /*a20b*/,  5 /*a20c*/,
    6 /*a20d*/,  6 /*a20e*/,  7 /*a20f*/,  4 /*a210*/,  5 /*a211*/,
    5 /*a212*/,  6 /*a213*/,  5 /*a214*/,  6 /*a215*/,  6 /*a216*/,
    7 /*a217*/,  5 /*a218*/,  6 /*a219*/,  6 /*a21a*/,  7 /*a21b*/,
    6 /*a21c*/,  7 /*a21d*/,  7 /*a21e*/,  8 /*a21f*/,  4 /*a220*/,
    5 /*a221*/,  5 /*a222*/,  6 /*a223*/,  5 /*a224*/,  6 /*a225*/,
    6 /*a226*/,  7 /*a227*/,  5 /*a228*/,  6 /*a229*/,  6 /*a22a*/,
    7 /*a22b*/,  6 /*a22c*/,  7 /*a22d*/,  7 /*a22e*/,  8 /*a22f*/,
    5 /*a230*/,  6 /*a231*/,  6 /*a232*/,  7 /*a233*/,  6 /*a234*/,
    7 /*a235*/,  7 /*a236*/,  8 /*a237*/,  6 /*a238*/,  7 /*a239*/,
    7 /*a23a*/,  8 /*a23b*/,  7 /*a23c*/,  8 /*a23d*/,  8 /*a23e*/,
    9 /*a23f*/,  4 /*a240*/,  5 /*a241*/,  5 /*a242*/,  6 /*a243*/,
    5 /*a244*/,  6 /*a245*/,  6 /*a246*/,  7 /*a247*/,  5 /*a248*/,
    6 /*a249*/,  6 /*a24a*/,  7 /*a24b*/,  6 /*a24c*/,  7 /*a24d*/,
    7 /*a24e*/,  8 /*a24f*/,  5 /*a250*/,  6 /*a251*/,  6 /*a252*/,
    7 /*a253*/,  6 /*a254*/,  7 /*a255*/,  7 /*a256*/,  8 /*a257*/,
    6 /*a258*/,  7 /*a259*/,  7 /*a25a*/,  8 /*a25b*/,  7 /*a25c*/,
    8 /*a25d*/,  8 /*a25e*/,  9 /*a25f*/,  5 /*a260*/,  6 /*a261*/,
    6 /*a262*/,  7 /*a263*/,  6 /*a264*/,  7 /*a265*/,  7 /*a266*/,
    8 /*a267*/,  6 /*a268*/,  7 /*a269*/,  7 /*a26a*/,  8 /*a26b*/,
    7 /*a26c*/,  8 /*a26d*/,  8 /*a26e*/,  9 /*a26f*/,  6 /*a270*/,
    7 /*a271*/,  7 /*a272*/,  8 /*a273*/,  7 /*a274*/,  8 /*a275*/,
    8 /*a276*/,  9 /*a277*/,  7 /*a278*/,  8 /*a279*/,  8 /*a27a*/,
    9 /*a27b*/,  8 /*a27c*/,  9 /*a27d*/,  9 /*a27e*/,  10 /*a27f*/,
    4 /*a280*/,  5 /*a281*/,  5 /*a282*/,  6 /*a283*/,  5 /*a284*/,
    6 /*a285*/,  6 /*a286*/,  7 /*a287*/,  5 /*a288*/,  6 /*a289*/,
    6 /*a28a*/,  7 /*a28b*/,  6 /*a28c*/,  7 /*a28d*/,  7 /*a28e*/,
    8 /*a28f*/,  5 /*a290*/,  6 /*a291*/,  6 /*a292*/,  7 /*a293*/,
    6 /*a294*/,  7 /*a295*/,  7 /*a296*/,  8 /*a297*/,  6 /*a298*/,
    7 /*a299*/,  7 /*a29a*/,  8 /*a29b*/,  7 /*a29c*/,  8 /*a29d*/,
    8 /*a29e*/,  9 /*a29f*/,  5 /*a2a0*/,  6 /*a2a1*/,  6 /*a2a2*/,
    7 /*a2a3*/,  6 /*a2a4*/,  7 /*a2a5*/,  7 /*a2a6*/,  8 /*a2a7*/,
    6 /*a2a8*/,  7 /*a2a9*/,  7 /*a2aa*/,  8 /*a2ab*/,  7 /*a2ac*/,
    8 /*a2ad*/,  8 /*a2ae*/,  9 /*a2af*/,  6 /*a2b0*/,  7 /*a2b1*/,
    7 /*a2b2*/,  8 /*a2b3*/,  7 /*a2b4*/,  8 /*a2b5*/,  8 /*a2b6*/,
    9 /*a2b7*/,  7 /*a2b8*/,  8 /*a2b9*/,  8 /*a2ba*/,  9 /*a2bb*/,
    8 /*a2bc*/,  9 /*a2bd*/,  9 /*a2be*/,  10 /*a2bf*/, 5 /*a2c0*/,
    6 /*a2c1*/,  6 /*a2c2*/,  7 /*a2c3*/,  6 /*a2c4*/,  7 /*a2c5*/,
    7 /*a2c6*/,  8 /*a2c7*/,  6 /*a2c8*/,  7 /*a2c9*/,  7 /*a2ca*/,
    8 /*a2cb*/,  7 /*a2cc*/,  8 /*a2cd*/,  8 /*a2ce*/,  9 /*a2cf*/,
    6 /*a2d0*/,  7 /*a2d1*/,  7 /*a2d2*/,  8 /*a2d3*/,  7 /*a2d4*/,
    8 /*a2d5*/,  8 /*a2d6*/,  9 /*a2d7*/,  7 /*a2d8*/,  8 /*a2d9*/,
    8 /*a2da*/,  9 /*a2db*/,  8 /*a2dc*/,  9 /*a2dd*/,  9 /*a2de*/,
    10 /*a2df*/, 6 /*a2e0*/,  7 /*a2e1*/,  7 /*a2e2*/,  8 /*a2e3*/,
    7 /*a2e4*/,  8 /*a2e5*/,  8 /*a2e6*/,  9 /*a2e7*/,  7 /*a2e8*/,
    8 /*a2e9*/,  8 /*a2ea*/,  9 /*a2eb*/,  8 /*a2ec*/,  9 /*a2ed*/,
    9 /*a2ee*/,  10 /*a2ef*/, 7 /*a2f0*/,  8 /*a2f1*/,  8 /*a2f2*/,
    9 /*a2f3*/,  8 /*a2f4*/,  9 /*a2f5*/,  9 /*a2f6*/,  10 /*a2f7*/,
    8 /*a2f8*/,  9 /*a2f9*/,  9 /*a2fa*/,  10 /*a2fb*/, 9 /*a2fc*/,
    10 /*a2fd*/, 10 /*a2fe*/, 11 /*a2ff*/, 4 /*a300*/,  5 /*a301*/,
    5 /*a302*/,  6 /*a303*/,  5 /*a304*/,  6 /*a305*/,  6 /*a306*/,
    7 /*a307*/,  5 /*a308*/,  6 /*a309*/,  6 /*a30a*/,  7 /*a30b*/,
    6 /*a30c*/,  7 /*a30d*/,  7 /*a30e*/,  8 /*a30f*/,  5 /*a310*/,
    6 /*a311*/,  6 /*a312*/,  7 /*a313*/,  6 /*a314*/,  7 /*a315*/,
    7 /*a316*/,  8 /*a317*/,  6 /*a318*/,  7 /*a319*/,  7 /*a31a*/,
    8 /*a31b*/,  7 /*a31c*/,  8 /*a31d*/,  8 /*a31e*/,  9 /*a31f*/,
    5 /*a320*/,  6 /*a321*/,  6 /*a322*/,  7 /*a323*/,  6 /*a324*/,
    7 /*a325*/,  7 /*a326*/,  8 /*a327*/,  6 /*a328*/,  7 /*a329*/,
    7 /*a32a*/,  8 /*a32b*/,  7 /*a32c*/,  8 /*a32d*/,  8 /*a32e*/,
    9 /*a32f*/,  6 /*a330*/,  7 /*a331*/,  7 /*a332*/,  8 /*a333*/,
    7 /*a334*/,  8 /*a335*/,  8 /*a336*/,  9 /*a337*/,  7 /*a338*/,
    8 /*a339*/,  8 /*a33a*/,  9 /*a33b*/,  8 /*a33c*/,  9 /*a33d*/,
    9 /*a33e*/,  10 /*a33f*/, 5 /*a340*/,  6 /*a341*/,  6 /*a342*/,
    7 /*a343*/,  6 /*a344*/,  7 /*a345*/,  7 /*a346*/,  8 /*a347*/,
    6 /*a348*/,  7 /*a349*/,  7 /*a34a*/,  8 /*a34b*/,  7 /*a34c*/,
    8 /*a34d*/,  8 /*a34e*/,  9 /*a34f*/,  6 /*a350*/,  7 /*a351*/,
    7 /*a352*/,  8 /*a353*/,  7 /*a354*/,  8 /*a355*/,  8 /*a356*/,
    9 /*a357*/,  7 /*a358*/,  8 /*a359*/,  8 /*a35a*/,  9 /*a35b*/,
    8 /*a35c*/,  9 /*a35d*/,  9 /*a35e*/,  10 /*a35f*/, 6 /*a360*/,
    7 /*a361*/,  7 /*a362*/,  8 /*a363*/,  7 /*a364*/,  8 /*a365*/,
    8 /*a366*/,  9 /*a367*/,  7 /*a368*/,  8 /*a369*/,  8 /*a36a*/,
    9 /*a36b*/,  8 /*a36c*/,  9 /*a36d*/,  9 /*a36e*/,  10 /*a36f*/,
    7 /*a370*/,  8 /*a371*/,  8 /*a372*/,  9 /*a373*/,  8 /*a374*/,
    9 /*a375*/,  9 /*a376*/,  10 /*a377*/, 8 /*a378*/,  9 /*a379*/,
    9 /*a37a*/,  10 /*a37b*/, 9 /*a37c*/,  10 /*a37d*/, 10 /*a37e*/,
    11 /*a37f*/, 5 /*a380*/,  6 /*a381*/,  6 /*a382*/,  7 /*a383*/,
    6 /*a384*/,  7 /*a385*/,  7 /*a386*/,  8 /*a387*/,  6 /*a388*/,
    7 /*a389*/,  7 /*a38a*/,  8 /*a38b*/,  7 /*a38c*/,  8 /*a38d*/,
    8 /*a38e*/,  9 /*a38f*/,  6 /*a390*/,  7 /*a391*/,  7 /*a392*/,
    8 /*a393*/,  7 /*a394*/,  8 /*a395*/,  8 /*a396*/,  9 /*a397*/,
    7 /*a398*/,  8 /*a399*/,  8 /*a39a*/,  9 /*a39b*/,  8 /*a39c*/,
    9 /*a39d*/,  9 /*a39e*/,  10 /*a39f*/, 6 /*a3a0*/,  7 /*a3a1*/,
    7 /*a3a2*/,  8 /*a3a3*/,  7 /*a3a4*/,  8 /*a3a5*/,  8 /*a3a6*/,
    9 /*a3a7*/,  7 /*a3a8*/,  8 /*a3a9*/,  8 /*a3aa*/,  9 /*a3ab*/,
    8 /*a3ac*/,  9 /*a3ad*/,  9 /*a3ae*/,  10 /*a3af*/, 7 /*a3b0*/,
    8 /*a3b1*/,  8 /*a3b2*/,  9 /*a3b3*/,  8 /*a3b4*/,  9 /*a3b5*/,
    9 /*a3b6*/,  10 /*a3b7*/, 8 /*a3b8*/,  9 /*a3b9*/,  9 /*a3ba*/,
    10 /*a3bb*/, 9 /*a3bc*/,  10 /*a3bd*/, 10 /*a3be*/, 11 /*a3bf*/,
    6 /*a3c0*/,  7 /*a3c1*/,  7 /*a3c2*/,  8 /*a3c3*/,  7 /*a3c4*/,
    8 /*a3c5*/,  8 /*a3c6*/,  9 /*a3c7*/,  7 /*a3c8*/,  8 /*a3c9*/,
    8 /*a3ca*/,  9 /*a3cb*/,  8 /*a3cc*/,  9 /*a3cd*/,  9 /*a3ce*/,
    10 /*a3cf*/, 7 /*a3d0*/,  8 /*a3d1*/,  8 /*a3d2*/,  9 /*a3d3*/,
    8 /*a3d4*/,  9 /*a3d5*/,  9 /*a3d6*/,  10 /*a3d7*/, 8 /*a3d8*/,
    9 /*a3d9*/,  9 /*a3da*/,  10 /*a3db*/, 9 /*a3dc*/,  10 /*a3dd*/,
    10 /*a3de*/, 11 /*a3df*/, 7 /*a3e0*/,  8 /*a3e1*/,  8 /*a3e2*/,
    9 /*a3e3*/,  8 /*a3e4*/,  9 /*a3e5*/,  9 /*a3e6*/,  10 /*a3e7*/,
    8 /*a3e8*/,  9 /*a3e9*/,  9 /*a3ea*/,  10 /*a3eb*/, 9 /*a3ec*/,
    10 /*a3ed*/, 10 /*a3ee*/, 11 /*a3ef*/, 8 /*a3f0*/,  9 /*a3f1*/,
    9 /*a3f2*/,  10 /*a3f3*/, 9 /*a3f4*/,  10 /*a3f5*/, 10 /*a3f6*/,
    11 /*a3f7*/, 9 /*a3f8*/,  10 /*a3f9*/, 10 /*a3fa*/, 11 /*a3fb*/,
    10 /*a3fc*/, 11 /*a3fd*/, 11 /*a3fe*/, 12 /*a3ff*/, 3 /*a400*/,
    4 /*a401*/,  4 /*a402*/,  5 /*a403*/,  4 /*a404*/,  5 /*a405*/,
    5 /*a406*/,  6 /*a407*/,  4 /*a408*/,  5 /*a409*/,  5 /*a40a*/,
    6 /*a40b*/,  5 /*a40c*/,  6 /*a40d*/,  6 /*a40e*/,  7 /*a40f*/,
    4 /*a410*/,  5 /*a411*/,  5 /*a412*/,  6 /*a413*/,  5 /*a414*/,
    6 /*a415*/,  6 /*a416*/,  7 /*a417*/,  5 /*a418*/,  6 /*a419*/,
    6 /*a41a*/,  7 /*a41b*/,  6 /*a41c*/,  7 /*a41d*/,  7 /*a41e*/,
    8 /*a41f*/,  4 /*a420*/,  5 /*a421*/,  5 /*a422*/,  6 /*a423*/,
    5 /*a424*/,  6 /*a425*/,  6 /*a426*/,  7 /*a427*/,  5 /*a428*/,
    6 /*a429*/,  6 /*a42a*/,  7 /*a42b*/,  6 /*a42c*/,  7 /*a42d*/,
    7 /*a42e*/,  8 /*a42f*/,  5 /*a430*/,  6 /*a431*/,  6 /*a432*/,
    7 /*a433*/,  6 /*a434*/,  7 /*a435*/,  7 /*a436*/,  8 /*a437*/,
    6 /*a438*/,  7 /*a439*/,  7 /*a43a*/,  8 /*a43b*/,  7 /*a43c*/,
    8 /*a43d*/,  8 /*a43e*/,  9 /*a43f*/,  4 /*a440*/,  5 /*a441*/,
    5 /*a442*/,  6 /*a443*/,  5 /*a444*/,  6 /*a445*/,  6 /*a446*/,
    7 /*a447*/,  5 /*a448*/,  6 /*a449*/,  6 /*a44a*/,  7 /*a44b*/,
    6 /*a44c*/,  7 /*a44d*/,  7 /*a44e*/,  8 /*a44f*/,  5 /*a450*/,
    6 /*a451*/,  6 /*a452*/,  7 /*a453*/,  6 /*a454*/,  7 /*a455*/,
    7 /*a456*/,  8 /*a457*/,  6 /*a458*/,  7 /*a459*/,  7 /*a45a*/,
    8 /*a45b*/,  7 /*a45c*/,  8 /*a45d*/,  8 /*a45e*/,  9 /*a45f*/,
    5 /*a460*/,  6 /*a461*/,  6 /*a462*/,  7 /*a463*/,  6 /*a464*/,
    7 /*a465*/,  7 /*a466*/,  8 /*a467*/,  6 /*a468*/,  7 /*a469*/,
    7 /*a46a*/,  8 /*a46b*/,  7 /*a46c*/,  8 /*a46d*/,  8 /*a46e*/,
    9 /*a46f*/,  6 /*a470*/,  7 /*a471*/,  7 /*a472*/,  8 /*a473*/,
    7 /*a474*/,  8 /*a475*/,  8 /*a476*/,  9 /*a477*/,  7 /*a478*/,
    8 /*a479*/,  8 /*a47a*/,  9 /*a47b*/,  8 /*a47c*/,  9 /*a47d*/,
    9 /*a47e*/,  10 /*a47f*/, 4 /*a480*/,  5 /*a481*/,  5 /*a482*/,
    6 /*a483*/,  5 /*a484*/,  6 /*a485*/,  6 /*a486*/,  7 /*a487*/,
    5 /*a488*/,  6 /*a489*/,  6 /*a48a*/,  7 /*a48b*/,  6 /*a48c*/,
    7 /*a48d*/,  7 /*a48e*/,  8 /*a48f*/,  5 /*a490*/,  6 /*a491*/,
    6 /*a492*/,  7 /*a493*/,  6 /*a494*/,  7 /*a495*/,  7 /*a496*/,
    8 /*a497*/,  6 /*a498*/,  7 /*a499*/,  7 /*a49a*/,  8 /*a49b*/,
    7 /*a49c*/,  8 /*a49d*/,  8 /*a49e*/,  9 /*a49f*/,  5 /*a4a0*/,
    6 /*a4a1*/,  6 /*a4a2*/,  7 /*a4a3*/,  6 /*a4a4*/,  7 /*a4a5*/,
    7 /*a4a6*/,  8 /*a4a7*/,  6 /*a4a8*/,  7 /*a4a9*/,  7 /*a4aa*/,
    8 /*a4ab*/,  7 /*a4ac*/,  8 /*a4ad*/,  8 /*a4ae*/,  9 /*a4af*/,
    6 /*a4b0*/,  7 /*a4b1*/,  7 /*a4b2*/,  8 /*a4b3*/,  7 /*a4b4*/,
    8 /*a4b5*/,  8 /*a4b6*/,  9 /*a4b7*/,  7 /*a4b8*/,  8 /*a4b9*/,
    8 /*a4ba*/,  9 /*a4bb*/,  8 /*a4bc*/,  9 /*a4bd*/,  9 /*a4be*/,
    10 /*a4bf*/, 5 /*a4c0*/,  6 /*a4c1*/,  6 /*a4c2*/,  7 /*a4c3*/,
    6 /*a4c4*/,  7 /*a4c5*/,  7 /*a4c6*/,  8 /*a4c7*/,  6 /*a4c8*/,
    7 /*a4c9*/,  7 /*a4ca*/,  8 /*a4cb*/,  7 /*a4cc*/,  8 /*a4cd*/,
    8 /*a4ce*/,  9 /*a4cf*/,  6 /*a4d0*/,  7 /*a4d1*/,  7 /*a4d2*/,
    8 /*a4d3*/,  7 /*a4d4*/,  8 /*a4d5*/,  8 /*a4d6*/,  9 /*a4d7*/,
    7 /*a4d8*/,  8 /*a4d9*/,  8 /*a4da*/,  9 /*a4db*/,  8 /*a4dc*/,
    9 /*a4dd*/,  9 /*a4de*/,  10 /*a4df*/, 6 /*a4e0*/,  7 /*a4e1*/,
    7 /*a4e2*/,  8 /*a4e3*/,  7 /*a4e4*/,  8 /*a4e5*/,  8 /*a4e6*/,
    9 /*a4e7*/,  7 /*a4e8*/,  8 /*a4e9*/,  8 /*a4ea*/,  9 /*a4eb*/,
    8 /*a4ec*/,  9 /*a4ed*/,  9 /*a4ee*/,  10 /*a4ef*/, 7 /*a4f0*/,
    8 /*a4f1*/,  8 /*a4f2*/,  9 /*a4f3*/,  8 /*a4f4*/,  9 /*a4f5*/,
    9 /*a4f6*/,  10 /*a4f7*/, 8 /*a4f8*/,  9 /*a4f9*/,  9 /*a4fa*/,
    10 /*a4fb*/, 9 /*a4fc*/,  10 /*a4fd*/, 10 /*a4fe*/, 11 /*a4ff*/,
    4 /*a500*/,  5 /*a501*/,  5 /*a502*/,  6 /*a503*/,  5 /*a504*/,
    6 /*a505*/,  6 /*a506*/,  7 /*a507*/,  5 /*a508*/,  6 /*a509*/,
    6 /*a50a*/,  7 /*a50b*/,  6 /*a50c*/,  7 /*a50d*/,  7 /*a50e*/,
    8 /*a50f*/,  5 /*a510*/,  6 /*a511*/,  6 /*a512*/,  7 /*a513*/,
    6 /*a514*/,  7 /*a515*/,  7 /*a516*/,  8 /*a517*/,  6 /*a518*/,
    7 /*a519*/,  7 /*a51a*/,  8 /*a51b*/,  7 /*a51c*/,  8 /*a51d*/,
    8 /*a51e*/,  9 /*a51f*/,  5 /*a520*/,  6 /*a521*/,  6 /*a522*/,
    7 /*a523*/,  6 /*a524*/,  7 /*a525*/,  7 /*a526*/,  8 /*a527*/,
    6 /*a528*/,  7 /*a529*/,  7 /*a52a*/,  8 /*a52b*/,  7 /*a52c*/,
    8 /*a52d*/,  8 /*a52e*/,  9 /*a52f*/,  6 /*a530*/,  7 /*a531*/,
    7 /*a532*/,  8 /*a533*/,  7 /*a534*/,  8 /*a535*/,  8 /*a536*/,
    9 /*a537*/,  7 /*a538*/,  8 /*a539*/,  8 /*a53a*/,  9 /*a53b*/,
    8 /*a53c*/,  9 /*a53d*/,  9 /*a53e*/,  10 /*a53f*/, 5 /*a540*/,
    6 /*a541*/,  6 /*a542*/,  7 /*a543*/,  6 /*a544*/,  7 /*a545*/,
    7 /*a546*/,  8 /*a547*/,  6 /*a548*/,  7 /*a549*/,  7 /*a54a*/,
    8 /*a54b*/,  7 /*a54c*/,  8 /*a54d*/,  8 /*a54e*/,  9 /*a54f*/,
    6 /*a550*/,  7 /*a551*/,  7 /*a552*/,  8 /*a553*/,  7 /*a554*/,
    8 /*a555*/,  8 /*a556*/,  9 /*a557*/,  7 /*a558*/,  8 /*a559*/,
    8 /*a55a*/,  9 /*a55b*/,  8 /*a55c*/,  9 /*a55d*/,  9 /*a55e*/,
    10 /*a55f*/, 6 /*a560*/,  7 /*a561*/,  7 /*a562*/,  8 /*a563*/,
    7 /*a564*/,  8 /*a565*/,  8 /*a566*/,  9 /*a567*/,  7 /*a568*/,
    8 /*a569*/,  8 /*a56a*/,  9 /*a56b*/,  8 /*a56c*/,  9 /*a56d*/,
    9 /*a56e*/,  10 /*a56f*/, 7 /*a570*/,  8 /*a571*/,  8 /*a572*/,
    9 /*a573*/,  8 /*a574*/,  9 /*a575*/,  9 /*a576*/,  10 /*a577*/,
    8 /*a578*/,  9 /*a579*/,  9 /*a57a*/,  10 /*a57b*/, 9 /*a57c*/,
    10 /*a57d*/, 10 /*a57e*/, 11 /*a57f*/, 5 /*a580*/,  6 /*a581*/,
    6 /*a582*/,  7 /*a583*/,  6 /*a584*/,  7 /*a585*/,  7 /*a586*/,
    8 /*a587*/,  6 /*a588*/,  7 /*a589*/,  7 /*a58a*/,  8 /*a58b*/,
    7 /*a58c*/,  8 /*a58d*/,  8 /*a58e*/,  9 /*a58f*/,  6 /*a590*/,
    7 /*a591*/,  7 /*a592*/,  8 /*a593*/,  7 /*a594*/,  8 /*a595*/,
    8 /*a596*/,  9 /*a597*/,  7 /*a598*/,  8 /*a599*/,  8 /*a59a*/,
    9 /*a59b*/,  8 /*a59c*/,  9 /*a59d*/,  9 /*a59e*/,  10 /*a59f*/,
    6 /*a5a0*/,  7 /*a5a1*/,  7 /*a5a2*/,  8 /*a5a3*/,  7 /*a5a4*/,
    8 /*a5a5*/,  8 /*a5a6*/,  9 /*a5a7*/,  7 /*a5a8*/,  8 /*a5a9*/,
    8 /*a5aa*/,  9 /*a5ab*/,  8 /*a5ac*/,  9 /*a5ad*/,  9 /*a5ae*/,
    10 /*a5af*/, 7 /*a5b0*/,  8 /*a5b1*/,  8 /*a5b2*/,  9 /*a5b3*/,
    8 /*a5b4*/,  9 /*a5b5*/,  9 /*a5b6*/,  10 /*a5b7*/, 8 /*a5b8*/,
    9 /*a5b9*/,  9 /*a5ba*/,  10 /*a5bb*/, 9 /*a5bc*/,  10 /*a5bd*/,
    10 /*a5be*/, 11 /*a5bf*/, 6 /*a5c0*/,  7 /*a5c1*/,  7 /*a5c2*/,
    8 /*a5c3*/,  7 /*a5c4*/,  8 /*a5c5*/,  8 /*a5c6*/,  9 /*a5c7*/,
    7 /*a5c8*/,  8 /*a5c9*/,  8 /*a5ca*/,  9 /*a5cb*/,  8 /*a5cc*/,
    9 /*a5cd*/,  9 /*a5ce*/,  10 /*a5cf*/, 7 /*a5d0*/,  8 /*a5d1*/,
    8 /*a5d2*/,  9 /*a5d3*/,  8 /*a5d4*/,  9 /*a5d5*/,  9 /*a5d6*/,
    10 /*a5d7*/, 8 /*a5d8*/,  9 /*a5d9*/,  9 /*a5da*/,  10 /*a5db*/,
    9 /*a5dc*/,  10 /*a5dd*/, 10 /*a5de*/, 11 /*a5df*/, 7 /*a5e0*/,
    8 /*a5e1*/,  8 /*a5e2*/,  9 /*a5e3*/,  8 /*a5e4*/,  9 /*a5e5*/,
    9 /*a5e6*/,  10 /*a5e7*/, 8 /*a5e8*/,  9 /*a5e9*/,  9 /*a5ea*/,
    10 /*a5eb*/, 9 /*a5ec*/,  10 /*a5ed*/, 10 /*a5ee*/, 11 /*a5ef*/,
    8 /*a5f0*/,  9 /*a5f1*/,  9 /*a5f2*/,  10 /*a5f3*/, 9 /*a5f4*/,
    10 /*a5f5*/, 10 /*a5f6*/, 11 /*a5f7*/, 9 /*a5f8*/,  10 /*a5f9*/,
    10 /*a5fa*/, 11 /*a5fb*/, 10 /*a5fc*/, 11 /*a5fd*/, 11 /*a5fe*/,
    12 /*a5ff*/, 4 /*a600*/,  5 /*a601*/,  5 /*a602*/,  6 /*a603*/,
    5 /*a604*/,  6 /*a605*/,  6 /*a606*/,  7 /*a607*/,  5 /*a608*/,
    6 /*a609*/,  6 /*a60a*/,  7 /*a60b*/,  6 /*a60c*/,  7 /*a60d*/,
    7 /*a60e*/,  8 /*a60f*/,  5 /*a610*/,  6 /*a611*/,  6 /*a612*/,
    7 /*a613*/,  6 /*a614*/,  7 /*a615*/,  7 /*a616*/,  8 /*a617*/,
    6 /*a618*/,  7 /*a619*/,  7 /*a61a*/,  8 /*a61b*/,  7 /*a61c*/,
    8 /*a61d*/,  8 /*a61e*/,  9 /*a61f*/,  5 /*a620*/,  6 /*a621*/,
    6 /*a622*/,  7 /*a623*/,  6 /*a624*/,  7 /*a625*/,  7 /*a626*/,
    8 /*a627*/,  6 /*a628*/,  7 /*a629*/,  7 /*a62a*/,  8 /*a62b*/,
    7 /*a62c*/,  8 /*a62d*/,  8 /*a62e*/,  9 /*a62f*/,  6 /*a630*/,
    7 /*a631*/,  7 /*a632*/,  8 /*a633*/,  7 /*a634*/,  8 /*a635*/,
    8 /*a636*/,  9 /*a637*/,  7 /*a638*/,  8 /*a639*/,  8 /*a63a*/,
    9 /*a63b*/,  8 /*a63c*/,  9 /*a63d*/,  9 /*a63e*/,  10 /*a63f*/,
    5 /*a640*/,  6 /*a641*/,  6 /*a642*/,  7 /*a643*/,  6 /*a644*/,
    7 /*a645*/,  7 /*a646*/,  8 /*a647*/,  6 /*a648*/,  7 /*a649*/,
    7 /*a64a*/,  8 /*a64b*/,  7 /*a64c*/,  8 /*a64d*/,  8 /*a64e*/,
    9 /*a64f*/,  6 /*a650*/,  7 /*a651*/,  7 /*a652*/,  8 /*a653*/,
    7 /*a654*/,  8 /*a655*/,  8 /*a656*/,  9 /*a657*/,  7 /*a658*/,
    8 /*a659*/,  8 /*a65a*/,  9 /*a65b*/,  8 /*a65c*/,  9 /*a65d*/,
    9 /*a65e*/,  10 /*a65f*/, 6 /*a660*/,  7 /*a661*/,  7 /*a662*/,
    8 /*a663*/,  7 /*a664*/,  8 /*a665*/,  8 /*a666*/,  9 /*a667*/,
    7 /*a668*/,  8 /*a669*/,  8 /*a66a*/,  9 /*a66b*/,  8 /*a66c*/,
    9 /*a66d*/,  9 /*a66e*/,  10 /*a66f*/, 7 /*a670*/,  8 /*a671*/,
    8 /*a672*/,  9 /*a673*/,  8 /*a674*/,  9 /*a675*/,  9 /*a676*/,
    10 /*a677*/, 8 /*a678*/,  9 /*a679*/,  9 /*a67a*/,  10 /*a67b*/,
    9 /*a67c*/,  10 /*a67d*/, 10 /*a67e*/, 11 /*a67f*/, 5 /*a680*/,
    6 /*a681*/,  6 /*a682*/,  7 /*a683*/,  6 /*a684*/,  7 /*a685*/,
    7 /*a686*/,  8 /*a687*/,  6 /*a688*/,  7 /*a689*/,  7 /*a68a*/,
    8 /*a68b*/,  7 /*a68c*/,  8 /*a68d*/,  8 /*a68e*/,  9 /*a68f*/,
    6 /*a690*/,  7 /*a691*/,  7 /*a692*/,  8 /*a693*/,  7 /*a694*/,
    8 /*a695*/,  8 /*a696*/,  9 /*a697*/,  7 /*a698*/,  8 /*a699*/,
    8 /*a69a*/,  9 /*a69b*/,  8 /*a69c*/,  9 /*a69d*/,  9 /*a69e*/,
    10 /*a69f*/, 6 /*a6a0*/,  7 /*a6a1*/,  7 /*a6a2*/,  8 /*a6a3*/,
    7 /*a6a4*/,  8 /*a6a5*/,  8 /*a6a6*/,  9 /*a6a7*/,  7 /*a6a8*/,
    8 /*a6a9*/,  8 /*a6aa*/,  9 /*a6ab*/,  8 /*a6ac*/,  9 /*a6ad*/,
    9 /*a6ae*/,  10 /*a6af*/, 7 /*a6b0*/,  8 /*a6b1*/,  8 /*a6b2*/,
    9 /*a6b3*/,  8 /*a6b4*/,  9 /*a6b5*/,  9 /*a6b6*/,  10 /*a6b7*/,
    8 /*a6b8*/,  9 /*a6b9*/,  9 /*a6ba*/,  10 /*a6bb*/, 9 /*a6bc*/,
    10 /*a6bd*/, 10 /*a6be*/, 11 /*a6bf*/, 6 /*a6c0*/,  7 /*a6c1*/,
    7 /*a6c2*/,  8 /*a6c3*/,  7 /*a6c4*/,  8 /*a6c5*/,  8 /*a6c6*/,
    9 /*a6c7*/,  7 /*a6c8*/,  8 /*a6c9*/,  8 /*a6ca*/,  9 /*a6cb*/,
    8 /*a6cc*/,  9 /*a6cd*/,  9 /*a6ce*/,  10 /*a6cf*/, 7 /*a6d0*/,
    8 /*a6d1*/,  8 /*a6d2*/,  9 /*a6d3*/,  8 /*a6d4*/,  9 /*a6d5*/,
    9 /*a6d6*/,  10 /*a6d7*/, 8 /*a6d8*/,  9 /*a6d9*/,  9 /*a6da*/,
    10 /*a6db*/, 9 /*a6dc*/,  10 /*a6dd*/, 10 /*a6de*/, 11 /*a6df*/,
    7 /*a6e0*/,  8 /*a6e1*/,  8 /*a6e2*/,  9 /*a6e3*/,  8 /*a6e4*/,
    9 /*a6e5*/,  9 /*a6e6*/,  10 /*a6e7*/, 8 /*a6e8*/,  9 /*a6e9*/,
    9 /*a6ea*/,  10 /*a6eb*/, 9 /*a6ec*/,  10 /*a6ed*/, 10 /*a6ee*/,
    11 /*a6ef*/, 8 /*a6f0*/,  9 /*a6f1*/,  9 /*a6f2*/,  10 /*a6f3*/,
    9 /*a6f4*/,  10 /*a6f5*/, 10 /*a6f6*/, 11 /*a6f7*/, 9 /*a6f8*/,
    10 /*a6f9*/, 10 /*a6fa*/, 11 /*a6fb*/, 10 /*a6fc*/, 11 /*a6fd*/,
    11 /*a6fe*/, 12 /*a6ff*/, 5 /*a700*/,  6 /*a701*/,  6 /*a702*/,
    7 /*a703*/,  6 /*a704*/,  7 /*a705*/,  7 /*a706*/,  8 /*a707*/,
    6 /*a708*/,  7 /*a709*/,  7 /*a70a*/,  8 /*a70b*/,  7 /*a70c*/,
    8 /*a70d*/,  8 /*a70e*/,  9 /*a70f*/,  6 /*a710*/,  7 /*a711*/,
    7 /*a712*/,  8 /*a713*/,  7 /*a714*/,  8 /*a715*/,  8 /*a716*/,
    9 /*a717*/,  7 /*a718*/,  8 /*a719*/,  8 /*a71a*/,  9 /*a71b*/,
    8 /*a71c*/,  9 /*a71d*/,  9 /*a71e*/,  10 /*a71f*/, 6 /*a720*/,
    7 /*a721*/,  7 /*a722*/,  8 /*a723*/,  7 /*a724*/,  8 /*a725*/,
    8 /*a726*/,  9 /*a727*/,  7 /*a728*/,  8 /*a729*/,  8 /*a72a*/,
    9 /*a72b*/,  8 /*a72c*/,  9 /*a72d*/,  9 /*a72e*/,  10 /*a72f*/,
    7 /*a730*/,  8 /*a731*/,  8 /*a732*/,  9 /*a733*/,  8 /*a734*/,
    9 /*a735*/,  9 /*a736*/,  10 /*a737*/, 8 /*a738*/,  9 /*a739*/,
    9 /*a73a*/,  10 /*a73b*/, 9 /*a73c*/,  10 /*a73d*/, 10 /*a73e*/,
    11 /*a73f*/, 6 /*a740*/,  7 /*a741*/,  7 /*a742*/,  8 /*a743*/,
    7 /*a744*/,  8 /*a745*/,  8 /*a746*/,  9 /*a747*/,  7 /*a748*/,
    8 /*a749*/,  8 /*a74a*/,  9 /*a74b*/,  8 /*a74c*/,  9 /*a74d*/,
    9 /*a74e*/,  10 /*a74f*/, 7 /*a750*/,  8 /*a751*/,  8 /*a752*/,
    9 /*a753*/,  8 /*a754*/,  9 /*a755*/,  9 /*a756*/,  10 /*a757*/,
    8 /*a758*/,  9 /*a759*/,  9 /*a75a*/,  10 /*a75b*/, 9 /*a75c*/,
    10 /*a75d*/, 10 /*a75e*/, 11 /*a75f*/, 7 /*a760*/,  8 /*a761*/,
    8 /*a762*/,  9 /*a763*/,  8 /*a764*/,  9 /*a765*/,  9 /*a766*/,
    10 /*a767*/, 8 /*a768*/,  9 /*a769*/,  9 /*a76a*/,  10 /*a76b*/,
    9 /*a76c*/,  10 /*a76d*/, 10 /*a76e*/, 11 /*a76f*/, 8 /*a770*/,
    9 /*a771*/,  9 /*a772*/,  10 /*a773*/, 9 /*a774*/,  10 /*a775*/,
    10 /*a776*/, 11 /*a777*/, 9 /*a778*/,  10 /*a779*/, 10 /*a77a*/,
    11 /*a77b*/, 10 /*a77c*/, 11 /*a77d*/, 11 /*a77e*/, 12 /*a77f*/,
    6 /*a780*/,  7 /*a781*/,  7 /*a782*/,  8 /*a783*/,  7 /*a784*/,
    8 /*a785*/,  8 /*a786*/,  9 /*a787*/,  7 /*a788*/,  8 /*a789*/,
    8 /*a78a*/,  9 /*a78b*/,  8 /*a78c*/,  9 /*a78d*/,  9 /*a78e*/,
    10 /*a78f*/, 7 /*a790*/,  8 /*a791*/,  8 /*a792*/,  9 /*a793*/,
    8 /*a794*/,  9 /*a795*/,  9 /*a796*/,  10 /*a797*/, 8 /*a798*/,
    9 /*a799*/,  9 /*a79a*/,  10 /*a79b*/, 9 /*a79c*/,  10 /*a79d*/,
    10 /*a79e*/, 11 /*a79f*/, 7 /*a7a0*/,  8 /*a7a1*/,  8 /*a7a2*/,
    9 /*a7a3*/,  8 /*a7a4*/,  9 /*a7a5*/,  9 /*a7a6*/,  10 /*a7a7*/,
    8 /*a7a8*/,  9 /*a7a9*/,  9 /*a7aa*/,  10 /*a7ab*/, 9 /*a7ac*/,
    10 /*a7ad*/, 10 /*a7ae*/, 11 /*a7af*/, 8 /*a7b0*/,  9 /*a7b1*/,
    9 /*a7b2*/,  10 /*a7b3*/, 9 /*a7b4*/,  10 /*a7b5*/, 10 /*a7b6*/,
    11 /*a7b7*/, 9 /*a7b8*/,  10 /*a7b9*/, 10 /*a7ba*/, 11 /*a7bb*/,
    10 /*a7bc*/, 11 /*a7bd*/, 11 /*a7be*/, 12 /*a7bf*/, 7 /*a7c0*/,
    8 /*a7c1*/,  8 /*a7c2*/,  9 /*a7c3*/,  8 /*a7c4*/,  9 /*a7c5*/,
    9 /*a7c6*/,  10 /*a7c7*/, 8 /*a7c8*/,  9 /*a7c9*/,  9 /*a7ca*/,
    10 /*a7cb*/, 9 /*a7cc*/,  10 /*a7cd*/, 10 /*a7ce*/, 11 /*a7cf*/,
    8 /*a7d0*/,  9 /*a7d1*/,  9 /*a7d2*/,  10 /*a7d3*/, 9 /*a7d4*/,
    10 /*a7d5*/, 10 /*a7d6*/, 11 /*a7d7*/, 9 /*a7d8*/,  10 /*a7d9*/,
    10 /*a7da*/, 11 /*a7db*/, 10 /*a7dc*/, 11 /*a7dd*/, 11 /*a7de*/,
    12 /*a7df*/, 8 /*a7e0*/,  9 /*a7e1*/,  9 /*a7e2*/,  10 /*a7e3*/,
    9 /*a7e4*/,  10 /*a7e5*/, 10 /*a7e6*/, 11 /*a7e7*/, 9 /*a7e8*/,
    10 /*a7e9*/, 10 /*a7ea*/, 11 /*a7eb*/, 10 /*a7ec*/, 11 /*a7ed*/,
    11 /*a7ee*/, 12 /*a7ef*/, 9 /*a7f0*/,  10 /*a7f1*/, 10 /*a7f2*/,
    11 /*a7f3*/, 10 /*a7f4*/, 11 /*a7f5*/, 11 /*a7f6*/, 12 /*a7f7*/,
    10 /*a7f8*/, 11 /*a7f9*/, 11 /*a7fa*/, 12 /*a7fb*/, 11 /*a7fc*/,
    12 /*a7fd*/, 12 /*a7fe*/, 13 /*a7ff*/, 3 /*a800*/,  4 /*a801*/,
    4 /*a802*/,  5 /*a803*/,  4 /*a804*/,  5 /*a805*/,  5 /*a806*/,
    6 /*a807*/,  4 /*a808*/,  5 /*a809*/,  5 /*a80a*/,  6 /*a80b*/,
    5 /*a80c*/,  6 /*a80d*/,  6 /*a80e*/,  7 /*a80f*/,  4 /*a810*/,
    5 /*a811*/,  5 /*a812*/,  6 /*a813*/,  5 /*a814*/,  6 /*a815*/,
    6 /*a816*/,  7 /*a817*/,  5 /*a818*/,  6 /*a819*/,  6 /*a81a*/,
    7 /*a81b*/,  6 /*a81c*/,  7 /*a81d*/,  7 /*a81e*/,  8 /*a81f*/,
    4 /*a820*/,  5 /*a821*/,  5 /*a822*/,  6 /*a823*/,  5 /*a824*/,
    6 /*a825*/,  6 /*a826*/,  7 /*a827*/,  5 /*a828*/,  6 /*a829*/,
    6 /*a82a*/,  7 /*a82b*/,  6 /*a82c*/,  7 /*a82d*/,  7 /*a82e*/,
    8 /*a82f*/,  5 /*a830*/,  6 /*a831*/,  6 /*a832*/,  7 /*a833*/,
    6 /*a834*/,  7 /*a835*/,  7 /*a836*/,  8 /*a837*/,  6 /*a838*/,
    7 /*a839*/,  7 /*a83a*/,  8 /*a83b*/,  7 /*a83c*/,  8 /*a83d*/,
    8 /*a83e*/,  9 /*a83f*/,  4 /*a840*/,  5 /*a841*/,  5 /*a842*/,
    6 /*a843*/,  5 /*a844*/,  6 /*a845*/,  6 /*a846*/,  7 /*a847*/,
    5 /*a848*/,  6 /*a849*/,  6 /*a84a*/,  7 /*a84b*/,  6 /*a84c*/,
    7 /*a84d*/,  7 /*a84e*/,  8 /*a84f*/,  5 /*a850*/,  6 /*a851*/,
    6 /*a852*/,  7 /*a853*/,  6 /*a854*/,  7 /*a855*/,  7 /*a856*/,
    8 /*a857*/,  6 /*a858*/,  7 /*a859*/,  7 /*a85a*/,  8 /*a85b*/,
    7 /*a85c*/,  8 /*a85d*/,  8 /*a85e*/,  9 /*a85f*/,  5 /*a860*/,
    6 /*a861*/,  6 /*a862*/,  7 /*a863*/,  6 /*a864*/,  7 /*a865*/,
    7 /*a866*/,  8 /*a867*/,  6 /*a868*/,  7 /*a869*/,  7 /*a86a*/,
    8 /*a86b*/,  7 /*a86c*/,  8 /*a86d*/,  8 /*a86e*/,  9 /*a86f*/,
    6 /*a870*/,  7 /*a871*/,  7 /*a872*/,  8 /*a873*/,  7 /*a874*/,
    8 /*a875*/,  8 /*a876*/,  9 /*a877*/,  7 /*a878*/,  8 /*a879*/,
    8 /*a87a*/,  9 /*a87b*/,  8 /*a87c*/,  9 /*a87d*/,  9 /*a87e*/,
    10 /*a87f*/, 4 /*a880*/,  5 /*a881*/,  5 /*a882*/,  6 /*a883*/,
    5 /*a884*/,  6 /*a885*/,  6 /*a886*/,  7 /*a887*/,  5 /*a888*/,
    6 /*a889*/,  6 /*a88a*/,  7 /*a88b*/,  6 /*a88c*/,  7 /*a88d*/,
    7 /*a88e*/,  8 /*a88f*/,  5 /*a890*/,  6 /*a891*/,  6 /*a892*/,
    7 /*a893*/,  6 /*a894*/,  7 /*a895*/,  7 /*a896*/,  8 /*a897*/,
    6 /*a898*/,  7 /*a899*/,  7 /*a89a*/,  8 /*a89b*/,  7 /*a89c*/,
    8 /*a89d*/,  8 /*a89e*/,  9 /*a89f*/,  5 /*a8a0*/,  6 /*a8a1*/,
    6 /*a8a2*/,  7 /*a8a3*/,  6 /*a8a4*/,  7 /*a8a5*/,  7 /*a8a6*/,
    8 /*a8a7*/,  6 /*a8a8*/,  7 /*a8a9*/,  7 /*a8aa*/,  8 /*a8ab*/,
    7 /*a8ac*/,  8 /*a8ad*/,  8 /*a8ae*/,  9 /*a8af*/,  6 /*a8b0*/,
    7 /*a8b1*/,  7 /*a8b2*/,  8 /*a8b3*/,  7 /*a8b4*/,  8 /*a8b5*/,
    8 /*a8b6*/,  9 /*a8b7*/,  7 /*a8b8*/,  8 /*a8b9*/,  8 /*a8ba*/,
    9 /*a8bb*/,  8 /*a8bc*/,  9 /*a8bd*/,  9 /*a8be*/,  10 /*a8bf*/,
    5 /*a8c0*/,  6 /*a8c1*/,  6 /*a8c2*/,  7 /*a8c3*/,  6 /*a8c4*/,
    7 /*a8c5*/,  7 /*a8c6*/,  8 /*a8c7*/,  6 /*a8c8*/,  7 /*a8c9*/,
    7 /*a8ca*/,  8 /*a8cb*/,  7 /*a8cc*/,  8 /*a8cd*/,  8 /*a8ce*/,
    9 /*a8cf*/,  6 /*a8d0*/,  7 /*a8d1*/,  7 /*a8d2*/,  8 /*a8d3*/,
    7 /*a8d4*/,  8 /*a8d5*/,  8 /*a8d6*/,  9 /*a8d7*/,  7 /*a8d8*/,
    8 /*a8d9*/,  8 /*a8da*/,  9 /*a8db*/,  8 /*a8dc*/,  9 /*a8dd*/,
    9 /*a8de*/,  10 /*a8df*/, 6 /*a8e0*/,  7 /*a8e1*/,  7 /*a8e2*/,
    8 /*a8e3*/,  7 /*a8e4*/,  8 /*a8e5*/,  8 /*a8e6*/,  9 /*a8e7*/,
    7 /*a8e8*/,  8 /*a8e9*/,  8 /*a8ea*/,  9 /*a8eb*/,  8 /*a8ec*/,
    9 /*a8ed*/,  9 /*a8ee*/,  10 /*a8ef*/, 7 /*a8f0*/,  8 /*a8f1*/,
    8 /*a8f2*/,  9 /*a8f3*/,  8 /*a8f4*/,  9 /*a8f5*/,  9 /*a8f6*/,
    10 /*a8f7*/, 8 /*a8f8*/,  9 /*a8f9*/,  9 /*a8fa*/,  10 /*a8fb*/,
    9 /*a8fc*/,  10 /*a8fd*/, 10 /*a8fe*/, 11 /*a8ff*/, 4 /*a900*/,
    5 /*a901*/,  5 /*a902*/,  6 /*a903*/,  5 /*a904*/,  6 /*a905*/,
    6 /*a906*/,  7 /*a907*/,  5 /*a908*/,  6 /*a909*/,  6 /*a90a*/,
    7 /*a90b*/,  6 /*a90c*/,  7 /*a90d*/,  7 /*a90e*/,  8 /*a90f*/,
    5 /*a910*/,  6 /*a911*/,  6 /*a912*/,  7 /*a913*/,  6 /*a914*/,
    7 /*a915*/,  7 /*a916*/,  8 /*a917*/,  6 /*a918*/,  7 /*a919*/,
    7 /*a91a*/,  8 /*a91b*/,  7 /*a91c*/,  8 /*a91d*/,  8 /*a91e*/,
    9 /*a91f*/,  5 /*a920*/,  6 /*a921*/,  6 /*a922*/,  7 /*a923*/,
    6 /*a924*/,  7 /*a925*/,  7 /*a926*/,  8 /*a927*/,  6 /*a928*/,
    7 /*a929*/,  7 /*a92a*/,  8 /*a92b*/,  7 /*a92c*/,  8 /*a92d*/,
    8 /*a92e*/,  9 /*a92f*/,  6 /*a930*/,  7 /*a931*/,  7 /*a932*/,
    8 /*a933*/,  7 /*a934*/,  8 /*a935*/,  8 /*a936*/,  9 /*a937*/,
    7 /*a938*/,  8 /*a939*/,  8 /*a93a*/,  9 /*a93b*/,  8 /*a93c*/,
    9 /*a93d*/,  9 /*a93e*/,  10 /*a93f*/, 5 /*a940*/,  6 /*a941*/,
    6 /*a942*/,  7 /*a943*/,  6 /*a944*/,  7 /*a945*/,  7 /*a946*/,
    8 /*a947*/,  6 /*a948*/,  7 /*a949*/,  7 /*a94a*/,  8 /*a94b*/,
    7 /*a94c*/,  8 /*a94d*/,  8 /*a94e*/,  9 /*a94f*/,  6 /*a950*/,
    7 /*a951*/,  7 /*a952*/,  8 /*a953*/,  7 /*a954*/,  8 /*a955*/,
    8 /*a956*/,  9 /*a957*/,  7 /*a958*/,  8 /*a959*/,  8 /*a95a*/,
    9 /*a95b*/,  8 /*a95c*/,  9 /*a95d*/,  9 /*a95e*/,  10 /*a95f*/,
    6 /*a960*/,  7 /*a961*/,  7 /*a962*/,  8 /*a963*/,  7 /*a964*/,
    8 /*a965*/,  8 /*a966*/,  9 /*a967*/,  7 /*a968*/,  8 /*a969*/,
    8 /*a96a*/,  9 /*a96b*/,  8 /*a96c*/,  9 /*a96d*/,  9 /*a96e*/,
    10 /*a96f*/, 7 /*a970*/,  8 /*a971*/,  8 /*a972*/,  9 /*a973*/,
    8 /*a974*/,  9 /*a975*/,  9 /*a976*/,  10 /*a977*/, 8 /*a978*/,
    9 /*a979*/,  9 /*a97a*/,  10 /*a97b*/, 9 /*a97c*/,  10 /*a97d*/,
    10 /*a97e*/, 11 /*a97f*/, 5 /*a980*/,  6 /*a981*/,  6 /*a982*/,
    7 /*a983*/,  6 /*a984*/,  7 /*a985*/,  7 /*a986*/,  8 /*a987*/,
    6 /*a988*/,  7 /*a989*/,  7 /*a98a*/,  8 /*a98b*/,  7 /*a98c*/,
    8 /*a98d*/,  8 /*a98e*/,  9 /*a98f*/,  6 /*a990*/,  7 /*a991*/,
    7 /*a992*/,  8 /*a993*/,  7 /*a994*/,  8 /*a995*/,  8 /*a996*/,
    9 /*a997*/,  7 /*a998*/,  8 /*a999*/,  8 /*a99a*/,  9 /*a99b*/,
    8 /*a99c*/,  9 /*a99d*/,  9 /*a99e*/,  10 /*a99f*/, 6 /*a9a0*/,
    7 /*a9a1*/,  7 /*a9a2*/,  8 /*a9a3*/,  7 /*a9a4*/,  8 /*a9a5*/,
    8 /*a9a6*/,  9 /*a9a7*/,  7 /*a9a8*/,  8 /*a9a9*/,  8 /*a9aa*/,
    9 /*a9ab*/,  8 /*a9ac*/,  9 /*a9ad*/,  9 /*a9ae*/,  10 /*a9af*/,
    7 /*a9b0*/,  8 /*a9b1*/,  8 /*a9b2*/,  9 /*a9b3*/,  8 /*a9b4*/,
    9 /*a9b5*/,  9 /*a9b6*/,  10 /*a9b7*/, 8 /*a9b8*/,  9 /*a9b9*/,
    9 /*a9ba*/,  10 /*a9bb*/, 9 /*a9bc*/,  10 /*a9bd*/, 10 /*a9be*/,
    11 /*a9bf*/, 6 /*a9c0*/,  7 /*a9c1*/,  7 /*a9c2*/,  8 /*a9c3*/,
    7 /*a9c4*/,  8 /*a9c5*/,  8 /*a9c6*/,  9 /*a9c7*/,  7 /*a9c8*/,
    8 /*a9c9*/,  8 /*a9ca*/,  9 /*a9cb*/,  8 /*a9cc*/,  9 /*a9cd*/,
    9 /*a9ce*/,  10 /*a9cf*/, 7 /*a9d0*/,  8 /*a9d1*/,  8 /*a9d2*/,
    9 /*a9d3*/,  8 /*a9d4*/,  9 /*a9d5*/,  9 /*a9d6*/,  10 /*a9d7*/,
    8 /*a9d8*/,  9 /*a9d9*/,  9 /*a9da*/,  10 /*a9db*/, 9 /*a9dc*/,
    10 /*a9dd*/, 10 /*a9de*/, 11 /*a9df*/, 7 /*a9e0*/,  8 /*a9e1*/,
    8 /*a9e2*/,  9 /*a9e3*/,  8 /*a9e4*/,  9 /*a9e5*/,  9 /*a9e6*/,
    10 /*a9e7*/, 8 /*a9e8*/,  9 /*a9e9*/,  9 /*a9ea*/,  10 /*a9eb*/,
    9 /*a9ec*/,  10 /*a9ed*/, 10 /*a9ee*/, 11 /*a9ef*/, 8 /*a9f0*/,
    9 /*a9f1*/,  9 /*a9f2*/,  10 /*a9f3*/, 9 /*a9f4*/,  10 /*a9f5*/,
    10 /*a9f6*/, 11 /*a9f7*/, 9 /*a9f8*/,  10 /*a9f9*/, 10 /*a9fa*/,
    11 /*a9fb*/, 10 /*a9fc*/, 11 /*a9fd*/, 11 /*a9fe*/, 12 /*a9ff*/,
    4 /*aa00*/,  5 /*aa01*/,  5 /*aa02*/,  6 /*aa03*/,  5 /*aa04*/,
    6 /*aa05*/,  6 /*aa06*/,  7 /*aa07*/,  5 /*aa08*/,  6 /*aa09*/,
    6 /*aa0a*/,  7 /*aa0b*/,  6 /*aa0c*/,  7 /*aa0d*/,  7 /*aa0e*/,
    8 /*aa0f*/,  5 /*aa10*/,  6 /*aa11*/,  6 /*aa12*/,  7 /*aa13*/,
    6 /*aa14*/,  7 /*aa15*/,  7 /*aa16*/,  8 /*aa17*/,  6 /*aa18*/,
    7 /*aa19*/,  7 /*aa1a*/,  8 /*aa1b*/,  7 /*aa1c*/,  8 /*aa1d*/,
    8 /*aa1e*/,  9 /*aa1f*/,  5 /*aa20*/,  6 /*aa21*/,  6 /*aa22*/,
    7 /*aa23*/,  6 /*aa24*/,  7 /*aa25*/,  7 /*aa26*/,  8 /*aa27*/,
    6 /*aa28*/,  7 /*aa29*/,  7 /*aa2a*/,  8 /*aa2b*/,  7 /*aa2c*/,
    8 /*aa2d*/,  8 /*aa2e*/,  9 /*aa2f*/,  6 /*aa30*/,  7 /*aa31*/,
    7 /*aa32*/,  8 /*aa33*/,  7 /*aa34*/,  8 /*aa35*/,  8 /*aa36*/,
    9 /*aa37*/,  7 /*aa38*/,  8 /*aa39*/,  8 /*aa3a*/,  9 /*aa3b*/,
    8 /*aa3c*/,  9 /*aa3d*/,  9 /*aa3e*/,  10 /*aa3f*/, 5 /*aa40*/,
    6 /*aa41*/,  6 /*aa42*/,  7 /*aa43*/,  6 /*aa44*/,  7 /*aa45*/,
    7 /*aa46*/,  8 /*aa47*/,  6 /*aa48*/,  7 /*aa49*/,  7 /*aa4a*/,
    8 /*aa4b*/,  7 /*aa4c*/,  8 /*aa4d*/,  8 /*aa4e*/,  9 /*aa4f*/,
    6 /*aa50*/,  7 /*aa51*/,  7 /*aa52*/,  8 /*aa53*/,  7 /*aa54*/,
    8 /*aa55*/,  8 /*aa56*/,  9 /*aa57*/,  7 /*aa58*/,  8 /*aa59*/,
    8 /*aa5a*/,  9 /*aa5b*/,  8 /*aa5c*/,  9 /*aa5d*/,  9 /*aa5e*/,
    10 /*aa5f*/, 6 /*aa60*/,  7 /*aa61*/,  7 /*aa62*/,  8 /*aa63*/,
    7 /*aa64*/,  8 /*aa65*/,  8 /*aa66*/,  9 /*aa67*/,  7 /*aa68*/,
    8 /*aa69*/,  8 /*aa6a*/,  9 /*aa6b*/,  8 /*aa6c*/,  9 /*aa6d*/,
    9 /*aa6e*/,  10 /*aa6f*/, 7 /*aa70*/,  8 /*aa71*/,  8 /*aa72*/,
    9 /*aa73*/,  8 /*aa74*/,  9 /*aa75*/,  9 /*aa76*/,  10 /*aa77*/,
    8 /*aa78*/,  9 /*aa79*/,  9 /*aa7a*/,  10 /*aa7b*/, 9 /*aa7c*/,
    10 /*aa7d*/, 10 /*aa7e*/, 11 /*aa7f*/, 5 /*aa80*/,  6 /*aa81*/,
    6 /*aa82*/,  7 /*aa83*/,  6 /*aa84*/,  7 /*aa85*/,  7 /*aa86*/,
    8 /*aa87*/,  6 /*aa88*/,  7 /*aa89*/,  7 /*aa8a*/,  8 /*aa8b*/,
    7 /*aa8c*/,  8 /*aa8d*/,  8 /*aa8e*/,  9 /*aa8f*/,  6 /*aa90*/,
    7 /*aa91*/,  7 /*aa92*/,  8 /*aa93*/,  7 /*aa94*/,  8 /*aa95*/,
    8 /*aa96*/,  9 /*aa97*/,  7 /*aa98*/,  8 /*aa99*/,  8 /*aa9a*/,
    9 /*aa9b*/,  8 /*aa9c*/,  9 /*aa9d*/,  9 /*aa9e*/,  10 /*aa9f*/,
    6 /*aaa0*/,  7 /*aaa1*/,  7 /*aaa2*/,  8 /*aaa3*/,  7 /*aaa4*/,
    8 /*aaa5*/,  8 /*aaa6*/,  9 /*aaa7*/,  7 /*aaa8*/,  8 /*aaa9*/,
    8 /*aaaa*/,  9 /*aaab*/,  8 /*aaac*/,  9 /*aaad*/,  9 /*aaae*/,
    10 /*aaaf*/, 7 /*aab0*/,  8 /*aab1*/,  8 /*aab2*/,  9 /*aab3*/,
    8 /*aab4*/,  9 /*aab5*/,  9 /*aab6*/,  10 /*aab7*/, 8 /*aab8*/,
    9 /*aab9*/,  9 /*aaba*/,  10 /*aabb*/, 9 /*aabc*/,  10 /*aabd*/,
    10 /*aabe*/, 11 /*aabf*/, 6 /*aac0*/,  7 /*aac1*/,  7 /*aac2*/,
    8 /*aac3*/,  7 /*aac4*/,  8 /*aac5*/,  8 /*aac6*/,  9 /*aac7*/,
    7 /*aac8*/,  8 /*aac9*/,  8 /*aaca*/,  9 /*aacb*/,  8 /*aacc*/,
    9 /*aacd*/,  9 /*aace*/,  10 /*aacf*/, 7 /*aad0*/,  8 /*aad1*/,
    8 /*aad2*/,  9 /*aad3*/,  8 /*aad4*/,  9 /*aad5*/,  9 /*aad6*/,
    10 /*aad7*/, 8 /*aad8*/,  9 /*aad9*/,  9 /*aada*/,  10 /*aadb*/,
    9 /*aadc*/,  10 /*aadd*/, 10 /*aade*/, 11 /*aadf*/, 7 /*aae0*/,
    8 /*aae1*/,  8 /*aae2*/,  9 /*aae3*/,  8 /*aae4*/,  9 /*aae5*/,
    9 /*aae6*/,  10 /*aae7*/, 8 /*aae8*/,  9 /*aae9*/,  9 /*aaea*/,
    10 /*aaeb*/, 9 /*aaec*/,  10 /*aaed*/, 10 /*aaee*/, 11 /*aaef*/,
    8 /*aaf0*/,  9 /*aaf1*/,  9 /*aaf2*/,  10 /*aaf3*/, 9 /*aaf4*/,
    10 /*aaf5*/, 10 /*aaf6*/, 11 /*aaf7*/, 9 /*aaf8*/,  10 /*aaf9*/,
    10 /*aafa*/, 11 /*aafb*/, 10 /*aafc*/, 11 /*aafd*/, 11 /*aafe*/,
    12 /*aaff*/, 5 /*ab00*/,  6 /*ab01*/,  6 /*ab02*/,  7 /*ab03*/,
    6 /*ab04*/,  7 /*ab05*/,  7 /*ab06*/,  8 /*ab07*/,  6 /*ab08*/,
    7 /*ab09*/,  7 /*ab0a*/,  8 /*ab0b*/,  7 /*ab0c*/,  8 /*ab0d*/,
    8 /*ab0e*/,  9 /*ab0f*/,  6 /*ab10*/,  7 /*ab11*/,  7 /*ab12*/,
    8 /*ab13*/,  7 /*ab14*/,  8 /*ab15*/,  8 /*ab16*/,  9 /*ab17*/,
    7 /*ab18*/,  8 /*ab19*/,  8 /*ab1a*/,  9 /*ab1b*/,  8 /*ab1c*/,
    9 /*ab1d*/,  9 /*ab1e*/,  10 /*ab1f*/, 6 /*ab20*/,  7 /*ab21*/,
    7 /*ab22*/,  8 /*ab23*/,  7 /*ab24*/,  8 /*ab25*/,  8 /*ab26*/,
    9 /*ab27*/,  7 /*ab28*/,  8 /*ab29*/,  8 /*ab2a*/,  9 /*ab2b*/,
    8 /*ab2c*/,  9 /*ab2d*/,  9 /*ab2e*/,  10 /*ab2f*/, 7 /*ab30*/,
    8 /*ab31*/,  8 /*ab32*/,  9 /*ab33*/,  8 /*ab34*/,  9 /*ab35*/,
    9 /*ab36*/,  10 /*ab37*/, 8 /*ab38*/,  9 /*ab39*/,  9 /*ab3a*/,
    10 /*ab3b*/, 9 /*ab3c*/,  10 /*ab3d*/, 10 /*ab3e*/, 11 /*ab3f*/,
    6 /*ab40*/,  7 /*ab41*/,  7 /*ab42*/,  8 /*ab43*/,  7 /*ab44*/,
    8 /*ab45*/,  8 /*ab46*/,  9 /*ab47*/,  7 /*ab48*/,  8 /*ab49*/,
    8 /*ab4a*/,  9 /*ab4b*/,  8 /*ab4c*/,  9 /*ab4d*/,  9 /*ab4e*/,
    10 /*ab4f*/, 7 /*ab50*/,  8 /*ab51*/,  8 /*ab52*/,  9 /*ab53*/,
    8 /*ab54*/,  9 /*ab55*/,  9 /*ab56*/,  10 /*ab57*/, 8 /*ab58*/,
    9 /*ab59*/,  9 /*ab5a*/,  10 /*ab5b*/, 9 /*ab5c*/,  10 /*ab5d*/,
    10 /*ab5e*/, 11 /*ab5f*/, 7 /*ab60*/,  8 /*ab61*/,  8 /*ab62*/,
    9 /*ab63*/,  8 /*ab64*/,  9 /*ab65*/,  9 /*ab66*/,  10 /*ab67*/,
    8 /*ab68*/,  9 /*ab69*/,  9 /*ab6a*/,  10 /*ab6b*/, 9 /*ab6c*/,
    10 /*ab6d*/, 10 /*ab6e*/, 11 /*ab6f*/, 8 /*ab70*/,  9 /*ab71*/,
    9 /*ab72*/,  10 /*ab73*/, 9 /*ab74*/,  10 /*ab75*/, 10 /*ab76*/,
    11 /*ab77*/, 9 /*ab78*/,  10 /*ab79*/, 10 /*ab7a*/, 11 /*ab7b*/,
    10 /*ab7c*/, 11 /*ab7d*/, 11 /*ab7e*/, 12 /*ab7f*/, 6 /*ab80*/,
    7 /*ab81*/,  7 /*ab82*/,  8 /*ab83*/,  7 /*ab84*/,  8 /*ab85*/,
    8 /*ab86*/,  9 /*ab87*/,  7 /*ab88*/,  8 /*ab89*/,  8 /*ab8a*/,
    9 /*ab8b*/,  8 /*ab8c*/,  9 /*ab8d*/,  9 /*ab8e*/,  10 /*ab8f*/,
    7 /*ab90*/,  8 /*ab91*/,  8 /*ab92*/,  9 /*ab93*/,  8 /*ab94*/,
    9 /*ab95*/,  9 /*ab96*/,  10 /*ab97*/, 8 /*ab98*/,  9 /*ab99*/,
    9 /*ab9a*/,  10 /*ab9b*/, 9 /*ab9c*/,  10 /*ab9d*/, 10 /*ab9e*/,
    11 /*ab9f*/, 7 /*aba0*/,  8 /*aba1*/,  8 /*aba2*/,  9 /*aba3*/,
    8 /*aba4*/,  9 /*aba5*/,  9 /*aba6*/,  10 /*aba7*/, 8 /*aba8*/,
    9 /*aba9*/,  9 /*abaa*/,  10 /*abab*/, 9 /*abac*/,  10 /*abad*/,
    10 /*abae*/, 11 /*abaf*/, 8 /*abb0*/,  9 /*abb1*/,  9 /*abb2*/,
    10 /*abb3*/, 9 /*abb4*/,  10 /*abb5*/, 10 /*abb6*/, 11 /*abb7*/,
    9 /*abb8*/,  10 /*abb9*/, 10 /*abba*/, 11 /*abbb*/, 10 /*abbc*/,
    11 /*abbd*/, 11 /*abbe*/, 12 /*abbf*/, 7 /*abc0*/,  8 /*abc1*/,
    8 /*abc2*/,  9 /*abc3*/,  8 /*abc4*/,  9 /*abc5*/,  9 /*abc6*/,
    10 /*abc7*/, 8 /*abc8*/,  9 /*abc9*/,  9 /*abca*/,  10 /*abcb*/,
    9 /*abcc*/,  10 /*abcd*/, 10 /*abce*/, 11 /*abcf*/, 8 /*abd0*/,
    9 /*abd1*/,  9 /*abd2*/,  10 /*abd3*/, 9 /*abd4*/,  10 /*abd5*/,
    10 /*abd6*/, 11 /*abd7*/, 9 /*abd8*/,  10 /*abd9*/, 10 /*abda*/,
    11 /*abdb*/, 10 /*abdc*/, 11 /*abdd*/, 11 /*abde*/, 12 /*abdf*/,
    8 /*abe0*/,  9 /*abe1*/,  9 /*abe2*/,  10 /*abe3*/, 9 /*abe4*/,
    10 /*abe5*/, 10 /*abe6*/, 11 /*abe7*/, 9 /*abe8*/,  10 /*abe9*/,
    10 /*abea*/, 11 /*abeb*/, 10 /*abec*/, 11 /*abed*/, 11 /*abee*/,
    12 /*abef*/, 9 /*abf0*/,  10 /*abf1*/, 10 /*abf2*/, 11 /*abf3*/,
    10 /*abf4*/, 11 /*abf5*/, 11 /*abf6*/, 12 /*abf7*/, 10 /*abf8*/,
    11 /*abf9*/, 11 /*abfa*/, 12 /*abfb*/, 11 /*abfc*/, 12 /*abfd*/,
    12 /*abfe*/, 13 /*abff*/, 4 /*ac00*/,  5 /*ac01*/,  5 /*ac02*/,
    6 /*ac03*/,  5 /*ac04*/,  6 /*ac05*/,  6 /*ac06*/,  7 /*ac07*/,
    5 /*ac08*/,  6 /*ac09*/,  6 /*ac0a*/,  7 /*ac0b*/,  6 /*ac0c*/,
    7 /*ac0d*/,  7 /*ac0e*/,  8 /*ac0f*/,  5 /*ac10*/,  6 /*ac11*/,
    6 /*ac12*/,  7 /*ac13*/,  6 /*ac14*/,  7 /*ac15*/,  7 /*ac16*/,
    8 /*ac17*/,  6 /*ac18*/,  7 /*ac19*/,  7 /*ac1a*/,  8 /*ac1b*/,
    7 /*ac1c*/,  8 /*ac1d*/,  8 /*ac1e*/,  9 /*ac1f*/,  5 /*ac20*/,
    6 /*ac21*/,  6 /*ac22*/,  7 /*ac23*/,  6 /*ac24*/,  7 /*ac25*/,
    7 /*ac26*/,  8 /*ac27*/,  6 /*ac28*/,  7 /*ac29*/,  7 /*ac2a*/,
    8 /*ac2b*/,  7 /*ac2c*/,  8 /*ac2d*/,  8 /*ac2e*/,  9 /*ac2f*/,
    6 /*ac30*/,  7 /*ac31*/,  7 /*ac32*/,  8 /*ac33*/,  7 /*ac34*/,
    8 /*ac35*/,  8 /*ac36*/,  9 /*ac37*/,  7 /*ac38*/,  8 /*ac39*/,
    8 /*ac3a*/,  9 /*ac3b*/,  8 /*ac3c*/,  9 /*ac3d*/,  9 /*ac3e*/,
    10 /*ac3f*/, 5 /*ac40*/,  6 /*ac41*/,  6 /*ac42*/,  7 /*ac43*/,
    6 /*ac44*/,  7 /*ac45*/,  7 /*ac46*/,  8 /*ac47*/,  6 /*ac48*/,
    7 /*ac49*/,  7 /*ac4a*/,  8 /*ac4b*/,  7 /*ac4c*/,  8 /*ac4d*/,
    8 /*ac4e*/,  9 /*ac4f*/,  6 /*ac50*/,  7 /*ac51*/,  7 /*ac52*/,
    8 /*ac53*/,  7 /*ac54*/,  8 /*ac55*/,  8 /*ac56*/,  9 /*ac57*/,
    7 /*ac58*/,  8 /*ac59*/,  8 /*ac5a*/,  9 /*ac5b*/,  8 /*ac5c*/,
    9 /*ac5d*/,  9 /*ac5e*/,  10 /*ac5f*/, 6 /*ac60*/,  7 /*ac61*/,
    7 /*ac62*/,  8 /*ac63*/,  7 /*ac64*/,  8 /*ac65*/,  8 /*ac66*/,
    9 /*ac67*/,  7 /*ac68*/,  8 /*ac69*/,  8 /*ac6a*/,  9 /*ac6b*/,
    8 /*ac6c*/,  9 /*ac6d*/,  9 /*ac6e*/,  10 /*ac6f*/, 7 /*ac70*/,
    8 /*ac71*/,  8 /*ac72*/,  9 /*ac73*/,  8 /*ac74*/,  9 /*ac75*/,
    9 /*ac76*/,  10 /*ac77*/, 8 /*ac78*/,  9 /*ac79*/,  9 /*ac7a*/,
    10 /*ac7b*/, 9 /*ac7c*/,  10 /*ac7d*/, 10 /*ac7e*/, 11 /*ac7f*/,
    5 /*ac80*/,  6 /*ac81*/,  6 /*ac82*/,  7 /*ac83*/,  6 /*ac84*/,
    7 /*ac85*/,  7 /*ac86*/,  8 /*ac87*/,  6 /*ac88*/,  7 /*ac89*/,
    7 /*ac8a*/,  8 /*ac8b*/,  7 /*ac8c*/,  8 /*ac8d*/,  8 /*ac8e*/,
    9 /*ac8f*/,  6 /*ac90*/,  7 /*ac91*/,  7 /*ac92*/,  8 /*ac93*/,
    7 /*ac94*/,  8 /*ac95*/,  8 /*ac96*/,  9 /*ac97*/,  7 /*ac98*/,
    8 /*ac99*/,  8 /*ac9a*/,  9 /*ac9b*/,  8 /*ac9c*/,  9 /*ac9d*/,
    9 /*ac9e*/,  10 /*ac9f*/, 6 /*aca0*/,  7 /*aca1*/,  7 /*aca2*/,
    8 /*aca3*/,  7 /*aca4*/,  8 /*aca5*/,  8 /*aca6*/,  9 /*aca7*/,
    7 /*aca8*/,  8 /*aca9*/,  8 /*acaa*/,  9 /*acab*/,  8 /*acac*/,
    9 /*acad*/,  9 /*acae*/,  10 /*acaf*/, 7 /*acb0*/,  8 /*acb1*/,
    8 /*acb2*/,  9 /*acb3*/,  8 /*acb4*/,  9 /*acb5*/,  9 /*acb6*/,
    10 /*acb7*/, 8 /*acb8*/,  9 /*acb9*/,  9 /*acba*/,  10 /*acbb*/,
    9 /*acbc*/,  10 /*acbd*/, 10 /*acbe*/, 11 /*acbf*/, 6 /*acc0*/,
    7 /*acc1*/,  7 /*acc2*/,  8 /*acc3*/,  7 /*acc4*/,  8 /*acc5*/,
    8 /*acc6*/,  9 /*acc7*/,  7 /*acc8*/,  8 /*acc9*/,  8 /*acca*/,
    9 /*accb*/,  8 /*accc*/,  9 /*accd*/,  9 /*acce*/,  10 /*accf*/,
    7 /*acd0*/,  8 /*acd1*/,  8 /*acd2*/,  9 /*acd3*/,  8 /*acd4*/,
    9 /*acd5*/,  9 /*acd6*/,  10 /*acd7*/, 8 /*acd8*/,  9 /*acd9*/,
    9 /*acda*/,  10 /*acdb*/, 9 /*acdc*/,  10 /*acdd*/, 10 /*acde*/,
    11 /*acdf*/, 7 /*ace0*/,  8 /*ace1*/,  8 /*ace2*/,  9 /*ace3*/,
    8 /*ace4*/,  9 /*ace5*/,  9 /*ace6*/,  10 /*ace7*/, 8 /*ace8*/,
    9 /*ace9*/,  9 /*acea*/,  10 /*aceb*/, 9 /*acec*/,  10 /*aced*/,
    10 /*acee*/, 11 /*acef*/, 8 /*acf0*/,  9 /*acf1*/,  9 /*acf2*/,
    10 /*acf3*/, 9 /*acf4*/,  10 /*acf5*/, 10 /*acf6*/, 11 /*acf7*/,
    9 /*acf8*/,  10 /*acf9*/, 10 /*acfa*/, 11 /*acfb*/, 10 /*acfc*/,
    11 /*acfd*/, 11 /*acfe*/, 12 /*acff*/, 5 /*ad00*/,  6 /*ad01*/,
    6 /*ad02*/,  7 /*ad03*/,  6 /*ad04*/,  7 /*ad05*/,  7 /*ad06*/,
    8 /*ad07*/,  6 /*ad08*/,  7 /*ad09*/,  7 /*ad0a*/,  8 /*ad0b*/,
    7 /*ad0c*/,  8 /*ad0d*/,  8 /*ad0e*/,  9 /*ad0f*/,  6 /*ad10*/,
    7 /*ad11*/,  7 /*ad12*/,  8 /*ad13*/,  7 /*ad14*/,  8 /*ad15*/,
    8 /*ad16*/,  9 /*ad17*/,  7 /*ad18*/,  8 /*ad19*/,  8 /*ad1a*/,
    9 /*ad1b*/,  8 /*ad1c*/,  9 /*ad1d*/,  9 /*ad1e*/,  10 /*ad1f*/,
    6 /*ad20*/,  7 /*ad21*/,  7 /*ad22*/,  8 /*ad23*/,  7 /*ad24*/,
    8 /*ad25*/,  8 /*ad26*/,  9 /*ad27*/,  7 /*ad28*/,  8 /*ad29*/,
    8 /*ad2a*/,  9 /*ad2b*/,  8 /*ad2c*/,  9 /*ad2d*/,  9 /*ad2e*/,
    10 /*ad2f*/, 7 /*ad30*/,  8 /*ad31*/,  8 /*ad32*/,  9 /*ad33*/,
    8 /*ad34*/,  9 /*ad35*/,  9 /*ad36*/,  10 /*ad37*/, 8 /*ad38*/,
    9 /*ad39*/,  9 /*ad3a*/,  10 /*ad3b*/, 9 /*ad3c*/,  10 /*ad3d*/,
    10 /*ad3e*/, 11 /*ad3f*/, 6 /*ad40*/,  7 /*ad41*/,  7 /*ad42*/,
    8 /*ad43*/,  7 /*ad44*/,  8 /*ad45*/,  8 /*ad46*/,  9 /*ad47*/,
    7 /*ad48*/,  8 /*ad49*/,  8 /*ad4a*/,  9 /*ad4b*/,  8 /*ad4c*/,
    9 /*ad4d*/,  9 /*ad4e*/,  10 /*ad4f*/, 7 /*ad50*/,  8 /*ad51*/,
    8 /*ad52*/,  9 /*ad53*/,  8 /*ad54*/,  9 /*ad55*/,  9 /*ad56*/,
    10 /*ad57*/, 8 /*ad58*/,  9 /*ad59*/,  9 /*ad5a*/,  10 /*ad5b*/,
    9 /*ad5c*/,  10 /*ad5d*/, 10 /*ad5e*/, 11 /*ad5f*/, 7 /*ad60*/,
    8 /*ad61*/,  8 /*ad62*/,  9 /*ad63*/,  8 /*ad64*/,  9 /*ad65*/,
    9 /*ad66*/,  10 /*ad67*/, 8 /*ad68*/,  9 /*ad69*/,  9 /*ad6a*/,
    10 /*ad6b*/, 9 /*ad6c*/,  10 /*ad6d*/, 10 /*ad6e*/, 11 /*ad6f*/,
    8 /*ad70*/,  9 /*ad71*/,  9 /*ad72*/,  10 /*ad73*/, 9 /*ad74*/,
    10 /*ad75*/, 10 /*ad76*/, 11 /*ad77*/, 9 /*ad78*/,  10 /*ad79*/,
    10 /*ad7a*/, 11 /*ad7b*/, 10 /*ad7c*/, 11 /*ad7d*/, 11 /*ad7e*/,
    12 /*ad7f*/, 6 /*ad80*/,  7 /*ad81*/,  7 /*ad82*/,  8 /*ad83*/,
    7 /*ad84*/,  8 /*ad85*/,  8 /*ad86*/,  9 /*ad87*/,  7 /*ad88*/,
    8 /*ad89*/,  8 /*ad8a*/,  9 /*ad8b*/,  8 /*ad8c*/,  9 /*ad8d*/,
    9 /*ad8e*/,  10 /*ad8f*/, 7 /*ad90*/,  8 /*ad91*/,  8 /*ad92*/,
    9 /*ad93*/,  8 /*ad94*/,  9 /*ad95*/,  9 /*ad96*/,  10 /*ad97*/,
    8 /*ad98*/,  9 /*ad99*/,  9 /*ad9a*/,  10 /*ad9b*/, 9 /*ad9c*/,
    10 /*ad9d*/, 10 /*ad9e*/, 11 /*ad9f*/, 7 /*ada0*/,  8 /*ada1*/,
    8 /*ada2*/,  9 /*ada3*/,  8 /*ada4*/,  9 /*ada5*/,  9 /*ada6*/,
    10 /*ada7*/, 8 /*ada8*/,  9 /*ada9*/,  9 /*adaa*/,  10 /*adab*/,
    9 /*adac*/,  10 /*adad*/, 10 /*adae*/, 11 /*adaf*/, 8 /*adb0*/,
    9 /*adb1*/,  9 /*adb2*/,  10 /*adb3*/, 9 /*adb4*/,  10 /*adb5*/,
    10 /*adb6*/, 11 /*adb7*/, 9 /*adb8*/,  10 /*adb9*/, 10 /*adba*/,
    11 /*adbb*/, 10 /*adbc*/, 11 /*adbd*/, 11 /*adbe*/, 12 /*adbf*/,
    7 /*adc0*/,  8 /*adc1*/,  8 /*adc2*/,  9 /*adc3*/,  8 /*adc4*/,
    9 /*adc5*/,  9 /*adc6*/,  10 /*adc7*/, 8 /*adc8*/,  9 /*adc9*/,
    9 /*adca*/,  10 /*adcb*/, 9 /*adcc*/,  10 /*adcd*/, 10 /*adce*/,
    11 /*adcf*/, 8 /*add0*/,  9 /*add1*/,  9 /*add2*/,  10 /*add3*/,
    9 /*add4*/,  10 /*add5*/, 10 /*add6*/, 11 /*add7*/, 9 /*add8*/,
    10 /*add9*/, 10 /*adda*/, 11 /*addb*/, 10 /*addc*/, 11 /*addd*/,
    11 /*adde*/, 12 /*addf*/, 8 /*ade0*/,  9 /*ade1*/,  9 /*ade2*/,
    10 /*ade3*/, 9 /*ade4*/,  10 /*ade5*/, 10 /*ade6*/, 11 /*ade7*/,
    9 /*ade8*/,  10 /*ade9*/, 10 /*adea*/, 11 /*adeb*/, 10 /*adec*/,
    11 /*aded*/, 11 /*adee*/, 12 /*adef*/, 9 /*adf0*/,  10 /*adf1*/,
    10 /*adf2*/, 11 /*adf3*/, 10 /*adf4*/, 11 /*adf5*/, 11 /*adf6*/,
    12 /*adf7*/, 10 /*adf8*/, 11 /*adf9*/, 11 /*adfa*/, 12 /*adfb*/,
    11 /*adfc*/, 12 /*adfd*/, 12 /*adfe*/, 13 /*adff*/, 5 /*ae00*/,
    6 /*ae01*/,  6 /*ae02*/,  7 /*ae03*/,  6 /*ae04*/,  7 /*ae05*/,
    7 /*ae06*/,  8 /*ae07*/,  6 /*ae08*/,  7 /*ae09*/,  7 /*ae0a*/,
    8 /*ae0b*/,  7 /*ae0c*/,  8 /*ae0d*/,  8 /*ae0e*/,  9 /*ae0f*/,
    6 /*ae10*/,  7 /*ae11*/,  7 /*ae12*/,  8 /*ae13*/,  7 /*ae14*/,
    8 /*ae15*/,  8 /*ae16*/,  9 /*ae17*/,  7 /*ae18*/,  8 /*ae19*/,
    8 /*ae1a*/,  9 /*ae1b*/,  8 /*ae1c*/,  9 /*ae1d*/,  9 /*ae1e*/,
    10 /*ae1f*/, 6 /*ae20*/,  7 /*ae21*/,  7 /*ae22*/,  8 /*ae23*/,
    7 /*ae24*/,  8 /*ae25*/,  8 /*ae26*/,  9 /*ae27*/,  7 /*ae28*/,
    8 /*ae29*/,  8 /*ae2a*/,  9 /*ae2b*/,  8 /*ae2c*/,  9 /*ae2d*/,
    9 /*ae2e*/,  10 /*ae2f*/, 7 /*ae30*/,  8 /*ae31*/,  8 /*ae32*/,
    9 /*ae33*/,  8 /*ae34*/,  9 /*ae35*/,  9 /*ae36*/,  10 /*ae37*/,
    8 /*ae38*/,  9 /*ae39*/,  9 /*ae3a*/,  10 /*ae3b*/, 9 /*ae3c*/,
    10 /*ae3d*/, 10 /*ae3e*/, 11 /*ae3f*/, 6 /*ae40*/,  7 /*ae41*/,
    7 /*ae42*/,  8 /*ae43*/,  7 /*ae44*/,  8 /*ae45*/,  8 /*ae46*/,
    9 /*ae47*/,  7 /*ae48*/,  8 /*ae49*/,  8 /*ae4a*/,  9 /*ae4b*/,
    8 /*ae4c*/,  9 /*ae4d*/,  9 /*ae4e*/,  10 /*ae4f*/, 7 /*ae50*/,
    8 /*ae51*/,  8 /*ae52*/,  9 /*ae53*/,  8 /*ae54*/,  9 /*ae55*/,
    9 /*ae56*/,  10 /*ae57*/, 8 /*ae58*/,  9 /*ae59*/,  9 /*ae5a*/,
    10 /*ae5b*/, 9 /*ae5c*/,  10 /*ae5d*/, 10 /*ae5e*/, 11 /*ae5f*/,
    7 /*ae60*/,  8 /*ae61*/,  8 /*ae62*/,  9 /*ae63*/,  8 /*ae64*/,
    9 /*ae65*/,  9 /*ae66*/,  10 /*ae67*/, 8 /*ae68*/,  9 /*ae69*/,
    9 /*ae6a*/,  10 /*ae6b*/, 9 /*ae6c*/,  10 /*ae6d*/, 10 /*ae6e*/,
    11 /*ae6f*/, 8 /*ae70*/,  9 /*ae71*/,  9 /*ae72*/,  10 /*ae73*/,
    9 /*ae74*/,  10 /*ae75*/, 10 /*ae76*/, 11 /*ae77*/, 9 /*ae78*/,
    10 /*ae79*/, 10 /*ae7a*/, 11 /*ae7b*/, 10 /*ae7c*/, 11 /*ae7d*/,
    11 /*ae7e*/, 12 /*ae7f*/, 6 /*ae80*/,  7 /*ae81*/,  7 /*ae82*/,
    8 /*ae83*/,  7 /*ae84*/,  8 /*ae85*/,  8 /*ae86*/,  9 /*ae87*/,
    7 /*ae88*/,  8 /*ae89*/,  8 /*ae8a*/,  9 /*ae8b*/,  8 /*ae8c*/,
    9 /*ae8d*/,  9 /*ae8e*/,  10 /*ae8f*/, 7 /*ae90*/,  8 /*ae91*/,
    8 /*ae92*/,  9 /*ae93*/,  8 /*ae94*/,  9 /*ae95*/,  9 /*ae96*/,
    10 /*ae97*/, 8 /*ae98*/,  9 /*ae99*/,  9 /*ae9a*/,  10 /*ae9b*/,
    9 /*ae9c*/,  10 /*ae9d*/, 10 /*ae9e*/, 11 /*ae9f*/, 7 /*aea0*/,
    8 /*aea1*/,  8 /*aea2*/,  9 /*aea3*/,  8 /*aea4*/,  9 /*aea5*/,
    9 /*aea6*/,  10 /*aea7*/, 8 /*aea8*/,  9 /*aea9*/,  9 /*aeaa*/,
    10 /*aeab*/, 9 /*aeac*/,  10 /*aead*/, 10 /*aeae*/, 11 /*aeaf*/,
    8 /*aeb0*/,  9 /*aeb1*/,  9 /*aeb2*/,  10 /*aeb3*/, 9 /*aeb4*/,
    10 /*aeb5*/, 10 /*aeb6*/, 11 /*aeb7*/, 9 /*aeb8*/,  10 /*aeb9*/,
    10 /*aeba*/, 11 /*aebb*/, 10 /*aebc*/, 11 /*aebd*/, 11 /*aebe*/,
    12 /*aebf*/, 7 /*aec0*/,  8 /*aec1*/,  8 /*aec2*/,  9 /*aec3*/,
    8 /*aec4*/,  9 /*aec5*/,  9 /*aec6*/,  10 /*aec7*/, 8 /*aec8*/,
    9 /*aec9*/,  9 /*aeca*/,  10 /*aecb*/, 9 /*aecc*/,  10 /*aecd*/,
    10 /*aece*/, 11 /*aecf*/, 8 /*aed0*/,  9 /*aed1*/,  9 /*aed2*/,
    10 /*aed3*/, 9 /*aed4*/,  10 /*aed5*/, 10 /*aed6*/, 11 /*aed7*/,
    9 /*aed8*/,  10 /*aed9*/, 10 /*aeda*/, 11 /*aedb*/, 10 /*aedc*/,
    11 /*aedd*/, 11 /*aede*/, 12 /*aedf*/, 8 /*aee0*/,  9 /*aee1*/,
    9 /*aee2*/,  10 /*aee3*/, 9 /*aee4*/,  10 /*aee5*/, 10 /*aee6*/,
    11 /*aee7*/, 9 /*aee8*/,  10 /*aee9*/, 10 /*aeea*/, 11 /*aeeb*/,
    10 /*aeec*/, 11 /*aeed*/, 11 /*aeee*/, 12 /*aeef*/, 9 /*aef0*/,
    10 /*aef1*/, 10 /*aef2*/, 11 /*aef3*/, 10 /*aef4*/, 11 /*aef5*/,
    11 /*aef6*/, 12 /*aef7*/, 10 /*aef8*/, 11 /*aef9*/, 11 /*aefa*/,
    12 /*aefb*/, 11 /*aefc*/, 12 /*aefd*/, 12 /*aefe*/, 13 /*aeff*/,
    6 /*af00*/,  7 /*af01*/,  7 /*af02*/,  8 /*af03*/,  7 /*af04*/,
    8 /*af05*/,  8 /*af06*/,  9 /*af07*/,  7 /*af08*/,  8 /*af09*/,
    8 /*af0a*/,  9 /*af0b*/,  8 /*af0c*/,  9 /*af0d*/,  9 /*af0e*/,
    10 /*af0f*/, 7 /*af10*/,  8 /*af11*/,  8 /*af12*/,  9 /*af13*/,
    8 /*af14*/,  9 /*af15*/,  9 /*af16*/,  10 /*af17*/, 8 /*af18*/,
    9 /*af19*/,  9 /*af1a*/,  10 /*af1b*/, 9 /*af1c*/,  10 /*af1d*/,
    10 /*af1e*/, 11 /*af1f*/, 7 /*af20*/,  8 /*af21*/,  8 /*af22*/,
    9 /*af23*/,  8 /*af24*/,  9 /*af25*/,  9 /*af26*/,  10 /*af27*/,
    8 /*af28*/,  9 /*af29*/,  9 /*af2a*/,  10 /*af2b*/, 9 /*af2c*/,
    10 /*af2d*/, 10 /*af2e*/, 11 /*af2f*/, 8 /*af30*/,  9 /*af31*/,
    9 /*af32*/,  10 /*af33*/, 9 /*af34*/,  10 /*af35*/, 10 /*af36*/,
    11 /*af37*/, 9 /*af38*/,  10 /*af39*/, 10 /*af3a*/, 11 /*af3b*/,
    10 /*af3c*/, 11 /*af3d*/, 11 /*af3e*/, 12 /*af3f*/, 7 /*af40*/,
    8 /*af41*/,  8 /*af42*/,  9 /*af43*/,  8 /*af44*/,  9 /*af45*/,
    9 /*af46*/,  10 /*af47*/, 8 /*af48*/,  9 /*af49*/,  9 /*af4a*/,
    10 /*af4b*/, 9 /*af4c*/,  10 /*af4d*/, 10 /*af4e*/, 11 /*af4f*/,
    8 /*af50*/,  9 /*af51*/,  9 /*af52*/,  10 /*af53*/, 9 /*af54*/,
    10 /*af55*/, 10 /*af56*/, 11 /*af57*/, 9 /*af58*/,  10 /*af59*/,
    10 /*af5a*/, 11 /*af5b*/, 10 /*af5c*/, 11 /*af5d*/, 11 /*af5e*/,
    12 /*af5f*/, 8 /*af60*/,  9 /*af61*/,  9 /*af62*/,  10 /*af63*/,
    9 /*af64*/,  10 /*af65*/, 10 /*af66*/, 11 /*af67*/, 9 /*af68*/,
    10 /*af69*/, 10 /*af6a*/, 11 /*af6b*/, 10 /*af6c*/, 11 /*af6d*/,
    11 /*af6e*/, 12 /*af6f*/, 9 /*af70*/,  10 /*af71*/, 10 /*af72*/,
    11 /*af73*/, 10 /*af74*/, 11 /*af75*/, 11 /*af76*/, 12 /*af77*/,
    10 /*af78*/, 11 /*af79*/, 11 /*af7a*/, 12 /*af7b*/, 11 /*af7c*/,
    12 /*af7d*/, 12 /*af7e*/, 13 /*af7f*/, 7 /*af80*/,  8 /*af81*/,
    8 /*af82*/,  9 /*af83*/,  8 /*af84*/,  9 /*af85*/,  9 /*af86*/,
    10 /*af87*/, 8 /*af88*/,  9 /*af89*/,  9 /*af8a*/,  10 /*af8b*/,
    9 /*af8c*/,  10 /*af8d*/, 10 /*af8e*/, 11 /*af8f*/, 8 /*af90*/,
    9 /*af91*/,  9 /*af92*/,  10 /*af93*/, 9 /*af94*/,  10 /*af95*/,
    10 /*af96*/, 11 /*af97*/, 9 /*af98*/,  10 /*af99*/, 10 /*af9a*/,
    11 /*af9b*/, 10 /*af9c*/, 11 /*af9d*/, 11 /*af9e*/, 12 /*af9f*/,
    8 /*afa0*/,  9 /*afa1*/,  9 /*afa2*/,  10 /*afa3*/, 9 /*afa4*/,
    10 /*afa5*/, 10 /*afa6*/, 11 /*afa7*/, 9 /*afa8*/,  10 /*afa9*/,
    10 /*afaa*/, 11 /*afab*/, 10 /*afac*/, 11 /*afad*/, 11 /*afae*/,
    12 /*afaf*/, 9 /*afb0*/,  10 /*afb1*/, 10 /*afb2*/, 11 /*afb3*/,
    10 /*afb4*/, 11 /*afb5*/, 11 /*afb6*/, 12 /*afb7*/, 10 /*afb8*/,
    11 /*afb9*/, 11 /*afba*/, 12 /*afbb*/, 11 /*afbc*/, 12 /*afbd*/,
    12 /*afbe*/, 13 /*afbf*/, 8 /*afc0*/,  9 /*afc1*/,  9 /*afc2*/,
    10 /*afc3*/, 9 /*afc4*/,  10 /*afc5*/, 10 /*afc6*/, 11 /*afc7*/,
    9 /*afc8*/,  10 /*afc9*/, 10 /*afca*/, 11 /*afcb*/, 10 /*afcc*/,
    11 /*afcd*/, 11 /*afce*/, 12 /*afcf*/, 9 /*afd0*/,  10 /*afd1*/,
    10 /*afd2*/, 11 /*afd3*/, 10 /*afd4*/, 11 /*afd5*/, 11 /*afd6*/,
    12 /*afd7*/, 10 /*afd8*/, 11 /*afd9*/, 11 /*afda*/, 12 /*afdb*/,
    11 /*afdc*/, 12 /*afdd*/, 12 /*afde*/, 13 /*afdf*/, 9 /*afe0*/,
    10 /*afe1*/, 10 /*afe2*/, 11 /*afe3*/, 10 /*afe4*/, 11 /*afe5*/,
    11 /*afe6*/, 12 /*afe7*/, 10 /*afe8*/, 11 /*afe9*/, 11 /*afea*/,
    12 /*afeb*/, 11 /*afec*/, 12 /*afed*/, 12 /*afee*/, 13 /*afef*/,
    10 /*aff0*/, 11 /*aff1*/, 11 /*aff2*/, 12 /*aff3*/, 11 /*aff4*/,
    12 /*aff5*/, 12 /*aff6*/, 13 /*aff7*/, 11 /*aff8*/, 12 /*aff9*/,
    12 /*affa*/, 13 /*affb*/, 12 /*affc*/, 13 /*affd*/, 13 /*affe*/,
    14 /*afff*/, 3 /*b000*/,  4 /*b001*/,  4 /*b002*/,  5 /*b003*/,
    4 /*b004*/,  5 /*b005*/,  5 /*b006*/,  6 /*b007*/,  4 /*b008*/,
    5 /*b009*/,  5 /*b00a*/,  6 /*b00b*/,  5 /*b00c*/,  6 /*b00d*/,
    6 /*b00e*/,  7 /*b00f*/,  4 /*b010*/,  5 /*b011*/,  5 /*b012*/,
    6 /*b013*/,  5 /*b014*/,  6 /*b015*/,  6 /*b016*/,  7 /*b017*/,
    5 /*b018*/,  6 /*b019*/,  6 /*b01a*/,  7 /*b01b*/,  6 /*b01c*/,
    7 /*b01d*/,  7 /*b01e*/,  8 /*b01f*/,  4 /*b020*/,  5 /*b021*/,
    5 /*b022*/,  6 /*b023*/,  5 /*b024*/,  6 /*b025*/,  6 /*b026*/,
    7 /*b027*/,  5 /*b028*/,  6 /*b029*/,  6 /*b02a*/,  7 /*b02b*/,
    6 /*b02c*/,  7 /*b02d*/,  7 /*b02e*/,  8 /*b02f*/,  5 /*b030*/,
    6 /*b031*/,  6 /*b032*/,  7 /*b033*/,  6 /*b034*/,  7 /*b035*/,
    7 /*b036*/,  8 /*b037*/,  6 /*b038*/,  7 /*b039*/,  7 /*b03a*/,
    8 /*b03b*/,  7 /*b03c*/,  8 /*b03d*/,  8 /*b03e*/,  9 /*b03f*/,
    4 /*b040*/,  5 /*b041*/,  5 /*b042*/,  6 /*b043*/,  5 /*b044*/,
    6 /*b045*/,  6 /*b046*/,  7 /*b047*/,  5 /*b048*/,  6 /*b049*/,
    6 /*b04a*/,  7 /*b04b*/,  6 /*b04c*/,  7 /*b04d*/,  7 /*b04e*/,
    8 /*b04f*/,  5 /*b050*/,  6 /*b051*/,  6 /*b052*/,  7 /*b053*/,
    6 /*b054*/,  7 /*b055*/,  7 /*b056*/,  8 /*b057*/,  6 /*b058*/,
    7 /*b059*/,  7 /*b05a*/,  8 /*b05b*/,  7 /*b05c*/,  8 /*b05d*/,
    8 /*b05e*/,  9 /*b05f*/,  5 /*b060*/,  6 /*b061*/,  6 /*b062*/,
    7 /*b063*/,  6 /*b064*/,  7 /*b065*/,  7 /*b066*/,  8 /*b067*/,
    6 /*b068*/,  7 /*b069*/,  7 /*b06a*/,  8 /*b06b*/,  7 /*b06c*/,
    8 /*b06d*/,  8 /*b06e*/,  9 /*b06f*/,  6 /*b070*/,  7 /*b071*/,
    7 /*b072*/,  8 /*b073*/,  7 /*b074*/,  8 /*b075*/,  8 /*b076*/,
    9 /*b077*/,  7 /*b078*/,  8 /*b079*/,  8 /*b07a*/,  9 /*b07b*/,
    8 /*b07c*/,  9 /*b07d*/,  9 /*b07e*/,  10 /*b07f*/, 4 /*b080*/,
    5 /*b081*/,  5 /*b082*/,  6 /*b083*/,  5 /*b084*/,  6 /*b085*/,
    6 /*b086*/,  7 /*b087*/,  5 /*b088*/,  6 /*b089*/,  6 /*b08a*/,
    7 /*b08b*/,  6 /*b08c*/,  7 /*b08d*/,  7 /*b08e*/,  8 /*b08f*/,
    5 /*b090*/,  6 /*b091*/,  6 /*b092*/,  7 /*b093*/,  6 /*b094*/,
    7 /*b095*/,  7 /*b096*/,  8 /*b097*/,  6 /*b098*/,  7 /*b099*/,
    7 /*b09a*/,  8 /*b09b*/,  7 /*b09c*/,  8 /*b09d*/,  8 /*b09e*/,
    9 /*b09f*/,  5 /*b0a0*/,  6 /*b0a1*/,  6 /*b0a2*/,  7 /*b0a3*/,
    6 /*b0a4*/,  7 /*b0a5*/,  7 /*b0a6*/,  8 /*b0a7*/,  6 /*b0a8*/,
    7 /*b0a9*/,  7 /*b0aa*/,  8 /*b0ab*/,  7 /*b0ac*/,  8 /*b0ad*/,
    8 /*b0ae*/,  9 /*b0af*/,  6 /*b0b0*/,  7 /*b0b1*/,  7 /*b0b2*/,
    8 /*b0b3*/,  7 /*b0b4*/,  8 /*b0b5*/,  8 /*b0b6*/,  9 /*b0b7*/,
    7 /*b0b8*/,  8 /*b0b9*/,  8 /*b0ba*/,  9 /*b0bb*/,  8 /*b0bc*/,
    9 /*b0bd*/,  9 /*b0be*/,  10 /*b0bf*/, 5 /*b0c0*/,  6 /*b0c1*/,
    6 /*b0c2*/,  7 /*b0c3*/,  6 /*b0c4*/,  7 /*b0c5*/,  7 /*b0c6*/,
    8 /*b0c7*/,  6 /*b0c8*/,  7 /*b0c9*/,  7 /*b0ca*/,  8 /*b0cb*/,
    7 /*b0cc*/,  8 /*b0cd*/,  8 /*b0ce*/,  9 /*b0cf*/,  6 /*b0d0*/,
    7 /*b0d1*/,  7 /*b0d2*/,  8 /*b0d3*/,  7 /*b0d4*/,  8 /*b0d5*/,
    8 /*b0d6*/,  9 /*b0d7*/,  7 /*b0d8*/,  8 /*b0d9*/,  8 /*b0da*/,
    9 /*b0db*/,  8 /*b0dc*/,  9 /*b0dd*/,  9 /*b0de*/,  10 /*b0df*/,
    6 /*b0e0*/,  7 /*b0e1*/,  7 /*b0e2*/,  8 /*b0e3*/,  7 /*b0e4*/,
    8 /*b0e5*/,  8 /*b0e6*/,  9 /*b0e7*/,  7 /*b0e8*/,  8 /*b0e9*/,
    8 /*b0ea*/,  9 /*b0eb*/,  8 /*b0ec*/,  9 /*b0ed*/,  9 /*b0ee*/,
    10 /*b0ef*/, 7 /*b0f0*/,  8 /*b0f1*/,  8 /*b0f2*/,  9 /*b0f3*/,
    8 /*b0f4*/,  9 /*b0f5*/,  9 /*b0f6*/,  10 /*b0f7*/, 8 /*b0f8*/,
    9 /*b0f9*/,  9 /*b0fa*/,  10 /*b0fb*/, 9 /*b0fc*/,  10 /*b0fd*/,
    10 /*b0fe*/, 11 /*b0ff*/, 4 /*b100*/,  5 /*b101*/,  5 /*b102*/,
    6 /*b103*/,  5 /*b104*/,  6 /*b105*/,  6 /*b106*/,  7 /*b107*/,
    5 /*b108*/,  6 /*b109*/,  6 /*b10a*/,  7 /*b10b*/,  6 /*b10c*/,
    7 /*b10d*/,  7 /*b10e*/,  8 /*b10f*/,  5 /*b110*/,  6 /*b111*/,
    6 /*b112*/,  7 /*b113*/,  6 /*b114*/,  7 /*b115*/,  7 /*b116*/,
    8 /*b117*/,  6 /*b118*/,  7 /*b119*/,  7 /*b11a*/,  8 /*b11b*/,
    7 /*b11c*/,  8 /*b11d*/,  8 /*b11e*/,  9 /*b11f*/,  5 /*b120*/,
    6 /*b121*/,  6 /*b122*/,  7 /*b123*/,  6 /*b124*/,  7 /*b125*/,
    7 /*b126*/,  8 /*b127*/,  6 /*b128*/,  7 /*b129*/,  7 /*b12a*/,
    8 /*b12b*/,  7 /*b12c*/,  8 /*b12d*/,  8 /*b12e*/,  9 /*b12f*/,
    6 /*b130*/,  7 /*b131*/,  7 /*b132*/,  8 /*b133*/,  7 /*b134*/,
    8 /*b135*/,  8 /*b136*/,  9 /*b137*/,  7 /*b138*/,  8 /*b139*/,
    8 /*b13a*/,  9 /*b13b*/,  8 /*b13c*/,  9 /*b13d*/,  9 /*b13e*/,
    10 /*b13f*/, 5 /*b140*/,  6 /*b141*/,  6 /*b142*/,  7 /*b143*/,
    6 /*b144*/,  7 /*b145*/,  7 /*b146*/,  8 /*b147*/,  6 /*b148*/,
    7 /*b149*/,  7 /*b14a*/,  8 /*b14b*/,  7 /*b14c*/,  8 /*b14d*/,
    8 /*b14e*/,  9 /*b14f*/,  6 /*b150*/,  7 /*b151*/,  7 /*b152*/,
    8 /*b153*/,  7 /*b154*/,  8 /*b155*/,  8 /*b156*/,  9 /*b157*/,
    7 /*b158*/,  8 /*b159*/,  8 /*b15a*/,  9 /*b15b*/,  8 /*b15c*/,
    9 /*b15d*/,  9 /*b15e*/,  10 /*b15f*/, 6 /*b160*/,  7 /*b161*/,
    7 /*b162*/,  8 /*b163*/,  7 /*b164*/,  8 /*b165*/,  8 /*b166*/,
    9 /*b167*/,  7 /*b168*/,  8 /*b169*/,  8 /*b16a*/,  9 /*b16b*/,
    8 /*b16c*/,  9 /*b16d*/,  9 /*b16e*/,  10 /*b16f*/, 7 /*b170*/,
    8 /*b171*/,  8 /*b172*/,  9 /*b173*/,  8 /*b174*/,  9 /*b175*/,
    9 /*b176*/,  10 /*b177*/, 8 /*b178*/,  9 /*b179*/,  9 /*b17a*/,
    10 /*b17b*/, 9 /*b17c*/,  10 /*b17d*/, 10 /*b17e*/, 11 /*b17f*/,
    5 /*b180*/,  6 /*b181*/,  6 /*b182*/,  7 /*b183*/,  6 /*b184*/,
    7 /*b185*/,  7 /*b186*/,  8 /*b187*/,  6 /*b188*/,  7 /*b189*/,
    7 /*b18a*/,  8 /*b18b*/,  7 /*b18c*/,  8 /*b18d*/,  8 /*b18e*/,
    9 /*b18f*/,  6 /*b190*/,  7 /*b191*/,  7 /*b192*/,  8 /*b193*/,
    7 /*b194*/,  8 /*b195*/,  8 /*b196*/,  9 /*b197*/,  7 /*b198*/,
    8 /*b199*/,  8 /*b19a*/,  9 /*b19b*/,  8 /*b19c*/,  9 /*b19d*/,
    9 /*b19e*/,  10 /*b19f*/, 6 /*b1a0*/,  7 /*b1a1*/,  7 /*b1a2*/,
    8 /*b1a3*/,  7 /*b1a4*/,  8 /*b1a5*/,  8 /*b1a6*/,  9 /*b1a7*/,
    7 /*b1a8*/,  8 /*b1a9*/,  8 /*b1aa*/,  9 /*b1ab*/,  8 /*b1ac*/,
    9 /*b1ad*/,  9 /*b1ae*/,  10 /*b1af*/, 7 /*b1b0*/,  8 /*b1b1*/,
    8 /*b1b2*/,  9 /*b1b3*/,  8 /*b1b4*/,  9 /*b1b5*/,  9 /*b1b6*/,
    10 /*b1b7*/, 8 /*b1b8*/,  9 /*b1b9*/,  9 /*b1ba*/,  10 /*b1bb*/,
    9 /*b1bc*/,  10 /*b1bd*/, 10 /*b1be*/, 11 /*b1bf*/, 6 /*b1c0*/,
    7 /*b1c1*/,  7 /*b1c2*/,  8 /*b1c3*/,  7 /*b1c4*/,  8 /*b1c5*/,
    8 /*b1c6*/,  9 /*b1c7*/,  7 /*b1c8*/,  8 /*b1c9*/,  8 /*b1ca*/,
    9 /*b1cb*/,  8 /*b1cc*/,  9 /*b1cd*/,  9 /*b1ce*/,  10 /*b1cf*/,
    7 /*b1d0*/,  8 /*b1d1*/,  8 /*b1d2*/,  9 /*b1d3*/,  8 /*b1d4*/,
    9 /*b1d5*/,  9 /*b1d6*/,  10 /*b1d7*/, 8 /*b1d8*/,  9 /*b1d9*/,
    9 /*b1da*/,  10 /*b1db*/, 9 /*b1dc*/,  10 /*b1dd*/, 10 /*b1de*/,
    11 /*b1df*/, 7 /*b1e0*/,  8 /*b1e1*/,  8 /*b1e2*/,  9 /*b1e3*/,
    8 /*b1e4*/,  9 /*b1e5*/,  9 /*b1e6*/,  10 /*b1e7*/, 8 /*b1e8*/,
    9 /*b1e9*/,  9 /*b1ea*/,  10 /*b1eb*/, 9 /*b1ec*/,  10 /*b1ed*/,
    10 /*b1ee*/, 11 /*b1ef*/, 8 /*b1f0*/,  9 /*b1f1*/,  9 /*b1f2*/,
    10 /*b1f3*/, 9 /*b1f4*/,  10 /*b1f5*/, 10 /*b1f6*/, 11 /*b1f7*/,
    9 /*b1f8*/,  10 /*b1f9*/, 10 /*b1fa*/, 11 /*b1fb*/, 10 /*b1fc*/,
    11 /*b1fd*/, 11 /*b1fe*/, 12 /*b1ff*/, 4 /*b200*/,  5 /*b201*/,
    5 /*b202*/,  6 /*b203*/,  5 /*b204*/,  6 /*b205*/,  6 /*b206*/,
    7 /*b207*/,  5 /*b208*/,  6 /*b209*/,  6 /*b20a*/,  7 /*b20b*/,
    6 /*b20c*/,  7 /*b20d*/,  7 /*b20e*/,  8 /*b20f*/,  5 /*b210*/,
    6 /*b211*/,  6 /*b212*/,  7 /*b213*/,  6 /*b214*/,  7 /*b215*/,
    7 /*b216*/,  8 /*b217*/,  6 /*b218*/,  7 /*b219*/,  7 /*b21a*/,
    8 /*b21b*/,  7 /*b21c*/,  8 /*b21d*/,  8 /*b21e*/,  9 /*b21f*/,
    5 /*b220*/,  6 /*b221*/,  6 /*b222*/,  7 /*b223*/,  6 /*b224*/,
    7 /*b225*/,  7 /*b226*/,  8 /*b227*/,  6 /*b228*/,  7 /*b229*/,
    7 /*b22a*/,  8 /*b22b*/,  7 /*b22c*/,  8 /*b22d*/,  8 /*b22e*/,
    9 /*b22f*/,  6 /*b230*/,  7 /*b231*/,  7 /*b232*/,  8 /*b233*/,
    7 /*b234*/,  8 /*b235*/,  8 /*b236*/,  9 /*b237*/,  7 /*b238*/,
    8 /*b239*/,  8 /*b23a*/,  9 /*b23b*/,  8 /*b23c*/,  9 /*b23d*/,
    9 /*b23e*/,  10 /*b23f*/, 5 /*b240*/,  6 /*b241*/,  6 /*b242*/,
    7 /*b243*/,  6 /*b244*/,  7 /*b245*/,  7 /*b246*/,  8 /*b247*/,
    6 /*b248*/,  7 /*b249*/,  7 /*b24a*/,  8 /*b24b*/,  7 /*b24c*/,
    8 /*b24d*/,  8 /*b24e*/,  9 /*b24f*/,  6 /*b250*/,  7 /*b251*/,
    7 /*b252*/,  8 /*b253*/,  7 /*b254*/,  8 /*b255*/,  8 /*b256*/,
    9 /*b257*/,  7 /*b258*/,  8 /*b259*/,  8 /*b25a*/,  9 /*b25b*/,
    8 /*b25c*/,  9 /*b25d*/,  9 /*b25e*/,  10 /*b25f*/, 6 /*b260*/,
    7 /*b261*/,  7 /*b262*/,  8 /*b263*/,  7 /*b264*/,  8 /*b265*/,
    8 /*b266*/,  9 /*b267*/,  7 /*b268*/,  8 /*b269*/,  8 /*b26a*/,
    9 /*b26b*/,  8 /*b26c*/,  9 /*b26d*/,  9 /*b26e*/,  10 /*b26f*/,
    7 /*b270*/,  8 /*b271*/,  8 /*b272*/,  9 /*b273*/,  8 /*b274*/,
    9 /*b275*/,  9 /*b276*/,  10 /*b277*/, 8 /*b278*/,  9 /*b279*/,
    9 /*b27a*/,  10 /*b27b*/, 9 /*b27c*/,  10 /*b27d*/, 10 /*b27e*/,
    11 /*b27f*/, 5 /*b280*/,  6 /*b281*/,  6 /*b282*/,  7 /*b283*/,
    6 /*b284*/,  7 /*b285*/,  7 /*b286*/,  8 /*b287*/,  6 /*b288*/,
    7 /*b289*/,  7 /*b28a*/,  8 /*b28b*/,  7 /*b28c*/,  8 /*b28d*/,
    8 /*b28e*/,  9 /*b28f*/,  6 /*b290*/,  7 /*b291*/,  7 /*b292*/,
    8 /*b293*/,  7 /*b294*/,  8 /*b295*/,  8 /*b296*/,  9 /*b297*/,
    7 /*b298*/,  8 /*b299*/,  8 /*b29a*/,  9 /*b29b*/,  8 /*b29c*/,
    9 /*b29d*/,  9 /*b29e*/,  10 /*b29f*/, 6 /*b2a0*/,  7 /*b2a1*/,
    7 /*b2a2*/,  8 /*b2a3*/,  7 /*b2a4*/,  8 /*b2a5*/,  8 /*b2a6*/,
    9 /*b2a7*/,  7 /*b2a8*/,  8 /*b2a9*/,  8 /*b2aa*/,  9 /*b2ab*/,
    8 /*b2ac*/,  9 /*b2ad*/,  9 /*b2ae*/,  10 /*b2af*/, 7 /*b2b0*/,
    8 /*b2b1*/,  8 /*b2b2*/,  9 /*b2b3*/,  8 /*b2b4*/,  9 /*b2b5*/,
    9 /*b2b6*/,  10 /*b2b7*/, 8 /*b2b8*/,  9 /*b2b9*/,  9 /*b2ba*/,
    10 /*b2bb*/, 9 /*b2bc*/,  10 /*b2bd*/, 10 /*b2be*/, 11 /*b2bf*/,
    6 /*b2c0*/,  7 /*b2c1*/,  7 /*b2c2*/,  8 /*b2c3*/,  7 /*b2c4*/,
    8 /*b2c5*/,  8 /*b2c6*/,  9 /*b2c7*/,  7 /*b2c8*/,  8 /*b2c9*/,
    8 /*b2ca*/,  9 /*b2cb*/,  8 /*b2cc*/,  9 /*b2cd*/,  9 /*b2ce*/,
    10 /*b2cf*/, 7 /*b2d0*/,  8 /*b2d1*/,  8 /*b2d2*/,  9 /*b2d3*/,
    8 /*b2d4*/,  9 /*b2d5*/,  9 /*b2d6*/,  10 /*b2d7*/, 8 /*b2d8*/,
    9 /*b2d9*/,  9 /*b2da*/,  10 /*b2db*/, 9 /*b2dc*/,  10 /*b2dd*/,
    10 /*b2de*/, 11 /*b2df*/, 7 /*b2e0*/,  8 /*b2e1*/,  8 /*b2e2*/,
    9 /*b2e3*/,  8 /*b2e4*/,  9 /*b2e5*/,  9 /*b2e6*/,  10 /*b2e7*/,
    8 /*b2e8*/,  9 /*b2e9*/,  9 /*b2ea*/,  10 /*b2eb*/, 9 /*b2ec*/,
    10 /*b2ed*/, 10 /*b2ee*/, 11 /*b2ef*/, 8 /*b2f0*/,  9 /*b2f1*/,
    9 /*b2f2*/,  10 /*b2f3*/, 9 /*b2f4*/,  10 /*b2f5*/, 10 /*b2f6*/,
    11 /*b2f7*/, 9 /*b2f8*/,  10 /*b2f9*/, 10 /*b2fa*/, 11 /*b2fb*/,
    10 /*b2fc*/, 11 /*b2fd*/, 11 /*b2fe*/, 12 /*b2ff*/, 5 /*b300*/,
    6 /*b301*/,  6 /*b302*/,  7 /*b303*/,  6 /*b304*/,  7 /*b305*/,
    7 /*b306*/,  8 /*b307*/,  6 /*b308*/,  7 /*b309*/,  7 /*b30a*/,
    8 /*b30b*/,  7 /*b30c*/,  8 /*b30d*/,  8 /*b30e*/,  9 /*b30f*/,
    6 /*b310*/,  7 /*b311*/,  7 /*b312*/,  8 /*b313*/,  7 /*b314*/,
    8 /*b315*/,  8 /*b316*/,  9 /*b317*/,  7 /*b318*/,  8 /*b319*/,
    8 /*b31a*/,  9 /*b31b*/,  8 /*b31c*/,  9 /*b31d*/,  9 /*b31e*/,
    10 /*b31f*/, 6 /*b320*/,  7 /*b321*/,  7 /*b322*/,  8 /*b323*/,
    7 /*b324*/,  8 /*b325*/,  8 /*b326*/,  9 /*b327*/,  7 /*b328*/,
    8 /*b329*/,  8 /*b32a*/,  9 /*b32b*/,  8 /*b32c*/,  9 /*b32d*/,
    9 /*b32e*/,  10 /*b32f*/, 7 /*b330*/,  8 /*b331*/,  8 /*b332*/,
    9 /*b333*/,  8 /*b334*/,  9 /*b335*/,  9 /*b336*/,  10 /*b337*/,
    8 /*b338*/,  9 /*b339*/,  9 /*b33a*/,  10 /*b33b*/, 9 /*b33c*/,
    10 /*b33d*/, 10 /*b33e*/, 11 /*b33f*/, 6 /*b340*/,  7 /*b341*/,
    7 /*b342*/,  8 /*b343*/,  7 /*b344*/,  8 /*b345*/,  8 /*b346*/,
    9 /*b347*/,  7 /*b348*/,  8 /*b349*/,  8 /*b34a*/,  9 /*b34b*/,
    8 /*b34c*/,  9 /*b34d*/,  9 /*b34e*/,  10 /*b34f*/, 7 /*b350*/,
    8 /*b351*/,  8 /*b352*/,  9 /*b353*/,  8 /*b354*/,  9 /*b355*/,
    9 /*b356*/,  10 /*b357*/, 8 /*b358*/,  9 /*b359*/,  9 /*b35a*/,
    10 /*b35b*/, 9 /*b35c*/,  10 /*b35d*/, 10 /*b35e*/, 11 /*b35f*/,
    7 /*b360*/,  8 /*b361*/,  8 /*b362*/,  9 /*b363*/,  8 /*b364*/,
    9 /*b365*/,  9 /*b366*/,  10 /*b367*/, 8 /*b368*/,  9 /*b369*/,
    9 /*b36a*/,  10 /*b36b*/, 9 /*b36c*/,  10 /*b36d*/, 10 /*b36e*/,
    11 /*b36f*/, 8 /*b370*/,  9 /*b371*/,  9 /*b372*/,  10 /*b373*/,
    9 /*b374*/,  10 /*b375*/, 10 /*b376*/, 11 /*b377*/, 9 /*b378*/,
    10 /*b379*/, 10 /*b37a*/, 11 /*b37b*/, 10 /*b37c*/, 11 /*b37d*/,
    11 /*b37e*/, 12 /*b37f*/, 6 /*b380*/,  7 /*b381*/,  7 /*b382*/,
    8 /*b383*/,  7 /*b384*/,  8 /*b385*/,  8 /*b386*/,  9 /*b387*/,
    7 /*b388*/,  8 /*b389*/,  8 /*b38a*/,  9 /*b38b*/,  8 /*b38c*/,
    9 /*b38d*/,  9 /*b38e*/,  10 /*b38f*/, 7 /*b390*/,  8 /*b391*/,
    8 /*b392*/,  9 /*b393*/,  8 /*b394*/,  9 /*b395*/,  9 /*b396*/,
    10 /*b397*/, 8 /*b398*/,  9 /*b399*/,  9 /*b39a*/,  10 /*b39b*/,
    9 /*b39c*/,  10 /*b39d*/, 10 /*b39e*/, 11 /*b39f*/, 7 /*b3a0*/,
    8 /*b3a1*/,  8 /*b3a2*/,  9 /*b3a3*/,  8 /*b3a4*/,  9 /*b3a5*/,
    9 /*b3a6*/,  10 /*b3a7*/, 8 /*b3a8*/,  9 /*b3a9*/,  9 /*b3aa*/,
    10 /*b3ab*/, 9 /*b3ac*/,  10 /*b3ad*/, 10 /*b3ae*/, 11 /*b3af*/,
    8 /*b3b0*/,  9 /*b3b1*/,  9 /*b3b2*/,  10 /*b3b3*/, 9 /*b3b4*/,
    10 /*b3b5*/, 10 /*b3b6*/, 11 /*b3b7*/, 9 /*b3b8*/,  10 /*b3b9*/,
    10 /*b3ba*/, 11 /*b3bb*/, 10 /*b3bc*/, 11 /*b3bd*/, 11 /*b3be*/,
    12 /*b3bf*/, 7 /*b3c0*/,  8 /*b3c1*/,  8 /*b3c2*/,  9 /*b3c3*/,
    8 /*b3c4*/,  9 /*b3c5*/,  9 /*b3c6*/,  10 /*b3c7*/, 8 /*b3c8*/,
    9 /*b3c9*/,  9 /*b3ca*/,  10 /*b3cb*/, 9 /*b3cc*/,  10 /*b3cd*/,
    10 /*b3ce*/, 11 /*b3cf*/, 8 /*b3d0*/,  9 /*b3d1*/,  9 /*b3d2*/,
    10 /*b3d3*/, 9 /*b3d4*/,  10 /*b3d5*/, 10 /*b3d6*/, 11 /*b3d7*/,
    9 /*b3d8*/,  10 /*b3d9*/, 10 /*b3da*/, 11 /*b3db*/, 10 /*b3dc*/,
    11 /*b3dd*/, 11 /*b3de*/, 12 /*b3df*/, 8 /*b3e0*/,  9 /*b3e1*/,
    9 /*b3e2*/,  10 /*b3e3*/, 9 /*b3e4*/,  10 /*b3e5*/, 10 /*b3e6*/,
    11 /*b3e7*/, 9 /*b3e8*/,  10 /*b3e9*/, 10 /*b3ea*/, 11 /*b3eb*/,
    10 /*b3ec*/, 11 /*b3ed*/, 11 /*b3ee*/, 12 /*b3ef*/, 9 /*b3f0*/,
    10 /*b3f1*/, 10 /*b3f2*/, 11 /*b3f3*/, 10 /*b3f4*/, 11 /*b3f5*/,
    11 /*b3f6*/, 12 /*b3f7*/, 10 /*b3f8*/, 11 /*b3f9*/, 11 /*b3fa*/,
    12 /*b3fb*/, 11 /*b3fc*/, 12 /*b3fd*/, 12 /*b3fe*/, 13 /*b3ff*/,
    4 /*b400*/,  5 /*b401*/,  5 /*b402*/,  6 /*b403*/,  5 /*b404*/,
    6 /*b405*/,  6 /*b406*/,  7 /*b407*/,  5 /*b408*/,  6 /*b409*/,
    6 /*b40a*/,  7 /*b40b*/,  6 /*b40c*/,  7 /*b40d*/,  7 /*b40e*/,
    8 /*b40f*/,  5 /*b410*/,  6 /*b411*/,  6 /*b412*/,  7 /*b413*/,
    6 /*b414*/,  7 /*b415*/,  7 /*b416*/,  8 /*b417*/,  6 /*b418*/,
    7 /*b419*/,  7 /*b41a*/,  8 /*b41b*/,  7 /*b41c*/,  8 /*b41d*/,
    8 /*b41e*/,  9 /*b41f*/,  5 /*b420*/,  6 /*b421*/,  6 /*b422*/,
    7 /*b423*/,  6 /*b424*/,  7 /*b425*/,  7 /*b426*/,  8 /*b427*/,
    6 /*b428*/,  7 /*b429*/,  7 /*b42a*/,  8 /*b42b*/,  7 /*b42c*/,
    8 /*b42d*/,  8 /*b42e*/,  9 /*b42f*/,  6 /*b430*/,  7 /*b431*/,
    7 /*b432*/,  8 /*b433*/,  7 /*b434*/,  8 /*b435*/,  8 /*b436*/,
    9 /*b437*/,  7 /*b438*/,  8 /*b439*/,  8 /*b43a*/,  9 /*b43b*/,
    8 /*b43c*/,  9 /*b43d*/,  9 /*b43e*/,  10 /*b43f*/, 5 /*b440*/,
    6 /*b441*/,  6 /*b442*/,  7 /*b443*/,  6 /*b444*/,  7 /*b445*/,
    7 /*b446*/,  8 /*b447*/,  6 /*b448*/,  7 /*b449*/,  7 /*b44a*/,
    8 /*b44b*/,  7 /*b44c*/,  8 /*b44d*/,  8 /*b44e*/,  9 /*b44f*/,
    6 /*b450*/,  7 /*b451*/,  7 /*b452*/,  8 /*b453*/,  7 /*b454*/,
    8 /*b455*/,  8 /*b456*/,  9 /*b457*/,  7 /*b458*/,  8 /*b459*/,
    8 /*b45a*/,  9 /*b45b*/,  8 /*b45c*/,  9 /*b45d*/,  9 /*b45e*/,
    10 /*b45f*/, 6 /*b460*/,  7 /*b461*/,  7 /*b462*/,  8 /*b463*/,
    7 /*b464*/,  8 /*b465*/,  8 /*b466*/,  9 /*b467*/,  7 /*b468*/,
    8 /*b469*/,  8 /*b46a*/,  9 /*b46b*/,  8 /*b46c*/,  9 /*b46d*/,
    9 /*b46e*/,  10 /*b46f*/, 7 /*b470*/,  8 /*b471*/,  8 /*b472*/,
    9 /*b473*/,  8 /*b474*/,  9 /*b475*/,  9 /*b476*/,  10 /*b477*/,
    8 /*b478*/,  9 /*b479*/,  9 /*b47a*/,  10 /*b47b*/, 9 /*b47c*/,
    10 /*b47d*/, 10 /*b47e*/, 11 /*b47f*/, 5 /*b480*/,  6 /*b481*/,
    6 /*b482*/,  7 /*b483*/,  6 /*b484*/,  7 /*b485*/,  7 /*b486*/,
    8 /*b487*/,  6 /*b488*/,  7 /*b489*/,  7 /*b48a*/,  8 /*b48b*/,
    7 /*b48c*/,  8 /*b48d*/,  8 /*b48e*/,  9 /*b48f*/,  6 /*b490*/,
    7 /*b491*/,  7 /*b492*/,  8 /*b493*/,  7 /*b494*/,  8 /*b495*/,
    8 /*b496*/,  9 /*b497*/,  7 /*b498*/,  8 /*b499*/,  8 /*b49a*/,
    9 /*b49b*/,  8 /*b49c*/,  9 /*b49d*/,  9 /*b49e*/,  10 /*b49f*/,
    6 /*b4a0*/,  7 /*b4a1*/,  7 /*b4a2*/,  8 /*b4a3*/,  7 /*b4a4*/,
    8 /*b4a5*/,  8 /*b4a6*/,  9 /*b4a7*/,  7 /*b4a8*/,  8 /*b4a9*/,
    8 /*b4aa*/,  9 /*b4ab*/,  8 /*b4ac*/,  9 /*b4ad*/,  9 /*b4ae*/,
    10 /*b4af*/, 7 /*b4b0*/,  8 /*b4b1*/,  8 /*b4b2*/,  9 /*b4b3*/,
    8 /*b4b4*/,  9 /*b4b5*/,  9 /*b4b6*/,  10 /*b4b7*/, 8 /*b4b8*/,
    9 /*b4b9*/,  9 /*b4ba*/,  10 /*b4bb*/, 9 /*b4bc*/,  10 /*b4bd*/,
    10 /*b4be*/, 11 /*b4bf*/, 6 /*b4c0*/,  7 /*b4c1*/,  7 /*b4c2*/,
    8 /*b4c3*/,  7 /*b4c4*/,  8 /*b4c5*/,  8 /*b4c6*/,  9 /*b4c7*/,
    7 /*b4c8*/,  8 /*b4c9*/,  8 /*b4ca*/,  9 /*b4cb*/,  8 /*b4cc*/,
    9 /*b4cd*/,  9 /*b4ce*/,  10 /*b4cf*/, 7 /*b4d0*/,  8 /*b4d1*/,
    8 /*b4d2*/,  9 /*b4d3*/,  8 /*b4d4*/,  9 /*b4d5*/,  9 /*b4d6*/,
    10 /*b4d7*/, 8 /*b4d8*/,  9 /*b4d9*/,  9 /*b4da*/,  10 /*b4db*/,
    9 /*b4dc*/,  10 /*b4dd*/, 10 /*b4de*/, 11 /*b4df*/, 7 /*b4e0*/,
    8 /*b4e1*/,  8 /*b4e2*/,  9 /*b4e3*/,  8 /*b4e4*/,  9 /*b4e5*/,
    9 /*b4e6*/,  10 /*b4e7*/, 8 /*b4e8*/,  9 /*b4e9*/,  9 /*b4ea*/,
    10 /*b4eb*/, 9 /*b4ec*/,  10 /*b4ed*/, 10 /*b4ee*/, 11 /*b4ef*/,
    8 /*b4f0*/,  9 /*b4f1*/,  9 /*b4f2*/,  10 /*b4f3*/, 9 /*b4f4*/,
    10 /*b4f5*/, 10 /*b4f6*/, 11 /*b4f7*/, 9 /*b4f8*/,  10 /*b4f9*/,
    10 /*b4fa*/, 11 /*b4fb*/, 10 /*b4fc*/, 11 /*b4fd*/, 11 /*b4fe*/,
    12 /*b4ff*/, 5 /*b500*/,  6 /*b501*/,  6 /*b502*/,  7 /*b503*/,
    6 /*b504*/,  7 /*b505*/,  7 /*b506*/,  8 /*b507*/,  6 /*b508*/,
    7 /*b509*/,  7 /*b50a*/,  8 /*b50b*/,  7 /*b50c*/,  8 /*b50d*/,
    8 /*b50e*/,  9 /*b50f*/,  6 /*b510*/,  7 /*b511*/,  7 /*b512*/,
    8 /*b513*/,  7 /*b514*/,  8 /*b515*/,  8 /*b516*/,  9 /*b517*/,
    7 /*b518*/,  8 /*b519*/,  8 /*b51a*/,  9 /*b51b*/,  8 /*b51c*/,
    9 /*b51d*/,  9 /*b51e*/,  10 /*b51f*/, 6 /*b520*/,  7 /*b521*/,
    7 /*b522*/,  8 /*b523*/,  7 /*b524*/,  8 /*b525*/,  8 /*b526*/,
    9 /*b527*/,  7 /*b528*/,  8 /*b529*/,  8 /*b52a*/,  9 /*b52b*/,
    8 /*b52c*/,  9 /*b52d*/,  9 /*b52e*/,  10 /*b52f*/, 7 /*b530*/,
    8 /*b531*/,  8 /*b532*/,  9 /*b533*/,  8 /*b534*/,  9 /*b535*/,
    9 /*b536*/,  10 /*b537*/, 8 /*b538*/,  9 /*b539*/,  9 /*b53a*/,
    10 /*b53b*/, 9 /*b53c*/,  10 /*b53d*/, 10 /*b53e*/, 11 /*b53f*/,
    6 /*b540*/,  7 /*b541*/,  7 /*b542*/,  8 /*b543*/,  7 /*b544*/,
    8 /*b545*/,  8 /*b546*/,  9 /*b547*/,  7 /*b548*/,  8 /*b549*/,
    8 /*b54a*/,  9 /*b54b*/,  8 /*b54c*/,  9 /*b54d*/,  9 /*b54e*/,
    10 /*b54f*/, 7 /*b550*/,  8 /*b551*/,  8 /*b552*/,  9 /*b553*/,
    8 /*b554*/,  9 /*b555*/,  9 /*b556*/,  10 /*b557*/, 8 /*b558*/,
    9 /*b559*/,  9 /*b55a*/,  10 /*b55b*/, 9 /*b55c*/,  10 /*b55d*/,
    10 /*b55e*/, 11 /*b55f*/, 7 /*b560*/,  8 /*b561*/,  8 /*b562*/,
    9 /*b563*/,  8 /*b564*/,  9 /*b565*/,  9 /*b566*/,  10 /*b567*/,
    8 /*b568*/,  9 /*b569*/,  9 /*b56a*/,  10 /*b56b*/, 9 /*b56c*/,
    10 /*b56d*/, 10 /*b56e*/, 11 /*b56f*/, 8 /*b570*/,  9 /*b571*/,
    9 /*b572*/,  10 /*b573*/, 9 /*b574*/,  10 /*b575*/, 10 /*b576*/,
    11 /*b577*/, 9 /*b578*/,  10 /*b579*/, 10 /*b57a*/, 11 /*b57b*/,
    10 /*b57c*/, 11 /*b57d*/, 11 /*b57e*/, 12 /*b57f*/, 6 /*b580*/,
    7 /*b581*/,  7 /*b582*/,  8 /*b583*/,  7 /*b584*/,  8 /*b585*/,
    8 /*b586*/,  9 /*b587*/,  7 /*b588*/,  8 /*b589*/,  8 /*b58a*/,
    9 /*b58b*/,  8 /*b58c*/,  9 /*b58d*/,  9 /*b58e*/,  10 /*b58f*/,
    7 /*b590*/,  8 /*b591*/,  8 /*b592*/,  9 /*b593*/,  8 /*b594*/,
    9 /*b595*/,  9 /*b596*/,  10 /*b597*/, 8 /*b598*/,  9 /*b599*/,
    9 /*b59a*/,  10 /*b59b*/, 9 /*b59c*/,  10 /*b59d*/, 10 /*b59e*/,
    11 /*b59f*/, 7 /*b5a0*/,  8 /*b5a1*/,  8 /*b5a2*/,  9 /*b5a3*/,
    8 /*b5a4*/,  9 /*b5a5*/,  9 /*b5a6*/,  10 /*b5a7*/, 8 /*b5a8*/,
    9 /*b5a9*/,  9 /*b5aa*/,  10 /*b5ab*/, 9 /*b5ac*/,  10 /*b5ad*/,
    10 /*b5ae*/, 11 /*b5af*/, 8 /*b5b0*/,  9 /*b5b1*/,  9 /*b5b2*/,
    10 /*b5b3*/, 9 /*b5b4*/,  10 /*b5b5*/, 10 /*b5b6*/, 11 /*b5b7*/,
    9 /*b5b8*/,  10 /*b5b9*/, 10 /*b5ba*/, 11 /*b5bb*/, 10 /*b5bc*/,
    11 /*b5bd*/, 11 /*b5be*/, 12 /*b5bf*/, 7 /*b5c0*/,  8 /*b5c1*/,
    8 /*b5c2*/,  9 /*b5c3*/,  8 /*b5c4*/,  9 /*b5c5*/,  9 /*b5c6*/,
    10 /*b5c7*/, 8 /*b5c8*/,  9 /*b5c9*/,  9 /*b5ca*/,  10 /*b5cb*/,
    9 /*b5cc*/,  10 /*b5cd*/, 10 /*b5ce*/, 11 /*b5cf*/, 8 /*b5d0*/,
    9 /*b5d1*/,  9 /*b5d2*/,  10 /*b5d3*/, 9 /*b5d4*/,  10 /*b5d5*/,
    10 /*b5d6*/, 11 /*b5d7*/, 9 /*b5d8*/,  10 /*b5d9*/, 10 /*b5da*/,
    11 /*b5db*/, 10 /*b5dc*/, 11 /*b5dd*/, 11 /*b5de*/, 12 /*b5df*/,
    8 /*b5e0*/,  9 /*b5e1*/,  9 /*b5e2*/,  10 /*b5e3*/, 9 /*b5e4*/,
    10 /*b5e5*/, 10 /*b5e6*/, 11 /*b5e7*/, 9 /*b5e8*/,  10 /*b5e9*/,
    10 /*b5ea*/, 11 /*b5eb*/, 10 /*b5ec*/, 11 /*b5ed*/, 11 /*b5ee*/,
    12 /*b5ef*/, 9 /*b5f0*/,  10 /*b5f1*/, 10 /*b5f2*/, 11 /*b5f3*/,
    10 /*b5f4*/, 11 /*b5f5*/, 11 /*b5f6*/, 12 /*b5f7*/, 10 /*b5f8*/,
    11 /*b5f9*/, 11 /*b5fa*/, 12 /*b5fb*/, 11 /*b5fc*/, 12 /*b5fd*/,
    12 /*b5fe*/, 13 /*b5ff*/, 5 /*b600*/,  6 /*b601*/,  6 /*b602*/,
    7 /*b603*/,  6 /*b604*/,  7 /*b605*/,  7 /*b606*/,  8 /*b607*/,
    6 /*b608*/,  7 /*b609*/,  7 /*b60a*/,  8 /*b60b*/,  7 /*b60c*/,
    8 /*b60d*/,  8 /*b60e*/,  9 /*b60f*/,  6 /*b610*/,  7 /*b611*/,
    7 /*b612*/,  8 /*b613*/,  7 /*b614*/,  8 /*b615*/,  8 /*b616*/,
    9 /*b617*/,  7 /*b618*/,  8 /*b619*/,  8 /*b61a*/,  9 /*b61b*/,
    8 /*b61c*/,  9 /*b61d*/,  9 /*b61e*/,  10 /*b61f*/, 6 /*b620*/,
    7 /*b621*/,  7 /*b622*/,  8 /*b623*/,  7 /*b624*/,  8 /*b625*/,
    8 /*b626*/,  9 /*b627*/,  7 /*b628*/,  8 /*b629*/,  8 /*b62a*/,
    9 /*b62b*/,  8 /*b62c*/,  9 /*b62d*/,  9 /*b62e*/,  10 /*b62f*/,
    7 /*b630*/,  8 /*b631*/,  8 /*b632*/,  9 /*b633*/,  8 /*b634*/,
    9 /*b635*/,  9 /*b636*/,  10 /*b637*/, 8 /*b638*/,  9 /*b639*/,
    9 /*b63a*/,  10 /*b63b*/, 9 /*b63c*/,  10 /*b63d*/, 10 /*b63e*/,
    11 /*b63f*/, 6 /*b640*/,  7 /*b641*/,  7 /*b642*/,  8 /*b643*/,
    7 /*b644*/,  8 /*b645*/,  8 /*b646*/,  9 /*b647*/,  7 /*b648*/,
    8 /*b649*/,  8 /*b64a*/,  9 /*b64b*/,  8 /*b64c*/,  9 /*b64d*/,
    9 /*b64e*/,  10 /*b64f*/, 7 /*b650*/,  8 /*b651*/,  8 /*b652*/,
    9 /*b653*/,  8 /*b654*/,  9 /*b655*/,  9 /*b656*/,  10 /*b657*/,
    8 /*b658*/,  9 /*b659*/,  9 /*b65a*/,  10 /*b65b*/, 9 /*b65c*/,
    10 /*b65d*/, 10 /*b65e*/, 11 /*b65f*/, 7 /*b660*/,  8 /*b661*/,
    8 /*b662*/,  9 /*b663*/,  8 /*b664*/,  9 /*b665*/,  9 /*b666*/,
    10 /*b667*/, 8 /*b668*/,  9 /*b669*/,  9 /*b66a*/,  10 /*b66b*/,
    9 /*b66c*/,  10 /*b66d*/, 10 /*b66e*/, 11 /*b66f*/, 8 /*b670*/,
    9 /*b671*/,  9 /*b672*/,  10 /*b673*/, 9 /*b674*/,  10 /*b675*/,
    10 /*b676*/, 11 /*b677*/, 9 /*b678*/,  10 /*b679*/, 10 /*b67a*/,
    11 /*b67b*/, 10 /*b67c*/, 11 /*b67d*/, 11 /*b67e*/, 12 /*b67f*/,
    6 /*b680*/,  7 /*b681*/,  7 /*b682*/,  8 /*b683*/,  7 /*b684*/,
    8 /*b685*/,  8 /*b686*/,  9 /*b687*/,  7 /*b688*/,  8 /*b689*/,
    8 /*b68a*/,  9 /*b68b*/,  8 /*b68c*/,  9 /*b68d*/,  9 /*b68e*/,
    10 /*b68f*/, 7 /*b690*/,  8 /*b691*/,  8 /*b692*/,  9 /*b693*/,
    8 /*b694*/,  9 /*b695*/,  9 /*b696*/,  10 /*b697*/, 8 /*b698*/,
    9 /*b699*/,  9 /*b69a*/,  10 /*b69b*/, 9 /*b69c*/,  10 /*b69d*/,
    10 /*b69e*/, 11 /*b69f*/, 7 /*b6a0*/,  8 /*b6a1*/,  8 /*b6a2*/,
    9 /*b6a3*/,  8 /*b6a4*/,  9 /*b6a5*/,  9 /*b6a6*/,  10 /*b6a7*/,
    8 /*b6a8*/,  9 /*b6a9*/,  9 /*b6aa*/,  10 /*b6ab*/, 9 /*b6ac*/,
    10 /*b6ad*/, 10 /*b6ae*/, 11 /*b6af*/, 8 /*b6b0*/,  9 /*b6b1*/,
    9 /*b6b2*/,  10 /*b6b3*/, 9 /*b6b4*/,  10 /*b6b5*/, 10 /*b6b6*/,
    11 /*b6b7*/, 9 /*b6b8*/,  10 /*b6b9*/, 10 /*b6ba*/, 11 /*b6bb*/,
    10 /*b6bc*/, 11 /*b6bd*/, 11 /*b6be*/, 12 /*b6bf*/, 7 /*b6c0*/,
    8 /*b6c1*/,  8 /*b6c2*/,  9 /*b6c3*/,  8 /*b6c4*/,  9 /*b6c5*/,
    9 /*b6c6*/,  10 /*b6c7*/, 8 /*b6c8*/,  9 /*b6c9*/,  9 /*b6ca*/,
    10 /*b6cb*/, 9 /*b6cc*/,  10 /*b6cd*/, 10 /*b6ce*/, 11 /*b6cf*/,
    8 /*b6d0*/,  9 /*b6d1*/,  9 /*b6d2*/,  10 /*b6d3*/, 9 /*b6d4*/,
    10 /*b6d5*/, 10 /*b6d6*/, 11 /*b6d7*/, 9 /*b6d8*/,  10 /*b6d9*/,
    10 /*b6da*/, 11 /*b6db*/, 10 /*b6dc*/, 11 /*b6dd*/, 11 /*b6de*/,
    12 /*b6df*/, 8 /*b6e0*/,  9 /*b6e1*/,  9 /*b6e2*/,  10 /*b6e3*/,
    9 /*b6e4*/,  10 /*b6e5*/, 10 /*b6e6*/, 11 /*b6e7*/, 9 /*b6e8*/,
    10 /*b6e9*/, 10 /*b6ea*/, 11 /*b6eb*/, 10 /*b6ec*/, 11 /*b6ed*/,
    11 /*b6ee*/, 12 /*b6ef*/, 9 /*b6f0*/,  10 /*b6f1*/, 10 /*b6f2*/,
    11 /*b6f3*/, 10 /*b6f4*/, 11 /*b6f5*/, 11 /*b6f6*/, 12 /*b6f7*/,
    10 /*b6f8*/, 11 /*b6f9*/, 11 /*b6fa*/, 12 /*b6fb*/, 11 /*b6fc*/,
    12 /*b6fd*/, 12 /*b6fe*/, 13 /*b6ff*/, 6 /*b700*/,  7 /*b701*/,
    7 /*b702*/,  8 /*b703*/,  7 /*b704*/,  8 /*b705*/,  8 /*b706*/,
    9 /*b707*/,  7 /*b708*/,  8 /*b709*/,  8 /*b70a*/,  9 /*b70b*/,
    8 /*b70c*/,  9 /*b70d*/,  9 /*b70e*/,  10 /*b70f*/, 7 /*b710*/,
    8 /*b711*/,  8 /*b712*/,  9 /*b713*/,  8 /*b714*/,  9 /*b715*/,
    9 /*b716*/,  10 /*b717*/, 8 /*b718*/,  9 /*b719*/,  9 /*b71a*/,
    10 /*b71b*/, 9 /*b71c*/,  10 /*b71d*/, 10 /*b71e*/, 11 /*b71f*/,
    7 /*b720*/,  8 /*b721*/,  8 /*b722*/,  9 /*b723*/,  8 /*b724*/,
    9 /*b725*/,  9 /*b726*/,  10 /*b727*/, 8 /*b728*/,  9 /*b729*/,
    9 /*b72a*/,  10 /*b72b*/, 9 /*b72c*/,  10 /*b72d*/, 10 /*b72e*/,
    11 /*b72f*/, 8 /*b730*/,  9 /*b731*/,  9 /*b732*/,  10 /*b733*/,
    9 /*b734*/,  10 /*b735*/, 10 /*b736*/, 11 /*b737*/, 9 /*b738*/,
    10 /*b739*/, 10 /*b73a*/, 11 /*b73b*/, 10 /*b73c*/, 11 /*b73d*/,
    11 /*b73e*/, 12 /*b73f*/, 7 /*b740*/,  8 /*b741*/,  8 /*b742*/,
    9 /*b743*/,  8 /*b744*/,  9 /*b745*/,  9 /*b746*/,  10 /*b747*/,
    8 /*b748*/,  9 /*b749*/,  9 /*b74a*/,  10 /*b74b*/, 9 /*b74c*/,
    10 /*b74d*/, 10 /*b74e*/, 11 /*b74f*/, 8 /*b750*/,  9 /*b751*/,
    9 /*b752*/,  10 /*b753*/, 9 /*b754*/,  10 /*b755*/, 10 /*b756*/,
    11 /*b757*/, 9 /*b758*/,  10 /*b759*/, 10 /*b75a*/, 11 /*b75b*/,
    10 /*b75c*/, 11 /*b75d*/, 11 /*b75e*/, 12 /*b75f*/, 8 /*b760*/,
    9 /*b761*/,  9 /*b762*/,  10 /*b763*/, 9 /*b764*/,  10 /*b765*/,
    10 /*b766*/, 11 /*b767*/, 9 /*b768*/,  10 /*b769*/, 10 /*b76a*/,
    11 /*b76b*/, 10 /*b76c*/, 11 /*b76d*/, 11 /*b76e*/, 12 /*b76f*/,
    9 /*b770*/,  10 /*b771*/, 10 /*b772*/, 11 /*b773*/, 10 /*b774*/,
    11 /*b775*/, 11 /*b776*/, 12 /*b777*/, 10 /*b778*/, 11 /*b779*/,
    11 /*b77a*/, 12 /*b77b*/, 11 /*b77c*/, 12 /*b77d*/, 12 /*b77e*/,
    13 /*b77f*/, 7 /*b780*/,  8 /*b781*/,  8 /*b782*/,  9 /*b783*/,
    8 /*b784*/,  9 /*b785*/,  9 /*b786*/,  10 /*b787*/, 8 /*b788*/,
    9 /*b789*/,  9 /*b78a*/,  10 /*b78b*/, 9 /*b78c*/,  10 /*b78d*/,
    10 /*b78e*/, 11 /*b78f*/, 8 /*b790*/,  9 /*b791*/,  9 /*b792*/,
    10 /*b793*/, 9 /*b794*/,  10 /*b795*/, 10 /*b796*/, 11 /*b797*/,
    9 /*b798*/,  10 /*b799*/, 10 /*b79a*/, 11 /*b79b*/, 10 /*b79c*/,
    11 /*b79d*/, 11 /*b79e*/, 12 /*b79f*/, 8 /*b7a0*/,  9 /*b7a1*/,
    9 /*b7a2*/,  10 /*b7a3*/, 9 /*b7a4*/,  10 /*b7a5*/, 10 /*b7a6*/,
    11 /*b7a7*/, 9 /*b7a8*/,  10 /*b7a9*/, 10 /*b7aa*/, 11 /*b7ab*/,
    10 /*b7ac*/, 11 /*b7ad*/, 11 /*b7ae*/, 12 /*b7af*/, 9 /*b7b0*/,
    10 /*b7b1*/, 10 /*b7b2*/, 11 /*b7b3*/, 10 /*b7b4*/, 11 /*b7b5*/,
    11 /*b7b6*/, 12 /*b7b7*/, 10 /*b7b8*/, 11 /*b7b9*/, 11 /*b7ba*/,
    12 /*b7bb*/, 11 /*b7bc*/, 12 /*b7bd*/, 12 /*b7be*/, 13 /*b7bf*/,
    8 /*b7c0*/,  9 /*b7c1*/,  9 /*b7c2*/,  10 /*b7c3*/, 9 /*b7c4*/,
    10 /*b7c5*/, 10 /*b7c6*/, 11 /*b7c7*/, 9 /*b7c8*/,  10 /*b7c9*/,
    10 /*b7ca*/, 11 /*b7cb*/, 10 /*b7cc*/, 11 /*b7cd*/, 11 /*b7ce*/,
    12 /*b7cf*/, 9 /*b7d0*/,  10 /*b7d1*/, 10 /*b7d2*/, 11 /*b7d3*/,
    10 /*b7d4*/, 11 /*b7d5*/, 11 /*b7d6*/, 12 /*b7d7*/, 10 /*b7d8*/,
    11 /*b7d9*/, 11 /*b7da*/, 12 /*b7db*/, 11 /*b7dc*/, 12 /*b7dd*/,
    12 /*b7de*/, 13 /*b7df*/, 9 /*b7e0*/,  10 /*b7e1*/, 10 /*b7e2*/,
    11 /*b7e3*/, 10 /*b7e4*/, 11 /*b7e5*/, 11 /*b7e6*/, 12 /*b7e7*/,
    10 /*b7e8*/, 11 /*b7e9*/, 11 /*b7ea*/, 12 /*b7eb*/, 11 /*b7ec*/,
    12 /*b7ed*/, 12 /*b7ee*/, 13 /*b7ef*/, 10 /*b7f0*/, 11 /*b7f1*/,
    11 /*b7f2*/, 12 /*b7f3*/, 11 /*b7f4*/, 12 /*b7f5*/, 12 /*b7f6*/,
    13 /*b7f7*/, 11 /*b7f8*/, 12 /*b7f9*/, 12 /*b7fa*/, 13 /*b7fb*/,
    12 /*b7fc*/, 13 /*b7fd*/, 13 /*b7fe*/, 14 /*b7ff*/, 4 /*b800*/,
    5 /*b801*/,  5 /*b802*/,  6 /*b803*/,  5 /*b804*/,  6 /*b805*/,
    6 /*b806*/,  7 /*b807*/,  5 /*b808*/,  6 /*b809*/,  6 /*b80a*/,
    7 /*b80b*/,  6 /*b80c*/,  7 /*b80d*/,  7 /*b80e*/,  8 /*b80f*/,
    5 /*b810*/,  6 /*b811*/,  6 /*b812*/,  7 /*b813*/,  6 /*b814*/,
    7 /*b815*/,  7 /*b816*/,  8 /*b817*/,  6 /*b818*/,  7 /*b819*/,
    7 /*b81a*/,  8 /*b81b*/,  7 /*b81c*/,  8 /*b81d*/,  8 /*b81e*/,
    9 /*b81f*/,  5 /*b820*/,  6 /*b821*/,  6 /*b822*/,  7 /*b823*/,
    6 /*b824*/,  7 /*b825*/,  7 /*b826*/,  8 /*b827*/,  6 /*b828*/,
    7 /*b829*/,  7 /*b82a*/,  8 /*b82b*/,  7 /*b82c*/,  8 /*b82d*/,
    8 /*b82e*/,  9 /*b82f*/,  6 /*b830*/,  7 /*b831*/,  7 /*b832*/,
    8 /*b833*/,  7 /*b834*/,  8 /*b835*/,  8 /*b836*/,  9 /*b837*/,
    7 /*b838*/,  8 /*b839*/,  8 /*b83a*/,  9 /*b83b*/,  8 /*b83c*/,
    9 /*b83d*/,  9 /*b83e*/,  10 /*b83f*/, 5 /*b840*/,  6 /*b841*/,
    6 /*b842*/,  7 /*b843*/,  6 /*b844*/,  7 /*b845*/,  7 /*b846*/,
    8 /*b847*/,  6 /*b848*/,  7 /*b849*/,  7 /*b84a*/,  8 /*b84b*/,
    7 /*b84c*/,  8 /*b84d*/,  8 /*b84e*/,  9 /*b84f*/,  6 /*b850*/,
    7 /*b851*/,  7 /*b852*/,  8 /*b853*/,  7 /*b854*/,  8 /*b855*/,
    8 /*b856*/,  9 /*b857*/,  7 /*b858*/,  8 /*b859*/,  8 /*b85a*/,
    9 /*b85b*/,  8 /*b85c*/,  9 /*b85d*/,  9 /*b85e*/,  10 /*b85f*/,
    6 /*b860*/,  7 /*b861*/,  7 /*b862*/,  8 /*b863*/,  7 /*b864*/,
    8 /*b865*/,  8 /*b866*/,  9 /*b867*/,  7 /*b868*/,  8 /*b869*/,
    8 /*b86a*/,  9 /*b86b*/,  8 /*b86c*/,  9 /*b86d*/,  9 /*b86e*/,
    10 /*b86f*/, 7 /*b870*/,  8 /*b871*/,  8 /*b872*/,  9 /*b873*/,
    8 /*b874*/,  9 /*b875*/,  9 /*b876*/,  10 /*b877*/, 8 /*b878*/,
    9 /*b879*/,  9 /*b87a*/,  10 /*b87b*/, 9 /*b87c*/,  10 /*b87d*/,
    10 /*b87e*/, 11 /*b87f*/, 5 /*b880*/,  6 /*b881*/,  6 /*b882*/,
    7 /*b883*/,  6 /*b884*/,  7 /*b885*/,  7 /*b886*/,  8 /*b887*/,
    6 /*b888*/,  7 /*b889*/,  7 /*b88a*/,  8 /*b88b*/,  7 /*b88c*/,
    8 /*b88d*/,  8 /*b88e*/,  9 /*b88f*/,  6 /*b890*/,  7 /*b891*/,
    7 /*b892*/,  8 /*b893*/,  7 /*b894*/,  8 /*b895*/,  8 /*b896*/,
    9 /*b897*/,  7 /*b898*/,  8 /*b899*/,  8 /*b89a*/,  9 /*b89b*/,
    8 /*b89c*/,  9 /*b89d*/,  9 /*b89e*/,  10 /*b89f*/, 6 /*b8a0*/,
    7 /*b8a1*/,  7 /*b8a2*/,  8 /*b8a3*/,  7 /*b8a4*/,  8 /*b8a5*/,
    8 /*b8a6*/,  9 /*b8a7*/,  7 /*b8a8*/,  8 /*b8a9*/,  8 /*b8aa*/,
    9 /*b8ab*/,  8 /*b8ac*/,  9 /*b8ad*/,  9 /*b8ae*/,  10 /*b8af*/,
    7 /*b8b0*/,  8 /*b8b1*/,  8 /*b8b2*/,  9 /*b8b3*/,  8 /*b8b4*/,
    9 /*b8b5*/,  9 /*b8b6*/,  10 /*b8b7*/, 8 /*b8b8*/,  9 /*b8b9*/,
    9 /*b8ba*/,  10 /*b8bb*/, 9 /*b8bc*/,  10 /*b8bd*/, 10 /*b8be*/,
    11 /*b8bf*/, 6 /*b8c0*/,  7 /*b8c1*/,  7 /*b8c2*/,  8 /*b8c3*/,
    7 /*b8c4*/,  8 /*b8c5*/,  8 /*b8c6*/,  9 /*b8c7*/,  7 /*b8c8*/,
    8 /*b8c9*/,  8 /*b8ca*/,  9 /*b8cb*/,  8 /*b8cc*/,  9 /*b8cd*/,
    9 /*b8ce*/,  10 /*b8cf*/, 7 /*b8d0*/,  8 /*b8d1*/,  8 /*b8d2*/,
    9 /*b8d3*/,  8 /*b8d4*/,  9 /*b8d5*/,  9 /*b8d6*/,  10 /*b8d7*/,
    8 /*b8d8*/,  9 /*b8d9*/,  9 /*b8da*/,  10 /*b8db*/, 9 /*b8dc*/,
    10 /*b8dd*/, 10 /*b8de*/, 11 /*b8df*/, 7 /*b8e0*/,  8 /*b8e1*/,
    8 /*b8e2*/,  9 /*b8e3*/,  8 /*b8e4*/,  9 /*b8e5*/,  9 /*b8e6*/,
    10 /*b8e7*/, 8 /*b8e8*/,  9 /*b8e9*/,  9 /*b8ea*/,  10 /*b8eb*/,
    9 /*b8ec*/,  10 /*b8ed*/, 10 /*b8ee*/, 11 /*b8ef*/, 8 /*b8f0*/,
    9 /*b8f1*/,  9 /*b8f2*/,  10 /*b8f3*/, 9 /*b8f4*/,  10 /*b8f5*/,
    10 /*b8f6*/, 11 /*b8f7*/, 9 /*b8f8*/,  10 /*b8f9*/, 10 /*b8fa*/,
    11 /*b8fb*/, 10 /*b8fc*/, 11 /*b8fd*/, 11 /*b8fe*/, 12 /*b8ff*/,
    5 /*b900*/,  6 /*b901*/,  6 /*b902*/,  7 /*b903*/,  6 /*b904*/,
    7 /*b905*/,  7 /*b906*/,  8 /*b907*/,  6 /*b908*/,  7 /*b909*/,
    7 /*b90a*/,  8 /*b90b*/,  7 /*b90c*/,  8 /*b90d*/,  8 /*b90e*/,
    9 /*b90f*/,  6 /*b910*/,  7 /*b911*/,  7 /*b912*/,  8 /*b913*/,
    7 /*b914*/,  8 /*b915*/,  8 /*b916*/,  9 /*b917*/,  7 /*b918*/,
    8 /*b919*/,  8 /*b91a*/,  9 /*b91b*/,  8 /*b91c*/,  9 /*b91d*/,
    9 /*b91e*/,  10 /*b91f*/, 6 /*b920*/,  7 /*b921*/,  7 /*b922*/,
    8 /*b923*/,  7 /*b924*/,  8 /*b925*/,  8 /*b926*/,  9 /*b927*/,
    7 /*b928*/,  8 /*b929*/,  8 /*b92a*/,  9 /*b92b*/,  8 /*b92c*/,
    9 /*b92d*/,  9 /*b92e*/,  10 /*b92f*/, 7 /*b930*/,  8 /*b931*/,
    8 /*b932*/,  9 /*b933*/,  8 /*b934*/,  9 /*b935*/,  9 /*b936*/,
    10 /*b937*/, 8 /*b938*/,  9 /*b939*/,  9 /*b93a*/,  10 /*b93b*/,
    9 /*b93c*/,  10 /*b93d*/, 10 /*b93e*/, 11 /*b93f*/, 6 /*b940*/,
    7 /*b941*/,  7 /*b942*/,  8 /*b943*/,  7 /*b944*/,  8 /*b945*/,
    8 /*b946*/,  9 /*b947*/,  7 /*b948*/,  8 /*b949*/,  8 /*b94a*/,
    9 /*b94b*/,  8 /*b94c*/,  9 /*b94d*/,  9 /*b94e*/,  10 /*b94f*/,
    7 /*b950*/,  8 /*b951*/,  8 /*b952*/,  9 /*b953*/,  8 /*b954*/,
    9 /*b955*/,  9 /*b956*/,  10 /*b957*/, 8 /*b958*/,  9 /*b959*/,
    9 /*b95a*/,  10 /*b95b*/, 9 /*b95c*/,  10 /*b95d*/, 10 /*b95e*/,
    11 /*b95f*/, 7 /*b960*/,  8 /*b961*/,  8 /*b962*/,  9 /*b963*/,
    8 /*b964*/,  9 /*b965*/,  9 /*b966*/,  10 /*b967*/, 8 /*b968*/,
    9 /*b969*/,  9 /*b96a*/,  10 /*b96b*/, 9 /*b96c*/,  10 /*b96d*/,
    10 /*b96e*/, 11 /*b96f*/, 8 /*b970*/,  9 /*b971*/,  9 /*b972*/,
    10 /*b973*/, 9 /*b974*/,  10 /*b975*/, 10 /*b976*/, 11 /*b977*/,
    9 /*b978*/,  10 /*b979*/, 10 /*b97a*/, 11 /*b97b*/, 10 /*b97c*/,
    11 /*b97d*/, 11 /*b97e*/, 12 /*b97f*/, 6 /*b980*/,  7 /*b981*/,
    7 /*b982*/,  8 /*b983*/,  7 /*b984*/,  8 /*b985*/,  8 /*b986*/,
    9 /*b987*/,  7 /*b988*/,  8 /*b989*/,  8 /*b98a*/,  9 /*b98b*/,
    8 /*b98c*/,  9 /*b98d*/,  9 /*b98e*/,  10 /*b98f*/, 7 /*b990*/,
    8 /*b991*/,  8 /*b992*/,  9 /*b993*/,  8 /*b994*/,  9 /*b995*/,
    9 /*b996*/,  10 /*b997*/, 8 /*b998*/,  9 /*b999*/,  9 /*b99a*/,
    10 /*b99b*/, 9 /*b99c*/,  10 /*b99d*/, 10 /*b99e*/, 11 /*b99f*/,
    7 /*b9a0*/,  8 /*b9a1*/,  8 /*b9a2*/,  9 /*b9a3*/,  8 /*b9a4*/,
    9 /*b9a5*/,  9 /*b9a6*/,  10 /*b9a7*/, 8 /*b9a8*/,  9 /*b9a9*/,
    9 /*b9aa*/,  10 /*b9ab*/, 9 /*b9ac*/,  10 /*b9ad*/, 10 /*b9ae*/,
    11 /*b9af*/, 8 /*b9b0*/,  9 /*b9b1*/,  9 /*b9b2*/,  10 /*b9b3*/,
    9 /*b9b4*/,  10 /*b9b5*/, 10 /*b9b6*/, 11 /*b9b7*/, 9 /*b9b8*/,
    10 /*b9b9*/, 10 /*b9ba*/, 11 /*b9bb*/, 10 /*b9bc*/, 11 /*b9bd*/,
    11 /*b9be*/, 12 /*b9bf*/, 7 /*b9c0*/,  8 /*b9c1*/,  8 /*b9c2*/,
    9 /*b9c3*/,  8 /*b9c4*/,  9 /*b9c5*/,  9 /*b9c6*/,  10 /*b9c7*/,
    8 /*b9c8*/,  9 /*b9c9*/,  9 /*b9ca*/,  10 /*b9cb*/, 9 /*b9cc*/,
    10 /*b9cd*/, 10 /*b9ce*/, 11 /*b9cf*/, 8 /*b9d0*/,  9 /*b9d1*/,
    9 /*b9d2*/,  10 /*b9d3*/, 9 /*b9d4*/,  10 /*b9d5*/, 10 /*b9d6*/,
    11 /*b9d7*/, 9 /*b9d8*/,  10 /*b9d9*/, 10 /*b9da*/, 11 /*b9db*/,
    10 /*b9dc*/, 11 /*b9dd*/, 11 /*b9de*/, 12 /*b9df*/, 8 /*b9e0*/,
    9 /*b9e1*/,  9 /*b9e2*/,  10 /*b9e3*/, 9 /*b9e4*/,  10 /*b9e5*/,
    10 /*b9e6*/, 11 /*b9e7*/, 9 /*b9e8*/,  10 /*b9e9*/, 10 /*b9ea*/,
    11 /*b9eb*/, 10 /*b9ec*/, 11 /*b9ed*/, 11 /*b9ee*/, 12 /*b9ef*/,
    9 /*b9f0*/,  10 /*b9f1*/, 10 /*b9f2*/, 11 /*b9f3*/, 10 /*b9f4*/,
    11 /*b9f5*/, 11 /*b9f6*/, 12 /*b9f7*/, 10 /*b9f8*/, 11 /*b9f9*/,
    11 /*b9fa*/, 12 /*b9fb*/, 11 /*b9fc*/, 12 /*b9fd*/, 12 /*b9fe*/,
    13 /*b9ff*/, 5 /*ba00*/,  6 /*ba01*/,  6 /*ba02*/,  7 /*ba03*/,
    6 /*ba04*/,  7 /*ba05*/,  7 /*ba06*/,  8 /*ba07*/,  6 /*ba08*/,
    7 /*ba09*/,  7 /*ba0a*/,  8 /*ba0b*/,  7 /*ba0c*/,  8 /*ba0d*/,
    8 /*ba0e*/,  9 /*ba0f*/,  6 /*ba10*/,  7 /*ba11*/,  7 /*ba12*/,
    8 /*ba13*/,  7 /*ba14*/,  8 /*ba15*/,  8 /*ba16*/,  9 /*ba17*/,
    7 /*ba18*/,  8 /*ba19*/,  8 /*ba1a*/,  9 /*ba1b*/,  8 /*ba1c*/,
    9 /*ba1d*/,  9 /*ba1e*/,  10 /*ba1f*/, 6 /*ba20*/,  7 /*ba21*/,
    7 /*ba22*/,  8 /*ba23*/,  7 /*ba24*/,  8 /*ba25*/,  8 /*ba26*/,
    9 /*ba27*/,  7 /*ba28*/,  8 /*ba29*/,  8 /*ba2a*/,  9 /*ba2b*/,
    8 /*ba2c*/,  9 /*ba2d*/,  9 /*ba2e*/,  10 /*ba2f*/, 7 /*ba30*/,
    8 /*ba31*/,  8 /*ba32*/,  9 /*ba33*/,  8 /*ba34*/,  9 /*ba35*/,
    9 /*ba36*/,  10 /*ba37*/, 8 /*ba38*/,  9 /*ba39*/,  9 /*ba3a*/,
    10 /*ba3b*/, 9 /*ba3c*/,  10 /*ba3d*/, 10 /*ba3e*/, 11 /*ba3f*/,
    6 /*ba40*/,  7 /*ba41*/,  7 /*ba42*/,  8 /*ba43*/,  7 /*ba44*/,
    8 /*ba45*/,  8 /*ba46*/,  9 /*ba47*/,  7 /*ba48*/,  8 /*ba49*/,
    8 /*ba4a*/,  9 /*ba4b*/,  8 /*ba4c*/,  9 /*ba4d*/,  9 /*ba4e*/,
    10 /*ba4f*/, 7 /*ba50*/,  8 /*ba51*/,  8 /*ba52*/,  9 /*ba53*/,
    8 /*ba54*/,  9 /*ba55*/,  9 /*ba56*/,  10 /*ba57*/, 8 /*ba58*/,
    9 /*ba59*/,  9 /*ba5a*/,  10 /*ba5b*/, 9 /*ba5c*/,  10 /*ba5d*/,
    10 /*ba5e*/, 11 /*ba5f*/, 7 /*ba60*/,  8 /*ba61*/,  8 /*ba62*/,
    9 /*ba63*/,  8 /*ba64*/,  9 /*ba65*/,  9 /*ba66*/,  10 /*ba67*/,
    8 /*ba68*/,  9 /*ba69*/,  9 /*ba6a*/,  10 /*ba6b*/, 9 /*ba6c*/,
    10 /*ba6d*/, 10 /*ba6e*/, 11 /*ba6f*/, 8 /*ba70*/,  9 /*ba71*/,
    9 /*ba72*/,  10 /*ba73*/, 9 /*ba74*/,  10 /*ba75*/, 10 /*ba76*/,
    11 /*ba77*/, 9 /*ba78*/,  10 /*ba79*/, 10 /*ba7a*/, 11 /*ba7b*/,
    10 /*ba7c*/, 11 /*ba7d*/, 11 /*ba7e*/, 12 /*ba7f*/, 6 /*ba80*/,
    7 /*ba81*/,  7 /*ba82*/,  8 /*ba83*/,  7 /*ba84*/,  8 /*ba85*/,
    8 /*ba86*/,  9 /*ba87*/,  7 /*ba88*/,  8 /*ba89*/,  8 /*ba8a*/,
    9 /*ba8b*/,  8 /*ba8c*/,  9 /*ba8d*/,  9 /*ba8e*/,  10 /*ba8f*/,
    7 /*ba90*/,  8 /*ba91*/,  8 /*ba92*/,  9 /*ba93*/,  8 /*ba94*/,
    9 /*ba95*/,  9 /*ba96*/,  10 /*ba97*/, 8 /*ba98*/,  9 /*ba99*/,
    9 /*ba9a*/,  10 /*ba9b*/, 9 /*ba9c*/,  10 /*ba9d*/, 10 /*ba9e*/,
    11 /*ba9f*/, 7 /*baa0*/,  8 /*baa1*/,  8 /*baa2*/,  9 /*baa3*/,
    8 /*baa4*/,  9 /*baa5*/,  9 /*baa6*/,  10 /*baa7*/, 8 /*baa8*/,
    9 /*baa9*/,  9 /*baaa*/,  10 /*baab*/, 9 /*baac*/,  10 /*baad*/,
    10 /*baae*/, 11 /*baaf*/, 8 /*bab0*/,  9 /*bab1*/,  9 /*bab2*/,
    10 /*bab3*/, 9 /*bab4*/,  10 /*bab5*/, 10 /*bab6*/, 11 /*bab7*/,
    9 /*bab8*/,  10 /*bab9*/, 10 /*baba*/, 11 /*babb*/, 10 /*babc*/,
    11 /*babd*/, 11 /*babe*/, 12 /*babf*/, 7 /*bac0*/,  8 /*bac1*/,
    8 /*bac2*/,  9 /*bac3*/,  8 /*bac4*/,  9 /*bac5*/,  9 /*bac6*/,
    10 /*bac7*/, 8 /*bac8*/,  9 /*bac9*/,  9 /*baca*/,  10 /*bacb*/,
    9 /*bacc*/,  10 /*bacd*/, 10 /*bace*/, 11 /*bacf*/, 8 /*bad0*/,
    9 /*bad1*/,  9 /*bad2*/,  10 /*bad3*/, 9 /*bad4*/,  10 /*bad5*/,
    10 /*bad6*/, 11 /*bad7*/, 9 /*bad8*/,  10 /*bad9*/, 10 /*bada*/,
    11 /*badb*/, 10 /*badc*/, 11 /*badd*/, 11 /*bade*/, 12 /*badf*/,
    8 /*bae0*/,  9 /*bae1*/,  9 /*bae2*/,  10 /*bae3*/, 9 /*bae4*/,
    10 /*bae5*/, 10 /*bae6*/, 11 /*bae7*/, 9 /*bae8*/,  10 /*bae9*/,
    10 /*baea*/, 11 /*baeb*/, 10 /*baec*/, 11 /*baed*/, 11 /*baee*/,
    12 /*baef*/, 9 /*baf0*/,  10 /*baf1*/, 10 /*baf2*/, 11 /*baf3*/,
    10 /*baf4*/, 11 /*baf5*/, 11 /*baf6*/, 12 /*baf7*/, 10 /*baf8*/,
    11 /*baf9*/, 11 /*bafa*/, 12 /*bafb*/, 11 /*bafc*/, 12 /*bafd*/,
    12 /*bafe*/, 13 /*baff*/, 6 /*bb00*/,  7 /*bb01*/,  7 /*bb02*/,
    8 /*bb03*/,  7 /*bb04*/,  8 /*bb05*/,  8 /*bb06*/,  9 /*bb07*/,
    7 /*bb08*/,  8 /*bb09*/,  8 /*bb0a*/,  9 /*bb0b*/,  8 /*bb0c*/,
    9 /*bb0d*/,  9 /*bb0e*/,  10 /*bb0f*/, 7 /*bb10*/,  8 /*bb11*/,
    8 /*bb12*/,  9 /*bb13*/,  8 /*bb14*/,  9 /*bb15*/,  9 /*bb16*/,
    10 /*bb17*/, 8 /*bb18*/,  9 /*bb19*/,  9 /*bb1a*/,  10 /*bb1b*/,
    9 /*bb1c*/,  10 /*bb1d*/, 10 /*bb1e*/, 11 /*bb1f*/, 7 /*bb20*/,
    8 /*bb21*/,  8 /*bb22*/,  9 /*bb23*/,  8 /*bb24*/,  9 /*bb25*/,
    9 /*bb26*/,  10 /*bb27*/, 8 /*bb28*/,  9 /*bb29*/,  9 /*bb2a*/,
    10 /*bb2b*/, 9 /*bb2c*/,  10 /*bb2d*/, 10 /*bb2e*/, 11 /*bb2f*/,
    8 /*bb30*/,  9 /*bb31*/,  9 /*bb32*/,  10 /*bb33*/, 9 /*bb34*/,
    10 /*bb35*/, 10 /*bb36*/, 11 /*bb37*/, 9 /*bb38*/,  10 /*bb39*/,
    10 /*bb3a*/, 11 /*bb3b*/, 10 /*bb3c*/, 11 /*bb3d*/, 11 /*bb3e*/,
    12 /*bb3f*/, 7 /*bb40*/,  8 /*bb41*/,  8 /*bb42*/,  9 /*bb43*/,
    8 /*bb44*/,  9 /*bb45*/,  9 /*bb46*/,  10 /*bb47*/, 8 /*bb48*/,
    9 /*bb49*/,  9 /*bb4a*/,  10 /*bb4b*/, 9 /*bb4c*/,  10 /*bb4d*/,
    10 /*bb4e*/, 11 /*bb4f*/, 8 /*bb50*/,  9 /*bb51*/,  9 /*bb52*/,
    10 /*bb53*/, 9 /*bb54*/,  10 /*bb55*/, 10 /*bb56*/, 11 /*bb57*/,
    9 /*bb58*/,  10 /*bb59*/, 10 /*bb5a*/, 11 /*bb5b*/, 10 /*bb5c*/,
    11 /*bb5d*/, 11 /*bb5e*/, 12 /*bb5f*/, 8 /*bb60*/,  9 /*bb61*/,
    9 /*bb62*/,  10 /*bb63*/, 9 /*bb64*/,  10 /*bb65*/, 10 /*bb66*/,
    11 /*bb67*/, 9 /*bb68*/,  10 /*bb69*/, 10 /*bb6a*/, 11 /*bb6b*/,
    10 /*bb6c*/, 11 /*bb6d*/, 11 /*bb6e*/, 12 /*bb6f*/, 9 /*bb70*/,
    10 /*bb71*/, 10 /*bb72*/, 11 /*bb73*/, 10 /*bb74*/, 11 /*bb75*/,
    11 /*bb76*/, 12 /*bb77*/, 10 /*bb78*/, 11 /*bb79*/, 11 /*bb7a*/,
    12 /*bb7b*/, 11 /*bb7c*/, 12 /*bb7d*/, 12 /*bb7e*/, 13 /*bb7f*/,
    7 /*bb80*/,  8 /*bb81*/,  8 /*bb82*/,  9 /*bb83*/,  8 /*bb84*/,
    9 /*bb85*/,  9 /*bb86*/,  10 /*bb87*/, 8 /*bb88*/,  9 /*bb89*/,
    9 /*bb8a*/,  10 /*bb8b*/, 9 /*bb8c*/,  10 /*bb8d*/, 10 /*bb8e*/,
    11 /*bb8f*/, 8 /*bb90*/,  9 /*bb91*/,  9 /*bb92*/,  10 /*bb93*/,
    9 /*bb94*/,  10 /*bb95*/, 10 /*bb96*/, 11 /*bb97*/, 9 /*bb98*/,
    10 /*bb99*/, 10 /*bb9a*/, 11 /*bb9b*/, 10 /*bb9c*/, 11 /*bb9d*/,
    11 /*bb9e*/, 12 /*bb9f*/, 8 /*bba0*/,  9 /*bba1*/,  9 /*bba2*/,
    10 /*bba3*/, 9 /*bba4*/,  10 /*bba5*/, 10 /*bba6*/, 11 /*bba7*/,
    9 /*bba8*/,  10 /*bba9*/, 10 /*bbaa*/, 11 /*bbab*/, 10 /*bbac*/,
    11 /*bbad*/, 11 /*bbae*/, 12 /*bbaf*/, 9 /*bbb0*/,  10 /*bbb1*/,
    10 /*bbb2*/, 11 /*bbb3*/, 10 /*bbb4*/, 11 /*bbb5*/, 11 /*bbb6*/,
    12 /*bbb7*/, 10 /*bbb8*/, 11 /*bbb9*/, 11 /*bbba*/, 12 /*bbbb*/,
    11 /*bbbc*/, 12 /*bbbd*/, 12 /*bbbe*/, 13 /*bbbf*/, 8 /*bbc0*/,
    9 /*bbc1*/,  9 /*bbc2*/,  10 /*bbc3*/, 9 /*bbc4*/,  10 /*bbc5*/,
    10 /*bbc6*/, 11 /*bbc7*/, 9 /*bbc8*/,  10 /*bbc9*/, 10 /*bbca*/,
    11 /*bbcb*/, 10 /*bbcc*/, 11 /*bbcd*/, 11 /*bbce*/, 12 /*bbcf*/,
    9 /*bbd0*/,  10 /*bbd1*/, 10 /*bbd2*/, 11 /*bbd3*/, 10 /*bbd4*/,
    11 /*bbd5*/, 11 /*bbd6*/, 12 /*bbd7*/, 10 /*bbd8*/, 11 /*bbd9*/,
    11 /*bbda*/, 12 /*bbdb*/, 11 /*bbdc*/, 12 /*bbdd*/, 12 /*bbde*/,
    13 /*bbdf*/, 9 /*bbe0*/,  10 /*bbe1*/, 10 /*bbe2*/, 11 /*bbe3*/,
    10 /*bbe4*/, 11 /*bbe5*/, 11 /*bbe6*/, 12 /*bbe7*/, 10 /*bbe8*/,
    11 /*bbe9*/, 11 /*bbea*/, 12 /*bbeb*/, 11 /*bbec*/, 12 /*bbed*/,
    12 /*bbee*/, 13 /*bbef*/, 10 /*bbf0*/, 11 /*bbf1*/, 11 /*bbf2*/,
    12 /*bbf3*/, 11 /*bbf4*/, 12 /*bbf5*/, 12 /*bbf6*/, 13 /*bbf7*/,
    11 /*bbf8*/, 12 /*bbf9*/, 12 /*bbfa*/, 13 /*bbfb*/, 12 /*bbfc*/,
    13 /*bbfd*/, 13 /*bbfe*/, 14 /*bbff*/, 5 /*bc00*/,  6 /*bc01*/,
    6 /*bc02*/,  7 /*bc03*/,  6 /*bc04*/,  7 /*bc05*/,  7 /*bc06*/,
    8 /*bc07*/,  6 /*bc08*/,  7 /*bc09*/,  7 /*bc0a*/,  8 /*bc0b*/,
    7 /*bc0c*/,  8 /*bc0d*/,  8 /*bc0e*/,  9 /*bc0f*/,  6 /*bc10*/,
    7 /*bc11*/,  7 /*bc12*/,  8 /*bc13*/,  7 /*bc14*/,  8 /*bc15*/,
    8 /*bc16*/,  9 /*bc17*/,  7 /*bc18*/,  8 /*bc19*/,  8 /*bc1a*/,
    9 /*bc1b*/,  8 /*bc1c*/,  9 /*bc1d*/,  9 /*bc1e*/,  10 /*bc1f*/,
    6 /*bc20*/,  7 /*bc21*/,  7 /*bc22*/,  8 /*bc23*/,  7 /*bc24*/,
    8 /*bc25*/,  8 /*bc26*/,  9 /*bc27*/,  7 /*bc28*/,  8 /*bc29*/,
    8 /*bc2a*/,  9 /*bc2b*/,  8 /*bc2c*/,  9 /*bc2d*/,  9 /*bc2e*/,
    10 /*bc2f*/, 7 /*bc30*/,  8 /*bc31*/,  8 /*bc32*/,  9 /*bc33*/,
    8 /*bc34*/,  9 /*bc35*/,  9 /*bc36*/,  10 /*bc37*/, 8 /*bc38*/,
    9 /*bc39*/,  9 /*bc3a*/,  10 /*bc3b*/, 9 /*bc3c*/,  10 /*bc3d*/,
    10 /*bc3e*/, 11 /*bc3f*/, 6 /*bc40*/,  7 /*bc41*/,  7 /*bc42*/,
    8 /*bc43*/,  7 /*bc44*/,  8 /*bc45*/,  8 /*bc46*/,  9 /*bc47*/,
    7 /*bc48*/,  8 /*bc49*/,  8 /*bc4a*/,  9 /*bc4b*/,  8 /*bc4c*/,
    9 /*bc4d*/,  9 /*bc4e*/,  10 /*bc4f*/, 7 /*bc50*/,  8 /*bc51*/,
    8 /*bc52*/,  9 /*bc53*/,  8 /*bc54*/,  9 /*bc55*/,  9 /*bc56*/,
    10 /*bc57*/, 8 /*bc58*/,  9 /*bc59*/,  9 /*bc5a*/,  10 /*bc5b*/,
    9 /*bc5c*/,  10 /*bc5d*/, 10 /*bc5e*/, 11 /*bc5f*/, 7 /*bc60*/,
    8 /*bc61*/,  8 /*bc62*/,  9 /*bc63*/,  8 /*bc64*/,  9 /*bc65*/,
    9 /*bc66*/,  10 /*bc67*/, 8 /*bc68*/,  9 /*bc69*/,  9 /*bc6a*/,
    10 /*bc6b*/, 9 /*bc6c*/,  10 /*bc6d*/, 10 /*bc6e*/, 11 /*bc6f*/,
    8 /*bc70*/,  9 /*bc71*/,  9 /*bc72*/,  10 /*bc73*/, 9 /*bc74*/,
    10 /*bc75*/, 10 /*bc76*/, 11 /*bc77*/, 9 /*bc78*/,  10 /*bc79*/,
    10 /*bc7a*/, 11 /*bc7b*/, 10 /*bc7c*/, 11 /*bc7d*/, 11 /*bc7e*/,
    12 /*bc7f*/, 6 /*bc80*/,  7 /*bc81*/,  7 /*bc82*/,  8 /*bc83*/,
    7 /*bc84*/,  8 /*bc85*/,  8 /*bc86*/,  9 /*bc87*/,  7 /*bc88*/,
    8 /*bc89*/,  8 /*bc8a*/,  9 /*bc8b*/,  8 /*bc8c*/,  9 /*bc8d*/,
    9 /*bc8e*/,  10 /*bc8f*/, 7 /*bc90*/,  8 /*bc91*/,  8 /*bc92*/,
    9 /*bc93*/,  8 /*bc94*/,  9 /*bc95*/,  9 /*bc96*/,  10 /*bc97*/,
    8 /*bc98*/,  9 /*bc99*/,  9 /*bc9a*/,  10 /*bc9b*/, 9 /*bc9c*/,
    10 /*bc9d*/, 10 /*bc9e*/, 11 /*bc9f*/, 7 /*bca0*/,  8 /*bca1*/,
    8 /*bca2*/,  9 /*bca3*/,  8 /*bca4*/,  9 /*bca5*/,  9 /*bca6*/,
    10 /*bca7*/, 8 /*bca8*/,  9 /*bca9*/,  9 /*bcaa*/,  10 /*bcab*/,
    9 /*bcac*/,  10 /*bcad*/, 10 /*bcae*/, 11 /*bcaf*/, 8 /*bcb0*/,
    9 /*bcb1*/,  9 /*bcb2*/,  10 /*bcb3*/, 9 /*bcb4*/,  10 /*bcb5*/,
    10 /*bcb6*/, 11 /*bcb7*/, 9 /*bcb8*/,  10 /*bcb9*/, 10 /*bcba*/,
    11 /*bcbb*/, 10 /*bcbc*/, 11 /*bcbd*/, 11 /*bcbe*/, 12 /*bcbf*/,
    7 /*bcc0*/,  8 /*bcc1*/,  8 /*bcc2*/,  9 /*bcc3*/,  8 /*bcc4*/,
    9 /*bcc5*/,  9 /*bcc6*/,  10 /*bcc7*/, 8 /*bcc8*/,  9 /*bcc9*/,
    9 /*bcca*/,  10 /*bccb*/, 9 /*bccc*/,  10 /*bccd*/, 10 /*bcce*/,
    11 /*bccf*/, 8 /*bcd0*/,  9 /*bcd1*/,  9 /*bcd2*/,  10 /*bcd3*/,
    9 /*bcd4*/,  10 /*bcd5*/, 10 /*bcd6*/, 11 /*bcd7*/, 9 /*bcd8*/,
    10 /*bcd9*/, 10 /*bcda*/, 11 /*bcdb*/, 10 /*bcdc*/, 11 /*bcdd*/,
    11 /*bcde*/, 12 /*bcdf*/, 8 /*bce0*/,  9 /*bce1*/,  9 /*bce2*/,
    10 /*bce3*/, 9 /*bce4*/,  10 /*bce5*/, 10 /*bce6*/, 11 /*bce7*/,
    9 /*bce8*/,  10 /*bce9*/, 10 /*bcea*/, 11 /*bceb*/, 10 /*bcec*/,
    11 /*bced*/, 11 /*bcee*/, 12 /*bcef*/, 9 /*bcf0*/,  10 /*bcf1*/,
    10 /*bcf2*/, 11 /*bcf3*/, 10 /*bcf4*/, 11 /*bcf5*/, 11 /*bcf6*/,
    12 /*bcf7*/, 10 /*bcf8*/, 11 /*bcf9*/, 11 /*bcfa*/, 12 /*bcfb*/,
    11 /*bcfc*/, 12 /*bcfd*/, 12 /*bcfe*/, 13 /*bcff*/, 6 /*bd00*/,
    7 /*bd01*/,  7 /*bd02*/,  8 /*bd03*/,  7 /*bd04*/,  8 /*bd05*/,
    8 /*bd06*/,  9 /*bd07*/,  7 /*bd08*/,  8 /*bd09*/,  8 /*bd0a*/,
    9 /*bd0b*/,  8 /*bd0c*/,  9 /*bd0d*/,  9 /*bd0e*/,  10 /*bd0f*/,
    7 /*bd10*/,  8 /*bd11*/,  8 /*bd12*/,  9 /*bd13*/,  8 /*bd14*/,
    9 /*bd15*/,  9 /*bd16*/,  10 /*bd17*/, 8 /*bd18*/,  9 /*bd19*/,
    9 /*bd1a*/,  10 /*bd1b*/, 9 /*bd1c*/,  10 /*bd1d*/, 10 /*bd1e*/,
    11 /*bd1f*/, 7 /*bd20*/,  8 /*bd21*/,  8 /*bd22*/,  9 /*bd23*/,
    8 /*bd24*/,  9 /*bd25*/,  9 /*bd26*/,  10 /*bd27*/, 8 /*bd28*/,
    9 /*bd29*/,  9 /*bd2a*/,  10 /*bd2b*/, 9 /*bd2c*/,  10 /*bd2d*/,
    10 /*bd2e*/, 11 /*bd2f*/, 8 /*bd30*/,  9 /*bd31*/,  9 /*bd32*/,
    10 /*bd33*/, 9 /*bd34*/,  10 /*bd35*/, 10 /*bd36*/, 11 /*bd37*/,
    9 /*bd38*/,  10 /*bd39*/, 10 /*bd3a*/, 11 /*bd3b*/, 10 /*bd3c*/,
    11 /*bd3d*/, 11 /*bd3e*/, 12 /*bd3f*/, 7 /*bd40*/,  8 /*bd41*/,
    8 /*bd42*/,  9 /*bd43*/,  8 /*bd44*/,  9 /*bd45*/,  9 /*bd46*/,
    10 /*bd47*/, 8 /*bd48*/,  9 /*bd49*/,  9 /*bd4a*/,  10 /*bd4b*/,
    9 /*bd4c*/,  10 /*bd4d*/, 10 /*bd4e*/, 11 /*bd4f*/, 8 /*bd50*/,
    9 /*bd51*/,  9 /*bd52*/,  10 /*bd53*/, 9 /*bd54*/,  10 /*bd55*/,
    10 /*bd56*/, 11 /*bd57*/, 9 /*bd58*/,  10 /*bd59*/, 10 /*bd5a*/,
    11 /*bd5b*/, 10 /*bd5c*/, 11 /*bd5d*/, 11 /*bd5e*/, 12 /*bd5f*/,
    8 /*bd60*/,  9 /*bd61*/,  9 /*bd62*/,  10 /*bd63*/, 9 /*bd64*/,
    10 /*bd65*/, 10 /*bd66*/, 11 /*bd67*/, 9 /*bd68*/,  10 /*bd69*/,
    10 /*bd6a*/, 11 /*bd6b*/, 10 /*bd6c*/, 11 /*bd6d*/, 11 /*bd6e*/,
    12 /*bd6f*/, 9 /*bd70*/,  10 /*bd71*/, 10 /*bd72*/, 11 /*bd73*/,
    10 /*bd74*/, 11 /*bd75*/, 11 /*bd76*/, 12 /*bd77*/, 10 /*bd78*/,
    11 /*bd79*/, 11 /*bd7a*/, 12 /*bd7b*/, 11 /*bd7c*/, 12 /*bd7d*/,
    12 /*bd7e*/, 13 /*bd7f*/, 7 /*bd80*/,  8 /*bd81*/,  8 /*bd82*/,
    9 /*bd83*/,  8 /*bd84*/,  9 /*bd85*/,  9 /*bd86*/,  10 /*bd87*/,
    8 /*bd88*/,  9 /*bd89*/,  9 /*bd8a*/,  10 /*bd8b*/, 9 /*bd8c*/,
    10 /*bd8d*/, 10 /*bd8e*/, 11 /*bd8f*/, 8 /*bd90*/,  9 /*bd91*/,
    9 /*bd92*/,  10 /*bd93*/, 9 /*bd94*/,  10 /*bd95*/, 10 /*bd96*/,
    11 /*bd97*/, 9 /*bd98*/,  10 /*bd99*/, 10 /*bd9a*/, 11 /*bd9b*/,
    10 /*bd9c*/, 11 /*bd9d*/, 11 /*bd9e*/, 12 /*bd9f*/, 8 /*bda0*/,
    9 /*bda1*/,  9 /*bda2*/,  10 /*bda3*/, 9 /*bda4*/,  10 /*bda5*/,
    10 /*bda6*/, 11 /*bda7*/, 9 /*bda8*/,  10 /*bda9*/, 10 /*bdaa*/,
    11 /*bdab*/, 10 /*bdac*/, 11 /*bdad*/, 11 /*bdae*/, 12 /*bdaf*/,
    9 /*bdb0*/,  10 /*bdb1*/, 10 /*bdb2*/, 11 /*bdb3*/, 10 /*bdb4*/,
    11 /*bdb5*/, 11 /*bdb6*/, 12 /*bdb7*/, 10 /*bdb8*/, 11 /*bdb9*/,
    11 /*bdba*/, 12 /*bdbb*/, 11 /*bdbc*/, 12 /*bdbd*/, 12 /*bdbe*/,
    13 /*bdbf*/, 8 /*bdc0*/,  9 /*bdc1*/,  9 /*bdc2*/,  10 /*bdc3*/,
    9 /*bdc4*/,  10 /*bdc5*/, 10 /*bdc6*/, 11 /*bdc7*/, 9 /*bdc8*/,
    10 /*bdc9*/, 10 /*bdca*/, 11 /*bdcb*/, 10 /*bdcc*/, 11 /*bdcd*/,
    11 /*bdce*/, 12 /*bdcf*/, 9 /*bdd0*/,  10 /*bdd1*/, 10 /*bdd2*/,
    11 /*bdd3*/, 10 /*bdd4*/, 11 /*bdd5*/, 11 /*bdd6*/, 12 /*bdd7*/,
    10 /*bdd8*/, 11 /*bdd9*/, 11 /*bdda*/, 12 /*bddb*/, 11 /*bddc*/,
    12 /*bddd*/, 12 /*bdde*/, 13 /*bddf*/, 9 /*bde0*/,  10 /*bde1*/,
    10 /*bde2*/, 11 /*bde3*/, 10 /*bde4*/, 11 /*bde5*/, 11 /*bde6*/,
    12 /*bde7*/, 10 /*bde8*/, 11 /*bde9*/, 11 /*bdea*/, 12 /*bdeb*/,
    11 /*bdec*/, 12 /*bded*/, 12 /*bdee*/, 13 /*bdef*/, 10 /*bdf0*/,
    11 /*bdf1*/, 11 /*bdf2*/, 12 /*bdf3*/, 11 /*bdf4*/, 12 /*bdf5*/,
    12 /*bdf6*/, 13 /*bdf7*/, 11 /*bdf8*/, 12 /*bdf9*/, 12 /*bdfa*/,
    13 /*bdfb*/, 12 /*bdfc*/, 13 /*bdfd*/, 13 /*bdfe*/, 14 /*bdff*/,
    6 /*be00*/,  7 /*be01*/,  7 /*be02*/,  8 /*be03*/,  7 /*be04*/,
    8 /*be05*/,  8 /*be06*/,  9 /*be07*/,  7 /*be08*/,  8 /*be09*/,
    8 /*be0a*/,  9 /*be0b*/,  8 /*be0c*/,  9 /*be0d*/,  9 /*be0e*/,
    10 /*be0f*/, 7 /*be10*/,  8 /*be11*/,  8 /*be12*/,  9 /*be13*/,
    8 /*be14*/,  9 /*be15*/,  9 /*be16*/,  10 /*be17*/, 8 /*be18*/,
    9 /*be19*/,  9 /*be1a*/,  10 /*be1b*/, 9 /*be1c*/,  10 /*be1d*/,
    10 /*be1e*/, 11 /*be1f*/, 7 /*be20*/,  8 /*be21*/,  8 /*be22*/,
    9 /*be23*/,  8 /*be24*/,  9 /*be25*/,  9 /*be26*/,  10 /*be27*/,
    8 /*be28*/,  9 /*be29*/,  9 /*be2a*/,  10 /*be2b*/, 9 /*be2c*/,
    10 /*be2d*/, 10 /*be2e*/, 11 /*be2f*/, 8 /*be30*/,  9 /*be31*/,
    9 /*be32*/,  10 /*be33*/, 9 /*be34*/,  10 /*be35*/, 10 /*be36*/,
    11 /*be37*/, 9 /*be38*/,  10 /*be39*/, 10 /*be3a*/, 11 /*be3b*/,
    10 /*be3c*/, 11 /*be3d*/, 11 /*be3e*/, 12 /*be3f*/, 7 /*be40*/,
    8 /*be41*/,  8 /*be42*/,  9 /*be43*/,  8 /*be44*/,  9 /*be45*/,
    9 /*be46*/,  10 /*be47*/, 8 /*be48*/,  9 /*be49*/,  9 /*be4a*/,
    10 /*be4b*/, 9 /*be4c*/,  10 /*be4d*/, 10 /*be4e*/, 11 /*be4f*/,
    8 /*be50*/,  9 /*be51*/,  9 /*be52*/,  10 /*be53*/, 9 /*be54*/,
    10 /*be55*/, 10 /*be56*/, 11 /*be57*/, 9 /*be58*/,  10 /*be59*/,
    10 /*be5a*/, 11 /*be5b*/, 10 /*be5c*/, 11 /*be5d*/, 11 /*be5e*/,
    12 /*be5f*/, 8 /*be60*/,  9 /*be61*/,  9 /*be62*/,  10 /*be63*/,
    9 /*be64*/,  10 /*be65*/, 10 /*be66*/, 11 /*be67*/, 9 /*be68*/,
    10 /*be69*/, 10 /*be6a*/, 11 /*be6b*/, 10 /*be6c*/, 11 /*be6d*/,
    11 /*be6e*/, 12 /*be6f*/, 9 /*be70*/,  10 /*be71*/, 10 /*be72*/,
    11 /*be73*/, 10 /*be74*/, 11 /*be75*/, 11 /*be76*/, 12 /*be77*/,
    10 /*be78*/, 11 /*be79*/, 11 /*be7a*/, 12 /*be7b*/, 11 /*be7c*/,
    12 /*be7d*/, 12 /*be7e*/, 13 /*be7f*/, 7 /*be80*/,  8 /*be81*/,
    8 /*be82*/,  9 /*be83*/,  8 /*be84*/,  9 /*be85*/,  9 /*be86*/,
    10 /*be87*/, 8 /*be88*/,  9 /*be89*/,  9 /*be8a*/,  10 /*be8b*/,
    9 /*be8c*/,  10 /*be8d*/, 10 /*be8e*/, 11 /*be8f*/, 8 /*be90*/,
    9 /*be91*/,  9 /*be92*/,  10 /*be93*/, 9 /*be94*/,  10 /*be95*/,
    10 /*be96*/, 11 /*be97*/, 9 /*be98*/,  10 /*be99*/, 10 /*be9a*/,
    11 /*be9b*/, 10 /*be9c*/, 11 /*be9d*/, 11 /*be9e*/, 12 /*be9f*/,
    8 /*bea0*/,  9 /*bea1*/,  9 /*bea2*/,  10 /*bea3*/, 9 /*bea4*/,
    10 /*bea5*/, 10 /*bea6*/, 11 /*bea7*/, 9 /*bea8*/,  10 /*bea9*/,
    10 /*beaa*/, 11 /*beab*/, 10 /*beac*/, 11 /*bead*/, 11 /*beae*/,
    12 /*beaf*/, 9 /*beb0*/,  10 /*beb1*/, 10 /*beb2*/, 11 /*beb3*/,
    10 /*beb4*/, 11 /*beb5*/, 11 /*beb6*/, 12 /*beb7*/, 10 /*beb8*/,
    11 /*beb9*/, 11 /*beba*/, 12 /*bebb*/, 11 /*bebc*/, 12 /*bebd*/,
    12 /*bebe*/, 13 /*bebf*/, 8 /*bec0*/,  9 /*bec1*/,  9 /*bec2*/,
    10 /*bec3*/, 9 /*bec4*/,  10 /*bec5*/, 10 /*bec6*/, 11 /*bec7*/,
    9 /*bec8*/,  10 /*bec9*/, 10 /*beca*/, 11 /*becb*/, 10 /*becc*/,
    11 /*becd*/, 11 /*bece*/, 12 /*becf*/, 9 /*bed0*/,  10 /*bed1*/,
    10 /*bed2*/, 11 /*bed3*/, 10 /*bed4*/, 11 /*bed5*/, 11 /*bed6*/,
    12 /*bed7*/, 10 /*bed8*/, 11 /*bed9*/, 11 /*beda*/, 12 /*bedb*/,
    11 /*bedc*/, 12 /*bedd*/, 12 /*bede*/, 13 /*bedf*/, 9 /*bee0*/,
    10 /*bee1*/, 10 /*bee2*/, 11 /*bee3*/, 10 /*bee4*/, 11 /*bee5*/,
    11 /*bee6*/, 12 /*bee7*/, 10 /*bee8*/, 11 /*bee9*/, 11 /*beea*/,
    12 /*beeb*/, 11 /*beec*/, 12 /*beed*/, 12 /*beee*/, 13 /*beef*/,
    10 /*bef0*/, 11 /*bef1*/, 11 /*bef2*/, 12 /*bef3*/, 11 /*bef4*/,
    12 /*bef5*/, 12 /*bef6*/, 13 /*bef7*/, 11 /*bef8*/, 12 /*bef9*/,
    12 /*befa*/, 13 /*befb*/, 12 /*befc*/, 13 /*befd*/, 13 /*befe*/,
    14 /*beff*/, 7 /*bf00*/,  8 /*bf01*/,  8 /*bf02*/,  9 /*bf03*/,
    8 /*bf04*/,  9 /*bf05*/,  9 /*bf06*/,  10 /*bf07*/, 8 /*bf08*/,
    9 /*bf09*/,  9 /*bf0a*/,  10 /*bf0b*/, 9 /*bf0c*/,  10 /*bf0d*/,
    10 /*bf0e*/, 11 /*bf0f*/, 8 /*bf10*/,  9 /*bf11*/,  9 /*bf12*/,
    10 /*bf13*/, 9 /*bf14*/,  10 /*bf15*/, 10 /*bf16*/, 11 /*bf17*/,
    9 /*bf18*/,  10 /*bf19*/, 10 /*bf1a*/, 11 /*bf1b*/, 10 /*bf1c*/,
    11 /*bf1d*/, 11 /*bf1e*/, 12 /*bf1f*/, 8 /*bf20*/,  9 /*bf21*/,
    9 /*bf22*/,  10 /*bf23*/, 9 /*bf24*/,  10 /*bf25*/, 10 /*bf26*/,
    11 /*bf27*/, 9 /*bf28*/,  10 /*bf29*/, 10 /*bf2a*/, 11 /*bf2b*/,
    10 /*bf2c*/, 11 /*bf2d*/, 11 /*bf2e*/, 12 /*bf2f*/, 9 /*bf30*/,
    10 /*bf31*/, 10 /*bf32*/, 11 /*bf33*/, 10 /*bf34*/, 11 /*bf35*/,
    11 /*bf36*/, 12 /*bf37*/, 10 /*bf38*/, 11 /*bf39*/, 11 /*bf3a*/,
    12 /*bf3b*/, 11 /*bf3c*/, 12 /*bf3d*/, 12 /*bf3e*/, 13 /*bf3f*/,
    8 /*bf40*/,  9 /*bf41*/,  9 /*bf42*/,  10 /*bf43*/, 9 /*bf44*/,
    10 /*bf45*/, 10 /*bf46*/, 11 /*bf47*/, 9 /*bf48*/,  10 /*bf49*/,
    10 /*bf4a*/, 11 /*bf4b*/, 10 /*bf4c*/, 11 /*bf4d*/, 11 /*bf4e*/,
    12 /*bf4f*/, 9 /*bf50*/,  10 /*bf51*/, 10 /*bf52*/, 11 /*bf53*/,
    10 /*bf54*/, 11 /*bf55*/, 11 /*bf56*/, 12 /*bf57*/, 10 /*bf58*/,
    11 /*bf59*/, 11 /*bf5a*/, 12 /*bf5b*/, 11 /*bf5c*/, 12 /*bf5d*/,
    12 /*bf5e*/, 13 /*bf5f*/, 9 /*bf60*/,  10 /*bf61*/, 10 /*bf62*/,
    11 /*bf63*/, 10 /*bf64*/, 11 /*bf65*/, 11 /*bf66*/, 12 /*bf67*/,
    10 /*bf68*/, 11 /*bf69*/, 11 /*bf6a*/, 12 /*bf6b*/, 11 /*bf6c*/,
    12 /*bf6d*/, 12 /*bf6e*/, 13 /*bf6f*/, 10 /*bf70*/, 11 /*bf71*/,
    11 /*bf72*/, 12 /*bf73*/, 11 /*bf74*/, 12 /*bf75*/, 12 /*bf76*/,
    13 /*bf77*/, 11 /*bf78*/, 12 /*bf79*/, 12 /*bf7a*/, 13 /*bf7b*/,
    12 /*bf7c*/, 13 /*bf7d*/, 13 /*bf7e*/, 14 /*bf7f*/, 8 /*bf80*/,
    9 /*bf81*/,  9 /*bf82*/,  10 /*bf83*/, 9 /*bf84*/,  10 /*bf85*/,
    10 /*bf86*/, 11 /*bf87*/, 9 /*bf88*/,  10 /*bf89*/, 10 /*bf8a*/,
    11 /*bf8b*/, 10 /*bf8c*/, 11 /*bf8d*/, 11 /*bf8e*/, 12 /*bf8f*/,
    9 /*bf90*/,  10 /*bf91*/, 10 /*bf92*/, 11 /*bf93*/, 10 /*bf94*/,
    11 /*bf95*/, 11 /*bf96*/, 12 /*bf97*/, 10 /*bf98*/, 11 /*bf99*/,
    11 /*bf9a*/, 12 /*bf9b*/, 11 /*bf9c*/, 12 /*bf9d*/, 12 /*bf9e*/,
    13 /*bf9f*/, 9 /*bfa0*/,  10 /*bfa1*/, 10 /*bfa2*/, 11 /*bfa3*/,
    10 /*bfa4*/, 11 /*bfa5*/, 11 /*bfa6*/, 12 /*bfa7*/, 10 /*bfa8*/,
    11 /*bfa9*/, 11 /*bfaa*/, 12 /*bfab*/, 11 /*bfac*/, 12 /*bfad*/,
    12 /*bfae*/, 13 /*bfaf*/, 10 /*bfb0*/, 11 /*bfb1*/, 11 /*bfb2*/,
    12 /*bfb3*/, 11 /*bfb4*/, 12 /*bfb5*/, 12 /*bfb6*/, 13 /*bfb7*/,
    11 /*bfb8*/, 12 /*bfb9*/, 12 /*bfba*/, 13 /*bfbb*/, 12 /*bfbc*/,
    13 /*bfbd*/, 13 /*bfbe*/, 14 /*bfbf*/, 9 /*bfc0*/,  10 /*bfc1*/,
    10 /*bfc2*/, 11 /*bfc3*/, 10 /*bfc4*/, 11 /*bfc5*/, 11 /*bfc6*/,
    12 /*bfc7*/, 10 /*bfc8*/, 11 /*bfc9*/, 11 /*bfca*/, 12 /*bfcb*/,
    11 /*bfcc*/, 12 /*bfcd*/, 12 /*bfce*/, 13 /*bfcf*/, 10 /*bfd0*/,
    11 /*bfd1*/, 11 /*bfd2*/, 12 /*bfd3*/, 11 /*bfd4*/, 12 /*bfd5*/,
    12 /*bfd6*/, 13 /*bfd7*/, 11 /*bfd8*/, 12 /*bfd9*/, 12 /*bfda*/,
    13 /*bfdb*/, 12 /*bfdc*/, 13 /*bfdd*/, 13 /*bfde*/, 14 /*bfdf*/,
    10 /*bfe0*/, 11 /*bfe1*/, 11 /*bfe2*/, 12 /*bfe3*/, 11 /*bfe4*/,
    12 /*bfe5*/, 12 /*bfe6*/, 13 /*bfe7*/, 11 /*bfe8*/, 12 /*bfe9*/,
    12 /*bfea*/, 13 /*bfeb*/, 12 /*bfec*/, 13 /*bfed*/, 13 /*bfee*/,
    14 /*bfef*/, 11 /*bff0*/, 12 /*bff1*/, 12 /*bff2*/, 13 /*bff3*/,
    12 /*bff4*/, 13 /*bff5*/, 13 /*bff6*/, 14 /*bff7*/, 12 /*bff8*/,
    13 /*bff9*/, 13 /*bffa*/, 14 /*bffb*/, 13 /*bffc*/, 14 /*bffd*/,
    14 /*bffe*/, 15 /*bfff*/, 2 /*c000*/,  3 /*c001*/,  3 /*c002*/,
    4 /*c003*/,  3 /*c004*/,  4 /*c005*/,  4 /*c006*/,  5 /*c007*/,
    3 /*c008*/,  4 /*c009*/,  4 /*c00a*/,  5 /*c00b*/,  4 /*c00c*/,
    5 /*c00d*/,  5 /*c00e*/,  6 /*c00f*/,  3 /*c010*/,  4 /*c011*/,
    4 /*c012*/,  5 /*c013*/,  4 /*c014*/,  5 /*c015*/,  5 /*c016*/,
    6 /*c017*/,  4 /*c018*/,  5 /*c019*/,  5 /*c01a*/,  6 /*c01b*/,
    5 /*c01c*/,  6 /*c01d*/,  6 /*c01e*/,  7 /*c01f*/,  3 /*c020*/,
    4 /*c021*/,  4 /*c022*/,  5 /*c023*/,  4 /*c024*/,  5 /*c025*/,
    5 /*c026*/,  6 /*c027*/,  4 /*c028*/,  5 /*c029*/,  5 /*c02a*/,
    6 /*c02b*/,  5 /*c02c*/,  6 /*c02d*/,  6 /*c02e*/,  7 /*c02f*/,
    4 /*c030*/,  5 /*c031*/,  5 /*c032*/,  6 /*c033*/,  5 /*c034*/,
    6 /*c035*/,  6 /*c036*/,  7 /*c037*/,  5 /*c038*/,  6 /*c039*/,
    6 /*c03a*/,  7 /*c03b*/,  6 /*c03c*/,  7 /*c03d*/,  7 /*c03e*/,
    8 /*c03f*/,  3 /*c040*/,  4 /*c041*/,  4 /*c042*/,  5 /*c043*/,
    4 /*c044*/,  5 /*c045*/,  5 /*c046*/,  6 /*c047*/,  4 /*c048*/,
    5 /*c049*/,  5 /*c04a*/,  6 /*c04b*/,  5 /*c04c*/,  6 /*c04d*/,
    6 /*c04e*/,  7 /*c04f*/,  4 /*c050*/,  5 /*c051*/,  5 /*c052*/,
    6 /*c053*/,  5 /*c054*/,  6 /*c055*/,  6 /*c056*/,  7 /*c057*/,
    5 /*c058*/,  6 /*c059*/,  6 /*c05a*/,  7 /*c05b*/,  6 /*c05c*/,
    7 /*c05d*/,  7 /*c05e*/,  8 /*c05f*/,  4 /*c060*/,  5 /*c061*/,
    5 /*c062*/,  6 /*c063*/,  5 /*c064*/,  6 /*c065*/,  6 /*c066*/,
    7 /*c067*/,  5 /*c068*/,  6 /*c069*/,  6 /*c06a*/,  7 /*c06b*/,
    6 /*c06c*/,  7 /*c06d*/,  7 /*c06e*/,  8 /*c06f*/,  5 /*c070*/,
    6 /*c071*/,  6 /*c072*/,  7 /*c073*/,  6 /*c074*/,  7 /*c075*/,
    7 /*c076*/,  8 /*c077*/,  6 /*c078*/,  7 /*c079*/,  7 /*c07a*/,
    8 /*c07b*/,  7 /*c07c*/,  8 /*c07d*/,  8 /*c07e*/,  9 /*c07f*/,
    3 /*c080*/,  4 /*c081*/,  4 /*c082*/,  5 /*c083*/,  4 /*c084*/,
    5 /*c085*/,  5 /*c086*/,  6 /*c087*/,  4 /*c088*/,  5 /*c089*/,
    5 /*c08a*/,  6 /*c08b*/,  5 /*c08c*/,  6 /*c08d*/,  6 /*c08e*/,
    7 /*c08f*/,  4 /*c090*/,  5 /*c091*/,  5 /*c092*/,  6 /*c093*/,
    5 /*c094*/,  6 /*c095*/,  6 /*c096*/,  7 /*c097*/,  5 /*c098*/,
    6 /*c099*/,  6 /*c09a*/,  7 /*c09b*/,  6 /*c09c*/,  7 /*c09d*/,
    7 /*c09e*/,  8 /*c09f*/,  4 /*c0a0*/,  5 /*c0a1*/,  5 /*c0a2*/,
    6 /*c0a3*/,  5 /*c0a4*/,  6 /*c0a5*/,  6 /*c0a6*/,  7 /*c0a7*/,
    5 /*c0a8*/,  6 /*c0a9*/,  6 /*c0aa*/,  7 /*c0ab*/,  6 /*c0ac*/,
    7 /*c0ad*/,  7 /*c0ae*/,  8 /*c0af*/,  5 /*c0b0*/,  6 /*c0b1*/,
    6 /*c0b2*/,  7 /*c0b3*/,  6 /*c0b4*/,  7 /*c0b5*/,  7 /*c0b6*/,
    8 /*c0b7*/,  6 /*c0b8*/,  7 /*c0b9*/,  7 /*c0ba*/,  8 /*c0bb*/,
    7 /*c0bc*/,  8 /*c0bd*/,  8 /*c0be*/,  9 /*c0bf*/,  4 /*c0c0*/,
    5 /*c0c1*/,  5 /*c0c2*/,  6 /*c0c3*/,  5 /*c0c4*/,  6 /*c0c5*/,
    6 /*c0c6*/,  7 /*c0c7*/,  5 /*c0c8*/,  6 /*c0c9*/,  6 /*c0ca*/,
    7 /*c0cb*/,  6 /*c0cc*/,  7 /*c0cd*/,  7 /*c0ce*/,  8 /*c0cf*/,
    5 /*c0d0*/,  6 /*c0d1*/,  6 /*c0d2*/,  7 /*c0d3*/,  6 /*c0d4*/,
    7 /*c0d5*/,  7 /*c0d6*/,  8 /*c0d7*/,  6 /*c0d8*/,  7 /*c0d9*/,
    7 /*c0da*/,  8 /*c0db*/,  7 /*c0dc*/,  8 /*c0dd*/,  8 /*c0de*/,
    9 /*c0df*/,  5 /*c0e0*/,  6 /*c0e1*/,  6 /*c0e2*/,  7 /*c0e3*/,
    6 /*c0e4*/,  7 /*c0e5*/,  7 /*c0e6*/,  8 /*c0e7*/,  6 /*c0e8*/,
    7 /*c0e9*/,  7 /*c0ea*/,  8 /*c0eb*/,  7 /*c0ec*/,  8 /*c0ed*/,
    8 /*c0ee*/,  9 /*c0ef*/,  6 /*c0f0*/,  7 /*c0f1*/,  7 /*c0f2*/,
    8 /*c0f3*/,  7 /*c0f4*/,  8 /*c0f5*/,  8 /*c0f6*/,  9 /*c0f7*/,
    7 /*c0f8*/,  8 /*c0f9*/,  8 /*c0fa*/,  9 /*c0fb*/,  8 /*c0fc*/,
    9 /*c0fd*/,  9 /*c0fe*/,  10 /*c0ff*/, 3 /*c100*/,  4 /*c101*/,
    4 /*c102*/,  5 /*c103*/,  4 /*c104*/,  5 /*c105*/,  5 /*c106*/,
    6 /*c107*/,  4 /*c108*/,  5 /*c109*/,  5 /*c10a*/,  6 /*c10b*/,
    5 /*c10c*/,  6 /*c10d*/,  6 /*c10e*/,  7 /*c10f*/,  4 /*c110*/,
    5 /*c111*/,  5 /*c112*/,  6 /*c113*/,  5 /*c114*/,  6 /*c115*/,
    6 /*c116*/,  7 /*c117*/,  5 /*c118*/,  6 /*c119*/,  6 /*c11a*/,
    7 /*c11b*/,  6 /*c11c*/,  7 /*c11d*/,  7 /*c11e*/,  8 /*c11f*/,
    4 /*c120*/,  5 /*c121*/,  5 /*c122*/,  6 /*c123*/,  5 /*c124*/,
    6 /*c125*/,  6 /*c126*/,  7 /*c127*/,  5 /*c128*/,  6 /*c129*/,
    6 /*c12a*/,  7 /*c12b*/,  6 /*c12c*/,  7 /*c12d*/,  7 /*c12e*/,
    8 /*c12f*/,  5 /*c130*/,  6 /*c131*/,  6 /*c132*/,  7 /*c133*/,
    6 /*c134*/,  7 /*c135*/,  7 /*c136*/,  8 /*c137*/,  6 /*c138*/,
    7 /*c139*/,  7 /*c13a*/,  8 /*c13b*/,  7 /*c13c*/,  8 /*c13d*/,
    8 /*c13e*/,  9 /*c13f*/,  4 /*c140*/,  5 /*c141*/,  5 /*c142*/,
    6 /*c143*/,  5 /*c144*/,  6 /*c145*/,  6 /*c146*/,  7 /*c147*/,
    5 /*c148*/,  6 /*c149*/,  6 /*c14a*/,  7 /*c14b*/,  6 /*c14c*/,
    7 /*c14d*/,  7 /*c14e*/,  8 /*c14f*/,  5 /*c150*/,  6 /*c151*/,
    6 /*c152*/,  7 /*c153*/,  6 /*c154*/,  7 /*c155*/,  7 /*c156*/,
    8 /*c157*/,  6 /*c158*/,  7 /*c159*/,  7 /*c15a*/,  8 /*c15b*/,
    7 /*c15c*/,  8 /*c15d*/,  8 /*c15e*/,  9 /*c15f*/,  5 /*c160*/,
    6 /*c161*/,  6 /*c162*/,  7 /*c163*/,  6 /*c164*/,  7 /*c165*/,
    7 /*c166*/,  8 /*c167*/,  6 /*c168*/,  7 /*c169*/,  7 /*c16a*/,
    8 /*c16b*/,  7 /*c16c*/,  8 /*c16d*/,  8 /*c16e*/,  9 /*c16f*/,
    6 /*c170*/,  7 /*c171*/,  7 /*c172*/,  8 /*c173*/,  7 /*c174*/,
    8 /*c175*/,  8 /*c176*/,  9 /*c177*/,  7 /*c178*/,  8 /*c179*/,
    8 /*c17a*/,  9 /*c17b*/,  8 /*c17c*/,  9 /*c17d*/,  9 /*c17e*/,
    10 /*c17f*/, 4 /*c180*/,  5 /*c181*/,  5 /*c182*/,  6 /*c183*/,
    5 /*c184*/,  6 /*c185*/,  6 /*c186*/,  7 /*c187*/,  5 /*c188*/,
    6 /*c189*/,  6 /*c18a*/,  7 /*c18b*/,  6 /*c18c*/,  7 /*c18d*/,
    7 /*c18e*/,  8 /*c18f*/,  5 /*c190*/,  6 /*c191*/,  6 /*c192*/,
    7 /*c193*/,  6 /*c194*/,  7 /*c195*/,  7 /*c196*/,  8 /*c197*/,
    6 /*c198*/,  7 /*c199*/,  7 /*c19a*/,  8 /*c19b*/,  7 /*c19c*/,
    8 /*c19d*/,  8 /*c19e*/,  9 /*c19f*/,  5 /*c1a0*/,  6 /*c1a1*/,
    6 /*c1a2*/,  7 /*c1a3*/,  6 /*c1a4*/,  7 /*c1a5*/,  7 /*c1a6*/,
    8 /*c1a7*/,  6 /*c1a8*/,  7 /*c1a9*/,  7 /*c1aa*/,  8 /*c1ab*/,
    7 /*c1ac*/,  8 /*c1ad*/,  8 /*c1ae*/,  9 /*c1af*/,  6 /*c1b0*/,
    7 /*c1b1*/,  7 /*c1b2*/,  8 /*c1b3*/,  7 /*c1b4*/,  8 /*c1b5*/,
    8 /*c1b6*/,  9 /*c1b7*/,  7 /*c1b8*/,  8 /*c1b9*/,  8 /*c1ba*/,
    9 /*c1bb*/,  8 /*c1bc*/,  9 /*c1bd*/,  9 /*c1be*/,  10 /*c1bf*/,
    5 /*c1c0*/,  6 /*c1c1*/,  6 /*c1c2*/,  7 /*c1c3*/,  6 /*c1c4*/,
    7 /*c1c5*/,  7 /*c1c6*/,  8 /*c1c7*/,  6 /*c1c8*/,  7 /*c1c9*/,
    7 /*c1ca*/,  8 /*c1cb*/,  7 /*c1cc*/,  8 /*c1cd*/,  8 /*c1ce*/,
    9 /*c1cf*/,  6 /*c1d0*/,  7 /*c1d1*/,  7 /*c1d2*/,  8 /*c1d3*/,
    7 /*c1d4*/,  8 /*c1d5*/,  8 /*c1d6*/,  9 /*c1d7*/,  7 /*c1d8*/,
    8 /*c1d9*/,  8 /*c1da*/,  9 /*c1db*/,  8 /*c1dc*/,  9 /*c1dd*/,
    9 /*c1de*/,  10 /*c1df*/, 6 /*c1e0*/,  7 /*c1e1*/,  7 /*c1e2*/,
    8 /*c1e3*/,  7 /*c1e4*/,  8 /*c1e5*/,  8 /*c1e6*/,  9 /*c1e7*/,
    7 /*c1e8*/,  8 /*c1e9*/,  8 /*c1ea*/,  9 /*c1eb*/,  8 /*c1ec*/,
    9 /*c1ed*/,  9 /*c1ee*/,  10 /*c1ef*/, 7 /*c1f0*/,  8 /*c1f1*/,
    8 /*c1f2*/,  9 /*c1f3*/,  8 /*c1f4*/,  9 /*c1f5*/,  9 /*c1f6*/,
    10 /*c1f7*/, 8 /*c1f8*/,  9 /*c1f9*/,  9 /*c1fa*/,  10 /*c1fb*/,
    9 /*c1fc*/,  10 /*c1fd*/, 10 /*c1fe*/, 11 /*c1ff*/, 3 /*c200*/,
    4 /*c201*/,  4 /*c202*/,  5 /*c203*/,  4 /*c204*/,  5 /*c205*/,
    5 /*c206*/,  6 /*c207*/,  4 /*c208*/,  5 /*c209*/,  5 /*c20a*/,
    6 /*c20b*/,  5 /*c20c*/,  6 /*c20d*/,  6 /*c20e*/,  7 /*c20f*/,
    4 /*c210*/,  5 /*c211*/,  5 /*c212*/,  6 /*c213*/,  5 /*c214*/,
    6 /*c215*/,  6 /*c216*/,  7 /*c217*/,  5 /*c218*/,  6 /*c219*/,
    6 /*c21a*/,  7 /*c21b*/,  6 /*c21c*/,  7 /*c21d*/,  7 /*c21e*/,
    8 /*c21f*/,  4 /*c220*/,  5 /*c221*/,  5 /*c222*/,  6 /*c223*/,
    5 /*c224*/,  6 /*c225*/,  6 /*c226*/,  7 /*c227*/,  5 /*c228*/,
    6 /*c229*/,  6 /*c22a*/,  7 /*c22b*/,  6 /*c22c*/,  7 /*c22d*/,
    7 /*c22e*/,  8 /*c22f*/,  5 /*c230*/,  6 /*c231*/,  6 /*c232*/,
    7 /*c233*/,  6 /*c234*/,  7 /*c235*/,  7 /*c236*/,  8 /*c237*/,
    6 /*c238*/,  7 /*c239*/,  7 /*c23a*/,  8 /*c23b*/,  7 /*c23c*/,
    8 /*c23d*/,  8 /*c23e*/,  9 /*c23f*/,  4 /*c240*/,  5 /*c241*/,
    5 /*c242*/,  6 /*c243*/,  5 /*c244*/,  6 /*c245*/,  6 /*c246*/,
    7 /*c247*/,  5 /*c248*/,  6 /*c249*/,  6 /*c24a*/,  7 /*c24b*/,
    6 /*c24c*/,  7 /*c24d*/,  7 /*c24e*/,  8 /*c24f*/,  5 /*c250*/,
    6 /*c251*/,  6 /*c252*/,  7 /*c253*/,  6 /*c254*/,  7 /*c255*/,
    7 /*c256*/,  8 /*c257*/,  6 /*c258*/,  7 /*c259*/,  7 /*c25a*/,
    8 /*c25b*/,  7 /*c25c*/,  8 /*c25d*/,  8 /*c25e*/,  9 /*c25f*/,
    5 /*c260*/,  6 /*c261*/,  6 /*c262*/,  7 /*c263*/,  6 /*c264*/,
    7 /*c265*/,  7 /*c266*/,  8 /*c267*/,  6 /*c268*/,  7 /*c269*/,
    7 /*c26a*/,  8 /*c26b*/,  7 /*c26c*/,  8 /*c26d*/,  8 /*c26e*/,
    9 /*c26f*/,  6 /*c270*/,  7 /*c271*/,  7 /*c272*/,  8 /*c273*/,
    7 /*c274*/,  8 /*c275*/,  8 /*c276*/,  9 /*c277*/,  7 /*c278*/,
    8 /*c279*/,  8 /*c27a*/,  9 /*c27b*/,  8 /*c27c*/,  9 /*c27d*/,
    9 /*c27e*/,  10 /*c27f*/, 4 /*c280*/,  5 /*c281*/,  5 /*c282*/,
    6 /*c283*/,  5 /*c284*/,  6 /*c285*/,  6 /*c286*/,  7 /*c287*/,
    5 /*c288*/,  6 /*c289*/,  6 /*c28a*/,  7 /*c28b*/,  6 /*c28c*/,
    7 /*c28d*/,  7 /*c28e*/,  8 /*c28f*/,  5 /*c290*/,  6 /*c291*/,
    6 /*c292*/,  7 /*c293*/,  6 /*c294*/,  7 /*c295*/,  7 /*c296*/,
    8 /*c297*/,  6 /*c298*/,  7 /*c299*/,  7 /*c29a*/,  8 /*c29b*/,
    7 /*c29c*/,  8 /*c29d*/,  8 /*c29e*/,  9 /*c29f*/,  5 /*c2a0*/,
    6 /*c2a1*/,  6 /*c2a2*/,  7 /*c2a3*/,  6 /*c2a4*/,  7 /*c2a5*/,
    7 /*c2a6*/,  8 /*c2a7*/,  6 /*c2a8*/,  7 /*c2a9*/,  7 /*c2aa*/,
    8 /*c2ab*/,  7 /*c2ac*/,  8 /*c2ad*/,  8 /*c2ae*/,  9 /*c2af*/,
    6 /*c2b0*/,  7 /*c2b1*/,  7 /*c2b2*/,  8 /*c2b3*/,  7 /*c2b4*/,
    8 /*c2b5*/,  8 /*c2b6*/,  9 /*c2b7*/,  7 /*c2b8*/,  8 /*c2b9*/,
    8 /*c2ba*/,  9 /*c2bb*/,  8 /*c2bc*/,  9 /*c2bd*/,  9 /*c2be*/,
    10 /*c2bf*/, 5 /*c2c0*/,  6 /*c2c1*/,  6 /*c2c2*/,  7 /*c2c3*/,
    6 /*c2c4*/,  7 /*c2c5*/,  7 /*c2c6*/,  8 /*c2c7*/,  6 /*c2c8*/,
    7 /*c2c9*/,  7 /*c2ca*/,  8 /*c2cb*/,  7 /*c2cc*/,  8 /*c2cd*/,
    8 /*c2ce*/,  9 /*c2cf*/,  6 /*c2d0*/,  7 /*c2d1*/,  7 /*c2d2*/,
    8 /*c2d3*/,  7 /*c2d4*/,  8 /*c2d5*/,  8 /*c2d6*/,  9 /*c2d7*/,
    7 /*c2d8*/,  8 /*c2d9*/,  8 /*c2da*/,  9 /*c2db*/,  8 /*c2dc*/,
    9 /*c2dd*/,  9 /*c2de*/,  10 /*c2df*/, 6 /*c2e0*/,  7 /*c2e1*/,
    7 /*c2e2*/,  8 /*c2e3*/,  7 /*c2e4*/,  8 /*c2e5*/,  8 /*c2e6*/,
    9 /*c2e7*/,  7 /*c2e8*/,  8 /*c2e9*/,  8 /*c2ea*/,  9 /*c2eb*/,
    8 /*c2ec*/,  9 /*c2ed*/,  9 /*c2ee*/,  10 /*c2ef*/, 7 /*c2f0*/,
    8 /*c2f1*/,  8 /*c2f2*/,  9 /*c2f3*/,  8 /*c2f4*/,  9 /*c2f5*/,
    9 /*c2f6*/,  10 /*c2f7*/, 8 /*c2f8*/,  9 /*c2f9*/,  9 /*c2fa*/,
    10 /*c2fb*/, 9 /*c2fc*/,  10 /*c2fd*/, 10 /*c2fe*/, 11 /*c2ff*/,
    4 /*c300*/,  5 /*c301*/,  5 /*c302*/,  6 /*c303*/,  5 /*c304*/,
    6 /*c305*/,  6 /*c306*/,  7 /*c307*/,  5 /*c308*/,  6 /*c309*/,
    6 /*c30a*/,  7 /*c30b*/,  6 /*c30c*/,  7 /*c30d*/,  7 /*c30e*/,
    8 /*c30f*/,  5 /*c310*/,  6 /*c311*/,  6 /*c312*/,  7 /*c313*/,
    6 /*c314*/,  7 /*c315*/,  7 /*c316*/,  8 /*c317*/,  6 /*c318*/,
    7 /*c319*/,  7 /*c31a*/,  8 /*c31b*/,  7 /*c31c*/,  8 /*c31d*/,
    8 /*c31e*/,  9 /*c31f*/,  5 /*c320*/,  6 /*c321*/,  6 /*c322*/,
    7 /*c323*/,  6 /*c324*/,  7 /*c325*/,  7 /*c326*/,  8 /*c327*/,
    6 /*c328*/,  7 /*c329*/,  7 /*c32a*/,  8 /*c32b*/,  7 /*c32c*/,
    8 /*c32d*/,  8 /*c32e*/,  9 /*c32f*/,  6 /*c330*/,  7 /*c331*/,
    7 /*c332*/,  8 /*c333*/,  7 /*c334*/,  8 /*c335*/,  8 /*c336*/,
    9 /*c337*/,  7 /*c338*/,  8 /*c339*/,  8 /*c33a*/,  9 /*c33b*/,
    8 /*c33c*/,  9 /*c33d*/,  9 /*c33e*/,  10 /*c33f*/, 5 /*c340*/,
    6 /*c341*/,  6 /*c342*/,  7 /*c343*/,  6 /*c344*/,  7 /*c345*/,
    7 /*c346*/,  8 /*c347*/,  6 /*c348*/,  7 /*c349*/,  7 /*c34a*/,
    8 /*c34b*/,  7 /*c34c*/,  8 /*c34d*/,  8 /*c34e*/,  9 /*c34f*/,
    6 /*c350*/,  7 /*c351*/,  7 /*c352*/,  8 /*c353*/,  7 /*c354*/,
    8 /*c355*/,  8 /*c356*/,  9 /*c357*/,  7 /*c358*/,  8 /*c359*/,
    8 /*c35a*/,  9 /*c35b*/,  8 /*c35c*/,  9 /*c35d*/,  9 /*c35e*/,
    10 /*c35f*/, 6 /*c360*/,  7 /*c361*/,  7 /*c362*/,  8 /*c363*/,
    7 /*c364*/,  8 /*c365*/,  8 /*c366*/,  9 /*c367*/,  7 /*c368*/,
    8 /*c369*/,  8 /*c36a*/,  9 /*c36b*/,  8 /*c36c*/,  9 /*c36d*/,
    9 /*c36e*/,  10 /*c36f*/, 7 /*c370*/,  8 /*c371*/,  8 /*c372*/,
    9 /*c373*/,  8 /*c374*/,  9 /*c375*/,  9 /*c376*/,  10 /*c377*/,
    8 /*c378*/,  9 /*c379*/,  9 /*c37a*/,  10 /*c37b*/, 9 /*c37c*/,
    10 /*c37d*/, 10 /*c37e*/, 11 /*c37f*/, 5 /*c380*/,  6 /*c381*/,
    6 /*c382*/,  7 /*c383*/,  6 /*c384*/,  7 /*c385*/,  7 /*c386*/,
    8 /*c387*/,  6 /*c388*/,  7 /*c389*/,  7 /*c38a*/,  8 /*c38b*/,
    7 /*c38c*/,  8 /*c38d*/,  8 /*c38e*/,  9 /*c38f*/,  6 /*c390*/,
    7 /*c391*/,  7 /*c392*/,  8 /*c393*/,  7 /*c394*/,  8 /*c395*/,
    8 /*c396*/,  9 /*c397*/,  7 /*c398*/,  8 /*c399*/,  8 /*c39a*/,
    9 /*c39b*/,  8 /*c39c*/,  9 /*c39d*/,  9 /*c39e*/,  10 /*c39f*/,
    6 /*c3a0*/,  7 /*c3a1*/,  7 /*c3a2*/,  8 /*c3a3*/,  7 /*c3a4*/,
    8 /*c3a5*/,  8 /*c3a6*/,  9 /*c3a7*/,  7 /*c3a8*/,  8 /*c3a9*/,
    8 /*c3aa*/,  9 /*c3ab*/,  8 /*c3ac*/,  9 /*c3ad*/,  9 /*c3ae*/,
    10 /*c3af*/, 7 /*c3b0*/,  8 /*c3b1*/,  8 /*c3b2*/,  9 /*c3b3*/,
    8 /*c3b4*/,  9 /*c3b5*/,  9 /*c3b6*/,  10 /*c3b7*/, 8 /*c3b8*/,
    9 /*c3b9*/,  9 /*c3ba*/,  10 /*c3bb*/, 9 /*c3bc*/,  10 /*c3bd*/,
    10 /*c3be*/, 11 /*c3bf*/, 6 /*c3c0*/,  7 /*c3c1*/,  7 /*c3c2*/,
    8 /*c3c3*/,  7 /*c3c4*/,  8 /*c3c5*/,  8 /*c3c6*/,  9 /*c3c7*/,
    7 /*c3c8*/,  8 /*c3c9*/,  8 /*c3ca*/,  9 /*c3cb*/,  8 /*c3cc*/,
    9 /*c3cd*/,  9 /*c3ce*/,  10 /*c3cf*/, 7 /*c3d0*/,  8 /*c3d1*/,
    8 /*c3d2*/,  9 /*c3d3*/,  8 /*c3d4*/,  9 /*c3d5*/,  9 /*c3d6*/,
    10 /*c3d7*/, 8 /*c3d8*/,  9 /*c3d9*/,  9 /*c3da*/,  10 /*c3db*/,
    9 /*c3dc*/,  10 /*c3dd*/, 10 /*c3de*/, 11 /*c3df*/, 7 /*c3e0*/,
    8 /*c3e1*/,  8 /*c3e2*/,  9 /*c3e3*/,  8 /*c3e4*/,  9 /*c3e5*/,
    9 /*c3e6*/,  10 /*c3e7*/, 8 /*c3e8*/,  9 /*c3e9*/,  9 /*c3ea*/,
    10 /*c3eb*/, 9 /*c3ec*/,  10 /*c3ed*/, 10 /*c3ee*/, 11 /*c3ef*/,
    8 /*c3f0*/,  9 /*c3f1*/,  9 /*c3f2*/,  10 /*c3f3*/, 9 /*c3f4*/,
    10 /*c3f5*/, 10 /*c3f6*/, 11 /*c3f7*/, 9 /*c3f8*/,  10 /*c3f9*/,
    10 /*c3fa*/, 11 /*c3fb*/, 10 /*c3fc*/, 11 /*c3fd*/, 11 /*c3fe*/,
    12 /*c3ff*/, 3 /*c400*/,  4 /*c401*/,  4 /*c402*/,  5 /*c403*/,
    4 /*c404*/,  5 /*c405*/,  5 /*c406*/,  6 /*c407*/,  4 /*c408*/,
    5 /*c409*/,  5 /*c40a*/,  6 /*c40b*/,  5 /*c40c*/,  6 /*c40d*/,
    6 /*c40e*/,  7 /*c40f*/,  4 /*c410*/,  5 /*c411*/,  5 /*c412*/,
    6 /*c413*/,  5 /*c414*/,  6 /*c415*/,  6 /*c416*/,  7 /*c417*/,
    5 /*c418*/,  6 /*c419*/,  6 /*c41a*/,  7 /*c41b*/,  6 /*c41c*/,
    7 /*c41d*/,  7 /*c41e*/,  8 /*c41f*/,  4 /*c420*/,  5 /*c421*/,
    5 /*c422*/,  6 /*c423*/,  5 /*c424*/,  6 /*c425*/,  6 /*c426*/,
    7 /*c427*/,  5 /*c428*/,  6 /*c429*/,  6 /*c42a*/,  7 /*c42b*/,
    6 /*c42c*/,  7 /*c42d*/,  7 /*c42e*/,  8 /*c42f*/,  5 /*c430*/,
    6 /*c431*/,  6 /*c432*/,  7 /*c433*/,  6 /*c434*/,  7 /*c435*/,
    7 /*c436*/,  8 /*c437*/,  6 /*c438*/,  7 /*c439*/,  7 /*c43a*/,
    8 /*c43b*/,  7 /*c43c*/,  8 /*c43d*/,  8 /*c43e*/,  9 /*c43f*/,
    4 /*c440*/,  5 /*c441*/,  5 /*c442*/,  6 /*c443*/,  5 /*c444*/,
    6 /*c445*/,  6 /*c446*/,  7 /*c447*/,  5 /*c448*/,  6 /*c449*/,
    6 /*c44a*/,  7 /*c44b*/,  6 /*c44c*/,  7 /*c44d*/,  7 /*c44e*/,
    8 /*c44f*/,  5 /*c450*/,  6 /*c451*/,  6 /*c452*/,  7 /*c453*/,
    6 /*c454*/,  7 /*c455*/,  7 /*c456*/,  8 /*c457*/,  6 /*c458*/,
    7 /*c459*/,  7 /*c45a*/,  8 /*c45b*/,  7 /*c45c*/,  8 /*c45d*/,
    8 /*c45e*/,  9 /*c45f*/,  5 /*c460*/,  6 /*c461*/,  6 /*c462*/,
    7 /*c463*/,  6 /*c464*/,  7 /*c465*/,  7 /*c466*/,  8 /*c467*/,
    6 /*c468*/,  7 /*c469*/,  7 /*c46a*/,  8 /*c46b*/,  7 /*c46c*/,
    8 /*c46d*/,  8 /*c46e*/,  9 /*c46f*/,  6 /*c470*/,  7 /*c471*/,
    7 /*c472*/,  8 /*c473*/,  7 /*c474*/,  8 /*c475*/,  8 /*c476*/,
    9 /*c477*/,  7 /*c478*/,  8 /*c479*/,  8 /*c47a*/,  9 /*c47b*/,
    8 /*c47c*/,  9 /*c47d*/,  9 /*c47e*/,  10 /*c47f*/, 4 /*c480*/,
    5 /*c481*/,  5 /*c482*/,  6 /*c483*/,  5 /*c484*/,  6 /*c485*/,
    6 /*c486*/,  7 /*c487*/,  5 /*c488*/,  6 /*c489*/,  6 /*c48a*/,
    7 /*c48b*/,  6 /*c48c*/,  7 /*c48d*/,  7 /*c48e*/,  8 /*c48f*/,
    5 /*c490*/,  6 /*c491*/,  6 /*c492*/,  7 /*c493*/,  6 /*c494*/,
    7 /*c495*/,  7 /*c496*/,  8 /*c497*/,  6 /*c498*/,  7 /*c499*/,
    7 /*c49a*/,  8 /*c49b*/,  7 /*c49c*/,  8 /*c49d*/,  8 /*c49e*/,
    9 /*c49f*/,  5 /*c4a0*/,  6 /*c4a1*/,  6 /*c4a2*/,  7 /*c4a3*/,
    6 /*c4a4*/,  7 /*c4a5*/,  7 /*c4a6*/,  8 /*c4a7*/,  6 /*c4a8*/,
    7 /*c4a9*/,  7 /*c4aa*/,  8 /*c4ab*/,  7 /*c4ac*/,  8 /*c4ad*/,
    8 /*c4ae*/,  9 /*c4af*/,  6 /*c4b0*/,  7 /*c4b1*/,  7 /*c4b2*/,
    8 /*c4b3*/,  7 /*c4b4*/,  8 /*c4b5*/,  8 /*c4b6*/,  9 /*c4b7*/,
    7 /*c4b8*/,  8 /*c4b9*/,  8 /*c4ba*/,  9 /*c4bb*/,  8 /*c4bc*/,
    9 /*c4bd*/,  9 /*c4be*/,  10 /*c4bf*/, 5 /*c4c0*/,  6 /*c4c1*/,
    6 /*c4c2*/,  7 /*c4c3*/,  6 /*c4c4*/,  7 /*c4c5*/,  7 /*c4c6*/,
    8 /*c4c7*/,  6 /*c4c8*/,  7 /*c4c9*/,  7 /*c4ca*/,  8 /*c4cb*/,
    7 /*c4cc*/,  8 /*c4cd*/,  8 /*c4ce*/,  9 /*c4cf*/,  6 /*c4d0*/,
    7 /*c4d1*/,  7 /*c4d2*/,  8 /*c4d3*/,  7 /*c4d4*/,  8 /*c4d5*/,
    8 /*c4d6*/,  9 /*c4d7*/,  7 /*c4d8*/,  8 /*c4d9*/,  8 /*c4da*/,
    9 /*c4db*/,  8 /*c4dc*/,  9 /*c4dd*/,  9 /*c4de*/,  10 /*c4df*/,
    6 /*c4e0*/,  7 /*c4e1*/,  7 /*c4e2*/,  8 /*c4e3*/,  7 /*c4e4*/,
    8 /*c4e5*/,  8 /*c4e6*/,  9 /*c4e7*/,  7 /*c4e8*/,  8 /*c4e9*/,
    8 /*c4ea*/,  9 /*c4eb*/,  8 /*c4ec*/,  9 /*c4ed*/,  9 /*c4ee*/,
    10 /*c4ef*/, 7 /*c4f0*/,  8 /*c4f1*/,  8 /*c4f2*/,  9 /*c4f3*/,
    8 /*c4f4*/,  9 /*c4f5*/,  9 /*c4f6*/,  10 /*c4f7*/, 8 /*c4f8*/,
    9 /*c4f9*/,  9 /*c4fa*/,  10 /*c4fb*/, 9 /*c4fc*/,  10 /*c4fd*/,
    10 /*c4fe*/, 11 /*c4ff*/, 4 /*c500*/,  5 /*c501*/,  5 /*c502*/,
    6 /*c503*/,  5 /*c504*/,  6 /*c505*/,  6 /*c506*/,  7 /*c507*/,
    5 /*c508*/,  6 /*c509*/,  6 /*c50a*/,  7 /*c50b*/,  6 /*c50c*/,
    7 /*c50d*/,  7 /*c50e*/,  8 /*c50f*/,  5 /*c510*/,  6 /*c511*/,
    6 /*c512*/,  7 /*c513*/,  6 /*c514*/,  7 /*c515*/,  7 /*c516*/,
    8 /*c517*/,  6 /*c518*/,  7 /*c519*/,  7 /*c51a*/,  8 /*c51b*/,
    7 /*c51c*/,  8 /*c51d*/,  8 /*c51e*/,  9 /*c51f*/,  5 /*c520*/,
    6 /*c521*/,  6 /*c522*/,  7 /*c523*/,  6 /*c524*/,  7 /*c525*/,
    7 /*c526*/,  8 /*c527*/,  6 /*c528*/,  7 /*c529*/,  7 /*c52a*/,
    8 /*c52b*/,  7 /*c52c*/,  8 /*c52d*/,  8 /*c52e*/,  9 /*c52f*/,
    6 /*c530*/,  7 /*c531*/,  7 /*c532*/,  8 /*c533*/,  7 /*c534*/,
    8 /*c535*/,  8 /*c536*/,  9 /*c537*/,  7 /*c538*/,  8 /*c539*/,
    8 /*c53a*/,  9 /*c53b*/,  8 /*c53c*/,  9 /*c53d*/,  9 /*c53e*/,
    10 /*c53f*/, 5 /*c540*/,  6 /*c541*/,  6 /*c542*/,  7 /*c543*/,
    6 /*c544*/,  7 /*c545*/,  7 /*c546*/,  8 /*c547*/,  6 /*c548*/,
    7 /*c549*/,  7 /*c54a*/,  8 /*c54b*/,  7 /*c54c*/,  8 /*c54d*/,
    8 /*c54e*/,  9 /*c54f*/,  6 /*c550*/,  7 /*c551*/,  7 /*c552*/,
    8 /*c553*/,  7 /*c554*/,  8 /*c555*/,  8 /*c556*/,  9 /*c557*/,
    7 /*c558*/,  8 /*c559*/,  8 /*c55a*/,  9 /*c55b*/,  8 /*c55c*/,
    9 /*c55d*/,  9 /*c55e*/,  10 /*c55f*/, 6 /*c560*/,  7 /*c561*/,
    7 /*c562*/,  8 /*c563*/,  7 /*c564*/,  8 /*c565*/,  8 /*c566*/,
    9 /*c567*/,  7 /*c568*/,  8 /*c569*/,  8 /*c56a*/,  9 /*c56b*/,
    8 /*c56c*/,  9 /*c56d*/,  9 /*c56e*/,  10 /*c56f*/, 7 /*c570*/,
    8 /*c571*/,  8 /*c572*/,  9 /*c573*/,  8 /*c574*/,  9 /*c575*/,
    9 /*c576*/,  10 /*c577*/, 8 /*c578*/,  9 /*c579*/,  9 /*c57a*/,
    10 /*c57b*/, 9 /*c57c*/,  10 /*c57d*/, 10 /*c57e*/, 11 /*c57f*/,
    5 /*c580*/,  6 /*c581*/,  6 /*c582*/,  7 /*c583*/,  6 /*c584*/,
    7 /*c585*/,  7 /*c586*/,  8 /*c587*/,  6 /*c588*/,  7 /*c589*/,
    7 /*c58a*/,  8 /*c58b*/,  7 /*c58c*/,  8 /*c58d*/,  8 /*c58e*/,
    9 /*c58f*/,  6 /*c590*/,  7 /*c591*/,  7 /*c592*/,  8 /*c593*/,
    7 /*c594*/,  8 /*c595*/,  8 /*c596*/,  9 /*c597*/,  7 /*c598*/,
    8 /*c599*/,  8 /*c59a*/,  9 /*c59b*/,  8 /*c59c*/,  9 /*c59d*/,
    9 /*c59e*/,  10 /*c59f*/, 6 /*c5a0*/,  7 /*c5a1*/,  7 /*c5a2*/,
    8 /*c5a3*/,  7 /*c5a4*/,  8 /*c5a5*/,  8 /*c5a6*/,  9 /*c5a7*/,
    7 /*c5a8*/,  8 /*c5a9*/,  8 /*c5aa*/,  9 /*c5ab*/,  8 /*c5ac*/,
    9 /*c5ad*/,  9 /*c5ae*/,  10 /*c5af*/, 7 /*c5b0*/,  8 /*c5b1*/,
    8 /*c5b2*/,  9 /*c5b3*/,  8 /*c5b4*/,  9 /*c5b5*/,  9 /*c5b6*/,
    10 /*c5b7*/, 8 /*c5b8*/,  9 /*c5b9*/,  9 /*c5ba*/,  10 /*c5bb*/,
    9 /*c5bc*/,  10 /*c5bd*/, 10 /*c5be*/, 11 /*c5bf*/, 6 /*c5c0*/,
    7 /*c5c1*/,  7 /*c5c2*/,  8 /*c5c3*/,  7 /*c5c4*/,  8 /*c5c5*/,
    8 /*c5c6*/,  9 /*c5c7*/,  7 /*c5c8*/,  8 /*c5c9*/,  8 /*c5ca*/,
    9 /*c5cb*/,  8 /*c5cc*/,  9 /*c5cd*/,  9 /*c5ce*/,  10 /*c5cf*/,
    7 /*c5d0*/,  8 /*c5d1*/,  8 /*c5d2*/,  9 /*c5d3*/,  8 /*c5d4*/,
    9 /*c5d5*/,  9 /*c5d6*/,  10 /*c5d7*/, 8 /*c5d8*/,  9 /*c5d9*/,
    9 /*c5da*/,  10 /*c5db*/, 9 /*c5dc*/,  10 /*c5dd*/, 10 /*c5de*/,
    11 /*c5df*/, 7 /*c5e0*/,  8 /*c5e1*/,  8 /*c5e2*/,  9 /*c5e3*/,
    8 /*c5e4*/,  9 /*c5e5*/,  9 /*c5e6*/,  10 /*c5e7*/, 8 /*c5e8*/,
    9 /*c5e9*/,  9 /*c5ea*/,  10 /*c5eb*/, 9 /*c5ec*/,  10 /*c5ed*/,
    10 /*c5ee*/, 11 /*c5ef*/, 8 /*c5f0*/,  9 /*c5f1*/,  9 /*c5f2*/,
    10 /*c5f3*/, 9 /*c5f4*/,  10 /*c5f5*/, 10 /*c5f6*/, 11 /*c5f7*/,
    9 /*c5f8*/,  10 /*c5f9*/, 10 /*c5fa*/, 11 /*c5fb*/, 10 /*c5fc*/,
    11 /*c5fd*/, 11 /*c5fe*/, 12 /*c5ff*/, 4 /*c600*/,  5 /*c601*/,
    5 /*c602*/,  6 /*c603*/,  5 /*c604*/,  6 /*c605*/,  6 /*c606*/,
    7 /*c607*/,  5 /*c608*/,  6 /*c609*/,  6 /*c60a*/,  7 /*c60b*/,
    6 /*c60c*/,  7 /*c60d*/,  7 /*c60e*/,  8 /*c60f*/,  5 /*c610*/,
    6 /*c611*/,  6 /*c612*/,  7 /*c613*/,  6 /*c614*/,  7 /*c615*/,
    7 /*c616*/,  8 /*c617*/,  6 /*c618*/,  7 /*c619*/,  7 /*c61a*/,
    8 /*c61b*/,  7 /*c61c*/,  8 /*c61d*/,  8 /*c61e*/,  9 /*c61f*/,
    5 /*c620*/,  6 /*c621*/,  6 /*c622*/,  7 /*c623*/,  6 /*c624*/,
    7 /*c625*/,  7 /*c626*/,  8 /*c627*/,  6 /*c628*/,  7 /*c629*/,
    7 /*c62a*/,  8 /*c62b*/,  7 /*c62c*/,  8 /*c62d*/,  8 /*c62e*/,
    9 /*c62f*/,  6 /*c630*/,  7 /*c631*/,  7 /*c632*/,  8 /*c633*/,
    7 /*c634*/,  8 /*c635*/,  8 /*c636*/,  9 /*c637*/,  7 /*c638*/,
    8 /*c639*/,  8 /*c63a*/,  9 /*c63b*/,  8 /*c63c*/,  9 /*c63d*/,
    9 /*c63e*/,  10 /*c63f*/, 5 /*c640*/,  6 /*c641*/,  6 /*c642*/,
    7 /*c643*/,  6 /*c644*/,  7 /*c645*/,  7 /*c646*/,  8 /*c647*/,
    6 /*c648*/,  7 /*c649*/,  7 /*c64a*/,  8 /*c64b*/,  7 /*c64c*/,
    8 /*c64d*/,  8 /*c64e*/,  9 /*c64f*/,  6 /*c650*/,  7 /*c651*/,
    7 /*c652*/,  8 /*c653*/,  7 /*c654*/,  8 /*c655*/,  8 /*c656*/,
    9 /*c657*/,  7 /*c658*/,  8 /*c659*/,  8 /*c65a*/,  9 /*c65b*/,
    8 /*c65c*/,  9 /*c65d*/,  9 /*c65e*/,  10 /*c65f*/, 6 /*c660*/,
    7 /*c661*/,  7 /*c662*/,  8 /*c663*/,  7 /*c664*/,  8 /*c665*/,
    8 /*c666*/,  9 /*c667*/,  7 /*c668*/,  8 /*c669*/,  8 /*c66a*/,
    9 /*c66b*/,  8 /*c66c*/,  9 /*c66d*/,  9 /*c66e*/,  10 /*c66f*/,
    7 /*c670*/,  8 /*c671*/,  8 /*c672*/,  9 /*c673*/,  8 /*c674*/,
    9 /*c675*/,  9 /*c676*/,  10 /*c677*/, 8 /*c678*/,  9 /*c679*/,
    9 /*c67a*/,  10 /*c67b*/, 9 /*c67c*/,  10 /*c67d*/, 10 /*c67e*/,
    11 /*c67f*/, 5 /*c680*/,  6 /*c681*/,  6 /*c682*/,  7 /*c683*/,
    6 /*c684*/,  7 /*c685*/,  7 /*c686*/,  8 /*c687*/,  6 /*c688*/,
    7 /*c689*/,  7 /*c68a*/,  8 /*c68b*/,  7 /*c68c*/,  8 /*c68d*/,
    8 /*c68e*/,  9 /*c68f*/,  6 /*c690*/,  7 /*c691*/,  7 /*c692*/,
    8 /*c693*/,  7 /*c694*/,  8 /*c695*/,  8 /*c696*/,  9 /*c697*/,
    7 /*c698*/,  8 /*c699*/,  8 /*c69a*/,  9 /*c69b*/,  8 /*c69c*/,
    9 /*c69d*/,  9 /*c69e*/,  10 /*c69f*/, 6 /*c6a0*/,  7 /*c6a1*/,
    7 /*c6a2*/,  8 /*c6a3*/,  7 /*c6a4*/,  8 /*c6a5*/,  8 /*c6a6*/,
    9 /*c6a7*/,  7 /*c6a8*/,  8 /*c6a9*/,  8 /*c6aa*/,  9 /*c6ab*/,
    8 /*c6ac*/,  9 /*c6ad*/,  9 /*c6ae*/,  10 /*c6af*/, 7 /*c6b0*/,
    8 /*c6b1*/,  8 /*c6b2*/,  9 /*c6b3*/,  8 /*c6b4*/,  9 /*c6b5*/,
    9 /*c6b6*/,  10 /*c6b7*/, 8 /*c6b8*/,  9 /*c6b9*/,  9 /*c6ba*/,
    10 /*c6bb*/, 9 /*c6bc*/,  10 /*c6bd*/, 10 /*c6be*/, 11 /*c6bf*/,
    6 /*c6c0*/,  7 /*c6c1*/,  7 /*c6c2*/,  8 /*c6c3*/,  7 /*c6c4*/,
    8 /*c6c5*/,  8 /*c6c6*/,  9 /*c6c7*/,  7 /*c6c8*/,  8 /*c6c9*/,
    8 /*c6ca*/,  9 /*c6cb*/,  8 /*c6cc*/,  9 /*c6cd*/,  9 /*c6ce*/,
    10 /*c6cf*/, 7 /*c6d0*/,  8 /*c6d1*/,  8 /*c6d2*/,  9 /*c6d3*/,
    8 /*c6d4*/,  9 /*c6d5*/,  9 /*c6d6*/,  10 /*c6d7*/, 8 /*c6d8*/,
    9 /*c6d9*/,  9 /*c6da*/,  10 /*c6db*/, 9 /*c6dc*/,  10 /*c6dd*/,
    10 /*c6de*/, 11 /*c6df*/, 7 /*c6e0*/,  8 /*c6e1*/,  8 /*c6e2*/,
    9 /*c6e3*/,  8 /*c6e4*/,  9 /*c6e5*/,  9 /*c6e6*/,  10 /*c6e7*/,
    8 /*c6e8*/,  9 /*c6e9*/,  9 /*c6ea*/,  10 /*c6eb*/, 9 /*c6ec*/,
    10 /*c6ed*/, 10 /*c6ee*/, 11 /*c6ef*/, 8 /*c6f0*/,  9 /*c6f1*/,
    9 /*c6f2*/,  10 /*c6f3*/, 9 /*c6f4*/,  10 /*c6f5*/, 10 /*c6f6*/,
    11 /*c6f7*/, 9 /*c6f8*/,  10 /*c6f9*/, 10 /*c6fa*/, 11 /*c6fb*/,
    10 /*c6fc*/, 11 /*c6fd*/, 11 /*c6fe*/, 12 /*c6ff*/, 5 /*c700*/,
    6 /*c701*/,  6 /*c702*/,  7 /*c703*/,  6 /*c704*/,  7 /*c705*/,
    7 /*c706*/,  8 /*c707*/,  6 /*c708*/,  7 /*c709*/,  7 /*c70a*/,
    8 /*c70b*/,  7 /*c70c*/,  8 /*c70d*/,  8 /*c70e*/,  9 /*c70f*/,
    6 /*c710*/,  7 /*c711*/,  7 /*c712*/,  8 /*c713*/,  7 /*c714*/,
    8 /*c715*/,  8 /*c716*/,  9 /*c717*/,  7 /*c718*/,  8 /*c719*/,
    8 /*c71a*/,  9 /*c71b*/,  8 /*c71c*/,  9 /*c71d*/,  9 /*c71e*/,
    10 /*c71f*/, 6 /*c720*/,  7 /*c721*/,  7 /*c722*/,  8 /*c723*/,
    7 /*c724*/,  8 /*c725*/,  8 /*c726*/,  9 /*c727*/,  7 /*c728*/,
    8 /*c729*/,  8 /*c72a*/,  9 /*c72b*/,  8 /*c72c*/,  9 /*c72d*/,
    9 /*c72e*/,  10 /*c72f*/, 7 /*c730*/,  8 /*c731*/,  8 /*c732*/,
    9 /*c733*/,  8 /*c734*/,  9 /*c735*/,  9 /*c736*/,  10 /*c737*/,
    8 /*c738*/,  9 /*c739*/,  9 /*c73a*/,  10 /*c73b*/, 9 /*c73c*/,
    10 /*c73d*/, 10 /*c73e*/, 11 /*c73f*/, 6 /*c740*/,  7 /*c741*/,
    7 /*c742*/,  8 /*c743*/,  7 /*c744*/,  8 /*c745*/,  8 /*c746*/,
    9 /*c747*/,  7 /*c748*/,  8 /*c749*/,  8 /*c74a*/,  9 /*c74b*/,
    8 /*c74c*/,  9 /*c74d*/,  9 /*c74e*/,  10 /*c74f*/, 7 /*c750*/,
    8 /*c751*/,  8 /*c752*/,  9 /*c753*/,  8 /*c754*/,  9 /*c755*/,
    9 /*c756*/,  10 /*c757*/, 8 /*c758*/,  9 /*c759*/,  9 /*c75a*/,
    10 /*c75b*/, 9 /*c75c*/,  10 /*c75d*/, 10 /*c75e*/, 11 /*c75f*/,
    7 /*c760*/,  8 /*c761*/,  8 /*c762*/,  9 /*c763*/,  8 /*c764*/,
    9 /*c765*/,  9 /*c766*/,  10 /*c767*/, 8 /*c768*/,  9 /*c769*/,
    9 /*c76a*/,  10 /*c76b*/, 9 /*c76c*/,  10 /*c76d*/, 10 /*c76e*/,
    11 /*c76f*/, 8 /*c770*/,  9 /*c771*/,  9 /*c772*/,  10 /*c773*/,
    9 /*c774*/,  10 /*c775*/, 10 /*c776*/, 11 /*c777*/, 9 /*c778*/,
    10 /*c779*/, 10 /*c77a*/, 11 /*c77b*/, 10 /*c77c*/, 11 /*c77d*/,
    11 /*c77e*/, 12 /*c77f*/, 6 /*c780*/,  7 /*c781*/,  7 /*c782*/,
    8 /*c783*/,  7 /*c784*/,  8 /*c785*/,  8 /*c786*/,  9 /*c787*/,
    7 /*c788*/,  8 /*c789*/,  8 /*c78a*/,  9 /*c78b*/,  8 /*c78c*/,
    9 /*c78d*/,  9 /*c78e*/,  10 /*c78f*/, 7 /*c790*/,  8 /*c791*/,
    8 /*c792*/,  9 /*c793*/,  8 /*c794*/,  9 /*c795*/,  9 /*c796*/,
    10 /*c797*/, 8 /*c798*/,  9 /*c799*/,  9 /*c79a*/,  10 /*c79b*/,
    9 /*c79c*/,  10 /*c79d*/, 10 /*c79e*/, 11 /*c79f*/, 7 /*c7a0*/,
    8 /*c7a1*/,  8 /*c7a2*/,  9 /*c7a3*/,  8 /*c7a4*/,  9 /*c7a5*/,
    9 /*c7a6*/,  10 /*c7a7*/, 8 /*c7a8*/,  9 /*c7a9*/,  9 /*c7aa*/,
    10 /*c7ab*/, 9 /*c7ac*/,  10 /*c7ad*/, 10 /*c7ae*/, 11 /*c7af*/,
    8 /*c7b0*/,  9 /*c7b1*/,  9 /*c7b2*/,  10 /*c7b3*/, 9 /*c7b4*/,
    10 /*c7b5*/, 10 /*c7b6*/, 11 /*c7b7*/, 9 /*c7b8*/,  10 /*c7b9*/,
    10 /*c7ba*/, 11 /*c7bb*/, 10 /*c7bc*/, 11 /*c7bd*/, 11 /*c7be*/,
    12 /*c7bf*/, 7 /*c7c0*/,  8 /*c7c1*/,  8 /*c7c2*/,  9 /*c7c3*/,
    8 /*c7c4*/,  9 /*c7c5*/,  9 /*c7c6*/,  10 /*c7c7*/, 8 /*c7c8*/,
    9 /*c7c9*/,  9 /*c7ca*/,  10 /*c7cb*/, 9 /*c7cc*/,  10 /*c7cd*/,
    10 /*c7ce*/, 11 /*c7cf*/, 8 /*c7d0*/,  9 /*c7d1*/,  9 /*c7d2*/,
    10 /*c7d3*/, 9 /*c7d4*/,  10 /*c7d5*/, 10 /*c7d6*/, 11 /*c7d7*/,
    9 /*c7d8*/,  10 /*c7d9*/, 10 /*c7da*/, 11 /*c7db*/, 10 /*c7dc*/,
    11 /*c7dd*/, 11 /*c7de*/, 12 /*c7df*/, 8 /*c7e0*/,  9 /*c7e1*/,
    9 /*c7e2*/,  10 /*c7e3*/, 9 /*c7e4*/,  10 /*c7e5*/, 10 /*c7e6*/,
    11 /*c7e7*/, 9 /*c7e8*/,  10 /*c7e9*/, 10 /*c7ea*/, 11 /*c7eb*/,
    10 /*c7ec*/, 11 /*c7ed*/, 11 /*c7ee*/, 12 /*c7ef*/, 9 /*c7f0*/,
    10 /*c7f1*/, 10 /*c7f2*/, 11 /*c7f3*/, 10 /*c7f4*/, 11 /*c7f5*/,
    11 /*c7f6*/, 12 /*c7f7*/, 10 /*c7f8*/, 11 /*c7f9*/, 11 /*c7fa*/,
    12 /*c7fb*/, 11 /*c7fc*/, 12 /*c7fd*/, 12 /*c7fe*/, 13 /*c7ff*/,
    3 /*c800*/,  4 /*c801*/,  4 /*c802*/,  5 /*c803*/,  4 /*c804*/,
    5 /*c805*/,  5 /*c806*/,  6 /*c807*/,  4 /*c808*/,  5 /*c809*/,
    5 /*c80a*/,  6 /*c80b*/,  5 /*c80c*/,  6 /*c80d*/,  6 /*c80e*/,
    7 /*c80f*/,  4 /*c810*/,  5 /*c811*/,  5 /*c812*/,  6 /*c813*/,
    5 /*c814*/,  6 /*c815*/,  6 /*c816*/,  7 /*c817*/,  5 /*c818*/,
    6 /*c819*/,  6 /*c81a*/,  7 /*c81b*/,  6 /*c81c*/,  7 /*c81d*/,
    7 /*c81e*/,  8 /*c81f*/,  4 /*c820*/,  5 /*c821*/,  5 /*c822*/,
    6 /*c823*/,  5 /*c824*/,  6 /*c825*/,  6 /*c826*/,  7 /*c827*/,
    5 /*c828*/,  6 /*c829*/,  6 /*c82a*/,  7 /*c82b*/,  6 /*c82c*/,
    7 /*c82d*/,  7 /*c82e*/,  8 /*c82f*/,  5 /*c830*/,  6 /*c831*/,
    6 /*c832*/,  7 /*c833*/,  6 /*c834*/,  7 /*c835*/,  7 /*c836*/,
    8 /*c837*/,  6 /*c838*/,  7 /*c839*/,  7 /*c83a*/,  8 /*c83b*/,
    7 /*c83c*/,  8 /*c83d*/,  8 /*c83e*/,  9 /*c83f*/,  4 /*c840*/,
    5 /*c841*/,  5 /*c842*/,  6 /*c843*/,  5 /*c844*/,  6 /*c845*/,
    6 /*c846*/,  7 /*c847*/,  5 /*c848*/,  6 /*c849*/,  6 /*c84a*/,
    7 /*c84b*/,  6 /*c84c*/,  7 /*c84d*/,  7 /*c84e*/,  8 /*c84f*/,
    5 /*c850*/,  6 /*c851*/,  6 /*c852*/,  7 /*c853*/,  6 /*c854*/,
    7 /*c855*/,  7 /*c856*/,  8 /*c857*/,  6 /*c858*/,  7 /*c859*/,
    7 /*c85a*/,  8 /*c85b*/,  7 /*c85c*/,  8 /*c85d*/,  8 /*c85e*/,
    9 /*c85f*/,  5 /*c860*/,  6 /*c861*/,  6 /*c862*/,  7 /*c863*/,
    6 /*c864*/,  7 /*c865*/,  7 /*c866*/,  8 /*c867*/,  6 /*c868*/,
    7 /*c869*/,  7 /*c86a*/,  8 /*c86b*/,  7 /*c86c*/,  8 /*c86d*/,
    8 /*c86e*/,  9 /*c86f*/,  6 /*c870*/,  7 /*c871*/,  7 /*c872*/,
    8 /*c873*/,  7 /*c874*/,  8 /*c875*/,  8 /*c876*/,  9 /*c877*/,
    7 /*c878*/,  8 /*c879*/,  8 /*c87a*/,  9 /*c87b*/,  8 /*c87c*/,
    9 /*c87d*/,  9 /*c87e*/,  10 /*c87f*/, 4 /*c880*/,  5 /*c881*/,
    5 /*c882*/,  6 /*c883*/,  5 /*c884*/,  6 /*c885*/,  6 /*c886*/,
    7 /*c887*/,  5 /*c888*/,  6 /*c889*/,  6 /*c88a*/,  7 /*c88b*/,
    6 /*c88c*/,  7 /*c88d*/,  7 /*c88e*/,  8 /*c88f*/,  5 /*c890*/,
    6 /*c891*/,  6 /*c892*/,  7 /*c893*/,  6 /*c894*/,  7 /*c895*/,
    7 /*c896*/,  8 /*c897*/,  6 /*c898*/,  7 /*c899*/,  7 /*c89a*/,
    8 /*c89b*/,  7 /*c89c*/,  8 /*c89d*/,  8 /*c89e*/,  9 /*c89f*/,
    5 /*c8a0*/,  6 /*c8a1*/,  6 /*c8a2*/,  7 /*c8a3*/,  6 /*c8a4*/,
    7 /*c8a5*/,  7 /*c8a6*/,  8 /*c8a7*/,  6 /*c8a8*/,  7 /*c8a9*/,
    7 /*c8aa*/,  8 /*c8ab*/,  7 /*c8ac*/,  8 /*c8ad*/,  8 /*c8ae*/,
    9 /*c8af*/,  6 /*c8b0*/,  7 /*c8b1*/,  7 /*c8b2*/,  8 /*c8b3*/,
    7 /*c8b4*/,  8 /*c8b5*/,  8 /*c8b6*/,  9 /*c8b7*/,  7 /*c8b8*/,
    8 /*c8b9*/,  8 /*c8ba*/,  9 /*c8bb*/,  8 /*c8bc*/,  9 /*c8bd*/,
    9 /*c8be*/,  10 /*c8bf*/, 5 /*c8c0*/,  6 /*c8c1*/,  6 /*c8c2*/,
    7 /*c8c3*/,  6 /*c8c4*/,  7 /*c8c5*/,  7 /*c8c6*/,  8 /*c8c7*/,
    6 /*c8c8*/,  7 /*c8c9*/,  7 /*c8ca*/,  8 /*c8cb*/,  7 /*c8cc*/,
    8 /*c8cd*/,  8 /*c8ce*/,  9 /*c8cf*/,  6 /*c8d0*/,  7 /*c8d1*/,
    7 /*c8d2*/,  8 /*c8d3*/,  7 /*c8d4*/,  8 /*c8d5*/,  8 /*c8d6*/,
    9 /*c8d7*/,  7 /*c8d8*/,  8 /*c8d9*/,  8 /*c8da*/,  9 /*c8db*/,
    8 /*c8dc*/,  9 /*c8dd*/,  9 /*c8de*/,  10 /*c8df*/, 6 /*c8e0*/,
    7 /*c8e1*/,  7 /*c8e2*/,  8 /*c8e3*/,  7 /*c8e4*/,  8 /*c8e5*/,
    8 /*c8e6*/,  9 /*c8e7*/,  7 /*c8e8*/,  8 /*c8e9*/,  8 /*c8ea*/,
    9 /*c8eb*/,  8 /*c8ec*/,  9 /*c8ed*/,  9 /*c8ee*/,  10 /*c8ef*/,
    7 /*c8f0*/,  8 /*c8f1*/,  8 /*c8f2*/,  9 /*c8f3*/,  8 /*c8f4*/,
    9 /*c8f5*/,  9 /*c8f6*/,  10 /*c8f7*/, 8 /*c8f8*/,  9 /*c8f9*/,
    9 /*c8fa*/,  10 /*c8fb*/, 9 /*c8fc*/,  10 /*c8fd*/, 10 /*c8fe*/,
    11 /*c8ff*/, 4 /*c900*/,  5 /*c901*/,  5 /*c902*/,  6 /*c903*/,
    5 /*c904*/,  6 /*c905*/,  6 /*c906*/,  7 /*c907*/,  5 /*c908*/,
    6 /*c909*/,  6 /*c90a*/,  7 /*c90b*/,  6 /*c90c*/,  7 /*c90d*/,
    7 /*c90e*/,  8 /*c90f*/,  5 /*c910*/,  6 /*c911*/,  6 /*c912*/,
    7 /*c913*/,  6 /*c914*/,  7 /*c915*/,  7 /*c916*/,  8 /*c917*/,
    6 /*c918*/,  7 /*c919*/,  7 /*c91a*/,  8 /*c91b*/,  7 /*c91c*/,
    8 /*c91d*/,  8 /*c91e*/,  9 /*c91f*/,  5 /*c920*/,  6 /*c921*/,
    6 /*c922*/,  7 /*c923*/,  6 /*c924*/,  7 /*c925*/,  7 /*c926*/,
    8 /*c927*/,  6 /*c928*/,  7 /*c929*/,  7 /*c92a*/,  8 /*c92b*/,
    7 /*c92c*/,  8 /*c92d*/,  8 /*c92e*/,  9 /*c92f*/,  6 /*c930*/,
    7 /*c931*/,  7 /*c932*/,  8 /*c933*/,  7 /*c934*/,  8 /*c935*/,
    8 /*c936*/,  9 /*c937*/,  7 /*c938*/,  8 /*c939*/,  8 /*c93a*/,
    9 /*c93b*/,  8 /*c93c*/,  9 /*c93d*/,  9 /*c93e*/,  10 /*c93f*/,
    5 /*c940*/,  6 /*c941*/,  6 /*c942*/,  7 /*c943*/,  6 /*c944*/,
    7 /*c945*/,  7 /*c946*/,  8 /*c947*/,  6 /*c948*/,  7 /*c949*/,
    7 /*c94a*/,  8 /*c94b*/,  7 /*c94c*/,  8 /*c94d*/,  8 /*c94e*/,
    9 /*c94f*/,  6 /*c950*/,  7 /*c951*/,  7 /*c952*/,  8 /*c953*/,
    7 /*c954*/,  8 /*c955*/,  8 /*c956*/,  9 /*c957*/,  7 /*c958*/,
    8 /*c959*/,  8 /*c95a*/,  9 /*c95b*/,  8 /*c95c*/,  9 /*c95d*/,
    9 /*c95e*/,  10 /*c95f*/, 6 /*c960*/,  7 /*c961*/,  7 /*c962*/,
    8 /*c963*/,  7 /*c964*/,  8 /*c965*/,  8 /*c966*/,  9 /*c967*/,
    7 /*c968*/,  8 /*c969*/,  8 /*c96a*/,  9 /*c96b*/,  8 /*c96c*/,
    9 /*c96d*/,  9 /*c96e*/,  10 /*c96f*/, 7 /*c970*/,  8 /*c971*/,
    8 /*c972*/,  9 /*c973*/,  8 /*c974*/,  9 /*c975*/,  9 /*c976*/,
    10 /*c977*/, 8 /*c978*/,  9 /*c979*/,  9 /*c97a*/,  10 /*c97b*/,
    9 /*c97c*/,  10 /*c97d*/, 10 /*c97e*/, 11 /*c97f*/, 5 /*c980*/,
    6 /*c981*/,  6 /*c982*/,  7 /*c983*/,  6 /*c984*/,  7 /*c985*/,
    7 /*c986*/,  8 /*c987*/,  6 /*c988*/,  7 /*c989*/,  7 /*c98a*/,
    8 /*c98b*/,  7 /*c98c*/,  8 /*c98d*/,  8 /*c98e*/,  9 /*c98f*/,
    6 /*c990*/,  7 /*c991*/,  7 /*c992*/,  8 /*c993*/,  7 /*c994*/,
    8 /*c995*/,  8 /*c996*/,  9 /*c997*/,  7 /*c998*/,  8 /*c999*/,
    8 /*c99a*/,  9 /*c99b*/,  8 /*c99c*/,  9 /*c99d*/,  9 /*c99e*/,
    10 /*c99f*/, 6 /*c9a0*/,  7 /*c9a1*/,  7 /*c9a2*/,  8 /*c9a3*/,
    7 /*c9a4*/,  8 /*c9a5*/,  8 /*c9a6*/,  9 /*c9a7*/,  7 /*c9a8*/,
    8 /*c9a9*/,  8 /*c9aa*/,  9 /*c9ab*/,  8 /*c9ac*/,  9 /*c9ad*/,
    9 /*c9ae*/,  10 /*c9af*/, 7 /*c9b0*/,  8 /*c9b1*/,  8 /*c9b2*/,
    9 /*c9b3*/,  8 /*c9b4*/,  9 /*c9b5*/,  9 /*c9b6*/,  10 /*c9b7*/,
    8 /*c9b8*/,  9 /*c9b9*/,  9 /*c9ba*/,  10 /*c9bb*/, 9 /*c9bc*/,
    10 /*c9bd*/, 10 /*c9be*/, 11 /*c9bf*/, 6 /*c9c0*/,  7 /*c9c1*/,
    7 /*c9c2*/,  8 /*c9c3*/,  7 /*c9c4*/,  8 /*c9c5*/,  8 /*c9c6*/,
    9 /*c9c7*/,  7 /*c9c8*/,  8 /*c9c9*/,  8 /*c9ca*/,  9 /*c9cb*/,
    8 /*c9cc*/,  9 /*c9cd*/,  9 /*c9ce*/,  10 /*c9cf*/, 7 /*c9d0*/,
    8 /*c9d1*/,  8 /*c9d2*/,  9 /*c9d3*/,  8 /*c9d4*/,  9 /*c9d5*/,
    9 /*c9d6*/,  10 /*c9d7*/, 8 /*c9d8*/,  9 /*c9d9*/,  9 /*c9da*/,
    10 /*c9db*/, 9 /*c9dc*/,  10 /*c9dd*/, 10 /*c9de*/, 11 /*c9df*/,
    7 /*c9e0*/,  8 /*c9e1*/,  8 /*c9e2*/,  9 /*c9e3*/,  8 /*c9e4*/,
    9 /*c9e5*/,  9 /*c9e6*/,  10 /*c9e7*/, 8 /*c9e8*/,  9 /*c9e9*/,
    9 /*c9ea*/,  10 /*c9eb*/, 9 /*c9ec*/,  10 /*c9ed*/, 10 /*c9ee*/,
    11 /*c9ef*/, 8 /*c9f0*/,  9 /*c9f1*/,  9 /*c9f2*/,  10 /*c9f3*/,
    9 /*c9f4*/,  10 /*c9f5*/, 10 /*c9f6*/, 11 /*c9f7*/, 9 /*c9f8*/,
    10 /*c9f9*/, 10 /*c9fa*/, 11 /*c9fb*/, 10 /*c9fc*/, 11 /*c9fd*/,
    11 /*c9fe*/, 12 /*c9ff*/, 4 /*ca00*/,  5 /*ca01*/,  5 /*ca02*/,
    6 /*ca03*/,  5 /*ca04*/,  6 /*ca05*/,  6 /*ca06*/,  7 /*ca07*/,
    5 /*ca08*/,  6 /*ca09*/,  6 /*ca0a*/,  7 /*ca0b*/,  6 /*ca0c*/,
    7 /*ca0d*/,  7 /*ca0e*/,  8 /*ca0f*/,  5 /*ca10*/,  6 /*ca11*/,
    6 /*ca12*/,  7 /*ca13*/,  6 /*ca14*/,  7 /*ca15*/,  7 /*ca16*/,
    8 /*ca17*/,  6 /*ca18*/,  7 /*ca19*/,  7 /*ca1a*/,  8 /*ca1b*/,
    7 /*ca1c*/,  8 /*ca1d*/,  8 /*ca1e*/,  9 /*ca1f*/,  5 /*ca20*/,
    6 /*ca21*/,  6 /*ca22*/,  7 /*ca23*/,  6 /*ca24*/,  7 /*ca25*/,
    7 /*ca26*/,  8 /*ca27*/,  6 /*ca28*/,  7 /*ca29*/,  7 /*ca2a*/,
    8 /*ca2b*/,  7 /*ca2c*/,  8 /*ca2d*/,  8 /*ca2e*/,  9 /*ca2f*/,
    6 /*ca30*/,  7 /*ca31*/,  7 /*ca32*/,  8 /*ca33*/,  7 /*ca34*/,
    8 /*ca35*/,  8 /*ca36*/,  9 /*ca37*/,  7 /*ca38*/,  8 /*ca39*/,
    8 /*ca3a*/,  9 /*ca3b*/,  8 /*ca3c*/,  9 /*ca3d*/,  9 /*ca3e*/,
    10 /*ca3f*/, 5 /*ca40*/,  6 /*ca41*/,  6 /*ca42*/,  7 /*ca43*/,
    6 /*ca44*/,  7 /*ca45*/,  7 /*ca46*/,  8 /*ca47*/,  6 /*ca48*/,
    7 /*ca49*/,  7 /*ca4a*/,  8 /*ca4b*/,  7 /*ca4c*/,  8 /*ca4d*/,
    8 /*ca4e*/,  9 /*ca4f*/,  6 /*ca50*/,  7 /*ca51*/,  7 /*ca52*/,
    8 /*ca53*/,  7 /*ca54*/,  8 /*ca55*/,  8 /*ca56*/,  9 /*ca57*/,
    7 /*ca58*/,  8 /*ca59*/,  8 /*ca5a*/,  9 /*ca5b*/,  8 /*ca5c*/,
    9 /*ca5d*/,  9 /*ca5e*/,  10 /*ca5f*/, 6 /*ca60*/,  7 /*ca61*/,
    7 /*ca62*/,  8 /*ca63*/,  7 /*ca64*/,  8 /*ca65*/,  8 /*ca66*/,
    9 /*ca67*/,  7 /*ca68*/,  8 /*ca69*/,  8 /*ca6a*/,  9 /*ca6b*/,
    8 /*ca6c*/,  9 /*ca6d*/,  9 /*ca6e*/,  10 /*ca6f*/, 7 /*ca70*/,
    8 /*ca71*/,  8 /*ca72*/,  9 /*ca73*/,  8 /*ca74*/,  9 /*ca75*/,
    9 /*ca76*/,  10 /*ca77*/, 8 /*ca78*/,  9 /*ca79*/,  9 /*ca7a*/,
    10 /*ca7b*/, 9 /*ca7c*/,  10 /*ca7d*/, 10 /*ca7e*/, 11 /*ca7f*/,
    5 /*ca80*/,  6 /*ca81*/,  6 /*ca82*/,  7 /*ca83*/,  6 /*ca84*/,
    7 /*ca85*/,  7 /*ca86*/,  8 /*ca87*/,  6 /*ca88*/,  7 /*ca89*/,
    7 /*ca8a*/,  8 /*ca8b*/,  7 /*ca8c*/,  8 /*ca8d*/,  8 /*ca8e*/,
    9 /*ca8f*/,  6 /*ca90*/,  7 /*ca91*/,  7 /*ca92*/,  8 /*ca93*/,
    7 /*ca94*/,  8 /*ca95*/,  8 /*ca96*/,  9 /*ca97*/,  7 /*ca98*/,
    8 /*ca99*/,  8 /*ca9a*/,  9 /*ca9b*/,  8 /*ca9c*/,  9 /*ca9d*/,
    9 /*ca9e*/,  10 /*ca9f*/, 6 /*caa0*/,  7 /*caa1*/,  7 /*caa2*/,
    8 /*caa3*/,  7 /*caa4*/,  8 /*caa5*/,  8 /*caa6*/,  9 /*caa7*/,
    7 /*caa8*/,  8 /*caa9*/,  8 /*caaa*/,  9 /*caab*/,  8 /*caac*/,
    9 /*caad*/,  9 /*caae*/,  10 /*caaf*/, 7 /*cab0*/,  8 /*cab1*/,
    8 /*cab2*/,  9 /*cab3*/,  8 /*cab4*/,  9 /*cab5*/,  9 /*cab6*/,
    10 /*cab7*/, 8 /*cab8*/,  9 /*cab9*/,  9 /*caba*/,  10 /*cabb*/,
    9 /*cabc*/,  10 /*cabd*/, 10 /*cabe*/, 11 /*cabf*/, 6 /*cac0*/,
    7 /*cac1*/,  7 /*cac2*/,  8 /*cac3*/,  7 /*cac4*/,  8 /*cac5*/,
    8 /*cac6*/,  9 /*cac7*/,  7 /*cac8*/,  8 /*cac9*/,  8 /*caca*/,
    9 /*cacb*/,  8 /*cacc*/,  9 /*cacd*/,  9 /*cace*/,  10 /*cacf*/,
    7 /*cad0*/,  8 /*cad1*/,  8 /*cad2*/,  9 /*cad3*/,  8 /*cad4*/,
    9 /*cad5*/,  9 /*cad6*/,  10 /*cad7*/, 8 /*cad8*/,  9 /*cad9*/,
    9 /*cada*/,  10 /*cadb*/, 9 /*cadc*/,  10 /*cadd*/, 10 /*cade*/,
    11 /*cadf*/, 7 /*cae0*/,  8 /*cae1*/,  8 /*cae2*/,  9 /*cae3*/,
    8 /*cae4*/,  9 /*cae5*/,  9 /*cae6*/,  10 /*cae7*/, 8 /*cae8*/,
    9 /*cae9*/,  9 /*caea*/,  10 /*caeb*/, 9 /*caec*/,  10 /*caed*/,
    10 /*caee*/, 11 /*caef*/, 8 /*caf0*/,  9 /*caf1*/,  9 /*caf2*/,
    10 /*caf3*/, 9 /*caf4*/,  10 /*caf5*/, 10 /*caf6*/, 11 /*caf7*/,
    9 /*caf8*/,  10 /*caf9*/, 10 /*cafa*/, 11 /*cafb*/, 10 /*cafc*/,
    11 /*cafd*/, 11 /*cafe*/, 12 /*caff*/, 5 /*cb00*/,  6 /*cb01*/,
    6 /*cb02*/,  7 /*cb03*/,  6 /*cb04*/,  7 /*cb05*/,  7 /*cb06*/,
    8 /*cb07*/,  6 /*cb08*/,  7 /*cb09*/,  7 /*cb0a*/,  8 /*cb0b*/,
    7 /*cb0c*/,  8 /*cb0d*/,  8 /*cb0e*/,  9 /*cb0f*/,  6 /*cb10*/,
    7 /*cb11*/,  7 /*cb12*/,  8 /*cb13*/,  7 /*cb14*/,  8 /*cb15*/,
    8 /*cb16*/,  9 /*cb17*/,  7 /*cb18*/,  8 /*cb19*/,  8 /*cb1a*/,
    9 /*cb1b*/,  8 /*cb1c*/,  9 /*cb1d*/,  9 /*cb1e*/,  10 /*cb1f*/,
    6 /*cb20*/,  7 /*cb21*/,  7 /*cb22*/,  8 /*cb23*/,  7 /*cb24*/,
    8 /*cb25*/,  8 /*cb26*/,  9 /*cb27*/,  7 /*cb28*/,  8 /*cb29*/,
    8 /*cb2a*/,  9 /*cb2b*/,  8 /*cb2c*/,  9 /*cb2d*/,  9 /*cb2e*/,
    10 /*cb2f*/, 7 /*cb30*/,  8 /*cb31*/,  8 /*cb32*/,  9 /*cb33*/,
    8 /*cb34*/,  9 /*cb35*/,  9 /*cb36*/,  10 /*cb37*/, 8 /*cb38*/,
    9 /*cb39*/,  9 /*cb3a*/,  10 /*cb3b*/, 9 /*cb3c*/,  10 /*cb3d*/,
    10 /*cb3e*/, 11 /*cb3f*/, 6 /*cb40*/,  7 /*cb41*/,  7 /*cb42*/,
    8 /*cb43*/,  7 /*cb44*/,  8 /*cb45*/,  8 /*cb46*/,  9 /*cb47*/,
    7 /*cb48*/,  8 /*cb49*/,  8 /*cb4a*/,  9 /*cb4b*/,  8 /*cb4c*/,
    9 /*cb4d*/,  9 /*cb4e*/,  10 /*cb4f*/, 7 /*cb50*/,  8 /*cb51*/,
    8 /*cb52*/,  9 /*cb53*/,  8 /*cb54*/,  9 /*cb55*/,  9 /*cb56*/,
    10 /*cb57*/, 8 /*cb58*/,  9 /*cb59*/,  9 /*cb5a*/,  10 /*cb5b*/,
    9 /*cb5c*/,  10 /*cb5d*/, 10 /*cb5e*/, 11 /*cb5f*/, 7 /*cb60*/,
    8 /*cb61*/,  8 /*cb62*/,  9 /*cb63*/,  8 /*cb64*/,  9 /*cb65*/,
    9 /*cb66*/,  10 /*cb67*/, 8 /*cb68*/,  9 /*cb69*/,  9 /*cb6a*/,
    10 /*cb6b*/, 9 /*cb6c*/,  10 /*cb6d*/, 10 /*cb6e*/, 11 /*cb6f*/,
    8 /*cb70*/,  9 /*cb71*/,  9 /*cb72*/,  10 /*cb73*/, 9 /*cb74*/,
    10 /*cb75*/, 10 /*cb76*/, 11 /*cb77*/, 9 /*cb78*/,  10 /*cb79*/,
    10 /*cb7a*/, 11 /*cb7b*/, 10 /*cb7c*/, 11 /*cb7d*/, 11 /*cb7e*/,
    12 /*cb7f*/, 6 /*cb80*/,  7 /*cb81*/,  7 /*cb82*/,  8 /*cb83*/,
    7 /*cb84*/,  8 /*cb85*/,  8 /*cb86*/,  9 /*cb87*/,  7 /*cb88*/,
    8 /*cb89*/,  8 /*cb8a*/,  9 /*cb8b*/,  8 /*cb8c*/,  9 /*cb8d*/,
    9 /*cb8e*/,  10 /*cb8f*/, 7 /*cb90*/,  8 /*cb91*/,  8 /*cb92*/,
    9 /*cb93*/,  8 /*cb94*/,  9 /*cb95*/,  9 /*cb96*/,  10 /*cb97*/,
    8 /*cb98*/,  9 /*cb99*/,  9 /*cb9a*/,  10 /*cb9b*/, 9 /*cb9c*/,
    10 /*cb9d*/, 10 /*cb9e*/, 11 /*cb9f*/, 7 /*cba0*/,  8 /*cba1*/,
    8 /*cba2*/,  9 /*cba3*/,  8 /*cba4*/,  9 /*cba5*/,  9 /*cba6*/,
    10 /*cba7*/, 8 /*cba8*/,  9 /*cba9*/,  9 /*cbaa*/,  10 /*cbab*/,
    9 /*cbac*/,  10 /*cbad*/, 10 /*cbae*/, 11 /*cbaf*/, 8 /*cbb0*/,
    9 /*cbb1*/,  9 /*cbb2*/,  10 /*cbb3*/, 9 /*cbb4*/,  10 /*cbb5*/,
    10 /*cbb6*/, 11 /*cbb7*/, 9 /*cbb8*/,  10 /*cbb9*/, 10 /*cbba*/,
    11 /*cbbb*/, 10 /*cbbc*/, 11 /*cbbd*/, 11 /*cbbe*/, 12 /*cbbf*/,
    7 /*cbc0*/,  8 /*cbc1*/,  8 /*cbc2*/,  9 /*cbc3*/,  8 /*cbc4*/,
    9 /*cbc5*/,  9 /*cbc6*/,  10 /*cbc7*/, 8 /*cbc8*/,  9 /*cbc9*/,
    9 /*cbca*/,  10 /*cbcb*/, 9 /*cbcc*/,  10 /*cbcd*/, 10 /*cbce*/,
    11 /*cbcf*/, 8 /*cbd0*/,  9 /*cbd1*/,  9 /*cbd2*/,  10 /*cbd3*/,
    9 /*cbd4*/,  10 /*cbd5*/, 10 /*cbd6*/, 11 /*cbd7*/, 9 /*cbd8*/,
    10 /*cbd9*/, 10 /*cbda*/, 11 /*cbdb*/, 10 /*cbdc*/, 11 /*cbdd*/,
    11 /*cbde*/, 12 /*cbdf*/, 8 /*cbe0*/,  9 /*cbe1*/,  9 /*cbe2*/,
    10 /*cbe3*/, 9 /*cbe4*/,  10 /*cbe5*/, 10 /*cbe6*/, 11 /*cbe7*/,
    9 /*cbe8*/,  10 /*cbe9*/, 10 /*cbea*/, 11 /*cbeb*/, 10 /*cbec*/,
    11 /*cbed*/, 11 /*cbee*/, 12 /*cbef*/, 9 /*cbf0*/,  10 /*cbf1*/,
    10 /*cbf2*/, 11 /*cbf3*/, 10 /*cbf4*/, 11 /*cbf5*/, 11 /*cbf6*/,
    12 /*cbf7*/, 10 /*cbf8*/, 11 /*cbf9*/, 11 /*cbfa*/, 12 /*cbfb*/,
    11 /*cbfc*/, 12 /*cbfd*/, 12 /*cbfe*/, 13 /*cbff*/, 4 /*cc00*/,
    5 /*cc01*/,  5 /*cc02*/,  6 /*cc03*/,  5 /*cc04*/,  6 /*cc05*/,
    6 /*cc06*/,  7 /*cc07*/,  5 /*cc08*/,  6 /*cc09*/,  6 /*cc0a*/,
    7 /*cc0b*/,  6 /*cc0c*/,  7 /*cc0d*/,  7 /*cc0e*/,  8 /*cc0f*/,
    5 /*cc10*/,  6 /*cc11*/,  6 /*cc12*/,  7 /*cc13*/,  6 /*cc14*/,
    7 /*cc15*/,  7 /*cc16*/,  8 /*cc17*/,  6 /*cc18*/,  7 /*cc19*/,
    7 /*cc1a*/,  8 /*cc1b*/,  7 /*cc1c*/,  8 /*cc1d*/,  8 /*cc1e*/,
    9 /*cc1f*/,  5 /*cc20*/,  6 /*cc21*/,  6 /*cc22*/,  7 /*cc23*/,
    6 /*cc24*/,  7 /*cc25*/,  7 /*cc26*/,  8 /*cc27*/,  6 /*cc28*/,
    7 /*cc29*/,  7 /*cc2a*/,  8 /*cc2b*/,  7 /*cc2c*/,  8 /*cc2d*/,
    8 /*cc2e*/,  9 /*cc2f*/,  6 /*cc30*/,  7 /*cc31*/,  7 /*cc32*/,
    8 /*cc33*/,  7 /*cc34*/,  8 /*cc35*/,  8 /*cc36*/,  9 /*cc37*/,
    7 /*cc38*/,  8 /*cc39*/,  8 /*cc3a*/,  9 /*cc3b*/,  8 /*cc3c*/,
    9 /*cc3d*/,  9 /*cc3e*/,  10 /*cc3f*/, 5 /*cc40*/,  6 /*cc41*/,
    6 /*cc42*/,  7 /*cc43*/,  6 /*cc44*/,  7 /*cc45*/,  7 /*cc46*/,
    8 /*cc47*/,  6 /*cc48*/,  7 /*cc49*/,  7 /*cc4a*/,  8 /*cc4b*/,
    7 /*cc4c*/,  8 /*cc4d*/,  8 /*cc4e*/,  9 /*cc4f*/,  6 /*cc50*/,
    7 /*cc51*/,  7 /*cc52*/,  8 /*cc53*/,  7 /*cc54*/,  8 /*cc55*/,
    8 /*cc56*/,  9 /*cc57*/,  7 /*cc58*/,  8 /*cc59*/,  8 /*cc5a*/,
    9 /*cc5b*/,  8 /*cc5c*/,  9 /*cc5d*/,  9 /*cc5e*/,  10 /*cc5f*/,
    6 /*cc60*/,  7 /*cc61*/,  7 /*cc62*/,  8 /*cc63*/,  7 /*cc64*/,
    8 /*cc65*/,  8 /*cc66*/,  9 /*cc67*/,  7 /*cc68*/,  8 /*cc69*/,
    8 /*cc6a*/,  9 /*cc6b*/,  8 /*cc6c*/,  9 /*cc6d*/,  9 /*cc6e*/,
    10 /*cc6f*/, 7 /*cc70*/,  8 /*cc71*/,  8 /*cc72*/,  9 /*cc73*/,
    8 /*cc74*/,  9 /*cc75*/,  9 /*cc76*/,  10 /*cc77*/, 8 /*cc78*/,
    9 /*cc79*/,  9 /*cc7a*/,  10 /*cc7b*/, 9 /*cc7c*/,  10 /*cc7d*/,
    10 /*cc7e*/, 11 /*cc7f*/, 5 /*cc80*/,  6 /*cc81*/,  6 /*cc82*/,
    7 /*cc83*/,  6 /*cc84*/,  7 /*cc85*/,  7 /*cc86*/,  8 /*cc87*/,
    6 /*cc88*/,  7 /*cc89*/,  7 /*cc8a*/,  8 /*cc8b*/,  7 /*cc8c*/,
    8 /*cc8d*/,  8 /*cc8e*/,  9 /*cc8f*/,  6 /*cc90*/,  7 /*cc91*/,
    7 /*cc92*/,  8 /*cc93*/,  7 /*cc94*/,  8 /*cc95*/,  8 /*cc96*/,
    9 /*cc97*/,  7 /*cc98*/,  8 /*cc99*/,  8 /*cc9a*/,  9 /*cc9b*/,
    8 /*cc9c*/,  9 /*cc9d*/,  9 /*cc9e*/,  10 /*cc9f*/, 6 /*cca0*/,
    7 /*cca1*/,  7 /*cca2*/,  8 /*cca3*/,  7 /*cca4*/,  8 /*cca5*/,
    8 /*cca6*/,  9 /*cca7*/,  7 /*cca8*/,  8 /*cca9*/,  8 /*ccaa*/,
    9 /*ccab*/,  8 /*ccac*/,  9 /*ccad*/,  9 /*ccae*/,  10 /*ccaf*/,
    7 /*ccb0*/,  8 /*ccb1*/,  8 /*ccb2*/,  9 /*ccb3*/,  8 /*ccb4*/,
    9 /*ccb5*/,  9 /*ccb6*/,  10 /*ccb7*/, 8 /*ccb8*/,  9 /*ccb9*/,
    9 /*ccba*/,  10 /*ccbb*/, 9 /*ccbc*/,  10 /*ccbd*/, 10 /*ccbe*/,
    11 /*ccbf*/, 6 /*ccc0*/,  7 /*ccc1*/,  7 /*ccc2*/,  8 /*ccc3*/,
    7 /*ccc4*/,  8 /*ccc5*/,  8 /*ccc6*/,  9 /*ccc7*/,  7 /*ccc8*/,
    8 /*ccc9*/,  8 /*ccca*/,  9 /*cccb*/,  8 /*cccc*/,  9 /*cccd*/,
    9 /*ccce*/,  10 /*cccf*/, 7 /*ccd0*/,  8 /*ccd1*/,  8 /*ccd2*/,
    9 /*ccd3*/,  8 /*ccd4*/,  9 /*ccd5*/,  9 /*ccd6*/,  10 /*ccd7*/,
    8 /*ccd8*/,  9 /*ccd9*/,  9 /*ccda*/,  10 /*ccdb*/, 9 /*ccdc*/,
    10 /*ccdd*/, 10 /*ccde*/, 11 /*ccdf*/, 7 /*cce0*/,  8 /*cce1*/,
    8 /*cce2*/,  9 /*cce3*/,  8 /*cce4*/,  9 /*cce5*/,  9 /*cce6*/,
    10 /*cce7*/, 8 /*cce8*/,  9 /*cce9*/,  9 /*ccea*/,  10 /*cceb*/,
    9 /*ccec*/,  10 /*cced*/, 10 /*ccee*/, 11 /*ccef*/, 8 /*ccf0*/,
    9 /*ccf1*/,  9 /*ccf2*/,  10 /*ccf3*/, 9 /*ccf4*/,  10 /*ccf5*/,
    10 /*ccf6*/, 11 /*ccf7*/, 9 /*ccf8*/,  10 /*ccf9*/, 10 /*ccfa*/,
    11 /*ccfb*/, 10 /*ccfc*/, 11 /*ccfd*/, 11 /*ccfe*/, 12 /*ccff*/,
    5 /*cd00*/,  6 /*cd01*/,  6 /*cd02*/,  7 /*cd03*/,  6 /*cd04*/,
    7 /*cd05*/,  7 /*cd06*/,  8 /*cd07*/,  6 /*cd08*/,  7 /*cd09*/,
    7 /*cd0a*/,  8 /*cd0b*/,  7 /*cd0c*/,  8 /*cd0d*/,  8 /*cd0e*/,
    9 /*cd0f*/,  6 /*cd10*/,  7 /*cd11*/,  7 /*cd12*/,  8 /*cd13*/,
    7 /*cd14*/,  8 /*cd15*/,  8 /*cd16*/,  9 /*cd17*/,  7 /*cd18*/,
    8 /*cd19*/,  8 /*cd1a*/,  9 /*cd1b*/,  8 /*cd1c*/,  9 /*cd1d*/,
    9 /*cd1e*/,  10 /*cd1f*/, 6 /*cd20*/,  7 /*cd21*/,  7 /*cd22*/,
    8 /*cd23*/,  7 /*cd24*/,  8 /*cd25*/,  8 /*cd26*/,  9 /*cd27*/,
    7 /*cd28*/,  8 /*cd29*/,  8 /*cd2a*/,  9 /*cd2b*/,  8 /*cd2c*/,
    9 /*cd2d*/,  9 /*cd2e*/,  10 /*cd2f*/, 7 /*cd30*/,  8 /*cd31*/,
    8 /*cd32*/,  9 /*cd33*/,  8 /*cd34*/,  9 /*cd35*/,  9 /*cd36*/,
    10 /*cd37*/, 8 /*cd38*/,  9 /*cd39*/,  9 /*cd3a*/,  10 /*cd3b*/,
    9 /*cd3c*/,  10 /*cd3d*/, 10 /*cd3e*/, 11 /*cd3f*/, 6 /*cd40*/,
    7 /*cd41*/,  7 /*cd42*/,  8 /*cd43*/,  7 /*cd44*/,  8 /*cd45*/,
    8 /*cd46*/,  9 /*cd47*/,  7 /*cd48*/,  8 /*cd49*/,  8 /*cd4a*/,
    9 /*cd4b*/,  8 /*cd4c*/,  9 /*cd4d*/,  9 /*cd4e*/,  10 /*cd4f*/,
    7 /*cd50*/,  8 /*cd51*/,  8 /*cd52*/,  9 /*cd53*/,  8 /*cd54*/,
    9 /*cd55*/,  9 /*cd56*/,  10 /*cd57*/, 8 /*cd58*/,  9 /*cd59*/,
    9 /*cd5a*/,  10 /*cd5b*/, 9 /*cd5c*/,  10 /*cd5d*/, 10 /*cd5e*/,
    11 /*cd5f*/, 7 /*cd60*/,  8 /*cd61*/,  8 /*cd62*/,  9 /*cd63*/,
    8 /*cd64*/,  9 /*cd65*/,  9 /*cd66*/,  10 /*cd67*/, 8 /*cd68*/,
    9 /*cd69*/,  9 /*cd6a*/,  10 /*cd6b*/, 9 /*cd6c*/,  10 /*cd6d*/,
    10 /*cd6e*/, 11 /*cd6f*/, 8 /*cd70*/,  9 /*cd71*/,  9 /*cd72*/,
    10 /*cd73*/, 9 /*cd74*/,  10 /*cd75*/, 10 /*cd76*/, 11 /*cd77*/,
    9 /*cd78*/,  10 /*cd79*/, 10 /*cd7a*/, 11 /*cd7b*/, 10 /*cd7c*/,
    11 /*cd7d*/, 11 /*cd7e*/, 12 /*cd7f*/, 6 /*cd80*/,  7 /*cd81*/,
    7 /*cd82*/,  8 /*cd83*/,  7 /*cd84*/,  8 /*cd85*/,  8 /*cd86*/,
    9 /*cd87*/,  7 /*cd88*/,  8 /*cd89*/,  8 /*cd8a*/,  9 /*cd8b*/,
    8 /*cd8c*/,  9 /*cd8d*/,  9 /*cd8e*/,  10 /*cd8f*/, 7 /*cd90*/,
    8 /*cd91*/,  8 /*cd92*/,  9 /*cd93*/,  8 /*cd94*/,  9 /*cd95*/,
    9 /*cd96*/,  10 /*cd97*/, 8 /*cd98*/,  9 /*cd99*/,  9 /*cd9a*/,
    10 /*cd9b*/, 9 /*cd9c*/,  10 /*cd9d*/, 10 /*cd9e*/, 11 /*cd9f*/,
    7 /*cda0*/,  8 /*cda1*/,  8 /*cda2*/,  9 /*cda3*/,  8 /*cda4*/,
    9 /*cda5*/,  9 /*cda6*/,  10 /*cda7*/, 8 /*cda8*/,  9 /*cda9*/,
    9 /*cdaa*/,  10 /*cdab*/, 9 /*cdac*/,  10 /*cdad*/, 10 /*cdae*/,
    11 /*cdaf*/, 8 /*cdb0*/,  9 /*cdb1*/,  9 /*cdb2*/,  10 /*cdb3*/,
    9 /*cdb4*/,  10 /*cdb5*/, 10 /*cdb6*/, 11 /*cdb7*/, 9 /*cdb8*/,
    10 /*cdb9*/, 10 /*cdba*/, 11 /*cdbb*/, 10 /*cdbc*/, 11 /*cdbd*/,
    11 /*cdbe*/, 12 /*cdbf*/, 7 /*cdc0*/,  8 /*cdc1*/,  8 /*cdc2*/,
    9 /*cdc3*/,  8 /*cdc4*/,  9 /*cdc5*/,  9 /*cdc6*/,  10 /*cdc7*/,
    8 /*cdc8*/,  9 /*cdc9*/,  9 /*cdca*/,  10 /*cdcb*/, 9 /*cdcc*/,
    10 /*cdcd*/, 10 /*cdce*/, 11 /*cdcf*/, 8 /*cdd0*/,  9 /*cdd1*/,
    9 /*cdd2*/,  10 /*cdd3*/, 9 /*cdd4*/,  10 /*cdd5*/, 10 /*cdd6*/,
    11 /*cdd7*/, 9 /*cdd8*/,  10 /*cdd9*/, 10 /*cdda*/, 11 /*cddb*/,
    10 /*cddc*/, 11 /*cddd*/, 11 /*cdde*/, 12 /*cddf*/, 8 /*cde0*/,
    9 /*cde1*/,  9 /*cde2*/,  10 /*cde3*/, 9 /*cde4*/,  10 /*cde5*/,
    10 /*cde6*/, 11 /*cde7*/, 9 /*cde8*/,  10 /*cde9*/, 10 /*cdea*/,
    11 /*cdeb*/, 10 /*cdec*/, 11 /*cded*/, 11 /*cdee*/, 12 /*cdef*/,
    9 /*cdf0*/,  10 /*cdf1*/, 10 /*cdf2*/, 11 /*cdf3*/, 10 /*cdf4*/,
    11 /*cdf5*/, 11 /*cdf6*/, 12 /*cdf7*/, 10 /*cdf8*/, 11 /*cdf9*/,
    11 /*cdfa*/, 12 /*cdfb*/, 11 /*cdfc*/, 12 /*cdfd*/, 12 /*cdfe*/,
    13 /*cdff*/, 5 /*ce00*/,  6 /*ce01*/,  6 /*ce02*/,  7 /*ce03*/,
    6 /*ce04*/,  7 /*ce05*/,  7 /*ce06*/,  8 /*ce07*/,  6 /*ce08*/,
    7 /*ce09*/,  7 /*ce0a*/,  8 /*ce0b*/,  7 /*ce0c*/,  8 /*ce0d*/,
    8 /*ce0e*/,  9 /*ce0f*/,  6 /*ce10*/,  7 /*ce11*/,  7 /*ce12*/,
    8 /*ce13*/,  7 /*ce14*/,  8 /*ce15*/,  8 /*ce16*/,  9 /*ce17*/,
    7 /*ce18*/,  8 /*ce19*/,  8 /*ce1a*/,  9 /*ce1b*/,  8 /*ce1c*/,
    9 /*ce1d*/,  9 /*ce1e*/,  10 /*ce1f*/, 6 /*ce20*/,  7 /*ce21*/,
    7 /*ce22*/,  8 /*ce23*/,  7 /*ce24*/,  8 /*ce25*/,  8 /*ce26*/,
    9 /*ce27*/,  7 /*ce28*/,  8 /*ce29*/,  8 /*ce2a*/,  9 /*ce2b*/,
    8 /*ce2c*/,  9 /*ce2d*/,  9 /*ce2e*/,  10 /*ce2f*/, 7 /*ce30*/,
    8 /*ce31*/,  8 /*ce32*/,  9 /*ce33*/,  8 /*ce34*/,  9 /*ce35*/,
    9 /*ce36*/,  10 /*ce37*/, 8 /*ce38*/,  9 /*ce39*/,  9 /*ce3a*/,
    10 /*ce3b*/, 9 /*ce3c*/,  10 /*ce3d*/, 10 /*ce3e*/, 11 /*ce3f*/,
    6 /*ce40*/,  7 /*ce41*/,  7 /*ce42*/,  8 /*ce43*/,  7 /*ce44*/,
    8 /*ce45*/,  8 /*ce46*/,  9 /*ce47*/,  7 /*ce48*/,  8 /*ce49*/,
    8 /*ce4a*/,  9 /*ce4b*/,  8 /*ce4c*/,  9 /*ce4d*/,  9 /*ce4e*/,
    10 /*ce4f*/, 7 /*ce50*/,  8 /*ce51*/,  8 /*ce52*/,  9 /*ce53*/,
    8 /*ce54*/,  9 /*ce55*/,  9 /*ce56*/,  10 /*ce57*/, 8 /*ce58*/,
    9 /*ce59*/,  9 /*ce5a*/,  10 /*ce5b*/, 9 /*ce5c*/,  10 /*ce5d*/,
    10 /*ce5e*/, 11 /*ce5f*/, 7 /*ce60*/,  8 /*ce61*/,  8 /*ce62*/,
    9 /*ce63*/,  8 /*ce64*/,  9 /*ce65*/,  9 /*ce66*/,  10 /*ce67*/,
    8 /*ce68*/,  9 /*ce69*/,  9 /*ce6a*/,  10 /*ce6b*/, 9 /*ce6c*/,
    10 /*ce6d*/, 10 /*ce6e*/, 11 /*ce6f*/, 8 /*ce70*/,  9 /*ce71*/,
    9 /*ce72*/,  10 /*ce73*/, 9 /*ce74*/,  10 /*ce75*/, 10 /*ce76*/,
    11 /*ce77*/, 9 /*ce78*/,  10 /*ce79*/, 10 /*ce7a*/, 11 /*ce7b*/,
    10 /*ce7c*/, 11 /*ce7d*/, 11 /*ce7e*/, 12 /*ce7f*/, 6 /*ce80*/,
    7 /*ce81*/,  7 /*ce82*/,  8 /*ce83*/,  7 /*ce84*/,  8 /*ce85*/,
    8 /*ce86*/,  9 /*ce87*/,  7 /*ce88*/,  8 /*ce89*/,  8 /*ce8a*/,
    9 /*ce8b*/,  8 /*ce8c*/,  9 /*ce8d*/,  9 /*ce8e*/,  10 /*ce8f*/,
    7 /*ce90*/,  8 /*ce91*/,  8 /*ce92*/,  9 /*ce93*/,  8 /*ce94*/,
    9 /*ce95*/,  9 /*ce96*/,  10 /*ce97*/, 8 /*ce98*/,  9 /*ce99*/,
    9 /*ce9a*/,  10 /*ce9b*/, 9 /*ce9c*/,  10 /*ce9d*/, 10 /*ce9e*/,
    11 /*ce9f*/, 7 /*cea0*/,  8 /*cea1*/,  8 /*cea2*/,  9 /*cea3*/,
    8 /*cea4*/,  9 /*cea5*/,  9 /*cea6*/,  10 /*cea7*/, 8 /*cea8*/,
    9 /*cea9*/,  9 /*ceaa*/,  10 /*ceab*/, 9 /*ceac*/,  10 /*cead*/,
    10 /*ceae*/, 11 /*ceaf*/, 8 /*ceb0*/,  9 /*ceb1*/,  9 /*ceb2*/,
    10 /*ceb3*/, 9 /*ceb4*/,  10 /*ceb5*/, 10 /*ceb6*/, 11 /*ceb7*/,
    9 /*ceb8*/,  10 /*ceb9*/, 10 /*ceba*/, 11 /*cebb*/, 10 /*cebc*/,
    11 /*cebd*/, 11 /*cebe*/, 12 /*cebf*/, 7 /*cec0*/,  8 /*cec1*/,
    8 /*cec2*/,  9 /*cec3*/,  8 /*cec4*/,  9 /*cec5*/,  9 /*cec6*/,
    10 /*cec7*/, 8 /*cec8*/,  9 /*cec9*/,  9 /*ceca*/,  10 /*cecb*/,
    9 /*cecc*/,  10 /*cecd*/, 10 /*cece*/, 11 /*cecf*/, 8 /*ced0*/,
    9 /*ced1*/,  9 /*ced2*/,  10 /*ced3*/, 9 /*ced4*/,  10 /*ced5*/,
    10 /*ced6*/, 11 /*ced7*/, 9 /*ced8*/,  10 /*ced9*/, 10 /*ceda*/,
    11 /*cedb*/, 10 /*cedc*/, 11 /*cedd*/, 11 /*cede*/, 12 /*cedf*/,
    8 /*cee0*/,  9 /*cee1*/,  9 /*cee2*/,  10 /*cee3*/, 9 /*cee4*/,
    10 /*cee5*/, 10 /*cee6*/, 11 /*cee7*/, 9 /*cee8*/,  10 /*cee9*/,
    10 /*ceea*/, 11 /*ceeb*/, 10 /*ceec*/, 11 /*ceed*/, 11 /*ceee*/,
    12 /*ceef*/, 9 /*cef0*/,  10 /*cef1*/, 10 /*cef2*/, 11 /*cef3*/,
    10 /*cef4*/, 11 /*cef5*/, 11 /*cef6*/, 12 /*cef7*/, 10 /*cef8*/,
    11 /*cef9*/, 11 /*cefa*/, 12 /*cefb*/, 11 /*cefc*/, 12 /*cefd*/,
    12 /*cefe*/, 13 /*ceff*/, 6 /*cf00*/,  7 /*cf01*/,  7 /*cf02*/,
    8 /*cf03*/,  7 /*cf04*/,  8 /*cf05*/,  8 /*cf06*/,  9 /*cf07*/,
    7 /*cf08*/,  8 /*cf09*/,  8 /*cf0a*/,  9 /*cf0b*/,  8 /*cf0c*/,
    9 /*cf0d*/,  9 /*cf0e*/,  10 /*cf0f*/, 7 /*cf10*/,  8 /*cf11*/,
    8 /*cf12*/,  9 /*cf13*/,  8 /*cf14*/,  9 /*cf15*/,  9 /*cf16*/,
    10 /*cf17*/, 8 /*cf18*/,  9 /*cf19*/,  9 /*cf1a*/,  10 /*cf1b*/,
    9 /*cf1c*/,  10 /*cf1d*/, 10 /*cf1e*/, 11 /*cf1f*/, 7 /*cf20*/,
    8 /*cf21*/,  8 /*cf22*/,  9 /*cf23*/,  8 /*cf24*/,  9 /*cf25*/,
    9 /*cf26*/,  10 /*cf27*/, 8 /*cf28*/,  9 /*cf29*/,  9 /*cf2a*/,
    10 /*cf2b*/, 9 /*cf2c*/,  10 /*cf2d*/, 10 /*cf2e*/, 11 /*cf2f*/,
    8 /*cf30*/,  9 /*cf31*/,  9 /*cf32*/,  10 /*cf33*/, 9 /*cf34*/,
    10 /*cf35*/, 10 /*cf36*/, 11 /*cf37*/, 9 /*cf38*/,  10 /*cf39*/,
    10 /*cf3a*/, 11 /*cf3b*/, 10 /*cf3c*/, 11 /*cf3d*/, 11 /*cf3e*/,
    12 /*cf3f*/, 7 /*cf40*/,  8 /*cf41*/,  8 /*cf42*/,  9 /*cf43*/,
    8 /*cf44*/,  9 /*cf45*/,  9 /*cf46*/,  10 /*cf47*/, 8 /*cf48*/,
    9 /*cf49*/,  9 /*cf4a*/,  10 /*cf4b*/, 9 /*cf4c*/,  10 /*cf4d*/,
    10 /*cf4e*/, 11 /*cf4f*/, 8 /*cf50*/,  9 /*cf51*/,  9 /*cf52*/,
    10 /*cf53*/, 9 /*cf54*/,  10 /*cf55*/, 10 /*cf56*/, 11 /*cf57*/,
    9 /*cf58*/,  10 /*cf59*/, 10 /*cf5a*/, 11 /*cf5b*/, 10 /*cf5c*/,
    11 /*cf5d*/, 11 /*cf5e*/, 12 /*cf5f*/, 8 /*cf60*/,  9 /*cf61*/,
    9 /*cf62*/,  10 /*cf63*/, 9 /*cf64*/,  10 /*cf65*/, 10 /*cf66*/,
    11 /*cf67*/, 9 /*cf68*/,  10 /*cf69*/, 10 /*cf6a*/, 11 /*cf6b*/,
    10 /*cf6c*/, 11 /*cf6d*/, 11 /*cf6e*/, 12 /*cf6f*/, 9 /*cf70*/,
    10 /*cf71*/, 10 /*cf72*/, 11 /*cf73*/, 10 /*cf74*/, 11 /*cf75*/,
    11 /*cf76*/, 12 /*cf77*/, 10 /*cf78*/, 11 /*cf79*/, 11 /*cf7a*/,
    12 /*cf7b*/, 11 /*cf7c*/, 12 /*cf7d*/, 12 /*cf7e*/, 13 /*cf7f*/,
    7 /*cf80*/,  8 /*cf81*/,  8 /*cf82*/,  9 /*cf83*/,  8 /*cf84*/,
    9 /*cf85*/,  9 /*cf86*/,  10 /*cf87*/, 8 /*cf88*/,  9 /*cf89*/,
    9 /*cf8a*/,  10 /*cf8b*/, 9 /*cf8c*/,  10 /*cf8d*/, 10 /*cf8e*/,
    11 /*cf8f*/, 8 /*cf90*/,  9 /*cf91*/,  9 /*cf92*/,  10 /*cf93*/,
    9 /*cf94*/,  10 /*cf95*/, 10 /*cf96*/, 11 /*cf97*/, 9 /*cf98*/,
    10 /*cf99*/, 10 /*cf9a*/, 11 /*cf9b*/, 10 /*cf9c*/, 11 /*cf9d*/,
    11 /*cf9e*/, 12 /*cf9f*/, 8 /*cfa0*/,  9 /*cfa1*/,  9 /*cfa2*/,
    10 /*cfa3*/, 9 /*cfa4*/,  10 /*cfa5*/, 10 /*cfa6*/, 11 /*cfa7*/,
    9 /*cfa8*/,  10 /*cfa9*/, 10 /*cfaa*/, 11 /*cfab*/, 10 /*cfac*/,
    11 /*cfad*/, 11 /*cfae*/, 12 /*cfaf*/, 9 /*cfb0*/,  10 /*cfb1*/,
    10 /*cfb2*/, 11 /*cfb3*/, 10 /*cfb4*/, 11 /*cfb5*/, 11 /*cfb6*/,
    12 /*cfb7*/, 10 /*cfb8*/, 11 /*cfb9*/, 11 /*cfba*/, 12 /*cfbb*/,
    11 /*cfbc*/, 12 /*cfbd*/, 12 /*cfbe*/, 13 /*cfbf*/, 8 /*cfc0*/,
    9 /*cfc1*/,  9 /*cfc2*/,  10 /*cfc3*/, 9 /*cfc4*/,  10 /*cfc5*/,
    10 /*cfc6*/, 11 /*cfc7*/, 9 /*cfc8*/,  10 /*cfc9*/, 10 /*cfca*/,
    11 /*cfcb*/, 10 /*cfcc*/, 11 /*cfcd*/, 11 /*cfce*/, 12 /*cfcf*/,
    9 /*cfd0*/,  10 /*cfd1*/, 10 /*cfd2*/, 11 /*cfd3*/, 10 /*cfd4*/,
    11 /*cfd5*/, 11 /*cfd6*/, 12 /*cfd7*/, 10 /*cfd8*/, 11 /*cfd9*/,
    11 /*cfda*/, 12 /*cfdb*/, 11 /*cfdc*/, 12 /*cfdd*/, 12 /*cfde*/,
    13 /*cfdf*/, 9 /*cfe0*/,  10 /*cfe1*/, 10 /*cfe2*/, 11 /*cfe3*/,
    10 /*cfe4*/, 11 /*cfe5*/, 11 /*cfe6*/, 12 /*cfe7*/, 10 /*cfe8*/,
    11 /*cfe9*/, 11 /*cfea*/, 12 /*cfeb*/, 11 /*cfec*/, 12 /*cfed*/,
    12 /*cfee*/, 13 /*cfef*/, 10 /*cff0*/, 11 /*cff1*/, 11 /*cff2*/,
    12 /*cff3*/, 11 /*cff4*/, 12 /*cff5*/, 12 /*cff6*/, 13 /*cff7*/,
    11 /*cff8*/, 12 /*cff9*/, 12 /*cffa*/, 13 /*cffb*/, 12 /*cffc*/,
    13 /*cffd*/, 13 /*cffe*/, 14 /*cfff*/, 3 /*d000*/,  4 /*d001*/,
    4 /*d002*/,  5 /*d003*/,  4 /*d004*/,  5 /*d005*/,  5 /*d006*/,
    6 /*d007*/,  4 /*d008*/,  5 /*d009*/,  5 /*d00a*/,  6 /*d00b*/,
    5 /*d00c*/,  6 /*d00d*/,  6 /*d00e*/,  7 /*d00f*/,  4 /*d010*/,
    5 /*d011*/,  5 /*d012*/,  6 /*d013*/,  5 /*d014*/,  6 /*d015*/,
    6 /*d016*/,  7 /*d017*/,  5 /*d018*/,  6 /*d019*/,  6 /*d01a*/,
    7 /*d01b*/,  6 /*d01c*/,  7 /*d01d*/,  7 /*d01e*/,  8 /*d01f*/,
    4 /*d020*/,  5 /*d021*/,  5 /*d022*/,  6 /*d023*/,  5 /*d024*/,
    6 /*d025*/,  6 /*d026*/,  7 /*d027*/,  5 /*d028*/,  6 /*d029*/,
    6 /*d02a*/,  7 /*d02b*/,  6 /*d02c*/,  7 /*d02d*/,  7 /*d02e*/,
    8 /*d02f*/,  5 /*d030*/,  6 /*d031*/,  6 /*d032*/,  7 /*d033*/,
    6 /*d034*/,  7 /*d035*/,  7 /*d036*/,  8 /*d037*/,  6 /*d038*/,
    7 /*d039*/,  7 /*d03a*/,  8 /*d03b*/,  7 /*d03c*/,  8 /*d03d*/,
    8 /*d03e*/,  9 /*d03f*/,  4 /*d040*/,  5 /*d041*/,  5 /*d042*/,
    6 /*d043*/,  5 /*d044*/,  6 /*d045*/,  6 /*d046*/,  7 /*d047*/,
    5 /*d048*/,  6 /*d049*/,  6 /*d04a*/,  7 /*d04b*/,  6 /*d04c*/,
    7 /*d04d*/,  7 /*d04e*/,  8 /*d04f*/,  5 /*d050*/,  6 /*d051*/,
    6 /*d052*/,  7 /*d053*/,  6 /*d054*/,  7 /*d055*/,  7 /*d056*/,
    8 /*d057*/,  6 /*d058*/,  7 /*d059*/,  7 /*d05a*/,  8 /*d05b*/,
    7 /*d05c*/,  8 /*d05d*/,  8 /*d05e*/,  9 /*d05f*/,  5 /*d060*/,
    6 /*d061*/,  6 /*d062*/,  7 /*d063*/,  6 /*d064*/,  7 /*d065*/,
    7 /*d066*/,  8 /*d067*/,  6 /*d068*/,  7 /*d069*/,  7 /*d06a*/,
    8 /*d06b*/,  7 /*d06c*/,  8 /*d06d*/,  8 /*d06e*/,  9 /*d06f*/,
    6 /*d070*/,  7 /*d071*/,  7 /*d072*/,  8 /*d073*/,  7 /*d074*/,
    8 /*d075*/,  8 /*d076*/,  9 /*d077*/,  7 /*d078*/,  8 /*d079*/,
    8 /*d07a*/,  9 /*d07b*/,  8 /*d07c*/,  9 /*d07d*/,  9 /*d07e*/,
    10 /*d07f*/, 4 /*d080*/,  5 /*d081*/,  5 /*d082*/,  6 /*d083*/,
    5 /*d084*/,  6 /*d085*/,  6 /*d086*/,  7 /*d087*/,  5 /*d088*/,
    6 /*d089*/,  6 /*d08a*/,  7 /*d08b*/,  6 /*d08c*/,  7 /*d08d*/,
    7 /*d08e*/,  8 /*d08f*/,  5 /*d090*/,  6 /*d091*/,  6 /*d092*/,
    7 /*d093*/,  6 /*d094*/,  7 /*d095*/,  7 /*d096*/,  8 /*d097*/,
    6 /*d098*/,  7 /*d099*/,  7 /*d09a*/,  8 /*d09b*/,  7 /*d09c*/,
    8 /*d09d*/,  8 /*d09e*/,  9 /*d09f*/,  5 /*d0a0*/,  6 /*d0a1*/,
    6 /*d0a2*/,  7 /*d0a3*/,  6 /*d0a4*/,  7 /*d0a5*/,  7 /*d0a6*/,
    8 /*d0a7*/,  6 /*d0a8*/,  7 /*d0a9*/,  7 /*d0aa*/,  8 /*d0ab*/,
    7 /*d0ac*/,  8 /*d0ad*/,  8 /*d0ae*/,  9 /*d0af*/,  6 /*d0b0*/,
    7 /*d0b1*/,  7 /*d0b2*/,  8 /*d0b3*/,  7 /*d0b4*/,  8 /*d0b5*/,
    8 /*d0b6*/,  9 /*d0b7*/,  7 /*d0b8*/,  8 /*d0b9*/,  8 /*d0ba*/,
    9 /*d0bb*/,  8 /*d0bc*/,  9 /*d0bd*/,  9 /*d0be*/,  10 /*d0bf*/,
    5 /*d0c0*/,  6 /*d0c1*/,  6 /*d0c2*/,  7 /*d0c3*/,  6 /*d0c4*/,
    7 /*d0c5*/,  7 /*d0c6*/,  8 /*d0c7*/,  6 /*d0c8*/,  7 /*d0c9*/,
    7 /*d0ca*/,  8 /*d0cb*/,  7 /*d0cc*/,  8 /*d0cd*/,  8 /*d0ce*/,
    9 /*d0cf*/,  6 /*d0d0*/,  7 /*d0d1*/,  7 /*d0d2*/,  8 /*d0d3*/,
    7 /*d0d4*/,  8 /*d0d5*/,  8 /*d0d6*/,  9 /*d0d7*/,  7 /*d0d8*/,
    8 /*d0d9*/,  8 /*d0da*/,  9 /*d0db*/,  8 /*d0dc*/,  9 /*d0dd*/,
    9 /*d0de*/,  10 /*d0df*/, 6 /*d0e0*/,  7 /*d0e1*/,  7 /*d0e2*/,
    8 /*d0e3*/,  7 /*d0e4*/,  8 /*d0e5*/,  8 /*d0e6*/,  9 /*d0e7*/,
    7 /*d0e8*/,  8 /*d0e9*/,  8 /*d0ea*/,  9 /*d0eb*/,  8 /*d0ec*/,
    9 /*d0ed*/,  9 /*d0ee*/,  10 /*d0ef*/, 7 /*d0f0*/,  8 /*d0f1*/,
    8 /*d0f2*/,  9 /*d0f3*/,  8 /*d0f4*/,  9 /*d0f5*/,  9 /*d0f6*/,
    10 /*d0f7*/, 8 /*d0f8*/,  9 /*d0f9*/,  9 /*d0fa*/,  10 /*d0fb*/,
    9 /*d0fc*/,  10 /*d0fd*/, 10 /*d0fe*/, 11 /*d0ff*/, 4 /*d100*/,
    5 /*d101*/,  5 /*d102*/,  6 /*d103*/,  5 /*d104*/,  6 /*d105*/,
    6 /*d106*/,  7 /*d107*/,  5 /*d108*/,  6 /*d109*/,  6 /*d10a*/,
    7 /*d10b*/,  6 /*d10c*/,  7 /*d10d*/,  7 /*d10e*/,  8 /*d10f*/,
    5 /*d110*/,  6 /*d111*/,  6 /*d112*/,  7 /*d113*/,  6 /*d114*/,
    7 /*d115*/,  7 /*d116*/,  8 /*d117*/,  6 /*d118*/,  7 /*d119*/,
    7 /*d11a*/,  8 /*d11b*/,  7 /*d11c*/,  8 /*d11d*/,  8 /*d11e*/,
    9 /*d11f*/,  5 /*d120*/,  6 /*d121*/,  6 /*d122*/,  7 /*d123*/,
    6 /*d124*/,  7 /*d125*/,  7 /*d126*/,  8 /*d127*/,  6 /*d128*/,
    7 /*d129*/,  7 /*d12a*/,  8 /*d12b*/,  7 /*d12c*/,  8 /*d12d*/,
    8 /*d12e*/,  9 /*d12f*/,  6 /*d130*/,  7 /*d131*/,  7 /*d132*/,
    8 /*d133*/,  7 /*d134*/,  8 /*d135*/,  8 /*d136*/,  9 /*d137*/,
    7 /*d138*/,  8 /*d139*/,  8 /*d13a*/,  9 /*d13b*/,  8 /*d13c*/,
    9 /*d13d*/,  9 /*d13e*/,  10 /*d13f*/, 5 /*d140*/,  6 /*d141*/,
    6 /*d142*/,  7 /*d143*/,  6 /*d144*/,  7 /*d145*/,  7 /*d146*/,
    8 /*d147*/,  6 /*d148*/,  7 /*d149*/,  7 /*d14a*/,  8 /*d14b*/,
    7 /*d14c*/,  8 /*d14d*/,  8 /*d14e*/,  9 /*d14f*/,  6 /*d150*/,
    7 /*d151*/,  7 /*d152*/,  8 /*d153*/,  7 /*d154*/,  8 /*d155*/,
    8 /*d156*/,  9 /*d157*/,  7 /*d158*/,  8 /*d159*/,  8 /*d15a*/,
    9 /*d15b*/,  8 /*d15c*/,  9 /*d15d*/,  9 /*d15e*/,  10 /*d15f*/,
    6 /*d160*/,  7 /*d161*/,  7 /*d162*/,  8 /*d163*/,  7 /*d164*/,
    8 /*d165*/,  8 /*d166*/,  9 /*d167*/,  7 /*d168*/,  8 /*d169*/,
    8 /*d16a*/,  9 /*d16b*/,  8 /*d16c*/,  9 /*d16d*/,  9 /*d16e*/,
    10 /*d16f*/, 7 /*d170*/,  8 /*d171*/,  8 /*d172*/,  9 /*d173*/,
    8 /*d174*/,  9 /*d175*/,  9 /*d176*/,  10 /*d177*/, 8 /*d178*/,
    9 /*d179*/,  9 /*d17a*/,  10 /*d17b*/, 9 /*d17c*/,  10 /*d17d*/,
    10 /*d17e*/, 11 /*d17f*/, 5 /*d180*/,  6 /*d181*/,  6 /*d182*/,
    7 /*d183*/,  6 /*d184*/,  7 /*d185*/,  7 /*d186*/,  8 /*d187*/,
    6 /*d188*/,  7 /*d189*/,  7 /*d18a*/,  8 /*d18b*/,  7 /*d18c*/,
    8 /*d18d*/,  8 /*d18e*/,  9 /*d18f*/,  6 /*d190*/,  7 /*d191*/,
    7 /*d192*/,  8 /*d193*/,  7 /*d194*/,  8 /*d195*/,  8 /*d196*/,
    9 /*d197*/,  7 /*d198*/,  8 /*d199*/,  8 /*d19a*/,  9 /*d19b*/,
    8 /*d19c*/,  9 /*d19d*/,  9 /*d19e*/,  10 /*d19f*/, 6 /*d1a0*/,
    7 /*d1a1*/,  7 /*d1a2*/,  8 /*d1a3*/,  7 /*d1a4*/,  8 /*d1a5*/,
    8 /*d1a6*/,  9 /*d1a7*/,  7 /*d1a8*/,  8 /*d1a9*/,  8 /*d1aa*/,
    9 /*d1ab*/,  8 /*d1ac*/,  9 /*d1ad*/,  9 /*d1ae*/,  10 /*d1af*/,
    7 /*d1b0*/,  8 /*d1b1*/,  8 /*d1b2*/,  9 /*d1b3*/,  8 /*d1b4*/,
    9 /*d1b5*/,  9 /*d1b6*/,  10 /*d1b7*/, 8 /*d1b8*/,  9 /*d1b9*/,
    9 /*d1ba*/,  10 /*d1bb*/, 9 /*d1bc*/,  10 /*d1bd*/, 10 /*d1be*/,
    11 /*d1bf*/, 6 /*d1c0*/,  7 /*d1c1*/,  7 /*d1c2*/,  8 /*d1c3*/,
    7 /*d1c4*/,  8 /*d1c5*/,  8 /*d1c6*/,  9 /*d1c7*/,  7 /*d1c8*/,
    8 /*d1c9*/,  8 /*d1ca*/,  9 /*d1cb*/,  8 /*d1cc*/,  9 /*d1cd*/,
    9 /*d1ce*/,  10 /*d1cf*/, 7 /*d1d0*/,  8 /*d1d1*/,  8 /*d1d2*/,
    9 /*d1d3*/,  8 /*d1d4*/,  9 /*d1d5*/,  9 /*d1d6*/,  10 /*d1d7*/,
    8 /*d1d8*/,  9 /*d1d9*/,  9 /*d1da*/,  10 /*d1db*/, 9 /*d1dc*/,
    10 /*d1dd*/, 10 /*d1de*/, 11 /*d1df*/, 7 /*d1e0*/,  8 /*d1e1*/,
    8 /*d1e2*/,  9 /*d1e3*/,  8 /*d1e4*/,  9 /*d1e5*/,  9 /*d1e6*/,
    10 /*d1e7*/, 8 /*d1e8*/,  9 /*d1e9*/,  9 /*d1ea*/,  10 /*d1eb*/,
    9 /*d1ec*/,  10 /*d1ed*/, 10 /*d1ee*/, 11 /*d1ef*/, 8 /*d1f0*/,
    9 /*d1f1*/,  9 /*d1f2*/,  10 /*d1f3*/, 9 /*d1f4*/,  10 /*d1f5*/,
    10 /*d1f6*/, 11 /*d1f7*/, 9 /*d1f8*/,  10 /*d1f9*/, 10 /*d1fa*/,
    11 /*d1fb*/, 10 /*d1fc*/, 11 /*d1fd*/, 11 /*d1fe*/, 12 /*d1ff*/,
    4 /*d200*/,  5 /*d201*/,  5 /*d202*/,  6 /*d203*/,  5 /*d204*/,
    6 /*d205*/,  6 /*d206*/,  7 /*d207*/,  5 /*d208*/,  6 /*d209*/,
    6 /*d20a*/,  7 /*d20b*/,  6 /*d20c*/,  7 /*d20d*/,  7 /*d20e*/,
    8 /*d20f*/,  5 /*d210*/,  6 /*d211*/,  6 /*d212*/,  7 /*d213*/,
    6 /*d214*/,  7 /*d215*/,  7 /*d216*/,  8 /*d217*/,  6 /*d218*/,
    7 /*d219*/,  7 /*d21a*/,  8 /*d21b*/,  7 /*d21c*/,  8 /*d21d*/,
    8 /*d21e*/,  9 /*d21f*/,  5 /*d220*/,  6 /*d221*/,  6 /*d222*/,
    7 /*d223*/,  6 /*d224*/,  7 /*d225*/,  7 /*d226*/,  8 /*d227*/,
    6 /*d228*/,  7 /*d229*/,  7 /*d22a*/,  8 /*d22b*/,  7 /*d22c*/,
    8 /*d22d*/,  8 /*d22e*/,  9 /*d22f*/,  6 /*d230*/,  7 /*d231*/,
    7 /*d232*/,  8 /*d233*/,  7 /*d234*/,  8 /*d235*/,  8 /*d236*/,
    9 /*d237*/,  7 /*d238*/,  8 /*d239*/,  8 /*d23a*/,  9 /*d23b*/,
    8 /*d23c*/,  9 /*d23d*/,  9 /*d23e*/,  10 /*d23f*/, 5 /*d240*/,
    6 /*d241*/,  6 /*d242*/,  7 /*d243*/,  6 /*d244*/,  7 /*d245*/,
    7 /*d246*/,  8 /*d247*/,  6 /*d248*/,  7 /*d249*/,  7 /*d24a*/,
    8 /*d24b*/,  7 /*d24c*/,  8 /*d24d*/,  8 /*d24e*/,  9 /*d24f*/,
    6 /*d250*/,  7 /*d251*/,  7 /*d252*/,  8 /*d253*/,  7 /*d254*/,
    8 /*d255*/,  8 /*d256*/,  9 /*d257*/,  7 /*d258*/,  8 /*d259*/,
    8 /*d25a*/,  9 /*d25b*/,  8 /*d25c*/,  9 /*d25d*/,  9 /*d25e*/,
    10 /*d25f*/, 6 /*d260*/,  7 /*d261*/,  7 /*d262*/,  8 /*d263*/,
    7 /*d264*/,  8 /*d265*/,  8 /*d266*/,  9 /*d267*/,  7 /*d268*/,
    8 /*d269*/,  8 /*d26a*/,  9 /*d26b*/,  8 /*d26c*/,  9 /*d26d*/,
    9 /*d26e*/,  10 /*d26f*/, 7 /*d270*/,  8 /*d271*/,  8 /*d272*/,
    9 /*d273*/,  8 /*d274*/,  9 /*d275*/,  9 /*d276*/,  10 /*d277*/,
    8 /*d278*/,  9 /*d279*/,  9 /*d27a*/,  10 /*d27b*/, 9 /*d27c*/,
    10 /*d27d*/, 10 /*d27e*/, 11 /*d27f*/, 5 /*d280*/,  6 /*d281*/,
    6 /*d282*/,  7 /*d283*/,  6 /*d284*/,  7 /*d285*/,  7 /*d286*/,
    8 /*d287*/,  6 /*d288*/,  7 /*d289*/,  7 /*d28a*/,  8 /*d28b*/,
    7 /*d28c*/,  8 /*d28d*/,  8 /*d28e*/,  9 /*d28f*/,  6 /*d290*/,
    7 /*d291*/,  7 /*d292*/,  8 /*d293*/,  7 /*d294*/,  8 /*d295*/,
    8 /*d296*/,  9 /*d297*/,  7 /*d298*/,  8 /*d299*/,  8 /*d29a*/,
    9 /*d29b*/,  8 /*d29c*/,  9 /*d29d*/,  9 /*d29e*/,  10 /*d29f*/,
    6 /*d2a0*/,  7 /*d2a1*/,  7 /*d2a2*/,  8 /*d2a3*/,  7 /*d2a4*/,
    8 /*d2a5*/,  8 /*d2a6*/,  9 /*d2a7*/,  7 /*d2a8*/,  8 /*d2a9*/,
    8 /*d2aa*/,  9 /*d2ab*/,  8 /*d2ac*/,  9 /*d2ad*/,  9 /*d2ae*/,
    10 /*d2af*/, 7 /*d2b0*/,  8 /*d2b1*/,  8 /*d2b2*/,  9 /*d2b3*/,
    8 /*d2b4*/,  9 /*d2b5*/,  9 /*d2b6*/,  10 /*d2b7*/, 8 /*d2b8*/,
    9 /*d2b9*/,  9 /*d2ba*/,  10 /*d2bb*/, 9 /*d2bc*/,  10 /*d2bd*/,
    10 /*d2be*/, 11 /*d2bf*/, 6 /*d2c0*/,  7 /*d2c1*/,  7 /*d2c2*/,
    8 /*d2c3*/,  7 /*d2c4*/,  8 /*d2c5*/,  8 /*d2c6*/,  9 /*d2c7*/,
    7 /*d2c8*/,  8 /*d2c9*/,  8 /*d2ca*/,  9 /*d2cb*/,  8 /*d2cc*/,
    9 /*d2cd*/,  9 /*d2ce*/,  10 /*d2cf*/, 7 /*d2d0*/,  8 /*d2d1*/,
    8 /*d2d2*/,  9 /*d2d3*/,  8 /*d2d4*/,  9 /*d2d5*/,  9 /*d2d6*/,
    10 /*d2d7*/, 8 /*d2d8*/,  9 /*d2d9*/,  9 /*d2da*/,  10 /*d2db*/,
    9 /*d2dc*/,  10 /*d2dd*/, 10 /*d2de*/, 11 /*d2df*/, 7 /*d2e0*/,
    8 /*d2e1*/,  8 /*d2e2*/,  9 /*d2e3*/,  8 /*d2e4*/,  9 /*d2e5*/,
    9 /*d2e6*/,  10 /*d2e7*/, 8 /*d2e8*/,  9 /*d2e9*/,  9 /*d2ea*/,
    10 /*d2eb*/, 9 /*d2ec*/,  10 /*d2ed*/, 10 /*d2ee*/, 11 /*d2ef*/,
    8 /*d2f0*/,  9 /*d2f1*/,  9 /*d2f2*/,  10 /*d2f3*/, 9 /*d2f4*/,
    10 /*d2f5*/, 10 /*d2f6*/, 11 /*d2f7*/, 9 /*d2f8*/,  10 /*d2f9*/,
    10 /*d2fa*/, 11 /*d2fb*/, 10 /*d2fc*/, 11 /*d2fd*/, 11 /*d2fe*/,
    12 /*d2ff*/, 5 /*d300*/,  6 /*d301*/,  6 /*d302*/,  7 /*d303*/,
    6 /*d304*/,  7 /*d305*/,  7 /*d306*/,  8 /*d307*/,  6 /*d308*/,
    7 /*d309*/,  7 /*d30a*/,  8 /*d30b*/,  7 /*d30c*/,  8 /*d30d*/,
    8 /*d30e*/,  9 /*d30f*/,  6 /*d310*/,  7 /*d311*/,  7 /*d312*/,
    8 /*d313*/,  7 /*d314*/,  8 /*d315*/,  8 /*d316*/,  9 /*d317*/,
    7 /*d318*/,  8 /*d319*/,  8 /*d31a*/,  9 /*d31b*/,  8 /*d31c*/,
    9 /*d31d*/,  9 /*d31e*/,  10 /*d31f*/, 6 /*d320*/,  7 /*d321*/,
    7 /*d322*/,  8 /*d323*/,  7 /*d324*/,  8 /*d325*/,  8 /*d326*/,
    9 /*d327*/,  7 /*d328*/,  8 /*d329*/,  8 /*d32a*/,  9 /*d32b*/,
    8 /*d32c*/,  9 /*d32d*/,  9 /*d32e*/,  10 /*d32f*/, 7 /*d330*/,
    8 /*d331*/,  8 /*d332*/,  9 /*d333*/,  8 /*d334*/,  9 /*d335*/,
    9 /*d336*/,  10 /*d337*/, 8 /*d338*/,  9 /*d339*/,  9 /*d33a*/,
    10 /*d33b*/, 9 /*d33c*/,  10 /*d33d*/, 10 /*d33e*/, 11 /*d33f*/,
    6 /*d340*/,  7 /*d341*/,  7 /*d342*/,  8 /*d343*/,  7 /*d344*/,
    8 /*d345*/,  8 /*d346*/,  9 /*d347*/,  7 /*d348*/,  8 /*d349*/,
    8 /*d34a*/,  9 /*d34b*/,  8 /*d34c*/,  9 /*d34d*/,  9 /*d34e*/,
    10 /*d34f*/, 7 /*d350*/,  8 /*d351*/,  8 /*d352*/,  9 /*d353*/,
    8 /*d354*/,  9 /*d355*/,  9 /*d356*/,  10 /*d357*/, 8 /*d358*/,
    9 /*d359*/,  9 /*d35a*/,  10 /*d35b*/, 9 /*d35c*/,  10 /*d35d*/,
    10 /*d35e*/, 11 /*d35f*/, 7 /*d360*/,  8 /*d361*/,  8 /*d362*/,
    9 /*d363*/,  8 /*d364*/,  9 /*d365*/,  9 /*d366*/,  10 /*d367*/,
    8 /*d368*/,  9 /*d369*/,  9 /*d36a*/,  10 /*d36b*/, 9 /*d36c*/,
    10 /*d36d*/, 10 /*d36e*/, 11 /*d36f*/, 8 /*d370*/,  9 /*d371*/,
    9 /*d372*/,  10 /*d373*/, 9 /*d374*/,  10 /*d375*/, 10 /*d376*/,
    11 /*d377*/, 9 /*d378*/,  10 /*d379*/, 10 /*d37a*/, 11 /*d37b*/,
    10 /*d37c*/, 11 /*d37d*/, 11 /*d37e*/, 12 /*d37f*/, 6 /*d380*/,
    7 /*d381*/,  7 /*d382*/,  8 /*d383*/,  7 /*d384*/,  8 /*d385*/,
    8 /*d386*/,  9 /*d387*/,  7 /*d388*/,  8 /*d389*/,  8 /*d38a*/,
    9 /*d38b*/,  8 /*d38c*/,  9 /*d38d*/,  9 /*d38e*/,  10 /*d38f*/,
    7 /*d390*/,  8 /*d391*/,  8 /*d392*/,  9 /*d393*/,  8 /*d394*/,
    9 /*d395*/,  9 /*d396*/,  10 /*d397*/, 8 /*d398*/,  9 /*d399*/,
    9 /*d39a*/,  10 /*d39b*/, 9 /*d39c*/,  10 /*d39d*/, 10 /*d39e*/,
    11 /*d39f*/, 7 /*d3a0*/,  8 /*d3a1*/,  8 /*d3a2*/,  9 /*d3a3*/,
    8 /*d3a4*/,  9 /*d3a5*/,  9 /*d3a6*/,  10 /*d3a7*/, 8 /*d3a8*/,
    9 /*d3a9*/,  9 /*d3aa*/,  10 /*d3ab*/, 9 /*d3ac*/,  10 /*d3ad*/,
    10 /*d3ae*/, 11 /*d3af*/, 8 /*d3b0*/,  9 /*d3b1*/,  9 /*d3b2*/,
    10 /*d3b3*/, 9 /*d3b4*/,  10 /*d3b5*/, 10 /*d3b6*/, 11 /*d3b7*/,
    9 /*d3b8*/,  10 /*d3b9*/, 10 /*d3ba*/, 11 /*d3bb*/, 10 /*d3bc*/,
    11 /*d3bd*/, 11 /*d3be*/, 12 /*d3bf*/, 7 /*d3c0*/,  8 /*d3c1*/,
    8 /*d3c2*/,  9 /*d3c3*/,  8 /*d3c4*/,  9 /*d3c5*/,  9 /*d3c6*/,
    10 /*d3c7*/, 8 /*d3c8*/,  9 /*d3c9*/,  9 /*d3ca*/,  10 /*d3cb*/,
    9 /*d3cc*/,  10 /*d3cd*/, 10 /*d3ce*/, 11 /*d3cf*/, 8 /*d3d0*/,
    9 /*d3d1*/,  9 /*d3d2*/,  10 /*d3d3*/, 9 /*d3d4*/,  10 /*d3d5*/,
    10 /*d3d6*/, 11 /*d3d7*/, 9 /*d3d8*/,  10 /*d3d9*/, 10 /*d3da*/,
    11 /*d3db*/, 10 /*d3dc*/, 11 /*d3dd*/, 11 /*d3de*/, 12 /*d3df*/,
    8 /*d3e0*/,  9 /*d3e1*/,  9 /*d3e2*/,  10 /*d3e3*/, 9 /*d3e4*/,
    10 /*d3e5*/, 10 /*d3e6*/, 11 /*d3e7*/, 9 /*d3e8*/,  10 /*d3e9*/,
    10 /*d3ea*/, 11 /*d3eb*/, 10 /*d3ec*/, 11 /*d3ed*/, 11 /*d3ee*/,
    12 /*d3ef*/, 9 /*d3f0*/,  10 /*d3f1*/, 10 /*d3f2*/, 11 /*d3f3*/,
    10 /*d3f4*/, 11 /*d3f5*/, 11 /*d3f6*/, 12 /*d3f7*/, 10 /*d3f8*/,
    11 /*d3f9*/, 11 /*d3fa*/, 12 /*d3fb*/, 11 /*d3fc*/, 12 /*d3fd*/,
    12 /*d3fe*/, 13 /*d3ff*/, 4 /*d400*/,  5 /*d401*/,  5 /*d402*/,
    6 /*d403*/,  5 /*d404*/,  6 /*d405*/,  6 /*d406*/,  7 /*d407*/,
    5 /*d408*/,  6 /*d409*/,  6 /*d40a*/,  7 /*d40b*/,  6 /*d40c*/,
    7 /*d40d*/,  7 /*d40e*/,  8 /*d40f*/,  5 /*d410*/,  6 /*d411*/,
    6 /*d412*/,  7 /*d413*/,  6 /*d414*/,  7 /*d415*/,  7 /*d416*/,
    8 /*d417*/,  6 /*d418*/,  7 /*d419*/,  7 /*d41a*/,  8 /*d41b*/,
    7 /*d41c*/,  8 /*d41d*/,  8 /*d41e*/,  9 /*d41f*/,  5 /*d420*/,
    6 /*d421*/,  6 /*d422*/,  7 /*d423*/,  6 /*d424*/,  7 /*d425*/,
    7 /*d426*/,  8 /*d427*/,  6 /*d428*/,  7 /*d429*/,  7 /*d42a*/,
    8 /*d42b*/,  7 /*d42c*/,  8 /*d42d*/,  8 /*d42e*/,  9 /*d42f*/,
    6 /*d430*/,  7 /*d431*/,  7 /*d432*/,  8 /*d433*/,  7 /*d434*/,
    8 /*d435*/,  8 /*d436*/,  9 /*d437*/,  7 /*d438*/,  8 /*d439*/,
    8 /*d43a*/,  9 /*d43b*/,  8 /*d43c*/,  9 /*d43d*/,  9 /*d43e*/,
    10 /*d43f*/, 5 /*d440*/,  6 /*d441*/,  6 /*d442*/,  7 /*d443*/,
    6 /*d444*/,  7 /*d445*/,  7 /*d446*/,  8 /*d447*/,  6 /*d448*/,
    7 /*d449*/,  7 /*d44a*/,  8 /*d44b*/,  7 /*d44c*/,  8 /*d44d*/,
    8 /*d44e*/,  9 /*d44f*/,  6 /*d450*/,  7 /*d451*/,  7 /*d452*/,
    8 /*d453*/,  7 /*d454*/,  8 /*d455*/,  8 /*d456*/,  9 /*d457*/,
    7 /*d458*/,  8 /*d459*/,  8 /*d45a*/,  9 /*d45b*/,  8 /*d45c*/,
    9 /*d45d*/,  9 /*d45e*/,  10 /*d45f*/, 6 /*d460*/,  7 /*d461*/,
    7 /*d462*/,  8 /*d463*/,  7 /*d464*/,  8 /*d465*/,  8 /*d466*/,
    9 /*d467*/,  7 /*d468*/,  8 /*d469*/,  8 /*d46a*/,  9 /*d46b*/,
    8 /*d46c*/,  9 /*d46d*/,  9 /*d46e*/,  10 /*d46f*/, 7 /*d470*/,
    8 /*d471*/,  8 /*d472*/,  9 /*d473*/,  8 /*d474*/,  9 /*d475*/,
    9 /*d476*/,  10 /*d477*/, 8 /*d478*/,  9 /*d479*/,  9 /*d47a*/,
    10 /*d47b*/, 9 /*d47c*/,  10 /*d47d*/, 10 /*d47e*/, 11 /*d47f*/,
    5 /*d480*/,  6 /*d481*/,  6 /*d482*/,  7 /*d483*/,  6 /*d484*/,
    7 /*d485*/,  7 /*d486*/,  8 /*d487*/,  6 /*d488*/,  7 /*d489*/,
    7 /*d48a*/,  8 /*d48b*/,  7 /*d48c*/,  8 /*d48d*/,  8 /*d48e*/,
    9 /*d48f*/,  6 /*d490*/,  7 /*d491*/,  7 /*d492*/,  8 /*d493*/,
    7 /*d494*/,  8 /*d495*/,  8 /*d496*/,  9 /*d497*/,  7 /*d498*/,
    8 /*d499*/,  8 /*d49a*/,  9 /*d49b*/,  8 /*d49c*/,  9 /*d49d*/,
    9 /*d49e*/,  10 /*d49f*/, 6 /*d4a0*/,  7 /*d4a1*/,  7 /*d4a2*/,
    8 /*d4a3*/,  7 /*d4a4*/,  8 /*d4a5*/,  8 /*d4a6*/,  9 /*d4a7*/,
    7 /*d4a8*/,  8 /*d4a9*/,  8 /*d4aa*/,  9 /*d4ab*/,  8 /*d4ac*/,
    9 /*d4ad*/,  9 /*d4ae*/,  10 /*d4af*/, 7 /*d4b0*/,  8 /*d4b1*/,
    8 /*d4b2*/,  9 /*d4b3*/,  8 /*d4b4*/,  9 /*d4b5*/,  9 /*d4b6*/,
    10 /*d4b7*/, 8 /*d4b8*/,  9 /*d4b9*/,  9 /*d4ba*/,  10 /*d4bb*/,
    9 /*d4bc*/,  10 /*d4bd*/, 10 /*d4be*/, 11 /*d4bf*/, 6 /*d4c0*/,
    7 /*d4c1*/,  7 /*d4c2*/,  8 /*d4c3*/,  7 /*d4c4*/,  8 /*d4c5*/,
    8 /*d4c6*/,  9 /*d4c7*/,  7 /*d4c8*/,  8 /*d4c9*/,  8 /*d4ca*/,
    9 /*d4cb*/,  8 /*d4cc*/,  9 /*d4cd*/,  9 /*d4ce*/,  10 /*d4cf*/,
    7 /*d4d0*/,  8 /*d4d1*/,  8 /*d4d2*/,  9 /*d4d3*/,  8 /*d4d4*/,
    9 /*d4d5*/,  9 /*d4d6*/,  10 /*d4d7*/, 8 /*d4d8*/,  9 /*d4d9*/,
    9 /*d4da*/,  10 /*d4db*/, 9 /*d4dc*/,  10 /*d4dd*/, 10 /*d4de*/,
    11 /*d4df*/, 7 /*d4e0*/,  8 /*d4e1*/,  8 /*d4e2*/,  9 /*d4e3*/,
    8 /*d4e4*/,  9 /*d4e5*/,  9 /*d4e6*/,  10 /*d4e7*/, 8 /*d4e8*/,
    9 /*d4e9*/,  9 /*d4ea*/,  10 /*d4eb*/, 9 /*d4ec*/,  10 /*d4ed*/,
    10 /*d4ee*/, 11 /*d4ef*/, 8 /*d4f0*/,  9 /*d4f1*/,  9 /*d4f2*/,
    10 /*d4f3*/, 9 /*d4f4*/,  10 /*d4f5*/, 10 /*d4f6*/, 11 /*d4f7*/,
    9 /*d4f8*/,  10 /*d4f9*/, 10 /*d4fa*/, 11 /*d4fb*/, 10 /*d4fc*/,
    11 /*d4fd*/, 11 /*d4fe*/, 12 /*d4ff*/, 5 /*d500*/,  6 /*d501*/,
    6 /*d502*/,  7 /*d503*/,  6 /*d504*/,  7 /*d505*/,  7 /*d506*/,
    8 /*d507*/,  6 /*d508*/,  7 /*d509*/,  7 /*d50a*/,  8 /*d50b*/,
    7 /*d50c*/,  8 /*d50d*/,  8 /*d50e*/,  9 /*d50f*/,  6 /*d510*/,
    7 /*d511*/,  7 /*d512*/,  8 /*d513*/,  7 /*d514*/,  8 /*d515*/,
    8 /*d516*/,  9 /*d517*/,  7 /*d518*/,  8 /*d519*/,  8 /*d51a*/,
    9 /*d51b*/,  8 /*d51c*/,  9 /*d51d*/,  9 /*d51e*/,  10 /*d51f*/,
    6 /*d520*/,  7 /*d521*/,  7 /*d522*/,  8 /*d523*/,  7 /*d524*/,
    8 /*d525*/,  8 /*d526*/,  9 /*d527*/,  7 /*d528*/,  8 /*d529*/,
    8 /*d52a*/,  9 /*d52b*/,  8 /*d52c*/,  9 /*d52d*/,  9 /*d52e*/,
    10 /*d52f*/, 7 /*d530*/,  8 /*d531*/,  8 /*d532*/,  9 /*d533*/,
    8 /*d534*/,  9 /*d535*/,  9 /*d536*/,  10 /*d537*/, 8 /*d538*/,
    9 /*d539*/,  9 /*d53a*/,  10 /*d53b*/, 9 /*d53c*/,  10 /*d53d*/,
    10 /*d53e*/, 11 /*d53f*/, 6 /*d540*/,  7 /*d541*/,  7 /*d542*/,
    8 /*d543*/,  7 /*d544*/,  8 /*d545*/,  8 /*d546*/,  9 /*d547*/,
    7 /*d548*/,  8 /*d549*/,  8 /*d54a*/,  9 /*d54b*/,  8 /*d54c*/,
    9 /*d54d*/,  9 /*d54e*/,  10 /*d54f*/, 7 /*d550*/,  8 /*d551*/,
    8 /*d552*/,  9 /*d553*/,  8 /*d554*/,  9 /*d555*/,  9 /*d556*/,
    10 /*d557*/, 8 /*d558*/,  9 /*d559*/,  9 /*d55a*/,  10 /*d55b*/,
    9 /*d55c*/,  10 /*d55d*/, 10 /*d55e*/, 11 /*d55f*/, 7 /*d560*/,
    8 /*d561*/,  8 /*d562*/,  9 /*d563*/,  8 /*d564*/,  9 /*d565*/,
    9 /*d566*/,  10 /*d567*/, 8 /*d568*/,  9 /*d569*/,  9 /*d56a*/,
    10 /*d56b*/, 9 /*d56c*/,  10 /*d56d*/, 10 /*d56e*/, 11 /*d56f*/,
    8 /*d570*/,  9 /*d571*/,  9 /*d572*/,  10 /*d573*/, 9 /*d574*/,
    10 /*d575*/, 10 /*d576*/, 11 /*d577*/, 9 /*d578*/,  10 /*d579*/,
    10 /*d57a*/, 11 /*d57b*/, 10 /*d57c*/, 11 /*d57d*/, 11 /*d57e*/,
    12 /*d57f*/, 6 /*d580*/,  7 /*d581*/,  7 /*d582*/,  8 /*d583*/,
    7 /*d584*/,  8 /*d585*/,  8 /*d586*/,  9 /*d587*/,  7 /*d588*/,
    8 /*d589*/,  8 /*d58a*/,  9 /*d58b*/,  8 /*d58c*/,  9 /*d58d*/,
    9 /*d58e*/,  10 /*d58f*/, 7 /*d590*/,  8 /*d591*/,  8 /*d592*/,
    9 /*d593*/,  8 /*d594*/,  9 /*d595*/,  9 /*d596*/,  10 /*d597*/,
    8 /*d598*/,  9 /*d599*/,  9 /*d59a*/,  10 /*d59b*/, 9 /*d59c*/,
    10 /*d59d*/, 10 /*d59e*/, 11 /*d59f*/, 7 /*d5a0*/,  8 /*d5a1*/,
    8 /*d5a2*/,  9 /*d5a3*/,  8 /*d5a4*/,  9 /*d5a5*/,  9 /*d5a6*/,
    10 /*d5a7*/, 8 /*d5a8*/,  9 /*d5a9*/,  9 /*d5aa*/,  10 /*d5ab*/,
    9 /*d5ac*/,  10 /*d5ad*/, 10 /*d5ae*/, 11 /*d5af*/, 8 /*d5b0*/,
    9 /*d5b1*/,  9 /*d5b2*/,  10 /*d5b3*/, 9 /*d5b4*/,  10 /*d5b5*/,
    10 /*d5b6*/, 11 /*d5b7*/, 9 /*d5b8*/,  10 /*d5b9*/, 10 /*d5ba*/,
    11 /*d5bb*/, 10 /*d5bc*/, 11 /*d5bd*/, 11 /*d5be*/, 12 /*d5bf*/,
    7 /*d5c0*/,  8 /*d5c1*/,  8 /*d5c2*/,  9 /*d5c3*/,  8 /*d5c4*/,
    9 /*d5c5*/,  9 /*d5c6*/,  10 /*d5c7*/, 8 /*d5c8*/,  9 /*d5c9*/,
    9 /*d5ca*/,  10 /*d5cb*/, 9 /*d5cc*/,  10 /*d5cd*/, 10 /*d5ce*/,
    11 /*d5cf*/, 8 /*d5d0*/,  9 /*d5d1*/,  9 /*d5d2*/,  10 /*d5d3*/,
    9 /*d5d4*/,  10 /*d5d5*/, 10 /*d5d6*/, 11 /*d5d7*/, 9 /*d5d8*/,
    10 /*d5d9*/, 10 /*d5da*/, 11 /*d5db*/, 10 /*d5dc*/, 11 /*d5dd*/,
    11 /*d5de*/, 12 /*d5df*/, 8 /*d5e0*/,  9 /*d5e1*/,  9 /*d5e2*/,
    10 /*d5e3*/, 9 /*d5e4*/,  10 /*d5e5*/, 10 /*d5e6*/, 11 /*d5e7*/,
    9 /*d5e8*/,  10 /*d5e9*/, 10 /*d5ea*/, 11 /*d5eb*/, 10 /*d5ec*/,
    11 /*d5ed*/, 11 /*d5ee*/, 12 /*d5ef*/, 9 /*d5f0*/,  10 /*d5f1*/,
    10 /*d5f2*/, 11 /*d5f3*/, 10 /*d5f4*/, 11 /*d5f5*/, 11 /*d5f6*/,
    12 /*d5f7*/, 10 /*d5f8*/, 11 /*d5f9*/, 11 /*d5fa*/, 12 /*d5fb*/,
    11 /*d5fc*/, 12 /*d5fd*/, 12 /*d5fe*/, 13 /*d5ff*/, 5 /*d600*/,
    6 /*d601*/,  6 /*d602*/,  7 /*d603*/,  6 /*d604*/,  7 /*d605*/,
    7 /*d606*/,  8 /*d607*/,  6 /*d608*/,  7 /*d609*/,  7 /*d60a*/,
    8 /*d60b*/,  7 /*d60c*/,  8 /*d60d*/,  8 /*d60e*/,  9 /*d60f*/,
    6 /*d610*/,  7 /*d611*/,  7 /*d612*/,  8 /*d613*/,  7 /*d614*/,
    8 /*d615*/,  8 /*d616*/,  9 /*d617*/,  7 /*d618*/,  8 /*d619*/,
    8 /*d61a*/,  9 /*d61b*/,  8 /*d61c*/,  9 /*d61d*/,  9 /*d61e*/,
    10 /*d61f*/, 6 /*d620*/,  7 /*d621*/,  7 /*d622*/,  8 /*d623*/,
    7 /*d624*/,  8 /*d625*/,  8 /*d626*/,  9 /*d627*/,  7 /*d628*/,
    8 /*d629*/,  8 /*d62a*/,  9 /*d62b*/,  8 /*d62c*/,  9 /*d62d*/,
    9 /*d62e*/,  10 /*d62f*/, 7 /*d630*/,  8 /*d631*/,  8 /*d632*/,
    9 /*d633*/,  8 /*d634*/,  9 /*d635*/,  9 /*d636*/,  10 /*d637*/,
    8 /*d638*/,  9 /*d639*/,  9 /*d63a*/,  10 /*d63b*/, 9 /*d63c*/,
    10 /*d63d*/, 10 /*d63e*/, 11 /*d63f*/, 6 /*d640*/,  7 /*d641*/,
    7 /*d642*/,  8 /*d643*/,  7 /*d644*/,  8 /*d645*/,  8 /*d646*/,
    9 /*d647*/,  7 /*d648*/,  8 /*d649*/,  8 /*d64a*/,  9 /*d64b*/,
    8 /*d64c*/,  9 /*d64d*/,  9 /*d64e*/,  10 /*d64f*/, 7 /*d650*/,
    8 /*d651*/,  8 /*d652*/,  9 /*d653*/,  8 /*d654*/,  9 /*d655*/,
    9 /*d656*/,  10 /*d657*/, 8 /*d658*/,  9 /*d659*/,  9 /*d65a*/,
    10 /*d65b*/, 9 /*d65c*/,  10 /*d65d*/, 10 /*d65e*/, 11 /*d65f*/,
    7 /*d660*/,  8 /*d661*/,  8 /*d662*/,  9 /*d663*/,  8 /*d664*/,
    9 /*d665*/,  9 /*d666*/,  10 /*d667*/, 8 /*d668*/,  9 /*d669*/,
    9 /*d66a*/,  10 /*d66b*/, 9 /*d66c*/,  10 /*d66d*/, 10 /*d66e*/,
    11 /*d66f*/, 8 /*d670*/,  9 /*d671*/,  9 /*d672*/,  10 /*d673*/,
    9 /*d674*/,  10 /*d675*/, 10 /*d676*/, 11 /*d677*/, 9 /*d678*/,
    10 /*d679*/, 10 /*d67a*/, 11 /*d67b*/, 10 /*d67c*/, 11 /*d67d*/,
    11 /*d67e*/, 12 /*d67f*/, 6 /*d680*/,  7 /*d681*/,  7 /*d682*/,
    8 /*d683*/,  7 /*d684*/,  8 /*d685*/,  8 /*d686*/,  9 /*d687*/,
    7 /*d688*/,  8 /*d689*/,  8 /*d68a*/,  9 /*d68b*/,  8 /*d68c*/,
    9 /*d68d*/,  9 /*d68e*/,  10 /*d68f*/, 7 /*d690*/,  8 /*d691*/,
    8 /*d692*/,  9 /*d693*/,  8 /*d694*/,  9 /*d695*/,  9 /*d696*/,
    10 /*d697*/, 8 /*d698*/,  9 /*d699*/,  9 /*d69a*/,  10 /*d69b*/,
    9 /*d69c*/,  10 /*d69d*/, 10 /*d69e*/, 11 /*d69f*/, 7 /*d6a0*/,
    8 /*d6a1*/,  8 /*d6a2*/,  9 /*d6a3*/,  8 /*d6a4*/,  9 /*d6a5*/,
    9 /*d6a6*/,  10 /*d6a7*/, 8 /*d6a8*/,  9 /*d6a9*/,  9 /*d6aa*/,
    10 /*d6ab*/, 9 /*d6ac*/,  10 /*d6ad*/, 10 /*d6ae*/, 11 /*d6af*/,
    8 /*d6b0*/,  9 /*d6b1*/,  9 /*d6b2*/,  10 /*d6b3*/, 9 /*d6b4*/,
    10 /*d6b5*/, 10 /*d6b6*/, 11 /*d6b7*/, 9 /*d6b8*/,  10 /*d6b9*/,
    10 /*d6ba*/, 11 /*d6bb*/, 10 /*d6bc*/, 11 /*d6bd*/, 11 /*d6be*/,
    12 /*d6bf*/, 7 /*d6c0*/,  8 /*d6c1*/,  8 /*d6c2*/,  9 /*d6c3*/,
    8 /*d6c4*/,  9 /*d6c5*/,  9 /*d6c6*/,  10 /*d6c7*/, 8 /*d6c8*/,
    9 /*d6c9*/,  9 /*d6ca*/,  10 /*d6cb*/, 9 /*d6cc*/,  10 /*d6cd*/,
    10 /*d6ce*/, 11 /*d6cf*/, 8 /*d6d0*/,  9 /*d6d1*/,  9 /*d6d2*/,
    10 /*d6d3*/, 9 /*d6d4*/,  10 /*d6d5*/, 10 /*d6d6*/, 11 /*d6d7*/,
    9 /*d6d8*/,  10 /*d6d9*/, 10 /*d6da*/, 11 /*d6db*/, 10 /*d6dc*/,
    11 /*d6dd*/, 11 /*d6de*/, 12 /*d6df*/, 8 /*d6e0*/,  9 /*d6e1*/,
    9 /*d6e2*/,  10 /*d6e3*/, 9 /*d6e4*/,  10 /*d6e5*/, 10 /*d6e6*/,
    11 /*d6e7*/, 9 /*d6e8*/,  10 /*d6e9*/, 10 /*d6ea*/, 11 /*d6eb*/,
    10 /*d6ec*/, 11 /*d6ed*/, 11 /*d6ee*/, 12 /*d6ef*/, 9 /*d6f0*/,
    10 /*d6f1*/, 10 /*d6f2*/, 11 /*d6f3*/, 10 /*d6f4*/, 11 /*d6f5*/,
    11 /*d6f6*/, 12 /*d6f7*/, 10 /*d6f8*/, 11 /*d6f9*/, 11 /*d6fa*/,
    12 /*d6fb*/, 11 /*d6fc*/, 12 /*d6fd*/, 12 /*d6fe*/, 13 /*d6ff*/,
    6 /*d700*/,  7 /*d701*/,  7 /*d702*/,  8 /*d703*/,  7 /*d704*/,
    8 /*d705*/,  8 /*d706*/,  9 /*d707*/,  7 /*d708*/,  8 /*d709*/,
    8 /*d70a*/,  9 /*d70b*/,  8 /*d70c*/,  9 /*d70d*/,  9 /*d70e*/,
    10 /*d70f*/, 7 /*d710*/,  8 /*d711*/,  8 /*d712*/,  9 /*d713*/,
    8 /*d714*/,  9 /*d715*/,  9 /*d716*/,  10 /*d717*/, 8 /*d718*/,
    9 /*d719*/,  9 /*d71a*/,  10 /*d71b*/, 9 /*d71c*/,  10 /*d71d*/,
    10 /*d71e*/, 11 /*d71f*/, 7 /*d720*/,  8 /*d721*/,  8 /*d722*/,
    9 /*d723*/,  8 /*d724*/,  9 /*d725*/,  9 /*d726*/,  10 /*d727*/,
    8 /*d728*/,  9 /*d729*/,  9 /*d72a*/,  10 /*d72b*/, 9 /*d72c*/,
    10 /*d72d*/, 10 /*d72e*/, 11 /*d72f*/, 8 /*d730*/,  9 /*d731*/,
    9 /*d732*/,  10 /*d733*/, 9 /*d734*/,  10 /*d735*/, 10 /*d736*/,
    11 /*d737*/, 9 /*d738*/,  10 /*d739*/, 10 /*d73a*/, 11 /*d73b*/,
    10 /*d73c*/, 11 /*d73d*/, 11 /*d73e*/, 12 /*d73f*/, 7 /*d740*/,
    8 /*d741*/,  8 /*d742*/,  9 /*d743*/,  8 /*d744*/,  9 /*d745*/,
    9 /*d746*/,  10 /*d747*/, 8 /*d748*/,  9 /*d749*/,  9 /*d74a*/,
    10 /*d74b*/, 9 /*d74c*/,  10 /*d74d*/, 10 /*d74e*/, 11 /*d74f*/,
    8 /*d750*/,  9 /*d751*/,  9 /*d752*/,  10 /*d753*/, 9 /*d754*/,
    10 /*d755*/, 10 /*d756*/, 11 /*d757*/, 9 /*d758*/,  10 /*d759*/,
    10 /*d75a*/, 11 /*d75b*/, 10 /*d75c*/, 11 /*d75d*/, 11 /*d75e*/,
    12 /*d75f*/, 8 /*d760*/,  9 /*d761*/,  9 /*d762*/,  10 /*d763*/,
    9 /*d764*/,  10 /*d765*/, 10 /*d766*/, 11 /*d767*/, 9 /*d768*/,
    10 /*d769*/, 10 /*d76a*/, 11 /*d76b*/, 10 /*d76c*/, 11 /*d76d*/,
    11 /*d76e*/, 12 /*d76f*/, 9 /*d770*/,  10 /*d771*/, 10 /*d772*/,
    11 /*d773*/, 10 /*d774*/, 11 /*d775*/, 11 /*d776*/, 12 /*d777*/,
    10 /*d778*/, 11 /*d779*/, 11 /*d77a*/, 12 /*d77b*/, 11 /*d77c*/,
    12 /*d77d*/, 12 /*d77e*/, 13 /*d77f*/, 7 /*d780*/,  8 /*d781*/,
    8 /*d782*/,  9 /*d783*/,  8 /*d784*/,  9 /*d785*/,  9 /*d786*/,
    10 /*d787*/, 8 /*d788*/,  9 /*d789*/,  9 /*d78a*/,  10 /*d78b*/,
    9 /*d78c*/,  10 /*d78d*/, 10 /*d78e*/, 11 /*d78f*/, 8 /*d790*/,
    9 /*d791*/,  9 /*d792*/,  10 /*d793*/, 9 /*d794*/,  10 /*d795*/,
    10 /*d796*/, 11 /*d797*/, 9 /*d798*/,  10 /*d799*/, 10 /*d79a*/,
    11 /*d79b*/, 10 /*d79c*/, 11 /*d79d*/, 11 /*d79e*/, 12 /*d79f*/,
    8 /*d7a0*/,  9 /*d7a1*/,  9 /*d7a2*/,  10 /*d7a3*/, 9 /*d7a4*/,
    10 /*d7a5*/, 10 /*d7a6*/, 11 /*d7a7*/, 9 /*d7a8*/,  10 /*d7a9*/,
    10 /*d7aa*/, 11 /*d7ab*/, 10 /*d7ac*/, 11 /*d7ad*/, 11 /*d7ae*/,
    12 /*d7af*/, 9 /*d7b0*/,  10 /*d7b1*/, 10 /*d7b2*/, 11 /*d7b3*/,
    10 /*d7b4*/, 11 /*d7b5*/, 11 /*d7b6*/, 12 /*d7b7*/, 10 /*d7b8*/,
    11 /*d7b9*/, 11 /*d7ba*/, 12 /*d7bb*/, 11 /*d7bc*/, 12 /*d7bd*/,
    12 /*d7be*/, 13 /*d7bf*/, 8 /*d7c0*/,  9 /*d7c1*/,  9 /*d7c2*/,
    10 /*d7c3*/, 9 /*d7c4*/,  10 /*d7c5*/, 10 /*d7c6*/, 11 /*d7c7*/,
    9 /*d7c8*/,  10 /*d7c9*/, 10 /*d7ca*/, 11 /*d7cb*/, 10 /*d7cc*/,
    11 /*d7cd*/, 11 /*d7ce*/, 12 /*d7cf*/, 9 /*d7d0*/,  10 /*d7d1*/,
    10 /*d7d2*/, 11 /*d7d3*/, 10 /*d7d4*/, 11 /*d7d5*/, 11 /*d7d6*/,
    12 /*d7d7*/, 10 /*d7d8*/, 11 /*d7d9*/, 11 /*d7da*/, 12 /*d7db*/,
    11 /*d7dc*/, 12 /*d7dd*/, 12 /*d7de*/, 13 /*d7df*/, 9 /*d7e0*/,
    10 /*d7e1*/, 10 /*d7e2*/, 11 /*d7e3*/, 10 /*d7e4*/, 11 /*d7e5*/,
    11 /*d7e6*/, 12 /*d7e7*/, 10 /*d7e8*/, 11 /*d7e9*/, 11 /*d7ea*/,
    12 /*d7eb*/, 11 /*d7ec*/, 12 /*d7ed*/, 12 /*d7ee*/, 13 /*d7ef*/,
    10 /*d7f0*/, 11 /*d7f1*/, 11 /*d7f2*/, 12 /*d7f3*/, 11 /*d7f4*/,
    12 /*d7f5*/, 12 /*d7f6*/, 13 /*d7f7*/, 11 /*d7f8*/, 12 /*d7f9*/,
    12 /*d7fa*/, 13 /*d7fb*/, 12 /*d7fc*/, 13 /*d7fd*/, 13 /*d7fe*/,
    14 /*d7ff*/, 4 /*d800*/,  5 /*d801*/,  5 /*d802*/,  6 /*d803*/,
    5 /*d804*/,  6 /*d805*/,  6 /*d806*/,  7 /*d807*/,  5 /*d808*/,
    6 /*d809*/,  6 /*d80a*/,  7 /*d80b*/,  6 /*d80c*/,  7 /*d80d*/,
    7 /*d80e*/,  8 /*d80f*/,  5 /*d810*/,  6 /*d811*/,  6 /*d812*/,
    7 /*d813*/,  6 /*d814*/,  7 /*d815*/,  7 /*d816*/,  8 /*d817*/,
    6 /*d818*/,  7 /*d819*/,  7 /*d81a*/,  8 /*d81b*/,  7 /*d81c*/,
    8 /*d81d*/,  8 /*d81e*/,  9 /*d81f*/,  5 /*d820*/,  6 /*d821*/,
    6 /*d822*/,  7 /*d823*/,  6 /*d824*/,  7 /*d825*/,  7 /*d826*/,
    8 /*d827*/,  6 /*d828*/,  7 /*d829*/,  7 /*d82a*/,  8 /*d82b*/,
    7 /*d82c*/,  8 /*d82d*/,  8 /*d82e*/,  9 /*d82f*/,  6 /*d830*/,
    7 /*d831*/,  7 /*d832*/,  8 /*d833*/,  7 /*d834*/,  8 /*d835*/,
    8 /*d836*/,  9 /*d837*/,  7 /*d838*/,  8 /*d839*/,  8 /*d83a*/,
    9 /*d83b*/,  8 /*d83c*/,  9 /*d83d*/,  9 /*d83e*/,  10 /*d83f*/,
    5 /*d840*/,  6 /*d841*/,  6 /*d842*/,  7 /*d843*/,  6 /*d844*/,
    7 /*d845*/,  7 /*d846*/,  8 /*d847*/,  6 /*d848*/,  7 /*d849*/,
    7 /*d84a*/,  8 /*d84b*/,  7 /*d84c*/,  8 /*d84d*/,  8 /*d84e*/,
    9 /*d84f*/,  6 /*d850*/,  7 /*d851*/,  7 /*d852*/,  8 /*d853*/,
    7 /*d854*/,  8 /*d855*/,  8 /*d856*/,  9 /*d857*/,  7 /*d858*/,
    8 /*d859*/,  8 /*d85a*/,  9 /*d85b*/,  8 /*d85c*/,  9 /*d85d*/,
    9 /*d85e*/,  10 /*d85f*/, 6 /*d860*/,  7 /*d861*/,  7 /*d862*/,
    8 /*d863*/,  7 /*d864*/,  8 /*d865*/,  8 /*d866*/,  9 /*d867*/,
    7 /*d868*/,  8 /*d869*/,  8 /*d86a*/,  9 /*d86b*/,  8 /*d86c*/,
    9 /*d86d*/,  9 /*d86e*/,  10 /*d86f*/, 7 /*d870*/,  8 /*d871*/,
    8 /*d872*/,  9 /*d873*/,  8 /*d874*/,  9 /*d875*/,  9 /*d876*/,
    10 /*d877*/, 8 /*d878*/,  9 /*d879*/,  9 /*d87a*/,  10 /*d87b*/,
    9 /*d87c*/,  10 /*d87d*/, 10 /*d87e*/, 11 /*d87f*/, 5 /*d880*/,
    6 /*d881*/,  6 /*d882*/,  7 /*d883*/,  6 /*d884*/,  7 /*d885*/,
    7 /*d886*/,  8 /*d887*/,  6 /*d888*/,  7 /*d889*/,  7 /*d88a*/,
    8 /*d88b*/,  7 /*d88c*/,  8 /*d88d*/,  8 /*d88e*/,  9 /*d88f*/,
    6 /*d890*/,  7 /*d891*/,  7 /*d892*/,  8 /*d893*/,  7 /*d894*/,
    8 /*d895*/,  8 /*d896*/,  9 /*d897*/,  7 /*d898*/,  8 /*d899*/,
    8 /*d89a*/,  9 /*d89b*/,  8 /*d89c*/,  9 /*d89d*/,  9 /*d89e*/,
    10 /*d89f*/, 6 /*d8a0*/,  7 /*d8a1*/,  7 /*d8a2*/,  8 /*d8a3*/,
    7 /*d8a4*/,  8 /*d8a5*/,  8 /*d8a6*/,  9 /*d8a7*/,  7 /*d8a8*/,
    8 /*d8a9*/,  8 /*d8aa*/,  9 /*d8ab*/,  8 /*d8ac*/,  9 /*d8ad*/,
    9 /*d8ae*/,  10 /*d8af*/, 7 /*d8b0*/,  8 /*d8b1*/,  8 /*d8b2*/,
    9 /*d8b3*/,  8 /*d8b4*/,  9 /*d8b5*/,  9 /*d8b6*/,  10 /*d8b7*/,
    8 /*d8b8*/,  9 /*d8b9*/,  9 /*d8ba*/,  10 /*d8bb*/, 9 /*d8bc*/,
    10 /*d8bd*/, 10 /*d8be*/, 11 /*d8bf*/, 6 /*d8c0*/,  7 /*d8c1*/,
    7 /*d8c2*/,  8 /*d8c3*/,  7 /*d8c4*/,  8 /*d8c5*/,  8 /*d8c6*/,
    9 /*d8c7*/,  7 /*d8c8*/,  8 /*d8c9*/,  8 /*d8ca*/,  9 /*d8cb*/,
    8 /*d8cc*/,  9 /*d8cd*/,  9 /*d8ce*/,  10 /*d8cf*/, 7 /*d8d0*/,
    8 /*d8d1*/,  8 /*d8d2*/,  9 /*d8d3*/,  8 /*d8d4*/,  9 /*d8d5*/,
    9 /*d8d6*/,  10 /*d8d7*/, 8 /*d8d8*/,  9 /*d8d9*/,  9 /*d8da*/,
    10 /*d8db*/, 9 /*d8dc*/,  10 /*d8dd*/, 10 /*d8de*/, 11 /*d8df*/,
    7 /*d8e0*/,  8 /*d8e1*/,  8 /*d8e2*/,  9 /*d8e3*/,  8 /*d8e4*/,
    9 /*d8e5*/,  9 /*d8e6*/,  10 /*d8e7*/, 8 /*d8e8*/,  9 /*d8e9*/,
    9 /*d8ea*/,  10 /*d8eb*/, 9 /*d8ec*/,  10 /*d8ed*/, 10 /*d8ee*/,
    11 /*d8ef*/, 8 /*d8f0*/,  9 /*d8f1*/,  9 /*d8f2*/,  10 /*d8f3*/,
    9 /*d8f4*/,  10 /*d8f5*/, 10 /*d8f6*/, 11 /*d8f7*/, 9 /*d8f8*/,
    10 /*d8f9*/, 10 /*d8fa*/, 11 /*d8fb*/, 10 /*d8fc*/, 11 /*d8fd*/,
    11 /*d8fe*/, 12 /*d8ff*/, 5 /*d900*/,  6 /*d901*/,  6 /*d902*/,
    7 /*d903*/,  6 /*d904*/,  7 /*d905*/,  7 /*d906*/,  8 /*d907*/,
    6 /*d908*/,  7 /*d909*/,  7 /*d90a*/,  8 /*d90b*/,  7 /*d90c*/,
    8 /*d90d*/,  8 /*d90e*/,  9 /*d90f*/,  6 /*d910*/,  7 /*d911*/,
    7 /*d912*/,  8 /*d913*/,  7 /*d914*/,  8 /*d915*/,  8 /*d916*/,
    9 /*d917*/,  7 /*d918*/,  8 /*d919*/,  8 /*d91a*/,  9 /*d91b*/,
    8 /*d91c*/,  9 /*d91d*/,  9 /*d91e*/,  10 /*d91f*/, 6 /*d920*/,
    7 /*d921*/,  7 /*d922*/,  8 /*d923*/,  7 /*d924*/,  8 /*d925*/,
    8 /*d926*/,  9 /*d927*/,  7 /*d928*/,  8 /*d929*/,  8 /*d92a*/,
    9 /*d92b*/,  8 /*d92c*/,  9 /*d92d*/,  9 /*d92e*/,  10 /*d92f*/,
    7 /*d930*/,  8 /*d931*/,  8 /*d932*/,  9 /*d933*/,  8 /*d934*/,
    9 /*d935*/,  9 /*d936*/,  10 /*d937*/, 8 /*d938*/,  9 /*d939*/,
    9 /*d93a*/,  10 /*d93b*/, 9 /*d93c*/,  10 /*d93d*/, 10 /*d93e*/,
    11 /*d93f*/, 6 /*d940*/,  7 /*d941*/,  7 /*d942*/,  8 /*d943*/,
    7 /*d944*/,  8 /*d945*/,  8 /*d946*/,  9 /*d947*/,  7 /*d948*/,
    8 /*d949*/,  8 /*d94a*/,  9 /*d94b*/,  8 /*d94c*/,  9 /*d94d*/,
    9 /*d94e*/,  10 /*d94f*/, 7 /*d950*/,  8 /*d951*/,  8 /*d952*/,
    9 /*d953*/,  8 /*d954*/,  9 /*d955*/,  9 /*d956*/,  10 /*d957*/,
    8 /*d958*/,  9 /*d959*/,  9 /*d95a*/,  10 /*d95b*/, 9 /*d95c*/,
    10 /*d95d*/, 10 /*d95e*/, 11 /*d95f*/, 7 /*d960*/,  8 /*d961*/,
    8 /*d962*/,  9 /*d963*/,  8 /*d964*/,  9 /*d965*/,  9 /*d966*/,
    10 /*d967*/, 8 /*d968*/,  9 /*d969*/,  9 /*d96a*/,  10 /*d96b*/,
    9 /*d96c*/,  10 /*d96d*/, 10 /*d96e*/, 11 /*d96f*/, 8 /*d970*/,
    9 /*d971*/,  9 /*d972*/,  10 /*d973*/, 9 /*d974*/,  10 /*d975*/,
    10 /*d976*/, 11 /*d977*/, 9 /*d978*/,  10 /*d979*/, 10 /*d97a*/,
    11 /*d97b*/, 10 /*d97c*/, 11 /*d97d*/, 11 /*d97e*/, 12 /*d97f*/,
    6 /*d980*/,  7 /*d981*/,  7 /*d982*/,  8 /*d983*/,  7 /*d984*/,
    8 /*d985*/,  8 /*d986*/,  9 /*d987*/,  7 /*d988*/,  8 /*d989*/,
    8 /*d98a*/,  9 /*d98b*/,  8 /*d98c*/,  9 /*d98d*/,  9 /*d98e*/,
    10 /*d98f*/, 7 /*d990*/,  8 /*d991*/,  8 /*d992*/,  9 /*d993*/,
    8 /*d994*/,  9 /*d995*/,  9 /*d996*/,  10 /*d997*/, 8 /*d998*/,
    9 /*d999*/,  9 /*d99a*/,  10 /*d99b*/, 9 /*d99c*/,  10 /*d99d*/,
    10 /*d99e*/, 11 /*d99f*/, 7 /*d9a0*/,  8 /*d9a1*/,  8 /*d9a2*/,
    9 /*d9a3*/,  8 /*d9a4*/,  9 /*d9a5*/,  9 /*d9a6*/,  10 /*d9a7*/,
    8 /*d9a8*/,  9 /*d9a9*/,  9 /*d9aa*/,  10 /*d9ab*/, 9 /*d9ac*/,
    10 /*d9ad*/, 10 /*d9ae*/, 11 /*d9af*/, 8 /*d9b0*/,  9 /*d9b1*/,
    9 /*d9b2*/,  10 /*d9b3*/, 9 /*d9b4*/,  10 /*d9b5*/, 10 /*d9b6*/,
    11 /*d9b7*/, 9 /*d9b8*/,  10 /*d9b9*/, 10 /*d9ba*/, 11 /*d9bb*/,
    10 /*d9bc*/, 11 /*d9bd*/, 11 /*d9be*/, 12 /*d9bf*/, 7 /*d9c0*/,
    8 /*d9c1*/,  8 /*d9c2*/,  9 /*d9c3*/,  8 /*d9c4*/,  9 /*d9c5*/,
    9 /*d9c6*/,  10 /*d9c7*/, 8 /*d9c8*/,  9 /*d9c9*/,  9 /*d9ca*/,
    10 /*d9cb*/, 9 /*d9cc*/,  10 /*d9cd*/, 10 /*d9ce*/, 11 /*d9cf*/,
    8 /*d9d0*/,  9 /*d9d1*/,  9 /*d9d2*/,  10 /*d9d3*/, 9 /*d9d4*/,
    10 /*d9d5*/, 10 /*d9d6*/, 11 /*d9d7*/, 9 /*d9d8*/,  10 /*d9d9*/,
    10 /*d9da*/, 11 /*d9db*/, 10 /*d9dc*/, 11 /*d9dd*/, 11 /*d9de*/,
    12 /*d9df*/, 8 /*d9e0*/,  9 /*d9e1*/,  9 /*d9e2*/,  10 /*d9e3*/,
    9 /*d9e4*/,  10 /*d9e5*/, 10 /*d9e6*/, 11 /*d9e7*/, 9 /*d9e8*/,
    10 /*d9e9*/, 10 /*d9ea*/, 11 /*d9eb*/, 10 /*d9ec*/, 11 /*d9ed*/,
    11 /*d9ee*/, 12 /*d9ef*/, 9 /*d9f0*/,  10 /*d9f1*/, 10 /*d9f2*/,
    11 /*d9f3*/, 10 /*d9f4*/, 11 /*d9f5*/, 11 /*d9f6*/, 12 /*d9f7*/,
    10 /*d9f8*/, 11 /*d9f9*/, 11 /*d9fa*/, 12 /*d9fb*/, 11 /*d9fc*/,
    12 /*d9fd*/, 12 /*d9fe*/, 13 /*d9ff*/, 5 /*da00*/,  6 /*da01*/,
    6 /*da02*/,  7 /*da03*/,  6 /*da04*/,  7 /*da05*/,  7 /*da06*/,
    8 /*da07*/,  6 /*da08*/,  7 /*da09*/,  7 /*da0a*/,  8 /*da0b*/,
    7 /*da0c*/,  8 /*da0d*/,  8 /*da0e*/,  9 /*da0f*/,  6 /*da10*/,
    7 /*da11*/,  7 /*da12*/,  8 /*da13*/,  7 /*da14*/,  8 /*da15*/,
    8 /*da16*/,  9 /*da17*/,  7 /*da18*/,  8 /*da19*/,  8 /*da1a*/,
    9 /*da1b*/,  8 /*da1c*/,  9 /*da1d*/,  9 /*da1e*/,  10 /*da1f*/,
    6 /*da20*/,  7 /*da21*/,  7 /*da22*/,  8 /*da23*/,  7 /*da24*/,
    8 /*da25*/,  8 /*da26*/,  9 /*da27*/,  7 /*da28*/,  8 /*da29*/,
    8 /*da2a*/,  9 /*da2b*/,  8 /*da2c*/,  9 /*da2d*/,  9 /*da2e*/,
    10 /*da2f*/, 7 /*da30*/,  8 /*da31*/,  8 /*da32*/,  9 /*da33*/,
    8 /*da34*/,  9 /*da35*/,  9 /*da36*/,  10 /*da37*/, 8 /*da38*/,
    9 /*da39*/,  9 /*da3a*/,  10 /*da3b*/, 9 /*da3c*/,  10 /*da3d*/,
    10 /*da3e*/, 11 /*da3f*/, 6 /*da40*/,  7 /*da41*/,  7 /*da42*/,
    8 /*da43*/,  7 /*da44*/,  8 /*da45*/,  8 /*da46*/,  9 /*da47*/,
    7 /*da48*/,  8 /*da49*/,  8 /*da4a*/,  9 /*da4b*/,  8 /*da4c*/,
    9 /*da4d*/,  9 /*da4e*/,  10 /*da4f*/, 7 /*da50*/,  8 /*da51*/,
    8 /*da52*/,  9 /*da53*/,  8 /*da54*/,  9 /*da55*/,  9 /*da56*/,
    10 /*da57*/, 8 /*da58*/,  9 /*da59*/,  9 /*da5a*/,  10 /*da5b*/,
    9 /*da5c*/,  10 /*da5d*/, 10 /*da5e*/, 11 /*da5f*/, 7 /*da60*/,
    8 /*da61*/,  8 /*da62*/,  9 /*da63*/,  8 /*da64*/,  9 /*da65*/,
    9 /*da66*/,  10 /*da67*/, 8 /*da68*/,  9 /*da69*/,  9 /*da6a*/,
    10 /*da6b*/, 9 /*da6c*/,  10 /*da6d*/, 10 /*da6e*/, 11 /*da6f*/,
    8 /*da70*/,  9 /*da71*/,  9 /*da72*/,  10 /*da73*/, 9 /*da74*/,
    10 /*da75*/, 10 /*da76*/, 11 /*da77*/, 9 /*da78*/,  10 /*da79*/,
    10 /*da7a*/, 11 /*da7b*/, 10 /*da7c*/, 11 /*da7d*/, 11 /*da7e*/,
    12 /*da7f*/, 6 /*da80*/,  7 /*da81*/,  7 /*da82*/,  8 /*da83*/,
    7 /*da84*/,  8 /*da85*/,  8 /*da86*/,  9 /*da87*/,  7 /*da88*/,
    8 /*da89*/,  8 /*da8a*/,  9 /*da8b*/,  8 /*da8c*/,  9 /*da8d*/,
    9 /*da8e*/,  10 /*da8f*/, 7 /*da90*/,  8 /*da91*/,  8 /*da92*/,
    9 /*da93*/,  8 /*da94*/,  9 /*da95*/,  9 /*da96*/,  10 /*da97*/,
    8 /*da98*/,  9 /*da99*/,  9 /*da9a*/,  10 /*da9b*/, 9 /*da9c*/,
    10 /*da9d*/, 10 /*da9e*/, 11 /*da9f*/, 7 /*daa0*/,  8 /*daa1*/,
    8 /*daa2*/,  9 /*daa3*/,  8 /*daa4*/,  9 /*daa5*/,  9 /*daa6*/,
    10 /*daa7*/, 8 /*daa8*/,  9 /*daa9*/,  9 /*daaa*/,  10 /*daab*/,
    9 /*daac*/,  10 /*daad*/, 10 /*daae*/, 11 /*daaf*/, 8 /*dab0*/,
    9 /*dab1*/,  9 /*dab2*/,  10 /*dab3*/, 9 /*dab4*/,  10 /*dab5*/,
    10 /*dab6*/, 11 /*dab7*/, 9 /*dab8*/,  10 /*dab9*/, 10 /*daba*/,
    11 /*dabb*/, 10 /*dabc*/, 11 /*dabd*/, 11 /*dabe*/, 12 /*dabf*/,
    7 /*dac0*/,  8 /*dac1*/,  8 /*dac2*/,  9 /*dac3*/,  8 /*dac4*/,
    9 /*dac5*/,  9 /*dac6*/,  10 /*dac7*/, 8 /*dac8*/,  9 /*dac9*/,
    9 /*daca*/,  10 /*dacb*/, 9 /*dacc*/,  10 /*dacd*/, 10 /*dace*/,
    11 /*dacf*/, 8 /*dad0*/,  9 /*dad1*/,  9 /*dad2*/,  10 /*dad3*/,
    9 /*dad4*/,  10 /*dad5*/, 10 /*dad6*/, 11 /*dad7*/, 9 /*dad8*/,
    10 /*dad9*/, 10 /*dada*/, 11 /*dadb*/, 10 /*dadc*/, 11 /*dadd*/,
    11 /*dade*/, 12 /*dadf*/, 8 /*dae0*/,  9 /*dae1*/,  9 /*dae2*/,
    10 /*dae3*/, 9 /*dae4*/,  10 /*dae5*/, 10 /*dae6*/, 11 /*dae7*/,
    9 /*dae8*/,  10 /*dae9*/, 10 /*daea*/, 11 /*daeb*/, 10 /*daec*/,
    11 /*daed*/, 11 /*daee*/, 12 /*daef*/, 9 /*daf0*/,  10 /*daf1*/,
    10 /*daf2*/, 11 /*daf3*/, 10 /*daf4*/, 11 /*daf5*/, 11 /*daf6*/,
    12 /*daf7*/, 10 /*daf8*/, 11 /*daf9*/, 11 /*dafa*/, 12 /*dafb*/,
    11 /*dafc*/, 12 /*dafd*/, 12 /*dafe*/, 13 /*daff*/, 6 /*db00*/,
    7 /*db01*/,  7 /*db02*/,  8 /*db03*/,  7 /*db04*/,  8 /*db05*/,
    8 /*db06*/,  9 /*db07*/,  7 /*db08*/,  8 /*db09*/,  8 /*db0a*/,
    9 /*db0b*/,  8 /*db0c*/,  9 /*db0d*/,  9 /*db0e*/,  10 /*db0f*/,
    7 /*db10*/,  8 /*db11*/,  8 /*db12*/,  9 /*db13*/,  8 /*db14*/,
    9 /*db15*/,  9 /*db16*/,  10 /*db17*/, 8 /*db18*/,  9 /*db19*/,
    9 /*db1a*/,  10 /*db1b*/, 9 /*db1c*/,  10 /*db1d*/, 10 /*db1e*/,
    11 /*db1f*/, 7 /*db20*/,  8 /*db21*/,  8 /*db22*/,  9 /*db23*/,
    8 /*db24*/,  9 /*db25*/,  9 /*db26*/,  10 /*db27*/, 8 /*db28*/,
    9 /*db29*/,  9 /*db2a*/,  10 /*db2b*/, 9 /*db2c*/,  10 /*db2d*/,
    10 /*db2e*/, 11 /*db2f*/, 8 /*db30*/,  9 /*db31*/,  9 /*db32*/,
    10 /*db33*/, 9 /*db34*/,  10 /*db35*/, 10 /*db36*/, 11 /*db37*/,
    9 /*db38*/,  10 /*db39*/, 10 /*db3a*/, 11 /*db3b*/, 10 /*db3c*/,
    11 /*db3d*/, 11 /*db3e*/, 12 /*db3f*/, 7 /*db40*/,  8 /*db41*/,
    8 /*db42*/,  9 /*db43*/,  8 /*db44*/,  9 /*db45*/,  9 /*db46*/,
    10 /*db47*/, 8 /*db48*/,  9 /*db49*/,  9 /*db4a*/,  10 /*db4b*/,
    9 /*db4c*/,  10 /*db4d*/, 10 /*db4e*/, 11 /*db4f*/, 8 /*db50*/,
    9 /*db51*/,  9 /*db52*/,  10 /*db53*/, 9 /*db54*/,  10 /*db55*/,
    10 /*db56*/, 11 /*db57*/, 9 /*db58*/,  10 /*db59*/, 10 /*db5a*/,
    11 /*db5b*/, 10 /*db5c*/, 11 /*db5d*/, 11 /*db5e*/, 12 /*db5f*/,
    8 /*db60*/,  9 /*db61*/,  9 /*db62*/,  10 /*db63*/, 9 /*db64*/,
    10 /*db65*/, 10 /*db66*/, 11 /*db67*/, 9 /*db68*/,  10 /*db69*/,
    10 /*db6a*/, 11 /*db6b*/, 10 /*db6c*/, 11 /*db6d*/, 11 /*db6e*/,
    12 /*db6f*/, 9 /*db70*/,  10 /*db71*/, 10 /*db72*/, 11 /*db73*/,
    10 /*db74*/, 11 /*db75*/, 11 /*db76*/, 12 /*db77*/, 10 /*db78*/,
    11 /*db79*/, 11 /*db7a*/, 12 /*db7b*/, 11 /*db7c*/, 12 /*db7d*/,
    12 /*db7e*/, 13 /*db7f*/, 7 /*db80*/,  8 /*db81*/,  8 /*db82*/,
    9 /*db83*/,  8 /*db84*/,  9 /*db85*/,  9 /*db86*/,  10 /*db87*/,
    8 /*db88*/,  9 /*db89*/,  9 /*db8a*/,  10 /*db8b*/, 9 /*db8c*/,
    10 /*db8d*/, 10 /*db8e*/, 11 /*db8f*/, 8 /*db90*/,  9 /*db91*/,
    9 /*db92*/,  10 /*db93*/, 9 /*db94*/,  10 /*db95*/, 10 /*db96*/,
    11 /*db97*/, 9 /*db98*/,  10 /*db99*/, 10 /*db9a*/, 11 /*db9b*/,
    10 /*db9c*/, 11 /*db9d*/, 11 /*db9e*/, 12 /*db9f*/, 8 /*dba0*/,
    9 /*dba1*/,  9 /*dba2*/,  10 /*dba3*/, 9 /*dba4*/,  10 /*dba5*/,
    10 /*dba6*/, 11 /*dba7*/, 9 /*dba8*/,  10 /*dba9*/, 10 /*dbaa*/,
    11 /*dbab*/, 10 /*dbac*/, 11 /*dbad*/, 11 /*dbae*/, 12 /*dbaf*/,
    9 /*dbb0*/,  10 /*dbb1*/, 10 /*dbb2*/, 11 /*dbb3*/, 10 /*dbb4*/,
    11 /*dbb5*/, 11 /*dbb6*/, 12 /*dbb7*/, 10 /*dbb8*/, 11 /*dbb9*/,
    11 /*dbba*/, 12 /*dbbb*/, 11 /*dbbc*/, 12 /*dbbd*/, 12 /*dbbe*/,
    13 /*dbbf*/, 8 /*dbc0*/,  9 /*dbc1*/,  9 /*dbc2*/,  10 /*dbc3*/,
    9 /*dbc4*/,  10 /*dbc5*/, 10 /*dbc6*/, 11 /*dbc7*/, 9 /*dbc8*/,
    10 /*dbc9*/, 10 /*dbca*/, 11 /*dbcb*/, 10 /*dbcc*/, 11 /*dbcd*/,
    11 /*dbce*/, 12 /*dbcf*/, 9 /*dbd0*/,  10 /*dbd1*/, 10 /*dbd2*/,
    11 /*dbd3*/, 10 /*dbd4*/, 11 /*dbd5*/, 11 /*dbd6*/, 12 /*dbd7*/,
    10 /*dbd8*/, 11 /*dbd9*/, 11 /*dbda*/, 12 /*dbdb*/, 11 /*dbdc*/,
    12 /*dbdd*/, 12 /*dbde*/, 13 /*dbdf*/, 9 /*dbe0*/,  10 /*dbe1*/,
    10 /*dbe2*/, 11 /*dbe3*/, 10 /*dbe4*/, 11 /*dbe5*/, 11 /*dbe6*/,
    12 /*dbe7*/, 10 /*dbe8*/, 11 /*dbe9*/, 11 /*dbea*/, 12 /*dbeb*/,
    11 /*dbec*/, 12 /*dbed*/, 12 /*dbee*/, 13 /*dbef*/, 10 /*dbf0*/,
    11 /*dbf1*/, 11 /*dbf2*/, 12 /*dbf3*/, 11 /*dbf4*/, 12 /*dbf5*/,
    12 /*dbf6*/, 13 /*dbf7*/, 11 /*dbf8*/, 12 /*dbf9*/, 12 /*dbfa*/,
    13 /*dbfb*/, 12 /*dbfc*/, 13 /*dbfd*/, 13 /*dbfe*/, 14 /*dbff*/,
    5 /*dc00*/,  6 /*dc01*/,  6 /*dc02*/,  7 /*dc03*/,  6 /*dc04*/,
    7 /*dc05*/,  7 /*dc06*/,  8 /*dc07*/,  6 /*dc08*/,  7 /*dc09*/,
    7 /*dc0a*/,  8 /*dc0b*/,  7 /*dc0c*/,  8 /*dc0d*/,  8 /*dc0e*/,
    9 /*dc0f*/,  6 /*dc10*/,  7 /*dc11*/,  7 /*dc12*/,  8 /*dc13*/,
    7 /*dc14*/,  8 /*dc15*/,  8 /*dc16*/,  9 /*dc17*/,  7 /*dc18*/,
    8 /*dc19*/,  8 /*dc1a*/,  9 /*dc1b*/,  8 /*dc1c*/,  9 /*dc1d*/,
    9 /*dc1e*/,  10 /*dc1f*/, 6 /*dc20*/,  7 /*dc21*/,  7 /*dc22*/,
    8 /*dc23*/,  7 /*dc24*/,  8 /*dc25*/,  8 /*dc26*/,  9 /*dc27*/,
    7 /*dc28*/,  8 /*dc29*/,  8 /*dc2a*/,  9 /*dc2b*/,  8 /*dc2c*/,
    9 /*dc2d*/,  9 /*dc2e*/,  10 /*dc2f*/, 7 /*dc30*/,  8 /*dc31*/,
    8 /*dc32*/,  9 /*dc33*/,  8 /*dc34*/,  9 /*dc35*/,  9 /*dc36*/,
    10 /*dc37*/, 8 /*dc38*/,  9 /*dc39*/,  9 /*dc3a*/,  10 /*dc3b*/,
    9 /*dc3c*/,  10 /*dc3d*/, 10 /*dc3e*/, 11 /*dc3f*/, 6 /*dc40*/,
    7 /*dc41*/,  7 /*dc42*/,  8 /*dc43*/,  7 /*dc44*/,  8 /*dc45*/,
    8 /*dc46*/,  9 /*dc47*/,  7 /*dc48*/,  8 /*dc49*/,  8 /*dc4a*/,
    9 /*dc4b*/,  8 /*dc4c*/,  9 /*dc4d*/,  9 /*dc4e*/,  10 /*dc4f*/,
    7 /*dc50*/,  8 /*dc51*/,  8 /*dc52*/,  9 /*dc53*/,  8 /*dc54*/,
    9 /*dc55*/,  9 /*dc56*/,  10 /*dc57*/, 8 /*dc58*/,  9 /*dc59*/,
    9 /*dc5a*/,  10 /*dc5b*/, 9 /*dc5c*/,  10 /*dc5d*/, 10 /*dc5e*/,
    11 /*dc5f*/, 7 /*dc60*/,  8 /*dc61*/,  8 /*dc62*/,  9 /*dc63*/,
    8 /*dc64*/,  9 /*dc65*/,  9 /*dc66*/,  10 /*dc67*/, 8 /*dc68*/,
    9 /*dc69*/,  9 /*dc6a*/,  10 /*dc6b*/, 9 /*dc6c*/,  10 /*dc6d*/,
    10 /*dc6e*/, 11 /*dc6f*/, 8 /*dc70*/,  9 /*dc71*/,  9 /*dc72*/,
    10 /*dc73*/, 9 /*dc74*/,  10 /*dc75*/, 10 /*dc76*/, 11 /*dc77*/,
    9 /*dc78*/,  10 /*dc79*/, 10 /*dc7a*/, 11 /*dc7b*/, 10 /*dc7c*/,
    11 /*dc7d*/, 11 /*dc7e*/, 12 /*dc7f*/, 6 /*dc80*/,  7 /*dc81*/,
    7 /*dc82*/,  8 /*dc83*/,  7 /*dc84*/,  8 /*dc85*/,  8 /*dc86*/,
    9 /*dc87*/,  7 /*dc88*/,  8 /*dc89*/,  8 /*dc8a*/,  9 /*dc8b*/,
    8 /*dc8c*/,  9 /*dc8d*/,  9 /*dc8e*/,  10 /*dc8f*/, 7 /*dc90*/,
    8 /*dc91*/,  8 /*dc92*/,  9 /*dc93*/,  8 /*dc94*/,  9 /*dc95*/,
    9 /*dc96*/,  10 /*dc97*/, 8 /*dc98*/,  9 /*dc99*/,  9 /*dc9a*/,
    10 /*dc9b*/, 9 /*dc9c*/,  10 /*dc9d*/, 10 /*dc9e*/, 11 /*dc9f*/,
    7 /*dca0*/,  8 /*dca1*/,  8 /*dca2*/,  9 /*dca3*/,  8 /*dca4*/,
    9 /*dca5*/,  9 /*dca6*/,  10 /*dca7*/, 8 /*dca8*/,  9 /*dca9*/,
    9 /*dcaa*/,  10 /*dcab*/, 9 /*dcac*/,  10 /*dcad*/, 10 /*dcae*/,
    11 /*dcaf*/, 8 /*dcb0*/,  9 /*dcb1*/,  9 /*dcb2*/,  10 /*dcb3*/,
    9 /*dcb4*/,  10 /*dcb5*/, 10 /*dcb6*/, 11 /*dcb7*/, 9 /*dcb8*/,
    10 /*dcb9*/, 10 /*dcba*/, 11 /*dcbb*/, 10 /*dcbc*/, 11 /*dcbd*/,
    11 /*dcbe*/, 12 /*dcbf*/, 7 /*dcc0*/,  8 /*dcc1*/,  8 /*dcc2*/,
    9 /*dcc3*/,  8 /*dcc4*/,  9 /*dcc5*/,  9 /*dcc6*/,  10 /*dcc7*/,
    8 /*dcc8*/,  9 /*dcc9*/,  9 /*dcca*/,  10 /*dccb*/, 9 /*dccc*/,
    10 /*dccd*/, 10 /*dcce*/, 11 /*dccf*/, 8 /*dcd0*/,  9 /*dcd1*/,
    9 /*dcd2*/,  10 /*dcd3*/, 9 /*dcd4*/,  10 /*dcd5*/, 10 /*dcd6*/,
    11 /*dcd7*/, 9 /*dcd8*/,  10 /*dcd9*/, 10 /*dcda*/, 11 /*dcdb*/,
    10 /*dcdc*/, 11 /*dcdd*/, 11 /*dcde*/, 12 /*dcdf*/, 8 /*dce0*/,
    9 /*dce1*/,  9 /*dce2*/,  10 /*dce3*/, 9 /*dce4*/,  10 /*dce5*/,
    10 /*dce6*/, 11 /*dce7*/, 9 /*dce8*/,  10 /*dce9*/, 10 /*dcea*/,
    11 /*dceb*/, 10 /*dcec*/, 11 /*dced*/, 11 /*dcee*/, 12 /*dcef*/,
    9 /*dcf0*/,  10 /*dcf1*/, 10 /*dcf2*/, 11 /*dcf3*/, 10 /*dcf4*/,
    11 /*dcf5*/, 11 /*dcf6*/, 12 /*dcf7*/, 10 /*dcf8*/, 11 /*dcf9*/,
    11 /*dcfa*/, 12 /*dcfb*/, 11 /*dcfc*/, 12 /*dcfd*/, 12 /*dcfe*/,
    13 /*dcff*/, 6 /*dd00*/,  7 /*dd01*/,  7 /*dd02*/,  8 /*dd03*/,
    7 /*dd04*/,  8 /*dd05*/,  8 /*dd06*/,  9 /*dd07*/,  7 /*dd08*/,
    8 /*dd09*/,  8 /*dd0a*/,  9 /*dd0b*/,  8 /*dd0c*/,  9 /*dd0d*/,
    9 /*dd0e*/,  10 /*dd0f*/, 7 /*dd10*/,  8 /*dd11*/,  8 /*dd12*/,
    9 /*dd13*/,  8 /*dd14*/,  9 /*dd15*/,  9 /*dd16*/,  10 /*dd17*/,
    8 /*dd18*/,  9 /*dd19*/,  9 /*dd1a*/,  10 /*dd1b*/, 9 /*dd1c*/,
    10 /*dd1d*/, 10 /*dd1e*/, 11 /*dd1f*/, 7 /*dd20*/,  8 /*dd21*/,
    8 /*dd22*/,  9 /*dd23*/,  8 /*dd24*/,  9 /*dd25*/,  9 /*dd26*/,
    10 /*dd27*/, 8 /*dd28*/,  9 /*dd29*/,  9 /*dd2a*/,  10 /*dd2b*/,
    9 /*dd2c*/,  10 /*dd2d*/, 10 /*dd2e*/, 11 /*dd2f*/, 8 /*dd30*/,
    9 /*dd31*/,  9 /*dd32*/,  10 /*dd33*/, 9 /*dd34*/,  10 /*dd35*/,
    10 /*dd36*/, 11 /*dd37*/, 9 /*dd38*/,  10 /*dd39*/, 10 /*dd3a*/,
    11 /*dd3b*/, 10 /*dd3c*/, 11 /*dd3d*/, 11 /*dd3e*/, 12 /*dd3f*/,
    7 /*dd40*/,  8 /*dd41*/,  8 /*dd42*/,  9 /*dd43*/,  8 /*dd44*/,
    9 /*dd45*/,  9 /*dd46*/,  10 /*dd47*/, 8 /*dd48*/,  9 /*dd49*/,
    9 /*dd4a*/,  10 /*dd4b*/, 9 /*dd4c*/,  10 /*dd4d*/, 10 /*dd4e*/,
    11 /*dd4f*/, 8 /*dd50*/,  9 /*dd51*/,  9 /*dd52*/,  10 /*dd53*/,
    9 /*dd54*/,  10 /*dd55*/, 10 /*dd56*/, 11 /*dd57*/, 9 /*dd58*/,
    10 /*dd59*/, 10 /*dd5a*/, 11 /*dd5b*/, 10 /*dd5c*/, 11 /*dd5d*/,
    11 /*dd5e*/, 12 /*dd5f*/, 8 /*dd60*/,  9 /*dd61*/,  9 /*dd62*/,
    10 /*dd63*/, 9 /*dd64*/,  10 /*dd65*/, 10 /*dd66*/, 11 /*dd67*/,
    9 /*dd68*/,  10 /*dd69*/, 10 /*dd6a*/, 11 /*dd6b*/, 10 /*dd6c*/,
    11 /*dd6d*/, 11 /*dd6e*/, 12 /*dd6f*/, 9 /*dd70*/,  10 /*dd71*/,
    10 /*dd72*/, 11 /*dd73*/, 10 /*dd74*/, 11 /*dd75*/, 11 /*dd76*/,
    12 /*dd77*/, 10 /*dd78*/, 11 /*dd79*/, 11 /*dd7a*/, 12 /*dd7b*/,
    11 /*dd7c*/, 12 /*dd7d*/, 12 /*dd7e*/, 13 /*dd7f*/, 7 /*dd80*/,
    8 /*dd81*/,  8 /*dd82*/,  9 /*dd83*/,  8 /*dd84*/,  9 /*dd85*/,
    9 /*dd86*/,  10 /*dd87*/, 8 /*dd88*/,  9 /*dd89*/,  9 /*dd8a*/,
    10 /*dd8b*/, 9 /*dd8c*/,  10 /*dd8d*/, 10 /*dd8e*/, 11 /*dd8f*/,
    8 /*dd90*/,  9 /*dd91*/,  9 /*dd92*/,  10 /*dd93*/, 9 /*dd94*/,
    10 /*dd95*/, 10 /*dd96*/, 11 /*dd97*/, 9 /*dd98*/,  10 /*dd99*/,
    10 /*dd9a*/, 11 /*dd9b*/, 10 /*dd9c*/, 11 /*dd9d*/, 11 /*dd9e*/,
    12 /*dd9f*/, 8 /*dda0*/,  9 /*dda1*/,  9 /*dda2*/,  10 /*dda3*/,
    9 /*dda4*/,  10 /*dda5*/, 10 /*dda6*/, 11 /*dda7*/, 9 /*dda8*/,
    10 /*dda9*/, 10 /*ddaa*/, 11 /*ddab*/, 10 /*ddac*/, 11 /*ddad*/,
    11 /*ddae*/, 12 /*ddaf*/, 9 /*ddb0*/,  10 /*ddb1*/, 10 /*ddb2*/,
    11 /*ddb3*/, 10 /*ddb4*/, 11 /*ddb5*/, 11 /*ddb6*/, 12 /*ddb7*/,
    10 /*ddb8*/, 11 /*ddb9*/, 11 /*ddba*/, 12 /*ddbb*/, 11 /*ddbc*/,
    12 /*ddbd*/, 12 /*ddbe*/, 13 /*ddbf*/, 8 /*ddc0*/,  9 /*ddc1*/,
    9 /*ddc2*/,  10 /*ddc3*/, 9 /*ddc4*/,  10 /*ddc5*/, 10 /*ddc6*/,
    11 /*ddc7*/, 9 /*ddc8*/,  10 /*ddc9*/, 10 /*ddca*/, 11 /*ddcb*/,
    10 /*ddcc*/, 11 /*ddcd*/, 11 /*ddce*/, 12 /*ddcf*/, 9 /*ddd0*/,
    10 /*ddd1*/, 10 /*ddd2*/, 11 /*ddd3*/, 10 /*ddd4*/, 11 /*ddd5*/,
    11 /*ddd6*/, 12 /*ddd7*/, 10 /*ddd8*/, 11 /*ddd9*/, 11 /*ddda*/,
    12 /*dddb*/, 11 /*dddc*/, 12 /*dddd*/, 12 /*ddde*/, 13 /*dddf*/,
    9 /*dde0*/,  10 /*dde1*/, 10 /*dde2*/, 11 /*dde3*/, 10 /*dde4*/,
    11 /*dde5*/, 11 /*dde6*/, 12 /*dde7*/, 10 /*dde8*/, 11 /*dde9*/,
    11 /*ddea*/, 12 /*ddeb*/, 11 /*ddec*/, 12 /*dded*/, 12 /*ddee*/,
    13 /*ddef*/, 10 /*ddf0*/, 11 /*ddf1*/, 11 /*ddf2*/, 12 /*ddf3*/,
    11 /*ddf4*/, 12 /*ddf5*/, 12 /*ddf6*/, 13 /*ddf7*/, 11 /*ddf8*/,
    12 /*ddf9*/, 12 /*ddfa*/, 13 /*ddfb*/, 12 /*ddfc*/, 13 /*ddfd*/,
    13 /*ddfe*/, 14 /*ddff*/, 6 /*de00*/,  7 /*de01*/,  7 /*de02*/,
    8 /*de03*/,  7 /*de04*/,  8 /*de05*/,  8 /*de06*/,  9 /*de07*/,
    7 /*de08*/,  8 /*de09*/,  8 /*de0a*/,  9 /*de0b*/,  8 /*de0c*/,
    9 /*de0d*/,  9 /*de0e*/,  10 /*de0f*/, 7 /*de10*/,  8 /*de11*/,
    8 /*de12*/,  9 /*de13*/,  8 /*de14*/,  9 /*de15*/,  9 /*de16*/,
    10 /*de17*/, 8 /*de18*/,  9 /*de19*/,  9 /*de1a*/,  10 /*de1b*/,
    9 /*de1c*/,  10 /*de1d*/, 10 /*de1e*/, 11 /*de1f*/, 7 /*de20*/,
    8 /*de21*/,  8 /*de22*/,  9 /*de23*/,  8 /*de24*/,  9 /*de25*/,
    9 /*de26*/,  10 /*de27*/, 8 /*de28*/,  9 /*de29*/,  9 /*de2a*/,
    10 /*de2b*/, 9 /*de2c*/,  10 /*de2d*/, 10 /*de2e*/, 11 /*de2f*/,
    8 /*de30*/,  9 /*de31*/,  9 /*de32*/,  10 /*de33*/, 9 /*de34*/,
    10 /*de35*/, 10 /*de36*/, 11 /*de37*/, 9 /*de38*/,  10 /*de39*/,
    10 /*de3a*/, 11 /*de3b*/, 10 /*de3c*/, 11 /*de3d*/, 11 /*de3e*/,
    12 /*de3f*/, 7 /*de40*/,  8 /*de41*/,  8 /*de42*/,  9 /*de43*/,
    8 /*de44*/,  9 /*de45*/,  9 /*de46*/,  10 /*de47*/, 8 /*de48*/,
    9 /*de49*/,  9 /*de4a*/,  10 /*de4b*/, 9 /*de4c*/,  10 /*de4d*/,
    10 /*de4e*/, 11 /*de4f*/, 8 /*de50*/,  9 /*de51*/,  9 /*de52*/,
    10 /*de53*/, 9 /*de54*/,  10 /*de55*/, 10 /*de56*/, 11 /*de57*/,
    9 /*de58*/,  10 /*de59*/, 10 /*de5a*/, 11 /*de5b*/, 10 /*de5c*/,
    11 /*de5d*/, 11 /*de5e*/, 12 /*de5f*/, 8 /*de60*/,  9 /*de61*/,
    9 /*de62*/,  10 /*de63*/, 9 /*de64*/,  10 /*de65*/, 10 /*de66*/,
    11 /*de67*/, 9 /*de68*/,  10 /*de69*/, 10 /*de6a*/, 11 /*de6b*/,
    10 /*de6c*/, 11 /*de6d*/, 11 /*de6e*/, 12 /*de6f*/, 9 /*de70*/,
    10 /*de71*/, 10 /*de72*/, 11 /*de73*/, 10 /*de74*/, 11 /*de75*/,
    11 /*de76*/, 12 /*de77*/, 10 /*de78*/, 11 /*de79*/, 11 /*de7a*/,
    12 /*de7b*/, 11 /*de7c*/, 12 /*de7d*/, 12 /*de7e*/, 13 /*de7f*/,
    7 /*de80*/,  8 /*de81*/,  8 /*de82*/,  9 /*de83*/,  8 /*de84*/,
    9 /*de85*/,  9 /*de86*/,  10 /*de87*/, 8 /*de88*/,  9 /*de89*/,
    9 /*de8a*/,  10 /*de8b*/, 9 /*de8c*/,  10 /*de8d*/, 10 /*de8e*/,
    11 /*de8f*/, 8 /*de90*/,  9 /*de91*/,  9 /*de92*/,  10 /*de93*/,
    9 /*de94*/,  10 /*de95*/, 10 /*de96*/, 11 /*de97*/, 9 /*de98*/,
    10 /*de99*/, 10 /*de9a*/, 11 /*de9b*/, 10 /*de9c*/, 11 /*de9d*/,
    11 /*de9e*/, 12 /*de9f*/, 8 /*dea0*/,  9 /*dea1*/,  9 /*dea2*/,
    10 /*dea3*/, 9 /*dea4*/,  10 /*dea5*/, 10 /*dea6*/, 11 /*dea7*/,
    9 /*dea8*/,  10 /*dea9*/, 10 /*deaa*/, 11 /*deab*/, 10 /*deac*/,
    11 /*dead*/, 11 /*deae*/, 12 /*deaf*/, 9 /*deb0*/,  10 /*deb1*/,
    10 /*deb2*/, 11 /*deb3*/, 10 /*deb4*/, 11 /*deb5*/, 11 /*deb6*/,
    12 /*deb7*/, 10 /*deb8*/, 11 /*deb9*/, 11 /*deba*/, 12 /*debb*/,
    11 /*debc*/, 12 /*debd*/, 12 /*debe*/, 13 /*debf*/, 8 /*dec0*/,
    9 /*dec1*/,  9 /*dec2*/,  10 /*dec3*/, 9 /*dec4*/,  10 /*dec5*/,
    10 /*dec6*/, 11 /*dec7*/, 9 /*dec8*/,  10 /*dec9*/, 10 /*deca*/,
    11 /*decb*/, 10 /*decc*/, 11 /*decd*/, 11 /*dece*/, 12 /*decf*/,
    9 /*ded0*/,  10 /*ded1*/, 10 /*ded2*/, 11 /*ded3*/, 10 /*ded4*/,
    11 /*ded5*/, 11 /*ded6*/, 12 /*ded7*/, 10 /*ded8*/, 11 /*ded9*/,
    11 /*deda*/, 12 /*dedb*/, 11 /*dedc*/, 12 /*dedd*/, 12 /*dede*/,
    13 /*dedf*/, 9 /*dee0*/,  10 /*dee1*/, 10 /*dee2*/, 11 /*dee3*/,
    10 /*dee4*/, 11 /*dee5*/, 11 /*dee6*/, 12 /*dee7*/, 10 /*dee8*/,
    11 /*dee9*/, 11 /*deea*/, 12 /*deeb*/, 11 /*deec*/, 12 /*deed*/,
    12 /*deee*/, 13 /*deef*/, 10 /*def0*/, 11 /*def1*/, 11 /*def2*/,
    12 /*def3*/, 11 /*def4*/, 12 /*def5*/, 12 /*def6*/, 13 /*def7*/,
    11 /*def8*/, 12 /*def9*/, 12 /*defa*/, 13 /*defb*/, 12 /*defc*/,
    13 /*defd*/, 13 /*defe*/, 14 /*deff*/, 7 /*df00*/,  8 /*df01*/,
    8 /*df02*/,  9 /*df03*/,  8 /*df04*/,  9 /*df05*/,  9 /*df06*/,
    10 /*df07*/, 8 /*df08*/,  9 /*df09*/,  9 /*df0a*/,  10 /*df0b*/,
    9 /*df0c*/,  10 /*df0d*/, 10 /*df0e*/, 11 /*df0f*/, 8 /*df10*/,
    9 /*df11*/,  9 /*df12*/,  10 /*df13*/, 9 /*df14*/,  10 /*df15*/,
    10 /*df16*/, 11 /*df17*/, 9 /*df18*/,  10 /*df19*/, 10 /*df1a*/,
    11 /*df1b*/, 10 /*df1c*/, 11 /*df1d*/, 11 /*df1e*/, 12 /*df1f*/,
    8 /*df20*/,  9 /*df21*/,  9 /*df22*/,  10 /*df23*/, 9 /*df24*/,
    10 /*df25*/, 10 /*df26*/, 11 /*df27*/, 9 /*df28*/,  10 /*df29*/,
    10 /*df2a*/, 11 /*df2b*/, 10 /*df2c*/, 11 /*df2d*/, 11 /*df2e*/,
    12 /*df2f*/, 9 /*df30*/,  10 /*df31*/, 10 /*df32*/, 11 /*df33*/,
    10 /*df34*/, 11 /*df35*/, 11 /*df36*/, 12 /*df37*/, 10 /*df38*/,
    11 /*df39*/, 11 /*df3a*/, 12 /*df3b*/, 11 /*df3c*/, 12 /*df3d*/,
    12 /*df3e*/, 13 /*df3f*/, 8 /*df40*/,  9 /*df41*/,  9 /*df42*/,
    10 /*df43*/, 9 /*df44*/,  10 /*df45*/, 10 /*df46*/, 11 /*df47*/,
    9 /*df48*/,  10 /*df49*/, 10 /*df4a*/, 11 /*df4b*/, 10 /*df4c*/,
    11 /*df4d*/, 11 /*df4e*/, 12 /*df4f*/, 9 /*df50*/,  10 /*df51*/,
    10 /*df52*/, 11 /*df53*/, 10 /*df54*/, 11 /*df55*/, 11 /*df56*/,
    12 /*df57*/, 10 /*df58*/, 11 /*df59*/, 11 /*df5a*/, 12 /*df5b*/,
    11 /*df5c*/, 12 /*df5d*/, 12 /*df5e*/, 13 /*df5f*/, 9 /*df60*/,
    10 /*df61*/, 10 /*df62*/, 11 /*df63*/, 10 /*df64*/, 11 /*df65*/,
    11 /*df66*/, 12 /*df67*/, 10 /*df68*/, 11 /*df69*/, 11 /*df6a*/,
    12 /*df6b*/, 11 /*df6c*/, 12 /*df6d*/, 12 /*df6e*/, 13 /*df6f*/,
    10 /*df70*/, 11 /*df71*/, 11 /*df72*/, 12 /*df73*/, 11 /*df74*/,
    12 /*df75*/, 12 /*df76*/, 13 /*df77*/, 11 /*df78*/, 12 /*df79*/,
    12 /*df7a*/, 13 /*df7b*/, 12 /*df7c*/, 13 /*df7d*/, 13 /*df7e*/,
    14 /*df7f*/, 8 /*df80*/,  9 /*df81*/,  9 /*df82*/,  10 /*df83*/,
    9 /*df84*/,  10 /*df85*/, 10 /*df86*/, 11 /*df87*/, 9 /*df88*/,
    10 /*df89*/, 10 /*df8a*/, 11 /*df8b*/, 10 /*df8c*/, 11 /*df8d*/,
    11 /*df8e*/, 12 /*df8f*/, 9 /*df90*/,  10 /*df91*/, 10 /*df92*/,
    11 /*df93*/, 10 /*df94*/, 11 /*df95*/, 11 /*df96*/, 12 /*df97*/,
    10 /*df98*/, 11 /*df99*/, 11 /*df9a*/, 12 /*df9b*/, 11 /*df9c*/,
    12 /*df9d*/, 12 /*df9e*/, 13 /*df9f*/, 9 /*dfa0*/,  10 /*dfa1*/,
    10 /*dfa2*/, 11 /*dfa3*/, 10 /*dfa4*/, 11 /*dfa5*/, 11 /*dfa6*/,
    12 /*dfa7*/, 10 /*dfa8*/, 11 /*dfa9*/, 11 /*dfaa*/, 12 /*dfab*/,
    11 /*dfac*/, 12 /*dfad*/, 12 /*dfae*/, 13 /*dfaf*/, 10 /*dfb0*/,
    11 /*dfb1*/, 11 /*dfb2*/, 12 /*dfb3*/, 11 /*dfb4*/, 12 /*dfb5*/,
    12 /*dfb6*/, 13 /*dfb7*/, 11 /*dfb8*/, 12 /*dfb9*/, 12 /*dfba*/,
    13 /*dfbb*/, 12 /*dfbc*/, 13 /*dfbd*/, 13 /*dfbe*/, 14 /*dfbf*/,
    9 /*dfc0*/,  10 /*dfc1*/, 10 /*dfc2*/, 11 /*dfc3*/, 10 /*dfc4*/,
    11 /*dfc5*/, 11 /*dfc6*/, 12 /*dfc7*/, 10 /*dfc8*/, 11 /*dfc9*/,
    11 /*dfca*/, 12 /*dfcb*/, 11 /*dfcc*/, 12 /*dfcd*/, 12 /*dfce*/,
    13 /*dfcf*/, 10 /*dfd0*/, 11 /*dfd1*/, 11 /*dfd2*/, 12 /*dfd3*/,
    11 /*dfd4*/, 12 /*dfd5*/, 12 /*dfd6*/, 13 /*dfd7*/, 11 /*dfd8*/,
    12 /*dfd9*/, 12 /*dfda*/, 13 /*dfdb*/, 12 /*dfdc*/, 13 /*dfdd*/,
    13 /*dfde*/, 14 /*dfdf*/, 10 /*dfe0*/, 11 /*dfe1*/, 11 /*dfe2*/,
    12 /*dfe3*/, 11 /*dfe4*/, 12 /*dfe5*/, 12 /*dfe6*/, 13 /*dfe7*/,
    11 /*dfe8*/, 12 /*dfe9*/, 12 /*dfea*/, 13 /*dfeb*/, 12 /*dfec*/,
    13 /*dfed*/, 13 /*dfee*/, 14 /*dfef*/, 11 /*dff0*/, 12 /*dff1*/,
    12 /*dff2*/, 13 /*dff3*/, 12 /*dff4*/, 13 /*dff5*/, 13 /*dff6*/,
    14 /*dff7*/, 12 /*dff8*/, 13 /*dff9*/, 13 /*dffa*/, 14 /*dffb*/,
    13 /*dffc*/, 14 /*dffd*/, 14 /*dffe*/, 15 /*dfff*/, 3 /*e000*/,
    4 /*e001*/,  4 /*e002*/,  5 /*e003*/,  4 /*e004*/,  5 /*e005*/,
    5 /*e006*/,  6 /*e007*/,  4 /*e008*/,  5 /*e009*/,  5 /*e00a*/,
    6 /*e00b*/,  5 /*e00c*/,  6 /*e00d*/,  6 /*e00e*/,  7 /*e00f*/,
    4 /*e010*/,  5 /*e011*/,  5 /*e012*/,  6 /*e013*/,  5 /*e014*/,
    6 /*e015*/,  6 /*e016*/,  7 /*e017*/,  5 /*e018*/,  6 /*e019*/,
    6 /*e01a*/,  7 /*e01b*/,  6 /*e01c*/,  7 /*e01d*/,  7 /*e01e*/,
    8 /*e01f*/,  4 /*e020*/,  5 /*e021*/,  5 /*e022*/,  6 /*e023*/,
    5 /*e024*/,  6 /*e025*/,  6 /*e026*/,  7 /*e027*/,  5 /*e028*/,
    6 /*e029*/,  6 /*e02a*/,  7 /*e02b*/,  6 /*e02c*/,  7 /*e02d*/,
    7 /*e02e*/,  8 /*e02f*/,  5 /*e030*/,  6 /*e031*/,  6 /*e032*/,
    7 /*e033*/,  6 /*e034*/,  7 /*e035*/,  7 /*e036*/,  8 /*e037*/,
    6 /*e038*/,  7 /*e039*/,  7 /*e03a*/,  8 /*e03b*/,  7 /*e03c*/,
    8 /*e03d*/,  8 /*e03e*/,  9 /*e03f*/,  4 /*e040*/,  5 /*e041*/,
    5 /*e042*/,  6 /*e043*/,  5 /*e044*/,  6 /*e045*/,  6 /*e046*/,
    7 /*e047*/,  5 /*e048*/,  6 /*e049*/,  6 /*e04a*/,  7 /*e04b*/,
    6 /*e04c*/,  7 /*e04d*/,  7 /*e04e*/,  8 /*e04f*/,  5 /*e050*/,
    6 /*e051*/,  6 /*e052*/,  7 /*e053*/,  6 /*e054*/,  7 /*e055*/,
    7 /*e056*/,  8 /*e057*/,  6 /*e058*/,  7 /*e059*/,  7 /*e05a*/,
    8 /*e05b*/,  7 /*e05c*/,  8 /*e05d*/,  8 /*e05e*/,  9 /*e05f*/,
    5 /*e060*/,  6 /*e061*/,  6 /*e062*/,  7 /*e063*/,  6 /*e064*/,
    7 /*e065*/,  7 /*e066*/,  8 /*e067*/,  6 /*e068*/,  7 /*e069*/,
    7 /*e06a*/,  8 /*e06b*/,  7 /*e06c*/,  8 /*e06d*/,  8 /*e06e*/,
    9 /*e06f*/,  6 /*e070*/,  7 /*e071*/,  7 /*e072*/,  8 /*e073*/,
    7 /*e074*/,  8 /*e075*/,  8 /*e076*/,  9 /*e077*/,  7 /*e078*/,
    8 /*e079*/,  8 /*e07a*/,  9 /*e07b*/,  8 /*e07c*/,  9 /*e07d*/,
    9 /*e07e*/,  10 /*e07f*/, 4 /*e080*/,  5 /*e081*/,  5 /*e082*/,
    6 /*e083*/,  5 /*e084*/,  6 /*e085*/,  6 /*e086*/,  7 /*e087*/,
    5 /*e088*/,  6 /*e089*/,  6 /*e08a*/,  7 /*e08b*/,  6 /*e08c*/,
    7 /*e08d*/,  7 /*e08e*/,  8 /*e08f*/,  5 /*e090*/,  6 /*e091*/,
    6 /*e092*/,  7 /*e093*/,  6 /*e094*/,  7 /*e095*/,  7 /*e096*/,
    8 /*e097*/,  6 /*e098*/,  7 /*e099*/,  7 /*e09a*/,  8 /*e09b*/,
    7 /*e09c*/,  8 /*e09d*/,  8 /*e09e*/,  9 /*e09f*/,  5 /*e0a0*/,
    6 /*e0a1*/,  6 /*e0a2*/,  7 /*e0a3*/,  6 /*e0a4*/,  7 /*e0a5*/,
    7 /*e0a6*/,  8 /*e0a7*/,  6 /*e0a8*/,  7 /*e0a9*/,  7 /*e0aa*/,
    8 /*e0ab*/,  7 /*e0ac*/,  8 /*e0ad*/,  8 /*e0ae*/,  9 /*e0af*/,
    6 /*e0b0*/,  7 /*e0b1*/,  7 /*e0b2*/,  8 /*e0b3*/,  7 /*e0b4*/,
    8 /*e0b5*/,  8 /*e0b6*/,  9 /*e0b7*/,  7 /*e0b8*/,  8 /*e0b9*/,
    8 /*e0ba*/,  9 /*e0bb*/,  8 /*e0bc*/,  9 /*e0bd*/,  9 /*e0be*/,
    10 /*e0bf*/, 5 /*e0c0*/,  6 /*e0c1*/,  6 /*e0c2*/,  7 /*e0c3*/,
    6 /*e0c4*/,  7 /*e0c5*/,  7 /*e0c6*/,  8 /*e0c7*/,  6 /*e0c8*/,
    7 /*e0c9*/,  7 /*e0ca*/,  8 /*e0cb*/,  7 /*e0cc*/,  8 /*e0cd*/,
    8 /*e0ce*/,  9 /*e0cf*/,  6 /*e0d0*/,  7 /*e0d1*/,  7 /*e0d2*/,
    8 /*e0d3*/,  7 /*e0d4*/,  8 /*e0d5*/,  8 /*e0d6*/,  9 /*e0d7*/,
    7 /*e0d8*/,  8 /*e0d9*/,  8 /*e0da*/,  9 /*e0db*/,  8 /*e0dc*/,
    9 /*e0dd*/,  9 /*e0de*/,  10 /*e0df*/, 6 /*e0e0*/,  7 /*e0e1*/,
    7 /*e0e2*/,  8 /*e0e3*/,  7 /*e0e4*/,  8 /*e0e5*/,  8 /*e0e6*/,
    9 /*e0e7*/,  7 /*e0e8*/,  8 /*e0e9*/,  8 /*e0ea*/,  9 /*e0eb*/,
    8 /*e0ec*/,  9 /*e0ed*/,  9 /*e0ee*/,  10 /*e0ef*/, 7 /*e0f0*/,
    8 /*e0f1*/,  8 /*e0f2*/,  9 /*e0f3*/,  8 /*e0f4*/,  9 /*e0f5*/,
    9 /*e0f6*/,  10 /*e0f7*/, 8 /*e0f8*/,  9 /*e0f9*/,  9 /*e0fa*/,
    10 /*e0fb*/, 9 /*e0fc*/,  10 /*e0fd*/, 10 /*e0fe*/, 11 /*e0ff*/,
    4 /*e100*/,  5 /*e101*/,  5 /*e102*/,  6 /*e103*/,  5 /*e104*/,
    6 /*e105*/,  6 /*e106*/,  7 /*e107*/,  5 /*e108*/,  6 /*e109*/,
    6 /*e10a*/,  7 /*e10b*/,  6 /*e10c*/,  7 /*e10d*/,  7 /*e10e*/,
    8 /*e10f*/,  5 /*e110*/,  6 /*e111*/,  6 /*e112*/,  7 /*e113*/,
    6 /*e114*/,  7 /*e115*/,  7 /*e116*/,  8 /*e117*/,  6 /*e118*/,
    7 /*e119*/,  7 /*e11a*/,  8 /*e11b*/,  7 /*e11c*/,  8 /*e11d*/,
    8 /*e11e*/,  9 /*e11f*/,  5 /*e120*/,  6 /*e121*/,  6 /*e122*/,
    7 /*e123*/,  6 /*e124*/,  7 /*e125*/,  7 /*e126*/,  8 /*e127*/,
    6 /*e128*/,  7 /*e129*/,  7 /*e12a*/,  8 /*e12b*/,  7 /*e12c*/,
    8 /*e12d*/,  8 /*e12e*/,  9 /*e12f*/,  6 /*e130*/,  7 /*e131*/,
    7 /*e132*/,  8 /*e133*/,  7 /*e134*/,  8 /*e135*/,  8 /*e136*/,
    9 /*e137*/,  7 /*e138*/,  8 /*e139*/,  8 /*e13a*/,  9 /*e13b*/,
    8 /*e13c*/,  9 /*e13d*/,  9 /*e13e*/,  10 /*e13f*/, 5 /*e140*/,
    6 /*e141*/,  6 /*e142*/,  7 /*e143*/,  6 /*e144*/,  7 /*e145*/,
    7 /*e146*/,  8 /*e147*/,  6 /*e148*/,  7 /*e149*/,  7 /*e14a*/,
    8 /*e14b*/,  7 /*e14c*/,  8 /*e14d*/,  8 /*e14e*/,  9 /*e14f*/,
    6 /*e150*/,  7 /*e151*/,  7 /*e152*/,  8 /*e153*/,  7 /*e154*/,
    8 /*e155*/,  8 /*e156*/,  9 /*e157*/,  7 /*e158*/,  8 /*e159*/,
    8 /*e15a*/,  9 /*e15b*/,  8 /*e15c*/,  9 /*e15d*/,  9 /*e15e*/,
    10 /*e15f*/, 6 /*e160*/,  7 /*e161*/,  7 /*e162*/,  8 /*e163*/,
    7 /*e164*/,  8 /*e165*/,  8 /*e166*/,  9 /*e167*/,  7 /*e168*/,
    8 /*e169*/,  8 /*e16a*/,  9 /*e16b*/,  8 /*e16c*/,  9 /*e16d*/,
    9 /*e16e*/,  10 /*e16f*/, 7 /*e170*/,  8 /*e171*/,  8 /*e172*/,
    9 /*e173*/,  8 /*e174*/,  9 /*e175*/,  9 /*e176*/,  10 /*e177*/,
    8 /*e178*/,  9 /*e179*/,  9 /*e17a*/,  10 /*e17b*/, 9 /*e17c*/,
    10 /*e17d*/, 10 /*e17e*/, 11 /*e17f*/, 5 /*e180*/,  6 /*e181*/,
    6 /*e182*/,  7 /*e183*/,  6 /*e184*/,  7 /*e185*/,  7 /*e186*/,
    8 /*e187*/,  6 /*e188*/,  7 /*e189*/,  7 /*e18a*/,  8 /*e18b*/,
    7 /*e18c*/,  8 /*e18d*/,  8 /*e18e*/,  9 /*e18f*/,  6 /*e190*/,
    7 /*e191*/,  7 /*e192*/,  8 /*e193*/,  7 /*e194*/,  8 /*e195*/,
    8 /*e196*/,  9 /*e197*/,  7 /*e198*/,  8 /*e199*/,  8 /*e19a*/,
    9 /*e19b*/,  8 /*e19c*/,  9 /*e19d*/,  9 /*e19e*/,  10 /*e19f*/,
    6 /*e1a0*/,  7 /*e1a1*/,  7 /*e1a2*/,  8 /*e1a3*/,  7 /*e1a4*/,
    8 /*e1a5*/,  8 /*e1a6*/,  9 /*e1a7*/,  7 /*e1a8*/,  8 /*e1a9*/,
    8 /*e1aa*/,  9 /*e1ab*/,  8 /*e1ac*/,  9 /*e1ad*/,  9 /*e1ae*/,
    10 /*e1af*/, 7 /*e1b0*/,  8 /*e1b1*/,  8 /*e1b2*/,  9 /*e1b3*/,
    8 /*e1b4*/,  9 /*e1b5*/,  9 /*e1b6*/,  10 /*e1b7*/, 8 /*e1b8*/,
    9 /*e1b9*/,  9 /*e1ba*/,  10 /*e1bb*/, 9 /*e1bc*/,  10 /*e1bd*/,
    10 /*e1be*/, 11 /*e1bf*/, 6 /*e1c0*/,  7 /*e1c1*/,  7 /*e1c2*/,
    8 /*e1c3*/,  7 /*e1c4*/,  8 /*e1c5*/,  8 /*e1c6*/,  9 /*e1c7*/,
    7 /*e1c8*/,  8 /*e1c9*/,  8 /*e1ca*/,  9 /*e1cb*/,  8 /*e1cc*/,
    9 /*e1cd*/,  9 /*e1ce*/,  10 /*e1cf*/, 7 /*e1d0*/,  8 /*e1d1*/,
    8 /*e1d2*/,  9 /*e1d3*/,  8 /*e1d4*/,  9 /*e1d5*/,  9 /*e1d6*/,
    10 /*e1d7*/, 8 /*e1d8*/,  9 /*e1d9*/,  9 /*e1da*/,  10 /*e1db*/,
    9 /*e1dc*/,  10 /*e1dd*/, 10 /*e1de*/, 11 /*e1df*/, 7 /*e1e0*/,
    8 /*e1e1*/,  8 /*e1e2*/,  9 /*e1e3*/,  8 /*e1e4*/,  9 /*e1e5*/,
    9 /*e1e6*/,  10 /*e1e7*/, 8 /*e1e8*/,  9 /*e1e9*/,  9 /*e1ea*/,
    10 /*e1eb*/, 9 /*e1ec*/,  10 /*e1ed*/, 10 /*e1ee*/, 11 /*e1ef*/,
    8 /*e1f0*/,  9 /*e1f1*/,  9 /*e1f2*/,  10 /*e1f3*/, 9 /*e1f4*/,
    10 /*e1f5*/, 10 /*e1f6*/, 11 /*e1f7*/, 9 /*e1f8*/,  10 /*e1f9*/,
    10 /*e1fa*/, 11 /*e1fb*/, 10 /*e1fc*/, 11 /*e1fd*/, 11 /*e1fe*/,
    12 /*e1ff*/, 4 /*e200*/,  5 /*e201*/,  5 /*e202*/,  6 /*e203*/,
    5 /*e204*/,  6 /*e205*/,  6 /*e206*/,  7 /*e207*/,  5 /*e208*/,
    6 /*e209*/,  6 /*e20a*/,  7 /*e20b*/,  6 /*e20c*/,  7 /*e20d*/,
    7 /*e20e*/,  8 /*e20f*/,  5 /*e210*/,  6 /*e211*/,  6 /*e212*/,
    7 /*e213*/,  6 /*e214*/,  7 /*e215*/,  7 /*e216*/,  8 /*e217*/,
    6 /*e218*/,  7 /*e219*/,  7 /*e21a*/,  8 /*e21b*/,  7 /*e21c*/,
    8 /*e21d*/,  8 /*e21e*/,  9 /*e21f*/,  5 /*e220*/,  6 /*e221*/,
    6 /*e222*/,  7 /*e223*/,  6 /*e224*/,  7 /*e225*/,  7 /*e226*/,
    8 /*e227*/,  6 /*e228*/,  7 /*e229*/,  7 /*e22a*/,  8 /*e22b*/,
    7 /*e22c*/,  8 /*e22d*/,  8 /*e22e*/,  9 /*e22f*/,  6 /*e230*/,
    7 /*e231*/,  7 /*e232*/,  8 /*e233*/,  7 /*e234*/,  8 /*e235*/,
    8 /*e236*/,  9 /*e237*/,  7 /*e238*/,  8 /*e239*/,  8 /*e23a*/,
    9 /*e23b*/,  8 /*e23c*/,  9 /*e23d*/,  9 /*e23e*/,  10 /*e23f*/,
    5 /*e240*/,  6 /*e241*/,  6 /*e242*/,  7 /*e243*/,  6 /*e244*/,
    7 /*e245*/,  7 /*e246*/,  8 /*e247*/,  6 /*e248*/,  7 /*e249*/,
    7 /*e24a*/,  8 /*e24b*/,  7 /*e24c*/,  8 /*e24d*/,  8 /*e24e*/,
    9 /*e24f*/,  6 /*e250*/,  7 /*e251*/,  7 /*e252*/,  8 /*e253*/,
    7 /*e254*/,  8 /*e255*/,  8 /*e256*/,  9 /*e257*/,  7 /*e258*/,
    8 /*e259*/,  8 /*e25a*/,  9 /*e25b*/,  8 /*e25c*/,  9 /*e25d*/,
    9 /*e25e*/,  10 /*e25f*/, 6 /*e260*/,  7 /*e261*/,  7 /*e262*/,
    8 /*e263*/,  7 /*e264*/,  8 /*e265*/,  8 /*e266*/,  9 /*e267*/,
    7 /*e268*/,  8 /*e269*/,  8 /*e26a*/,  9 /*e26b*/,  8 /*e26c*/,
    9 /*e26d*/,  9 /*e26e*/,  10 /*e26f*/, 7 /*e270*/,  8 /*e271*/,
    8 /*e272*/,  9 /*e273*/,  8 /*e274*/,  9 /*e275*/,  9 /*e276*/,
    10 /*e277*/, 8 /*e278*/,  9 /*e279*/,  9 /*e27a*/,  10 /*e27b*/,
    9 /*e27c*/,  10 /*e27d*/, 10 /*e27e*/, 11 /*e27f*/, 5 /*e280*/,
    6 /*e281*/,  6 /*e282*/,  7 /*e283*/,  6 /*e284*/,  7 /*e285*/,
    7 /*e286*/,  8 /*e287*/,  6 /*e288*/,  7 /*e289*/,  7 /*e28a*/,
    8 /*e28b*/,  7 /*e28c*/,  8 /*e28d*/,  8 /*e28e*/,  9 /*e28f*/,
    6 /*e290*/,  7 /*e291*/,  7 /*e292*/,  8 /*e293*/,  7 /*e294*/,
    8 /*e295*/,  8 /*e296*/,  9 /*e297*/,  7 /*e298*/,  8 /*e299*/,
    8 /*e29a*/,  9 /*e29b*/,  8 /*e29c*/,  9 /*e29d*/,  9 /*e29e*/,
    10 /*e29f*/, 6 /*e2a0*/,  7 /*e2a1*/,  7 /*e2a2*/,  8 /*e2a3*/,
    7 /*e2a4*/,  8 /*e2a5*/,  8 /*e2a6*/,  9 /*e2a7*/,  7 /*e2a8*/,
    8 /*e2a9*/,  8 /*e2aa*/,  9 /*e2ab*/,  8 /*e2ac*/,  9 /*e2ad*/,
    9 /*e2ae*/,  10 /*e2af*/, 7 /*e2b0*/,  8 /*e2b1*/,  8 /*e2b2*/,
    9 /*e2b3*/,  8 /*e2b4*/,  9 /*e2b5*/,  9 /*e2b6*/,  10 /*e2b7*/,
    8 /*e2b8*/,  9 /*e2b9*/,  9 /*e2ba*/,  10 /*e2bb*/, 9 /*e2bc*/,
    10 /*e2bd*/, 10 /*e2be*/, 11 /*e2bf*/, 6 /*e2c0*/,  7 /*e2c1*/,
    7 /*e2c2*/,  8 /*e2c3*/,  7 /*e2c4*/,  8 /*e2c5*/,  8 /*e2c6*/,
    9 /*e2c7*/,  7 /*e2c8*/,  8 /*e2c9*/,  8 /*e2ca*/,  9 /*e2cb*/,
    8 /*e2cc*/,  9 /*e2cd*/,  9 /*e2ce*/,  10 /*e2cf*/, 7 /*e2d0*/,
    8 /*e2d1*/,  8 /*e2d2*/,  9 /*e2d3*/,  8 /*e2d4*/,  9 /*e2d5*/,
    9 /*e2d6*/,  10 /*e2d7*/, 8 /*e2d8*/,  9 /*e2d9*/,  9 /*e2da*/,
    10 /*e2db*/, 9 /*e2dc*/,  10 /*e2dd*/, 10 /*e2de*/, 11 /*e2df*/,
    7 /*e2e0*/,  8 /*e2e1*/,  8 /*e2e2*/,  9 /*e2e3*/,  8 /*e2e4*/,
    9 /*e2e5*/,  9 /*e2e6*/,  10 /*e2e7*/, 8 /*e2e8*/,  9 /*e2e9*/,
    9 /*e2ea*/,  10 /*e2eb*/, 9 /*e2ec*/,  10 /*e2ed*/, 10 /*e2ee*/,
    11 /*e2ef*/, 8 /*e2f0*/,  9 /*e2f1*/,  9 /*e2f2*/,  10 /*e2f3*/,
    9 /*e2f4*/,  10 /*e2f5*/, 10 /*e2f6*/, 11 /*e2f7*/, 9 /*e2f8*/,
    10 /*e2f9*/, 10 /*e2fa*/, 11 /*e2fb*/, 10 /*e2fc*/, 11 /*e2fd*/,
    11 /*e2fe*/, 12 /*e2ff*/, 5 /*e300*/,  6 /*e301*/,  6 /*e302*/,
    7 /*e303*/,  6 /*e304*/,  7 /*e305*/,  7 /*e306*/,  8 /*e307*/,
    6 /*e308*/,  7 /*e309*/,  7 /*e30a*/,  8 /*e30b*/,  7 /*e30c*/,
    8 /*e30d*/,  8 /*e30e*/,  9 /*e30f*/,  6 /*e310*/,  7 /*e311*/,
    7 /*e312*/,  8 /*e313*/,  7 /*e314*/,  8 /*e315*/,  8 /*e316*/,
    9 /*e317*/,  7 /*e318*/,  8 /*e319*/,  8 /*e31a*/,  9 /*e31b*/,
    8 /*e31c*/,  9 /*e31d*/,  9 /*e31e*/,  10 /*e31f*/, 6 /*e320*/,
    7 /*e321*/,  7 /*e322*/,  8 /*e323*/,  7 /*e324*/,  8 /*e325*/,
    8 /*e326*/,  9 /*e327*/,  7 /*e328*/,  8 /*e329*/,  8 /*e32a*/,
    9 /*e32b*/,  8 /*e32c*/,  9 /*e32d*/,  9 /*e32e*/,  10 /*e32f*/,
    7 /*e330*/,  8 /*e331*/,  8 /*e332*/,  9 /*e333*/,  8 /*e334*/,
    9 /*e335*/,  9 /*e336*/,  10 /*e337*/, 8 /*e338*/,  9 /*e339*/,
    9 /*e33a*/,  10 /*e33b*/, 9 /*e33c*/,  10 /*e33d*/, 10 /*e33e*/,
    11 /*e33f*/, 6 /*e340*/,  7 /*e341*/,  7 /*e342*/,  8 /*e343*/,
    7 /*e344*/,  8 /*e345*/,  8 /*e346*/,  9 /*e347*/,  7 /*e348*/,
    8 /*e349*/,  8 /*e34a*/,  9 /*e34b*/,  8 /*e34c*/,  9 /*e34d*/,
    9 /*e34e*/,  10 /*e34f*/, 7 /*e350*/,  8 /*e351*/,  8 /*e352*/,
    9 /*e353*/,  8 /*e354*/,  9 /*e355*/,  9 /*e356*/,  10 /*e357*/,
    8 /*e358*/,  9 /*e359*/,  9 /*e35a*/,  10 /*e35b*/, 9 /*e35c*/,
    10 /*e35d*/, 10 /*e35e*/, 11 /*e35f*/, 7 /*e360*/,  8 /*e361*/,
    8 /*e362*/,  9 /*e363*/,  8 /*e364*/,  9 /*e365*/,  9 /*e366*/,
    10 /*e367*/, 8 /*e368*/,  9 /*e369*/,  9 /*e36a*/,  10 /*e36b*/,
    9 /*e36c*/,  10 /*e36d*/, 10 /*e36e*/, 11 /*e36f*/, 8 /*e370*/,
    9 /*e371*/,  9 /*e372*/,  10 /*e373*/, 9 /*e374*/,  10 /*e375*/,
    10 /*e376*/, 11 /*e377*/, 9 /*e378*/,  10 /*e379*/, 10 /*e37a*/,
    11 /*e37b*/, 10 /*e37c*/, 11 /*e37d*/, 11 /*e37e*/, 12 /*e37f*/,
    6 /*e380*/,  7 /*e381*/,  7 /*e382*/,  8 /*e383*/,  7 /*e384*/,
    8 /*e385*/,  8 /*e386*/,  9 /*e387*/,  7 /*e388*/,  8 /*e389*/,
    8 /*e38a*/,  9 /*e38b*/,  8 /*e38c*/,  9 /*e38d*/,  9 /*e38e*/,
    10 /*e38f*/, 7 /*e390*/,  8 /*e391*/,  8 /*e392*/,  9 /*e393*/,
    8 /*e394*/,  9 /*e395*/,  9 /*e396*/,  10 /*e397*/, 8 /*e398*/,
    9 /*e399*/,  9 /*e39a*/,  10 /*e39b*/, 9 /*e39c*/,  10 /*e39d*/,
    10 /*e39e*/, 11 /*e39f*/, 7 /*e3a0*/,  8 /*e3a1*/,  8 /*e3a2*/,
    9 /*e3a3*/,  8 /*e3a4*/,  9 /*e3a5*/,  9 /*e3a6*/,  10 /*e3a7*/,
    8 /*e3a8*/,  9 /*e3a9*/,  9 /*e3aa*/,  10 /*e3ab*/, 9 /*e3ac*/,
    10 /*e3ad*/, 10 /*e3ae*/, 11 /*e3af*/, 8 /*e3b0*/,  9 /*e3b1*/,
    9 /*e3b2*/,  10 /*e3b3*/, 9 /*e3b4*/,  10 /*e3b5*/, 10 /*e3b6*/,
    11 /*e3b7*/, 9 /*e3b8*/,  10 /*e3b9*/, 10 /*e3ba*/, 11 /*e3bb*/,
    10 /*e3bc*/, 11 /*e3bd*/, 11 /*e3be*/, 12 /*e3bf*/, 7 /*e3c0*/,
    8 /*e3c1*/,  8 /*e3c2*/,  9 /*e3c3*/,  8 /*e3c4*/,  9 /*e3c5*/,
    9 /*e3c6*/,  10 /*e3c7*/, 8 /*e3c8*/,  9 /*e3c9*/,  9 /*e3ca*/,
    10 /*e3cb*/, 9 /*e3cc*/,  10 /*e3cd*/, 10 /*e3ce*/, 11 /*e3cf*/,
    8 /*e3d0*/,  9 /*e3d1*/,  9 /*e3d2*/,  10 /*e3d3*/, 9 /*e3d4*/,
    10 /*e3d5*/, 10 /*e3d6*/, 11 /*e3d7*/, 9 /*e3d8*/,  10 /*e3d9*/,
    10 /*e3da*/, 11 /*e3db*/, 10 /*e3dc*/, 11 /*e3dd*/, 11 /*e3de*/,
    12 /*e3df*/, 8 /*e3e0*/,  9 /*e3e1*/,  9 /*e3e2*/,  10 /*e3e3*/,
    9 /*e3e4*/,  10 /*e3e5*/, 10 /*e3e6*/, 11 /*e3e7*/, 9 /*e3e8*/,
    10 /*e3e9*/, 10 /*e3ea*/, 11 /*e3eb*/, 10 /*e3ec*/, 11 /*e3ed*/,
    11 /*e3ee*/, 12 /*e3ef*/, 9 /*e3f0*/,  10 /*e3f1*/, 10 /*e3f2*/,
    11 /*e3f3*/, 10 /*e3f4*/, 11 /*e3f5*/, 11 /*e3f6*/, 12 /*e3f7*/,
    10 /*e3f8*/, 11 /*e3f9*/, 11 /*e3fa*/, 12 /*e3fb*/, 11 /*e3fc*/,
    12 /*e3fd*/, 12 /*e3fe*/, 13 /*e3ff*/, 4 /*e400*/,  5 /*e401*/,
    5 /*e402*/,  6 /*e403*/,  5 /*e404*/,  6 /*e405*/,  6 /*e406*/,
    7 /*e407*/,  5 /*e408*/,  6 /*e409*/,  6 /*e40a*/,  7 /*e40b*/,
    6 /*e40c*/,  7 /*e40d*/,  7 /*e40e*/,  8 /*e40f*/,  5 /*e410*/,
    6 /*e411*/,  6 /*e412*/,  7 /*e413*/,  6 /*e414*/,  7 /*e415*/,
    7 /*e416*/,  8 /*e417*/,  6 /*e418*/,  7 /*e419*/,  7 /*e41a*/,
    8 /*e41b*/,  7 /*e41c*/,  8 /*e41d*/,  8 /*e41e*/,  9 /*e41f*/,
    5 /*e420*/,  6 /*e421*/,  6 /*e422*/,  7 /*e423*/,  6 /*e424*/,
    7 /*e425*/,  7 /*e426*/,  8 /*e427*/,  6 /*e428*/,  7 /*e429*/,
    7 /*e42a*/,  8 /*e42b*/,  7 /*e42c*/,  8 /*e42d*/,  8 /*e42e*/,
    9 /*e42f*/,  6 /*e430*/,  7 /*e431*/,  7 /*e432*/,  8 /*e433*/,
    7 /*e434*/,  8 /*e435*/,  8 /*e436*/,  9 /*e437*/,  7 /*e438*/,
    8 /*e439*/,  8 /*e43a*/,  9 /*e43b*/,  8 /*e43c*/,  9 /*e43d*/,
    9 /*e43e*/,  10 /*e43f*/, 5 /*e440*/,  6 /*e441*/,  6 /*e442*/,
    7 /*e443*/,  6 /*e444*/,  7 /*e445*/,  7 /*e446*/,  8 /*e447*/,
    6 /*e448*/,  7 /*e449*/,  7 /*e44a*/,  8 /*e44b*/,  7 /*e44c*/,
    8 /*e44d*/,  8 /*e44e*/,  9 /*e44f*/,  6 /*e450*/,  7 /*e451*/,
    7 /*e452*/,  8 /*e453*/,  7 /*e454*/,  8 /*e455*/,  8 /*e456*/,
    9 /*e457*/,  7 /*e458*/,  8 /*e459*/,  8 /*e45a*/,  9 /*e45b*/,
    8 /*e45c*/,  9 /*e45d*/,  9 /*e45e*/,  10 /*e45f*/, 6 /*e460*/,
    7 /*e461*/,  7 /*e462*/,  8 /*e463*/,  7 /*e464*/,  8 /*e465*/,
    8 /*e466*/,  9 /*e467*/,  7 /*e468*/,  8 /*e469*/,  8 /*e46a*/,
    9 /*e46b*/,  8 /*e46c*/,  9 /*e46d*/,  9 /*e46e*/,  10 /*e46f*/,
    7 /*e470*/,  8 /*e471*/,  8 /*e472*/,  9 /*e473*/,  8 /*e474*/,
    9 /*e475*/,  9 /*e476*/,  10 /*e477*/, 8 /*e478*/,  9 /*e479*/,
    9 /*e47a*/,  10 /*e47b*/, 9 /*e47c*/,  10 /*e47d*/, 10 /*e47e*/,
    11 /*e47f*/, 5 /*e480*/,  6 /*e481*/,  6 /*e482*/,  7 /*e483*/,
    6 /*e484*/,  7 /*e485*/,  7 /*e486*/,  8 /*e487*/,  6 /*e488*/,
    7 /*e489*/,  7 /*e48a*/,  8 /*e48b*/,  7 /*e48c*/,  8 /*e48d*/,
    8 /*e48e*/,  9 /*e48f*/,  6 /*e490*/,  7 /*e491*/,  7 /*e492*/,
    8 /*e493*/,  7 /*e494*/,  8 /*e495*/,  8 /*e496*/,  9 /*e497*/,
    7 /*e498*/,  8 /*e499*/,  8 /*e49a*/,  9 /*e49b*/,  8 /*e49c*/,
    9 /*e49d*/,  9 /*e49e*/,  10 /*e49f*/, 6 /*e4a0*/,  7 /*e4a1*/,
    7 /*e4a2*/,  8 /*e4a3*/,  7 /*e4a4*/,  8 /*e4a5*/,  8 /*e4a6*/,
    9 /*e4a7*/,  7 /*e4a8*/,  8 /*e4a9*/,  8 /*e4aa*/,  9 /*e4ab*/,
    8 /*e4ac*/,  9 /*e4ad*/,  9 /*e4ae*/,  10 /*e4af*/, 7 /*e4b0*/,
    8 /*e4b1*/,  8 /*e4b2*/,  9 /*e4b3*/,  8 /*e4b4*/,  9 /*e4b5*/,
    9 /*e4b6*/,  10 /*e4b7*/, 8 /*e4b8*/,  9 /*e4b9*/,  9 /*e4ba*/,
    10 /*e4bb*/, 9 /*e4bc*/,  10 /*e4bd*/, 10 /*e4be*/, 11 /*e4bf*/,
    6 /*e4c0*/,  7 /*e4c1*/,  7 /*e4c2*/,  8 /*e4c3*/,  7 /*e4c4*/,
    8 /*e4c5*/,  8 /*e4c6*/,  9 /*e4c7*/,  7 /*e4c8*/,  8 /*e4c9*/,
    8 /*e4ca*/,  9 /*e4cb*/,  8 /*e4cc*/,  9 /*e4cd*/,  9 /*e4ce*/,
    10 /*e4cf*/, 7 /*e4d0*/,  8 /*e4d1*/,  8 /*e4d2*/,  9 /*e4d3*/,
    8 /*e4d4*/,  9 /*e4d5*/,  9 /*e4d6*/,  10 /*e4d7*/, 8 /*e4d8*/,
    9 /*e4d9*/,  9 /*e4da*/,  10 /*e4db*/, 9 /*e4dc*/,  10 /*e4dd*/,
    10 /*e4de*/, 11 /*e4df*/, 7 /*e4e0*/,  8 /*e4e1*/,  8 /*e4e2*/,
    9 /*e4e3*/,  8 /*e4e4*/,  9 /*e4e5*/,  9 /*e4e6*/,  10 /*e4e7*/,
    8 /*e4e8*/,  9 /*e4e9*/,  9 /*e4ea*/,  10 /*e4eb*/, 9 /*e4ec*/,
    10 /*e4ed*/, 10 /*e4ee*/, 11 /*e4ef*/, 8 /*e4f0*/,  9 /*e4f1*/,
    9 /*e4f2*/,  10 /*e4f3*/, 9 /*e4f4*/,  10 /*e4f5*/, 10 /*e4f6*/,
    11 /*e4f7*/, 9 /*e4f8*/,  10 /*e4f9*/, 10 /*e4fa*/, 11 /*e4fb*/,
    10 /*e4fc*/, 11 /*e4fd*/, 11 /*e4fe*/, 12 /*e4ff*/, 5 /*e500*/,
    6 /*e501*/,  6 /*e502*/,  7 /*e503*/,  6 /*e504*/,  7 /*e505*/,
    7 /*e506*/,  8 /*e507*/,  6 /*e508*/,  7 /*e509*/,  7 /*e50a*/,
    8 /*e50b*/,  7 /*e50c*/,  8 /*e50d*/,  8 /*e50e*/,  9 /*e50f*/,
    6 /*e510*/,  7 /*e511*/,  7 /*e512*/,  8 /*e513*/,  7 /*e514*/,
    8 /*e515*/,  8 /*e516*/,  9 /*e517*/,  7 /*e518*/,  8 /*e519*/,
    8 /*e51a*/,  9 /*e51b*/,  8 /*e51c*/,  9 /*e51d*/,  9 /*e51e*/,
    10 /*e51f*/, 6 /*e520*/,  7 /*e521*/,  7 /*e522*/,  8 /*e523*/,
    7 /*e524*/,  8 /*e525*/,  8 /*e526*/,  9 /*e527*/,  7 /*e528*/,
    8 /*e529*/,  8 /*e52a*/,  9 /*e52b*/,  8 /*e52c*/,  9 /*e52d*/,
    9 /*e52e*/,  10 /*e52f*/, 7 /*e530*/,  8 /*e531*/,  8 /*e532*/,
    9 /*e533*/,  8 /*e534*/,  9 /*e535*/,  9 /*e536*/,  10 /*e537*/,
    8 /*e538*/,  9 /*e539*/,  9 /*e53a*/,  10 /*e53b*/, 9 /*e53c*/,
    10 /*e53d*/, 10 /*e53e*/, 11 /*e53f*/, 6 /*e540*/,  7 /*e541*/,
    7 /*e542*/,  8 /*e543*/,  7 /*e544*/,  8 /*e545*/,  8 /*e546*/,
    9 /*e547*/,  7 /*e548*/,  8 /*e549*/,  8 /*e54a*/,  9 /*e54b*/,
    8 /*e54c*/,  9 /*e54d*/,  9 /*e54e*/,  10 /*e54f*/, 7 /*e550*/,
    8 /*e551*/,  8 /*e552*/,  9 /*e553*/,  8 /*e554*/,  9 /*e555*/,
    9 /*e556*/,  10 /*e557*/, 8 /*e558*/,  9 /*e559*/,  9 /*e55a*/,
    10 /*e55b*/, 9 /*e55c*/,  10 /*e55d*/, 10 /*e55e*/, 11 /*e55f*/,
    7 /*e560*/,  8 /*e561*/,  8 /*e562*/,  9 /*e563*/,  8 /*e564*/,
    9 /*e565*/,  9 /*e566*/,  10 /*e567*/, 8 /*e568*/,  9 /*e569*/,
    9 /*e56a*/,  10 /*e56b*/, 9 /*e56c*/,  10 /*e56d*/, 10 /*e56e*/,
    11 /*e56f*/, 8 /*e570*/,  9 /*e571*/,  9 /*e572*/,  10 /*e573*/,
    9 /*e574*/,  10 /*e575*/, 10 /*e576*/, 11 /*e577*/, 9 /*e578*/,
    10 /*e579*/, 10 /*e57a*/, 11 /*e57b*/, 10 /*e57c*/, 11 /*e57d*/,
    11 /*e57e*/, 12 /*e57f*/, 6 /*e580*/,  7 /*e581*/,  7 /*e582*/,
    8 /*e583*/,  7 /*e584*/,  8 /*e585*/,  8 /*e586*/,  9 /*e587*/,
    7 /*e588*/,  8 /*e589*/,  8 /*e58a*/,  9 /*e58b*/,  8 /*e58c*/,
    9 /*e58d*/,  9 /*e58e*/,  10 /*e58f*/, 7 /*e590*/,  8 /*e591*/,
    8 /*e592*/,  9 /*e593*/,  8 /*e594*/,  9 /*e595*/,  9 /*e596*/,
    10 /*e597*/, 8 /*e598*/,  9 /*e599*/,  9 /*e59a*/,  10 /*e59b*/,
    9 /*e59c*/,  10 /*e59d*/, 10 /*e59e*/, 11 /*e59f*/, 7 /*e5a0*/,
    8 /*e5a1*/,  8 /*e5a2*/,  9 /*e5a3*/,  8 /*e5a4*/,  9 /*e5a5*/,
    9 /*e5a6*/,  10 /*e5a7*/, 8 /*e5a8*/,  9 /*e5a9*/,  9 /*e5aa*/,
    10 /*e5ab*/, 9 /*e5ac*/,  10 /*e5ad*/, 10 /*e5ae*/, 11 /*e5af*/,
    8 /*e5b0*/,  9 /*e5b1*/,  9 /*e5b2*/,  10 /*e5b3*/, 9 /*e5b4*/,
    10 /*e5b5*/, 10 /*e5b6*/, 11 /*e5b7*/, 9 /*e5b8*/,  10 /*e5b9*/,
    10 /*e5ba*/, 11 /*e5bb*/, 10 /*e5bc*/, 11 /*e5bd*/, 11 /*e5be*/,
    12 /*e5bf*/, 7 /*e5c0*/,  8 /*e5c1*/,  8 /*e5c2*/,  9 /*e5c3*/,
    8 /*e5c4*/,  9 /*e5c5*/,  9 /*e5c6*/,  10 /*e5c7*/, 8 /*e5c8*/,
    9 /*e5c9*/,  9 /*e5ca*/,  10 /*e5cb*/, 9 /*e5cc*/,  10 /*e5cd*/,
    10 /*e5ce*/, 11 /*e5cf*/, 8 /*e5d0*/,  9 /*e5d1*/,  9 /*e5d2*/,
    10 /*e5d3*/, 9 /*e5d4*/,  10 /*e5d5*/, 10 /*e5d6*/, 11 /*e5d7*/,
    9 /*e5d8*/,  10 /*e5d9*/, 10 /*e5da*/, 11 /*e5db*/, 10 /*e5dc*/,
    11 /*e5dd*/, 11 /*e5de*/, 12 /*e5df*/, 8 /*e5e0*/,  9 /*e5e1*/,
    9 /*e5e2*/,  10 /*e5e3*/, 9 /*e5e4*/,  10 /*e5e5*/, 10 /*e5e6*/,
    11 /*e5e7*/, 9 /*e5e8*/,  10 /*e5e9*/, 10 /*e5ea*/, 11 /*e5eb*/,
    10 /*e5ec*/, 11 /*e5ed*/, 11 /*e5ee*/, 12 /*e5ef*/, 9 /*e5f0*/,
    10 /*e5f1*/, 10 /*e5f2*/, 11 /*e5f3*/, 10 /*e5f4*/, 11 /*e5f5*/,
    11 /*e5f6*/, 12 /*e5f7*/, 10 /*e5f8*/, 11 /*e5f9*/, 11 /*e5fa*/,
    12 /*e5fb*/, 11 /*e5fc*/, 12 /*e5fd*/, 12 /*e5fe*/, 13 /*e5ff*/,
    5 /*e600*/,  6 /*e601*/,  6 /*e602*/,  7 /*e603*/,  6 /*e604*/,
    7 /*e605*/,  7 /*e606*/,  8 /*e607*/,  6 /*e608*/,  7 /*e609*/,
    7 /*e60a*/,  8 /*e60b*/,  7 /*e60c*/,  8 /*e60d*/,  8 /*e60e*/,
    9 /*e60f*/,  6 /*e610*/,  7 /*e611*/,  7 /*e612*/,  8 /*e613*/,
    7 /*e614*/,  8 /*e615*/,  8 /*e616*/,  9 /*e617*/,  7 /*e618*/,
    8 /*e619*/,  8 /*e61a*/,  9 /*e61b*/,  8 /*e61c*/,  9 /*e61d*/,
    9 /*e61e*/,  10 /*e61f*/, 6 /*e620*/,  7 /*e621*/,  7 /*e622*/,
    8 /*e623*/,  7 /*e624*/,  8 /*e625*/,  8 /*e626*/,  9 /*e627*/,
    7 /*e628*/,  8 /*e629*/,  8 /*e62a*/,  9 /*e62b*/,  8 /*e62c*/,
    9 /*e62d*/,  9 /*e62e*/,  10 /*e62f*/, 7 /*e630*/,  8 /*e631*/,
    8 /*e632*/,  9 /*e633*/,  8 /*e634*/,  9 /*e635*/,  9 /*e636*/,
    10 /*e637*/, 8 /*e638*/,  9 /*e639*/,  9 /*e63a*/,  10 /*e63b*/,
    9 /*e63c*/,  10 /*e63d*/, 10 /*e63e*/, 11 /*e63f*/, 6 /*e640*/,
    7 /*e641*/,  7 /*e642*/,  8 /*e643*/,  7 /*e644*/,  8 /*e645*/,
    8 /*e646*/,  9 /*e647*/,  7 /*e648*/,  8 /*e649*/,  8 /*e64a*/,
    9 /*e64b*/,  8 /*e64c*/,  9 /*e64d*/,  9 /*e64e*/,  10 /*e64f*/,
    7 /*e650*/,  8 /*e651*/,  8 /*e652*/,  9 /*e653*/,  8 /*e654*/,
    9 /*e655*/,  9 /*e656*/,  10 /*e657*/, 8 /*e658*/,  9 /*e659*/,
    9 /*e65a*/,  10 /*e65b*/, 9 /*e65c*/,  10 /*e65d*/, 10 /*e65e*/,
    11 /*e65f*/, 7 /*e660*/,  8 /*e661*/,  8 /*e662*/,  9 /*e663*/,
    8 /*e664*/,  9 /*e665*/,  9 /*e666*/,  10 /*e667*/, 8 /*e668*/,
    9 /*e669*/,  9 /*e66a*/,  10 /*e66b*/, 9 /*e66c*/,  10 /*e66d*/,
    10 /*e66e*/, 11 /*e66f*/, 8 /*e670*/,  9 /*e671*/,  9 /*e672*/,
    10 /*e673*/, 9 /*e674*/,  10 /*e675*/, 10 /*e676*/, 11 /*e677*/,
    9 /*e678*/,  10 /*e679*/, 10 /*e67a*/, 11 /*e67b*/, 10 /*e67c*/,
    11 /*e67d*/, 11 /*e67e*/, 12 /*e67f*/, 6 /*e680*/,  7 /*e681*/,
    7 /*e682*/,  8 /*e683*/,  7 /*e684*/,  8 /*e685*/,  8 /*e686*/,
    9 /*e687*/,  7 /*e688*/,  8 /*e689*/,  8 /*e68a*/,  9 /*e68b*/,
    8 /*e68c*/,  9 /*e68d*/,  9 /*e68e*/,  10 /*e68f*/, 7 /*e690*/,
    8 /*e691*/,  8 /*e692*/,  9 /*e693*/,  8 /*e694*/,  9 /*e695*/,
    9 /*e696*/,  10 /*e697*/, 8 /*e698*/,  9 /*e699*/,  9 /*e69a*/,
    10 /*e69b*/, 9 /*e69c*/,  10 /*e69d*/, 10 /*e69e*/, 11 /*e69f*/,
    7 /*e6a0*/,  8 /*e6a1*/,  8 /*e6a2*/,  9 /*e6a3*/,  8 /*e6a4*/,
    9 /*e6a5*/,  9 /*e6a6*/,  10 /*e6a7*/, 8 /*e6a8*/,  9 /*e6a9*/,
    9 /*e6aa*/,  10 /*e6ab*/, 9 /*e6ac*/,  10 /*e6ad*/, 10 /*e6ae*/,
    11 /*e6af*/, 8 /*e6b0*/,  9 /*e6b1*/,  9 /*e6b2*/,  10 /*e6b3*/,
    9 /*e6b4*/,  10 /*e6b5*/, 10 /*e6b6*/, 11 /*e6b7*/, 9 /*e6b8*/,
    10 /*e6b9*/, 10 /*e6ba*/, 11 /*e6bb*/, 10 /*e6bc*/, 11 /*e6bd*/,
    11 /*e6be*/, 12 /*e6bf*/, 7 /*e6c0*/,  8 /*e6c1*/,  8 /*e6c2*/,
    9 /*e6c3*/,  8 /*e6c4*/,  9 /*e6c5*/,  9 /*e6c6*/,  10 /*e6c7*/,
    8 /*e6c8*/,  9 /*e6c9*/,  9 /*e6ca*/,  10 /*e6cb*/, 9 /*e6cc*/,
    10 /*e6cd*/, 10 /*e6ce*/, 11 /*e6cf*/, 8 /*e6d0*/,  9 /*e6d1*/,
    9 /*e6d2*/,  10 /*e6d3*/, 9 /*e6d4*/,  10 /*e6d5*/, 10 /*e6d6*/,
    11 /*e6d7*/, 9 /*e6d8*/,  10 /*e6d9*/, 10 /*e6da*/, 11 /*e6db*/,
    10 /*e6dc*/, 11 /*e6dd*/, 11 /*e6de*/, 12 /*e6df*/, 8 /*e6e0*/,
    9 /*e6e1*/,  9 /*e6e2*/,  10 /*e6e3*/, 9 /*e6e4*/,  10 /*e6e5*/,
    10 /*e6e6*/, 11 /*e6e7*/, 9 /*e6e8*/,  10 /*e6e9*/, 10 /*e6ea*/,
    11 /*e6eb*/, 10 /*e6ec*/, 11 /*e6ed*/, 11 /*e6ee*/, 12 /*e6ef*/,
    9 /*e6f0*/,  10 /*e6f1*/, 10 /*e6f2*/, 11 /*e6f3*/, 10 /*e6f4*/,
    11 /*e6f5*/, 11 /*e6f6*/, 12 /*e6f7*/, 10 /*e6f8*/, 11 /*e6f9*/,
    11 /*e6fa*/, 12 /*e6fb*/, 11 /*e6fc*/, 12 /*e6fd*/, 12 /*e6fe*/,
    13 /*e6ff*/, 6 /*e700*/,  7 /*e701*/,  7 /*e702*/,  8 /*e703*/,
    7 /*e704*/,  8 /*e705*/,  8 /*e706*/,  9 /*e707*/,  7 /*e708*/,
    8 /*e709*/,  8 /*e70a*/,  9 /*e70b*/,  8 /*e70c*/,  9 /*e70d*/,
    9 /*e70e*/,  10 /*e70f*/, 7 /*e710*/,  8 /*e711*/,  8 /*e712*/,
    9 /*e713*/,  8 /*e714*/,  9 /*e715*/,  9 /*e716*/,  10 /*e717*/,
    8 /*e718*/,  9 /*e719*/,  9 /*e71a*/,  10 /*e71b*/, 9 /*e71c*/,
    10 /*e71d*/, 10 /*e71e*/, 11 /*e71f*/, 7 /*e720*/,  8 /*e721*/,
    8 /*e722*/,  9 /*e723*/,  8 /*e724*/,  9 /*e725*/,  9 /*e726*/,
    10 /*e727*/, 8 /*e728*/,  9 /*e729*/,  9 /*e72a*/,  10 /*e72b*/,
    9 /*e72c*/,  10 /*e72d*/, 10 /*e72e*/, 11 /*e72f*/, 8 /*e730*/,
    9 /*e731*/,  9 /*e732*/,  10 /*e733*/, 9 /*e734*/,  10 /*e735*/,
    10 /*e736*/, 11 /*e737*/, 9 /*e738*/,  10 /*e739*/, 10 /*e73a*/,
    11 /*e73b*/, 10 /*e73c*/, 11 /*e73d*/, 11 /*e73e*/, 12 /*e73f*/,
    7 /*e740*/,  8 /*e741*/,  8 /*e742*/,  9 /*e743*/,  8 /*e744*/,
    9 /*e745*/,  9 /*e746*/,  10 /*e747*/, 8 /*e748*/,  9 /*e749*/,
    9 /*e74a*/,  10 /*e74b*/, 9 /*e74c*/,  10 /*e74d*/, 10 /*e74e*/,
    11 /*e74f*/, 8 /*e750*/,  9 /*e751*/,  9 /*e752*/,  10 /*e753*/,
    9 /*e754*/,  10 /*e755*/, 10 /*e756*/, 11 /*e757*/, 9 /*e758*/,
    10 /*e759*/, 10 /*e75a*/, 11 /*e75b*/, 10 /*e75c*/, 11 /*e75d*/,
    11 /*e75e*/, 12 /*e75f*/, 8 /*e760*/,  9 /*e761*/,  9 /*e762*/,
    10 /*e763*/, 9 /*e764*/,  10 /*e765*/, 10 /*e766*/, 11 /*e767*/,
    9 /*e768*/,  10 /*e769*/, 10 /*e76a*/, 11 /*e76b*/, 10 /*e76c*/,
    11 /*e76d*/, 11 /*e76e*/, 12 /*e76f*/, 9 /*e770*/,  10 /*e771*/,
    10 /*e772*/, 11 /*e773*/, 10 /*e774*/, 11 /*e775*/, 11 /*e776*/,
    12 /*e777*/, 10 /*e778*/, 11 /*e779*/, 11 /*e77a*/, 12 /*e77b*/,
    11 /*e77c*/, 12 /*e77d*/, 12 /*e77e*/, 13 /*e77f*/, 7 /*e780*/,
    8 /*e781*/,  8 /*e782*/,  9 /*e783*/,  8 /*e784*/,  9 /*e785*/,
    9 /*e786*/,  10 /*e787*/, 8 /*e788*/,  9 /*e789*/,  9 /*e78a*/,
    10 /*e78b*/, 9 /*e78c*/,  10 /*e78d*/, 10 /*e78e*/, 11 /*e78f*/,
    8 /*e790*/,  9 /*e791*/,  9 /*e792*/,  10 /*e793*/, 9 /*e794*/,
    10 /*e795*/, 10 /*e796*/, 11 /*e797*/, 9 /*e798*/,  10 /*e799*/,
    10 /*e79a*/, 11 /*e79b*/, 10 /*e79c*/, 11 /*e79d*/, 11 /*e79e*/,
    12 /*e79f*/, 8 /*e7a0*/,  9 /*e7a1*/,  9 /*e7a2*/,  10 /*e7a3*/,
    9 /*e7a4*/,  10 /*e7a5*/, 10 /*e7a6*/, 11 /*e7a7*/, 9 /*e7a8*/,
    10 /*e7a9*/, 10 /*e7aa*/, 11 /*e7ab*/, 10 /*e7ac*/, 11 /*e7ad*/,
    11 /*e7ae*/, 12 /*e7af*/, 9 /*e7b0*/,  10 /*e7b1*/, 10 /*e7b2*/,
    11 /*e7b3*/, 10 /*e7b4*/, 11 /*e7b5*/, 11 /*e7b6*/, 12 /*e7b7*/,
    10 /*e7b8*/, 11 /*e7b9*/, 11 /*e7ba*/, 12 /*e7bb*/, 11 /*e7bc*/,
    12 /*e7bd*/, 12 /*e7be*/, 13 /*e7bf*/, 8 /*e7c0*/,  9 /*e7c1*/,
    9 /*e7c2*/,  10 /*e7c3*/, 9 /*e7c4*/,  10 /*e7c5*/, 10 /*e7c6*/,
    11 /*e7c7*/, 9 /*e7c8*/,  10 /*e7c9*/, 10 /*e7ca*/, 11 /*e7cb*/,
    10 /*e7cc*/, 11 /*e7cd*/, 11 /*e7ce*/, 12 /*e7cf*/, 9 /*e7d0*/,
    10 /*e7d1*/, 10 /*e7d2*/, 11 /*e7d3*/, 10 /*e7d4*/, 11 /*e7d5*/,
    11 /*e7d6*/, 12 /*e7d7*/, 10 /*e7d8*/, 11 /*e7d9*/, 11 /*e7da*/,
    12 /*e7db*/, 11 /*e7dc*/, 12 /*e7dd*/, 12 /*e7de*/, 13 /*e7df*/,
    9 /*e7e0*/,  10 /*e7e1*/, 10 /*e7e2*/, 11 /*e7e3*/, 10 /*e7e4*/,
    11 /*e7e5*/, 11 /*e7e6*/, 12 /*e7e7*/, 10 /*e7e8*/, 11 /*e7e9*/,
    11 /*e7ea*/, 12 /*e7eb*/, 11 /*e7ec*/, 12 /*e7ed*/, 12 /*e7ee*/,
    13 /*e7ef*/, 10 /*e7f0*/, 11 /*e7f1*/, 11 /*e7f2*/, 12 /*e7f3*/,
    11 /*e7f4*/, 12 /*e7f5*/, 12 /*e7f6*/, 13 /*e7f7*/, 11 /*e7f8*/,
    12 /*e7f9*/, 12 /*e7fa*/, 13 /*e7fb*/, 12 /*e7fc*/, 13 /*e7fd*/,
    13 /*e7fe*/, 14 /*e7ff*/, 4 /*e800*/,  5 /*e801*/,  5 /*e802*/,
    6 /*e803*/,  5 /*e804*/,  6 /*e805*/,  6 /*e806*/,  7 /*e807*/,
    5 /*e808*/,  6 /*e809*/,  6 /*e80a*/,  7 /*e80b*/,  6 /*e80c*/,
    7 /*e80d*/,  7 /*e80e*/,  8 /*e80f*/,  5 /*e810*/,  6 /*e811*/,
    6 /*e812*/,  7 /*e813*/,  6 /*e814*/,  7 /*e815*/,  7 /*e816*/,
    8 /*e817*/,  6 /*e818*/,  7 /*e819*/,  7 /*e81a*/,  8 /*e81b*/,
    7 /*e81c*/,  8 /*e81d*/,  8 /*e81e*/,  9 /*e81f*/,  5 /*e820*/,
    6 /*e821*/,  6 /*e822*/,  7 /*e823*/,  6 /*e824*/,  7 /*e825*/,
    7 /*e826*/,  8 /*e827*/,  6 /*e828*/,  7 /*e829*/,  7 /*e82a*/,
    8 /*e82b*/,  7 /*e82c*/,  8 /*e82d*/,  8 /*e82e*/,  9 /*e82f*/,
    6 /*e830*/,  7 /*e831*/,  7 /*e832*/,  8 /*e833*/,  7 /*e834*/,
    8 /*e835*/,  8 /*e836*/,  9 /*e837*/,  7 /*e838*/,  8 /*e839*/,
    8 /*e83a*/,  9 /*e83b*/,  8 /*e83c*/,  9 /*e83d*/,  9 /*e83e*/,
    10 /*e83f*/, 5 /*e840*/,  6 /*e841*/,  6 /*e842*/,  7 /*e843*/,
    6 /*e844*/,  7 /*e845*/,  7 /*e846*/,  8 /*e847*/,  6 /*e848*/,
    7 /*e849*/,  7 /*e84a*/,  8 /*e84b*/,  7 /*e84c*/,  8 /*e84d*/,
    8 /*e84e*/,  9 /*e84f*/,  6 /*e850*/,  7 /*e851*/,  7 /*e852*/,
    8 /*e853*/,  7 /*e854*/,  8 /*e855*/,  8 /*e856*/,  9 /*e857*/,
    7 /*e858*/,  8 /*e859*/,  8 /*e85a*/,  9 /*e85b*/,  8 /*e85c*/,
    9 /*e85d*/,  9 /*e85e*/,  10 /*e85f*/, 6 /*e860*/,  7 /*e861*/,
    7 /*e862*/,  8 /*e863*/,  7 /*e864*/,  8 /*e865*/,  8 /*e866*/,
    9 /*e867*/,  7 /*e868*/,  8 /*e869*/,  8 /*e86a*/,  9 /*e86b*/,
    8 /*e86c*/,  9 /*e86d*/,  9 /*e86e*/,  10 /*e86f*/, 7 /*e870*/,
    8 /*e871*/,  8 /*e872*/,  9 /*e873*/,  8 /*e874*/,  9 /*e875*/,
    9 /*e876*/,  10 /*e877*/, 8 /*e878*/,  9 /*e879*/,  9 /*e87a*/,
    10 /*e87b*/, 9 /*e87c*/,  10 /*e87d*/, 10 /*e87e*/, 11 /*e87f*/,
    5 /*e880*/,  6 /*e881*/,  6 /*e882*/,  7 /*e883*/,  6 /*e884*/,
    7 /*e885*/,  7 /*e886*/,  8 /*e887*/,  6 /*e888*/,  7 /*e889*/,
    7 /*e88a*/,  8 /*e88b*/,  7 /*e88c*/,  8 /*e88d*/,  8 /*e88e*/,
    9 /*e88f*/,  6 /*e890*/,  7 /*e891*/,  7 /*e892*/,  8 /*e893*/,
    7 /*e894*/,  8 /*e895*/,  8 /*e896*/,  9 /*e897*/,  7 /*e898*/,
    8 /*e899*/,  8 /*e89a*/,  9 /*e89b*/,  8 /*e89c*/,  9 /*e89d*/,
    9 /*e89e*/,  10 /*e89f*/, 6 /*e8a0*/,  7 /*e8a1*/,  7 /*e8a2*/,
    8 /*e8a3*/,  7 /*e8a4*/,  8 /*e8a5*/,  8 /*e8a6*/,  9 /*e8a7*/,
    7 /*e8a8*/,  8 /*e8a9*/,  8 /*e8aa*/,  9 /*e8ab*/,  8 /*e8ac*/,
    9 /*e8ad*/,  9 /*e8ae*/,  10 /*e8af*/, 7 /*e8b0*/,  8 /*e8b1*/,
    8 /*e8b2*/,  9 /*e8b3*/,  8 /*e8b4*/,  9 /*e8b5*/,  9 /*e8b6*/,
    10 /*e8b7*/, 8 /*e8b8*/,  9 /*e8b9*/,  9 /*e8ba*/,  10 /*e8bb*/,
    9 /*e8bc*/,  10 /*e8bd*/, 10 /*e8be*/, 11 /*e8bf*/, 6 /*e8c0*/,
    7 /*e8c1*/,  7 /*e8c2*/,  8 /*e8c3*/,  7 /*e8c4*/,  8 /*e8c5*/,
    8 /*e8c6*/,  9 /*e8c7*/,  7 /*e8c8*/,  8 /*e8c9*/,  8 /*e8ca*/,
    9 /*e8cb*/,  8 /*e8cc*/,  9 /*e8cd*/,  9 /*e8ce*/,  10 /*e8cf*/,
    7 /*e8d0*/,  8 /*e8d1*/,  8 /*e8d2*/,  9 /*e8d3*/,  8 /*e8d4*/,
    9 /*e8d5*/,  9 /*e8d6*/,  10 /*e8d7*/, 8 /*e8d8*/,  9 /*e8d9*/,
    9 /*e8da*/,  10 /*e8db*/, 9 /*e8dc*/,  10 /*e8dd*/, 10 /*e8de*/,
    11 /*e8df*/, 7 /*e8e0*/,  8 /*e8e1*/,  8 /*e8e2*/,  9 /*e8e3*/,
    8 /*e8e4*/,  9 /*e8e5*/,  9 /*e8e6*/,  10 /*e8e7*/, 8 /*e8e8*/,
    9 /*e8e9*/,  9 /*e8ea*/,  10 /*e8eb*/, 9 /*e8ec*/,  10 /*e8ed*/,
    10 /*e8ee*/, 11 /*e8ef*/, 8 /*e8f0*/,  9 /*e8f1*/,  9 /*e8f2*/,
    10 /*e8f3*/, 9 /*e8f4*/,  10 /*e8f5*/, 10 /*e8f6*/, 11 /*e8f7*/,
    9 /*e8f8*/,  10 /*e8f9*/, 10 /*e8fa*/, 11 /*e8fb*/, 10 /*e8fc*/,
    11 /*e8fd*/, 11 /*e8fe*/, 12 /*e8ff*/, 5 /*e900*/,  6 /*e901*/,
    6 /*e902*/,  7 /*e903*/,  6 /*e904*/,  7 /*e905*/,  7 /*e906*/,
    8 /*e907*/,  6 /*e908*/,  7 /*e909*/,  7 /*e90a*/,  8 /*e90b*/,
    7 /*e90c*/,  8 /*e90d*/,  8 /*e90e*/,  9 /*e90f*/,  6 /*e910*/,
    7 /*e911*/,  7 /*e912*/,  8 /*e913*/,  7 /*e914*/,  8 /*e915*/,
    8 /*e916*/,  9 /*e917*/,  7 /*e918*/,  8 /*e919*/,  8 /*e91a*/,
    9 /*e91b*/,  8 /*e91c*/,  9 /*e91d*/,  9 /*e91e*/,  10 /*e91f*/,
    6 /*e920*/,  7 /*e921*/,  7 /*e922*/,  8 /*e923*/,  7 /*e924*/,
    8 /*e925*/,  8 /*e926*/,  9 /*e927*/,  7 /*e928*/,  8 /*e929*/,
    8 /*e92a*/,  9 /*e92b*/,  8 /*e92c*/,  9 /*e92d*/,  9 /*e92e*/,
    10 /*e92f*/, 7 /*e930*/,  8 /*e931*/,  8 /*e932*/,  9 /*e933*/,
    8 /*e934*/,  9 /*e935*/,  9 /*e936*/,  10 /*e937*/, 8 /*e938*/,
    9 /*e939*/,  9 /*e93a*/,  10 /*e93b*/, 9 /*e93c*/,  10 /*e93d*/,
    10 /*e93e*/, 11 /*e93f*/, 6 /*e940*/,  7 /*e941*/,  7 /*e942*/,
    8 /*e943*/,  7 /*e944*/,  8 /*e945*/,  8 /*e946*/,  9 /*e947*/,
    7 /*e948*/,  8 /*e949*/,  8 /*e94a*/,  9 /*e94b*/,  8 /*e94c*/,
    9 /*e94d*/,  9 /*e94e*/,  10 /*e94f*/, 7 /*e950*/,  8 /*e951*/,
    8 /*e952*/,  9 /*e953*/,  8 /*e954*/,  9 /*e955*/,  9 /*e956*/,
    10 /*e957*/, 8 /*e958*/,  9 /*e959*/,  9 /*e95a*/,  10 /*e95b*/,
    9 /*e95c*/,  10 /*e95d*/, 10 /*e95e*/, 11 /*e95f*/, 7 /*e960*/,
    8 /*e961*/,  8 /*e962*/,  9 /*e963*/,  8 /*e964*/,  9 /*e965*/,
    9 /*e966*/,  10 /*e967*/, 8 /*e968*/,  9 /*e969*/,  9 /*e96a*/,
    10 /*e96b*/, 9 /*e96c*/,  10 /*e96d*/, 10 /*e96e*/, 11 /*e96f*/,
    8 /*e970*/,  9 /*e971*/,  9 /*e972*/,  10 /*e973*/, 9 /*e974*/,
    10 /*e975*/, 10 /*e976*/, 11 /*e977*/, 9 /*e978*/,  10 /*e979*/,
    10 /*e97a*/, 11 /*e97b*/, 10 /*e97c*/, 11 /*e97d*/, 11 /*e97e*/,
    12 /*e97f*/, 6 /*e980*/,  7 /*e981*/,  7 /*e982*/,  8 /*e983*/,
    7 /*e984*/,  8 /*e985*/,  8 /*e986*/,  9 /*e987*/,  7 /*e988*/,
    8 /*e989*/,  8 /*e98a*/,  9 /*e98b*/,  8 /*e98c*/,  9 /*e98d*/,
    9 /*e98e*/,  10 /*e98f*/, 7 /*e990*/,  8 /*e991*/,  8 /*e992*/,
    9 /*e993*/,  8 /*e994*/,  9 /*e995*/,  9 /*e996*/,  10 /*e997*/,
    8 /*e998*/,  9 /*e999*/,  9 /*e99a*/,  10 /*e99b*/, 9 /*e99c*/,
    10 /*e99d*/, 10 /*e99e*/, 11 /*e99f*/, 7 /*e9a0*/,  8 /*e9a1*/,
    8 /*e9a2*/,  9 /*e9a3*/,  8 /*e9a4*/,  9 /*e9a5*/,  9 /*e9a6*/,
    10 /*e9a7*/, 8 /*e9a8*/,  9 /*e9a9*/,  9 /*e9aa*/,  10 /*e9ab*/,
    9 /*e9ac*/,  10 /*e9ad*/, 10 /*e9ae*/, 11 /*e9af*/, 8 /*e9b0*/,
    9 /*e9b1*/,  9 /*e9b2*/,  10 /*e9b3*/, 9 /*e9b4*/,  10 /*e9b5*/,
    10 /*e9b6*/, 11 /*e9b7*/, 9 /*e9b8*/,  10 /*e9b9*/, 10 /*e9ba*/,
    11 /*e9bb*/, 10 /*e9bc*/, 11 /*e9bd*/, 11 /*e9be*/, 12 /*e9bf*/,
    7 /*e9c0*/,  8 /*e9c1*/,  8 /*e9c2*/,  9 /*e9c3*/,  8 /*e9c4*/,
    9 /*e9c5*/,  9 /*e9c6*/,  10 /*e9c7*/, 8 /*e9c8*/,  9 /*e9c9*/,
    9 /*e9ca*/,  10 /*e9cb*/, 9 /*e9cc*/,  10 /*e9cd*/, 10 /*e9ce*/,
    11 /*e9cf*/, 8 /*e9d0*/,  9 /*e9d1*/,  9 /*e9d2*/,  10 /*e9d3*/,
    9 /*e9d4*/,  10 /*e9d5*/, 10 /*e9d6*/, 11 /*e9d7*/, 9 /*e9d8*/,
    10 /*e9d9*/, 10 /*e9da*/, 11 /*e9db*/, 10 /*e9dc*/, 11 /*e9dd*/,
    11 /*e9de*/, 12 /*e9df*/, 8 /*e9e0*/,  9 /*e9e1*/,  9 /*e9e2*/,
    10 /*e9e3*/, 9 /*e9e4*/,  10 /*e9e5*/, 10 /*e9e6*/, 11 /*e9e7*/,
    9 /*e9e8*/,  10 /*e9e9*/, 10 /*e9ea*/, 11 /*e9eb*/, 10 /*e9ec*/,
    11 /*e9ed*/, 11 /*e9ee*/, 12 /*e9ef*/, 9 /*e9f0*/,  10 /*e9f1*/,
    10 /*e9f2*/, 11 /*e9f3*/, 10 /*e9f4*/, 11 /*e9f5*/, 11 /*e9f6*/,
    12 /*e9f7*/, 10 /*e9f8*/, 11 /*e9f9*/, 11 /*e9fa*/, 12 /*e9fb*/,
    11 /*e9fc*/, 12 /*e9fd*/, 12 /*e9fe*/, 13 /*e9ff*/, 5 /*ea00*/,
    6 /*ea01*/,  6 /*ea02*/,  7 /*ea03*/,  6 /*ea04*/,  7 /*ea05*/,
    7 /*ea06*/,  8 /*ea07*/,  6 /*ea08*/,  7 /*ea09*/,  7 /*ea0a*/,
    8 /*ea0b*/,  7 /*ea0c*/,  8 /*ea0d*/,  8 /*ea0e*/,  9 /*ea0f*/,
    6 /*ea10*/,  7 /*ea11*/,  7 /*ea12*/,  8 /*ea13*/,  7 /*ea14*/,
    8 /*ea15*/,  8 /*ea16*/,  9 /*ea17*/,  7 /*ea18*/,  8 /*ea19*/,
    8 /*ea1a*/,  9 /*ea1b*/,  8 /*ea1c*/,  9 /*ea1d*/,  9 /*ea1e*/,
    10 /*ea1f*/, 6 /*ea20*/,  7 /*ea21*/,  7 /*ea22*/,  8 /*ea23*/,
    7 /*ea24*/,  8 /*ea25*/,  8 /*ea26*/,  9 /*ea27*/,  7 /*ea28*/,
    8 /*ea29*/,  8 /*ea2a*/,  9 /*ea2b*/,  8 /*ea2c*/,  9 /*ea2d*/,
    9 /*ea2e*/,  10 /*ea2f*/, 7 /*ea30*/,  8 /*ea31*/,  8 /*ea32*/,
    9 /*ea33*/,  8 /*ea34*/,  9 /*ea35*/,  9 /*ea36*/,  10 /*ea37*/,
    8 /*ea38*/,  9 /*ea39*/,  9 /*ea3a*/,  10 /*ea3b*/, 9 /*ea3c*/,
    10 /*ea3d*/, 10 /*ea3e*/, 11 /*ea3f*/, 6 /*ea40*/,  7 /*ea41*/,
    7 /*ea42*/,  8 /*ea43*/,  7 /*ea44*/,  8 /*ea45*/,  8 /*ea46*/,
    9 /*ea47*/,  7 /*ea48*/,  8 /*ea49*/,  8 /*ea4a*/,  9 /*ea4b*/,
    8 /*ea4c*/,  9 /*ea4d*/,  9 /*ea4e*/,  10 /*ea4f*/, 7 /*ea50*/,
    8 /*ea51*/,  8 /*ea52*/,  9 /*ea53*/,  8 /*ea54*/,  9 /*ea55*/,
    9 /*ea56*/,  10 /*ea57*/, 8 /*ea58*/,  9 /*ea59*/,  9 /*ea5a*/,
    10 /*ea5b*/, 9 /*ea5c*/,  10 /*ea5d*/, 10 /*ea5e*/, 11 /*ea5f*/,
    7 /*ea60*/,  8 /*ea61*/,  8 /*ea62*/,  9 /*ea63*/,  8 /*ea64*/,
    9 /*ea65*/,  9 /*ea66*/,  10 /*ea67*/, 8 /*ea68*/,  9 /*ea69*/,
    9 /*ea6a*/,  10 /*ea6b*/, 9 /*ea6c*/,  10 /*ea6d*/, 10 /*ea6e*/,
    11 /*ea6f*/, 8 /*ea70*/,  9 /*ea71*/,  9 /*ea72*/,  10 /*ea73*/,
    9 /*ea74*/,  10 /*ea75*/, 10 /*ea76*/, 11 /*ea77*/, 9 /*ea78*/,
    10 /*ea79*/, 10 /*ea7a*/, 11 /*ea7b*/, 10 /*ea7c*/, 11 /*ea7d*/,
    11 /*ea7e*/, 12 /*ea7f*/, 6 /*ea80*/,  7 /*ea81*/,  7 /*ea82*/,
    8 /*ea83*/,  7 /*ea84*/,  8 /*ea85*/,  8 /*ea86*/,  9 /*ea87*/,
    7 /*ea88*/,  8 /*ea89*/,  8 /*ea8a*/,  9 /*ea8b*/,  8 /*ea8c*/,
    9 /*ea8d*/,  9 /*ea8e*/,  10 /*ea8f*/, 7 /*ea90*/,  8 /*ea91*/,
    8 /*ea92*/,  9 /*ea93*/,  8 /*ea94*/,  9 /*ea95*/,  9 /*ea96*/,
    10 /*ea97*/, 8 /*ea98*/,  9 /*ea99*/,  9 /*ea9a*/,  10 /*ea9b*/,
    9 /*ea9c*/,  10 /*ea9d*/, 10 /*ea9e*/, 11 /*ea9f*/, 7 /*eaa0*/,
    8 /*eaa1*/,  8 /*eaa2*/,  9 /*eaa3*/,  8 /*eaa4*/,  9 /*eaa5*/,
    9 /*eaa6*/,  10 /*eaa7*/, 8 /*eaa8*/,  9 /*eaa9*/,  9 /*eaaa*/,
    10 /*eaab*/, 9 /*eaac*/,  10 /*eaad*/, 10 /*eaae*/, 11 /*eaaf*/,
    8 /*eab0*/,  9 /*eab1*/,  9 /*eab2*/,  10 /*eab3*/, 9 /*eab4*/,
    10 /*eab5*/, 10 /*eab6*/, 11 /*eab7*/, 9 /*eab8*/,  10 /*eab9*/,
    10 /*eaba*/, 11 /*eabb*/, 10 /*eabc*/, 11 /*eabd*/, 11 /*eabe*/,
    12 /*eabf*/, 7 /*eac0*/,  8 /*eac1*/,  8 /*eac2*/,  9 /*eac3*/,
    8 /*eac4*/,  9 /*eac5*/,  9 /*eac6*/,  10 /*eac7*/, 8 /*eac8*/,
    9 /*eac9*/,  9 /*eaca*/,  10 /*eacb*/, 9 /*eacc*/,  10 /*eacd*/,
    10 /*eace*/, 11 /*eacf*/, 8 /*ead0*/,  9 /*ead1*/,  9 /*ead2*/,
    10 /*ead3*/, 9 /*ead4*/,  10 /*ead5*/, 10 /*ead6*/, 11 /*ead7*/,
    9 /*ead8*/,  10 /*ead9*/, 10 /*eada*/, 11 /*eadb*/, 10 /*eadc*/,
    11 /*eadd*/, 11 /*eade*/, 12 /*eadf*/, 8 /*eae0*/,  9 /*eae1*/,
    9 /*eae2*/,  10 /*eae3*/, 9 /*eae4*/,  10 /*eae5*/, 10 /*eae6*/,
    11 /*eae7*/, 9 /*eae8*/,  10 /*eae9*/, 10 /*eaea*/, 11 /*eaeb*/,
    10 /*eaec*/, 11 /*eaed*/, 11 /*eaee*/, 12 /*eaef*/, 9 /*eaf0*/,
    10 /*eaf1*/, 10 /*eaf2*/, 11 /*eaf3*/, 10 /*eaf4*/, 11 /*eaf5*/,
    11 /*eaf6*/, 12 /*eaf7*/, 10 /*eaf8*/, 11 /*eaf9*/, 11 /*eafa*/,
    12 /*eafb*/, 11 /*eafc*/, 12 /*eafd*/, 12 /*eafe*/, 13 /*eaff*/,
    6 /*eb00*/,  7 /*eb01*/,  7 /*eb02*/,  8 /*eb03*/,  7 /*eb04*/,
    8 /*eb05*/,  8 /*eb06*/,  9 /*eb07*/,  7 /*eb08*/,  8 /*eb09*/,
    8 /*eb0a*/,  9 /*eb0b*/,  8 /*eb0c*/,  9 /*eb0d*/,  9 /*eb0e*/,
    10 /*eb0f*/, 7 /*eb10*/,  8 /*eb11*/,  8 /*eb12*/,  9 /*eb13*/,
    8 /*eb14*/,  9 /*eb15*/,  9 /*eb16*/,  10 /*eb17*/, 8 /*eb18*/,
    9 /*eb19*/,  9 /*eb1a*/,  10 /*eb1b*/, 9 /*eb1c*/,  10 /*eb1d*/,
    10 /*eb1e*/, 11 /*eb1f*/, 7 /*eb20*/,  8 /*eb21*/,  8 /*eb22*/,
    9 /*eb23*/,  8 /*eb24*/,  9 /*eb25*/,  9 /*eb26*/,  10 /*eb27*/,
    8 /*eb28*/,  9 /*eb29*/,  9 /*eb2a*/,  10 /*eb2b*/, 9 /*eb2c*/,
    10 /*eb2d*/, 10 /*eb2e*/, 11 /*eb2f*/, 8 /*eb30*/,  9 /*eb31*/,
    9 /*eb32*/,  10 /*eb33*/, 9 /*eb34*/,  10 /*eb35*/, 10 /*eb36*/,
    11 /*eb37*/, 9 /*eb38*/,  10 /*eb39*/, 10 /*eb3a*/, 11 /*eb3b*/,
    10 /*eb3c*/, 11 /*eb3d*/, 11 /*eb3e*/, 12 /*eb3f*/, 7 /*eb40*/,
    8 /*eb41*/,  8 /*eb42*/,  9 /*eb43*/,  8 /*eb44*/,  9 /*eb45*/,
    9 /*eb46*/,  10 /*eb47*/, 8 /*eb48*/,  9 /*eb49*/,  9 /*eb4a*/,
    10 /*eb4b*/, 9 /*eb4c*/,  10 /*eb4d*/, 10 /*eb4e*/, 11 /*eb4f*/,
    8 /*eb50*/,  9 /*eb51*/,  9 /*eb52*/,  10 /*eb53*/, 9 /*eb54*/,
    10 /*eb55*/, 10 /*eb56*/, 11 /*eb57*/, 9 /*eb58*/,  10 /*eb59*/,
    10 /*eb5a*/, 11 /*eb5b*/, 10 /*eb5c*/, 11 /*eb5d*/, 11 /*eb5e*/,
    12 /*eb5f*/, 8 /*eb60*/,  9 /*eb61*/,  9 /*eb62*/,  10 /*eb63*/,
    9 /*eb64*/,  10 /*eb65*/, 10 /*eb66*/, 11 /*eb67*/, 9 /*eb68*/,
    10 /*eb69*/, 10 /*eb6a*/, 11 /*eb6b*/, 10 /*eb6c*/, 11 /*eb6d*/,
    11 /*eb6e*/, 12 /*eb6f*/, 9 /*eb70*/,  10 /*eb71*/, 10 /*eb72*/,
    11 /*eb73*/, 10 /*eb74*/, 11 /*eb75*/, 11 /*eb76*/, 12 /*eb77*/,
    10 /*eb78*/, 11 /*eb79*/, 11 /*eb7a*/, 12 /*eb7b*/, 11 /*eb7c*/,
    12 /*eb7d*/, 12 /*eb7e*/, 13 /*eb7f*/, 7 /*eb80*/,  8 /*eb81*/,
    8 /*eb82*/,  9 /*eb83*/,  8 /*eb84*/,  9 /*eb85*/,  9 /*eb86*/,
    10 /*eb87*/, 8 /*eb88*/,  9 /*eb89*/,  9 /*eb8a*/,  10 /*eb8b*/,
    9 /*eb8c*/,  10 /*eb8d*/, 10 /*eb8e*/, 11 /*eb8f*/, 8 /*eb90*/,
    9 /*eb91*/,  9 /*eb92*/,  10 /*eb93*/, 9 /*eb94*/,  10 /*eb95*/,
    10 /*eb96*/, 11 /*eb97*/, 9 /*eb98*/,  10 /*eb99*/, 10 /*eb9a*/,
    11 /*eb9b*/, 10 /*eb9c*/, 11 /*eb9d*/, 11 /*eb9e*/, 12 /*eb9f*/,
    8 /*eba0*/,  9 /*eba1*/,  9 /*eba2*/,  10 /*eba3*/, 9 /*eba4*/,
    10 /*eba5*/, 10 /*eba6*/, 11 /*eba7*/, 9 /*eba8*/,  10 /*eba9*/,
    10 /*ebaa*/, 11 /*ebab*/, 10 /*ebac*/, 11 /*ebad*/, 11 /*ebae*/,
    12 /*ebaf*/, 9 /*ebb0*/,  10 /*ebb1*/, 10 /*ebb2*/, 11 /*ebb3*/,
    10 /*ebb4*/, 11 /*ebb5*/, 11 /*ebb6*/, 12 /*ebb7*/, 10 /*ebb8*/,
    11 /*ebb9*/, 11 /*ebba*/, 12 /*ebbb*/, 11 /*ebbc*/, 12 /*ebbd*/,
    12 /*ebbe*/, 13 /*ebbf*/, 8 /*ebc0*/,  9 /*ebc1*/,  9 /*ebc2*/,
    10 /*ebc3*/, 9 /*ebc4*/,  10 /*ebc5*/, 10 /*ebc6*/, 11 /*ebc7*/,
    9 /*ebc8*/,  10 /*ebc9*/, 10 /*ebca*/, 11 /*ebcb*/, 10 /*ebcc*/,
    11 /*ebcd*/, 11 /*ebce*/, 12 /*ebcf*/, 9 /*ebd0*/,  10 /*ebd1*/,
    10 /*ebd2*/, 11 /*ebd3*/, 10 /*ebd4*/, 11 /*ebd5*/, 11 /*ebd6*/,
    12 /*ebd7*/, 10 /*ebd8*/, 11 /*ebd9*/, 11 /*ebda*/, 12 /*ebdb*/,
    11 /*ebdc*/, 12 /*ebdd*/, 12 /*ebde*/, 13 /*ebdf*/, 9 /*ebe0*/,
    10 /*ebe1*/, 10 /*ebe2*/, 11 /*ebe3*/, 10 /*ebe4*/, 11 /*ebe5*/,
    11 /*ebe6*/, 12 /*ebe7*/, 10 /*ebe8*/, 11 /*ebe9*/, 11 /*ebea*/,
    12 /*ebeb*/, 11 /*ebec*/, 12 /*ebed*/, 12 /*ebee*/, 13 /*ebef*/,
    10 /*ebf0*/, 11 /*ebf1*/, 11 /*ebf2*/, 12 /*ebf3*/, 11 /*ebf4*/,
    12 /*ebf5*/, 12 /*ebf6*/, 13 /*ebf7*/, 11 /*ebf8*/, 12 /*ebf9*/,
    12 /*ebfa*/, 13 /*ebfb*/, 12 /*ebfc*/, 13 /*ebfd*/, 13 /*ebfe*/,
    14 /*ebff*/, 5 /*ec00*/,  6 /*ec01*/,  6 /*ec02*/,  7 /*ec03*/,
    6 /*ec04*/,  7 /*ec05*/,  7 /*ec06*/,  8 /*ec07*/,  6 /*ec08*/,
    7 /*ec09*/,  7 /*ec0a*/,  8 /*ec0b*/,  7 /*ec0c*/,  8 /*ec0d*/,
    8 /*ec0e*/,  9 /*ec0f*/,  6 /*ec10*/,  7 /*ec11*/,  7 /*ec12*/,
    8 /*ec13*/,  7 /*ec14*/,  8 /*ec15*/,  8 /*ec16*/,  9 /*ec17*/,
    7 /*ec18*/,  8 /*ec19*/,  8 /*ec1a*/,  9 /*ec1b*/,  8 /*ec1c*/,
    9 /*ec1d*/,  9 /*ec1e*/,  10 /*ec1f*/, 6 /*ec20*/,  7 /*ec21*/,
    7 /*ec22*/,  8 /*ec23*/,  7 /*ec24*/,  8 /*ec25*/,  8 /*ec26*/,
    9 /*ec27*/,  7 /*ec28*/,  8 /*ec29*/,  8 /*ec2a*/,  9 /*ec2b*/,
    8 /*ec2c*/,  9 /*ec2d*/,  9 /*ec2e*/,  10 /*ec2f*/, 7 /*ec30*/,
    8 /*ec31*/,  8 /*ec32*/,  9 /*ec33*/,  8 /*ec34*/,  9 /*ec35*/,
    9 /*ec36*/,  10 /*ec37*/, 8 /*ec38*/,  9 /*ec39*/,  9 /*ec3a*/,
    10 /*ec3b*/, 9 /*ec3c*/,  10 /*ec3d*/, 10 /*ec3e*/, 11 /*ec3f*/,
    6 /*ec40*/,  7 /*ec41*/,  7 /*ec42*/,  8 /*ec43*/,  7 /*ec44*/,
    8 /*ec45*/,  8 /*ec46*/,  9 /*ec47*/,  7 /*ec48*/,  8 /*ec49*/,
    8 /*ec4a*/,  9 /*ec4b*/,  8 /*ec4c*/,  9 /*ec4d*/,  9 /*ec4e*/,
    10 /*ec4f*/, 7 /*ec50*/,  8 /*ec51*/,  8 /*ec52*/,  9 /*ec53*/,
    8 /*ec54*/,  9 /*ec55*/,  9 /*ec56*/,  10 /*ec57*/, 8 /*ec58*/,
    9 /*ec59*/,  9 /*ec5a*/,  10 /*ec5b*/, 9 /*ec5c*/,  10 /*ec5d*/,
    10 /*ec5e*/, 11 /*ec5f*/, 7 /*ec60*/,  8 /*ec61*/,  8 /*ec62*/,
    9 /*ec63*/,  8 /*ec64*/,  9 /*ec65*/,  9 /*ec66*/,  10 /*ec67*/,
    8 /*ec68*/,  9 /*ec69*/,  9 /*ec6a*/,  10 /*ec6b*/, 9 /*ec6c*/,
    10 /*ec6d*/, 10 /*ec6e*/, 11 /*ec6f*/, 8 /*ec70*/,  9 /*ec71*/,
    9 /*ec72*/,  10 /*ec73*/, 9 /*ec74*/,  10 /*ec75*/, 10 /*ec76*/,
    11 /*ec77*/, 9 /*ec78*/,  10 /*ec79*/, 10 /*ec7a*/, 11 /*ec7b*/,
    10 /*ec7c*/, 11 /*ec7d*/, 11 /*ec7e*/, 12 /*ec7f*/, 6 /*ec80*/,
    7 /*ec81*/,  7 /*ec82*/,  8 /*ec83*/,  7 /*ec84*/,  8 /*ec85*/,
    8 /*ec86*/,  9 /*ec87*/,  7 /*ec88*/,  8 /*ec89*/,  8 /*ec8a*/,
    9 /*ec8b*/,  8 /*ec8c*/,  9 /*ec8d*/,  9 /*ec8e*/,  10 /*ec8f*/,
    7 /*ec90*/,  8 /*ec91*/,  8 /*ec92*/,  9 /*ec93*/,  8 /*ec94*/,
    9 /*ec95*/,  9 /*ec96*/,  10 /*ec97*/, 8 /*ec98*/,  9 /*ec99*/,
    9 /*ec9a*/,  10 /*ec9b*/, 9 /*ec9c*/,  10 /*ec9d*/, 10 /*ec9e*/,
    11 /*ec9f*/, 7 /*eca0*/,  8 /*eca1*/,  8 /*eca2*/,  9 /*eca3*/,
    8 /*eca4*/,  9 /*eca5*/,  9 /*eca6*/,  10 /*eca7*/, 8 /*eca8*/,
    9 /*eca9*/,  9 /*ecaa*/,  10 /*ecab*/, 9 /*ecac*/,  10 /*ecad*/,
    10 /*ecae*/, 11 /*ecaf*/, 8 /*ecb0*/,  9 /*ecb1*/,  9 /*ecb2*/,
    10 /*ecb3*/, 9 /*ecb4*/,  10 /*ecb5*/, 10 /*ecb6*/, 11 /*ecb7*/,
    9 /*ecb8*/,  10 /*ecb9*/, 10 /*ecba*/, 11 /*ecbb*/, 10 /*ecbc*/,
    11 /*ecbd*/, 11 /*ecbe*/, 12 /*ecbf*/, 7 /*ecc0*/,  8 /*ecc1*/,
    8 /*ecc2*/,  9 /*ecc3*/,  8 /*ecc4*/,  9 /*ecc5*/,  9 /*ecc6*/,
    10 /*ecc7*/, 8 /*ecc8*/,  9 /*ecc9*/,  9 /*ecca*/,  10 /*eccb*/,
    9 /*eccc*/,  10 /*eccd*/, 10 /*ecce*/, 11 /*eccf*/, 8 /*ecd0*/,
    9 /*ecd1*/,  9 /*ecd2*/,  10 /*ecd3*/, 9 /*ecd4*/,  10 /*ecd5*/,
    10 /*ecd6*/, 11 /*ecd7*/, 9 /*ecd8*/,  10 /*ecd9*/, 10 /*ecda*/,
    11 /*ecdb*/, 10 /*ecdc*/, 11 /*ecdd*/, 11 /*ecde*/, 12 /*ecdf*/,
    8 /*ece0*/,  9 /*ece1*/,  9 /*ece2*/,  10 /*ece3*/, 9 /*ece4*/,
    10 /*ece5*/, 10 /*ece6*/, 11 /*ece7*/, 9 /*ece8*/,  10 /*ece9*/,
    10 /*ecea*/, 11 /*eceb*/, 10 /*ecec*/, 11 /*eced*/, 11 /*ecee*/,
    12 /*ecef*/, 9 /*ecf0*/,  10 /*ecf1*/, 10 /*ecf2*/, 11 /*ecf3*/,
    10 /*ecf4*/, 11 /*ecf5*/, 11 /*ecf6*/, 12 /*ecf7*/, 10 /*ecf8*/,
    11 /*ecf9*/, 11 /*ecfa*/, 12 /*ecfb*/, 11 /*ecfc*/, 12 /*ecfd*/,
    12 /*ecfe*/, 13 /*ecff*/, 6 /*ed00*/,  7 /*ed01*/,  7 /*ed02*/,
    8 /*ed03*/,  7 /*ed04*/,  8 /*ed05*/,  8 /*ed06*/,  9 /*ed07*/,
    7 /*ed08*/,  8 /*ed09*/,  8 /*ed0a*/,  9 /*ed0b*/,  8 /*ed0c*/,
    9 /*ed0d*/,  9 /*ed0e*/,  10 /*ed0f*/, 7 /*ed10*/,  8 /*ed11*/,
    8 /*ed12*/,  9 /*ed13*/,  8 /*ed14*/,  9 /*ed15*/,  9 /*ed16*/,
    10 /*ed17*/, 8 /*ed18*/,  9 /*ed19*/,  9 /*ed1a*/,  10 /*ed1b*/,
    9 /*ed1c*/,  10 /*ed1d*/, 10 /*ed1e*/, 11 /*ed1f*/, 7 /*ed20*/,
    8 /*ed21*/,  8 /*ed22*/,  9 /*ed23*/,  8 /*ed24*/,  9 /*ed25*/,
    9 /*ed26*/,  10 /*ed27*/, 8 /*ed28*/,  9 /*ed29*/,  9 /*ed2a*/,
    10 /*ed2b*/, 9 /*ed2c*/,  10 /*ed2d*/, 10 /*ed2e*/, 11 /*ed2f*/,
    8 /*ed30*/,  9 /*ed31*/,  9 /*ed32*/,  10 /*ed33*/, 9 /*ed34*/,
    10 /*ed35*/, 10 /*ed36*/, 11 /*ed37*/, 9 /*ed38*/,  10 /*ed39*/,
    10 /*ed3a*/, 11 /*ed3b*/, 10 /*ed3c*/, 11 /*ed3d*/, 11 /*ed3e*/,
    12 /*ed3f*/, 7 /*ed40*/,  8 /*ed41*/,  8 /*ed42*/,  9 /*ed43*/,
    8 /*ed44*/,  9 /*ed45*/,  9 /*ed46*/,  10 /*ed47*/, 8 /*ed48*/,
    9 /*ed49*/,  9 /*ed4a*/,  10 /*ed4b*/, 9 /*ed4c*/,  10 /*ed4d*/,
    10 /*ed4e*/, 11 /*ed4f*/, 8 /*ed50*/,  9 /*ed51*/,  9 /*ed52*/,
    10 /*ed53*/, 9 /*ed54*/,  10 /*ed55*/, 10 /*ed56*/, 11 /*ed57*/,
    9 /*ed58*/,  10 /*ed59*/, 10 /*ed5a*/, 11 /*ed5b*/, 10 /*ed5c*/,
    11 /*ed5d*/, 11 /*ed5e*/, 12 /*ed5f*/, 8 /*ed60*/,  9 /*ed61*/,
    9 /*ed62*/,  10 /*ed63*/, 9 /*ed64*/,  10 /*ed65*/, 10 /*ed66*/,
    11 /*ed67*/, 9 /*ed68*/,  10 /*ed69*/, 10 /*ed6a*/, 11 /*ed6b*/,
    10 /*ed6c*/, 11 /*ed6d*/, 11 /*ed6e*/, 12 /*ed6f*/, 9 /*ed70*/,
    10 /*ed71*/, 10 /*ed72*/, 11 /*ed73*/, 10 /*ed74*/, 11 /*ed75*/,
    11 /*ed76*/, 12 /*ed77*/, 10 /*ed78*/, 11 /*ed79*/, 11 /*ed7a*/,
    12 /*ed7b*/, 11 /*ed7c*/, 12 /*ed7d*/, 12 /*ed7e*/, 13 /*ed7f*/,
    7 /*ed80*/,  8 /*ed81*/,  8 /*ed82*/,  9 /*ed83*/,  8 /*ed84*/,
    9 /*ed85*/,  9 /*ed86*/,  10 /*ed87*/, 8 /*ed88*/,  9 /*ed89*/,
    9 /*ed8a*/,  10 /*ed8b*/, 9 /*ed8c*/,  10 /*ed8d*/, 10 /*ed8e*/,
    11 /*ed8f*/, 8 /*ed90*/,  9 /*ed91*/,  9 /*ed92*/,  10 /*ed93*/,
    9 /*ed94*/,  10 /*ed95*/, 10 /*ed96*/, 11 /*ed97*/, 9 /*ed98*/,
    10 /*ed99*/, 10 /*ed9a*/, 11 /*ed9b*/, 10 /*ed9c*/, 11 /*ed9d*/,
    11 /*ed9e*/, 12 /*ed9f*/, 8 /*eda0*/,  9 /*eda1*/,  9 /*eda2*/,
    10 /*eda3*/, 9 /*eda4*/,  10 /*eda5*/, 10 /*eda6*/, 11 /*eda7*/,
    9 /*eda8*/,  10 /*eda9*/, 10 /*edaa*/, 11 /*edab*/, 10 /*edac*/,
    11 /*edad*/, 11 /*edae*/, 12 /*edaf*/, 9 /*edb0*/,  10 /*edb1*/,
    10 /*edb2*/, 11 /*edb3*/, 10 /*edb4*/, 11 /*edb5*/, 11 /*edb6*/,
    12 /*edb7*/, 10 /*edb8*/, 11 /*edb9*/, 11 /*edba*/, 12 /*edbb*/,
    11 /*edbc*/, 12 /*edbd*/, 12 /*edbe*/, 13 /*edbf*/, 8 /*edc0*/,
    9 /*edc1*/,  9 /*edc2*/,  10 /*edc3*/, 9 /*edc4*/,  10 /*edc5*/,
    10 /*edc6*/, 11 /*edc7*/, 9 /*edc8*/,  10 /*edc9*/, 10 /*edca*/,
    11 /*edcb*/, 10 /*edcc*/, 11 /*edcd*/, 11 /*edce*/, 12 /*edcf*/,
    9 /*edd0*/,  10 /*edd1*/, 10 /*edd2*/, 11 /*edd3*/, 10 /*edd4*/,
    11 /*edd5*/, 11 /*edd6*/, 12 /*edd7*/, 10 /*edd8*/, 11 /*edd9*/,
    11 /*edda*/, 12 /*eddb*/, 11 /*eddc*/, 12 /*eddd*/, 12 /*edde*/,
    13 /*eddf*/, 9 /*ede0*/,  10 /*ede1*/, 10 /*ede2*/, 11 /*ede3*/,
    10 /*ede4*/, 11 /*ede5*/, 11 /*ede6*/, 12 /*ede7*/, 10 /*ede8*/,
    11 /*ede9*/, 11 /*edea*/, 12 /*edeb*/, 11 /*edec*/, 12 /*eded*/,
    12 /*edee*/, 13 /*edef*/, 10 /*edf0*/, 11 /*edf1*/, 11 /*edf2*/,
    12 /*edf3*/, 11 /*edf4*/, 12 /*edf5*/, 12 /*edf6*/, 13 /*edf7*/,
    11 /*edf8*/, 12 /*edf9*/, 12 /*edfa*/, 13 /*edfb*/, 12 /*edfc*/,
    13 /*edfd*/, 13 /*edfe*/, 14 /*edff*/, 6 /*ee00*/,  7 /*ee01*/,
    7 /*ee02*/,  8 /*ee03*/,  7 /*ee04*/,  8 /*ee05*/,  8 /*ee06*/,
    9 /*ee07*/,  7 /*ee08*/,  8 /*ee09*/,  8 /*ee0a*/,  9 /*ee0b*/,
    8 /*ee0c*/,  9 /*ee0d*/,  9 /*ee0e*/,  10 /*ee0f*/, 7 /*ee10*/,
    8 /*ee11*/,  8 /*ee12*/,  9 /*ee13*/,  8 /*ee14*/,  9 /*ee15*/,
    9 /*ee16*/,  10 /*ee17*/, 8 /*ee18*/,  9 /*ee19*/,  9 /*ee1a*/,
    10 /*ee1b*/, 9 /*ee1c*/,  10 /*ee1d*/, 10 /*ee1e*/, 11 /*ee1f*/,
    7 /*ee20*/,  8 /*ee21*/,  8 /*ee22*/,  9 /*ee23*/,  8 /*ee24*/,
    9 /*ee25*/,  9 /*ee26*/,  10 /*ee27*/, 8 /*ee28*/,  9 /*ee29*/,
    9 /*ee2a*/,  10 /*ee2b*/, 9 /*ee2c*/,  10 /*ee2d*/, 10 /*ee2e*/,
    11 /*ee2f*/, 8 /*ee30*/,  9 /*ee31*/,  9 /*ee32*/,  10 /*ee33*/,
    9 /*ee34*/,  10 /*ee35*/, 10 /*ee36*/, 11 /*ee37*/, 9 /*ee38*/,
    10 /*ee39*/, 10 /*ee3a*/, 11 /*ee3b*/, 10 /*ee3c*/, 11 /*ee3d*/,
    11 /*ee3e*/, 12 /*ee3f*/, 7 /*ee40*/,  8 /*ee41*/,  8 /*ee42*/,
    9 /*ee43*/,  8 /*ee44*/,  9 /*ee45*/,  9 /*ee46*/,  10 /*ee47*/,
    8 /*ee48*/,  9 /*ee49*/,  9 /*ee4a*/,  10 /*ee4b*/, 9 /*ee4c*/,
    10 /*ee4d*/, 10 /*ee4e*/, 11 /*ee4f*/, 8 /*ee50*/,  9 /*ee51*/,
    9 /*ee52*/,  10 /*ee53*/, 9 /*ee54*/,  10 /*ee55*/, 10 /*ee56*/,
    11 /*ee57*/, 9 /*ee58*/,  10 /*ee59*/, 10 /*ee5a*/, 11 /*ee5b*/,
    10 /*ee5c*/, 11 /*ee5d*/, 11 /*ee5e*/, 12 /*ee5f*/, 8 /*ee60*/,
    9 /*ee61*/,  9 /*ee62*/,  10 /*ee63*/, 9 /*ee64*/,  10 /*ee65*/,
    10 /*ee66*/, 11 /*ee67*/, 9 /*ee68*/,  10 /*ee69*/, 10 /*ee6a*/,
    11 /*ee6b*/, 10 /*ee6c*/, 11 /*ee6d*/, 11 /*ee6e*/, 12 /*ee6f*/,
    9 /*ee70*/,  10 /*ee71*/, 10 /*ee72*/, 11 /*ee73*/, 10 /*ee74*/,
    11 /*ee75*/, 11 /*ee76*/, 12 /*ee77*/, 10 /*ee78*/, 11 /*ee79*/,
    11 /*ee7a*/, 12 /*ee7b*/, 11 /*ee7c*/, 12 /*ee7d*/, 12 /*ee7e*/,
    13 /*ee7f*/, 7 /*ee80*/,  8 /*ee81*/,  8 /*ee82*/,  9 /*ee83*/,
    8 /*ee84*/,  9 /*ee85*/,  9 /*ee86*/,  10 /*ee87*/, 8 /*ee88*/,
    9 /*ee89*/,  9 /*ee8a*/,  10 /*ee8b*/, 9 /*ee8c*/,  10 /*ee8d*/,
    10 /*ee8e*/, 11 /*ee8f*/, 8 /*ee90*/,  9 /*ee91*/,  9 /*ee92*/,
    10 /*ee93*/, 9 /*ee94*/,  10 /*ee95*/, 10 /*ee96*/, 11 /*ee97*/,
    9 /*ee98*/,  10 /*ee99*/, 10 /*ee9a*/, 11 /*ee9b*/, 10 /*ee9c*/,
    11 /*ee9d*/, 11 /*ee9e*/, 12 /*ee9f*/, 8 /*eea0*/,  9 /*eea1*/,
    9 /*eea2*/,  10 /*eea3*/, 9 /*eea4*/,  10 /*eea5*/, 10 /*eea6*/,
    11 /*eea7*/, 9 /*eea8*/,  10 /*eea9*/, 10 /*eeaa*/, 11 /*eeab*/,
    10 /*eeac*/, 11 /*eead*/, 11 /*eeae*/, 12 /*eeaf*/, 9 /*eeb0*/,
    10 /*eeb1*/, 10 /*eeb2*/, 11 /*eeb3*/, 10 /*eeb4*/, 11 /*eeb5*/,
    11 /*eeb6*/, 12 /*eeb7*/, 10 /*eeb8*/, 11 /*eeb9*/, 11 /*eeba*/,
    12 /*eebb*/, 11 /*eebc*/, 12 /*eebd*/, 12 /*eebe*/, 13 /*eebf*/,
    8 /*eec0*/,  9 /*eec1*/,  9 /*eec2*/,  10 /*eec3*/, 9 /*eec4*/,
    10 /*eec5*/, 10 /*eec6*/, 11 /*eec7*/, 9 /*eec8*/,  10 /*eec9*/,
    10 /*eeca*/, 11 /*eecb*/, 10 /*eecc*/, 11 /*eecd*/, 11 /*eece*/,
    12 /*eecf*/, 9 /*eed0*/,  10 /*eed1*/, 10 /*eed2*/, 11 /*eed3*/,
    10 /*eed4*/, 11 /*eed5*/, 11 /*eed6*/, 12 /*eed7*/, 10 /*eed8*/,
    11 /*eed9*/, 11 /*eeda*/, 12 /*eedb*/, 11 /*eedc*/, 12 /*eedd*/,
    12 /*eede*/, 13 /*eedf*/, 9 /*eee0*/,  10 /*eee1*/, 10 /*eee2*/,
    11 /*eee3*/, 10 /*eee4*/, 11 /*eee5*/, 11 /*eee6*/, 12 /*eee7*/,
    10 /*eee8*/, 11 /*eee9*/, 11 /*eeea*/, 12 /*eeeb*/, 11 /*eeec*/,
    12 /*eeed*/, 12 /*eeee*/, 13 /*eeef*/, 10 /*eef0*/, 11 /*eef1*/,
    11 /*eef2*/, 12 /*eef3*/, 11 /*eef4*/, 12 /*eef5*/, 12 /*eef6*/,
    13 /*eef7*/, 11 /*eef8*/, 12 /*eef9*/, 12 /*eefa*/, 13 /*eefb*/,
    12 /*eefc*/, 13 /*eefd*/, 13 /*eefe*/, 14 /*eeff*/, 7 /*ef00*/,
    8 /*ef01*/,  8 /*ef02*/,  9 /*ef03*/,  8 /*ef04*/,  9 /*ef05*/,
    9 /*ef06*/,  10 /*ef07*/, 8 /*ef08*/,  9 /*ef09*/,  9 /*ef0a*/,
    10 /*ef0b*/, 9 /*ef0c*/,  10 /*ef0d*/, 10 /*ef0e*/, 11 /*ef0f*/,
    8 /*ef10*/,  9 /*ef11*/,  9 /*ef12*/,  10 /*ef13*/, 9 /*ef14*/,
    10 /*ef15*/, 10 /*ef16*/, 11 /*ef17*/, 9 /*ef18*/,  10 /*ef19*/,
    10 /*ef1a*/, 11 /*ef1b*/, 10 /*ef1c*/, 11 /*ef1d*/, 11 /*ef1e*/,
    12 /*ef1f*/, 8 /*ef20*/,  9 /*ef21*/,  9 /*ef22*/,  10 /*ef23*/,
    9 /*ef24*/,  10 /*ef25*/, 10 /*ef26*/, 11 /*ef27*/, 9 /*ef28*/,
    10 /*ef29*/, 10 /*ef2a*/, 11 /*ef2b*/, 10 /*ef2c*/, 11 /*ef2d*/,
    11 /*ef2e*/, 12 /*ef2f*/, 9 /*ef30*/,  10 /*ef31*/, 10 /*ef32*/,
    11 /*ef33*/, 10 /*ef34*/, 11 /*ef35*/, 11 /*ef36*/, 12 /*ef37*/,
    10 /*ef38*/, 11 /*ef39*/, 11 /*ef3a*/, 12 /*ef3b*/, 11 /*ef3c*/,
    12 /*ef3d*/, 12 /*ef3e*/, 13 /*ef3f*/, 8 /*ef40*/,  9 /*ef41*/,
    9 /*ef42*/,  10 /*ef43*/, 9 /*ef44*/,  10 /*ef45*/, 10 /*ef46*/,
    11 /*ef47*/, 9 /*ef48*/,  10 /*ef49*/, 10 /*ef4a*/, 11 /*ef4b*/,
    10 /*ef4c*/, 11 /*ef4d*/, 11 /*ef4e*/, 12 /*ef4f*/, 9 /*ef50*/,
    10 /*ef51*/, 10 /*ef52*/, 11 /*ef53*/, 10 /*ef54*/, 11 /*ef55*/,
    11 /*ef56*/, 12 /*ef57*/, 10 /*ef58*/, 11 /*ef59*/, 11 /*ef5a*/,
    12 /*ef5b*/, 11 /*ef5c*/, 12 /*ef5d*/, 12 /*ef5e*/, 13 /*ef5f*/,
    9 /*ef60*/,  10 /*ef61*/, 10 /*ef62*/, 11 /*ef63*/, 10 /*ef64*/,
    11 /*ef65*/, 11 /*ef66*/, 12 /*ef67*/, 10 /*ef68*/, 11 /*ef69*/,
    11 /*ef6a*/, 12 /*ef6b*/, 11 /*ef6c*/, 12 /*ef6d*/, 12 /*ef6e*/,
    13 /*ef6f*/, 10 /*ef70*/, 11 /*ef71*/, 11 /*ef72*/, 12 /*ef73*/,
    11 /*ef74*/, 12 /*ef75*/, 12 /*ef76*/, 13 /*ef77*/, 11 /*ef78*/,
    12 /*ef79*/, 12 /*ef7a*/, 13 /*ef7b*/, 12 /*ef7c*/, 13 /*ef7d*/,
    13 /*ef7e*/, 14 /*ef7f*/, 8 /*ef80*/,  9 /*ef81*/,  9 /*ef82*/,
    10 /*ef83*/, 9 /*ef84*/,  10 /*ef85*/, 10 /*ef86*/, 11 /*ef87*/,
    9 /*ef88*/,  10 /*ef89*/, 10 /*ef8a*/, 11 /*ef8b*/, 10 /*ef8c*/,
    11 /*ef8d*/, 11 /*ef8e*/, 12 /*ef8f*/, 9 /*ef90*/,  10 /*ef91*/,
    10 /*ef92*/, 11 /*ef93*/, 10 /*ef94*/, 11 /*ef95*/, 11 /*ef96*/,
    12 /*ef97*/, 10 /*ef98*/, 11 /*ef99*/, 11 /*ef9a*/, 12 /*ef9b*/,
    11 /*ef9c*/, 12 /*ef9d*/, 12 /*ef9e*/, 13 /*ef9f*/, 9 /*efa0*/,
    10 /*efa1*/, 10 /*efa2*/, 11 /*efa3*/, 10 /*efa4*/, 11 /*efa5*/,
    11 /*efa6*/, 12 /*efa7*/, 10 /*efa8*/, 11 /*efa9*/, 11 /*efaa*/,
    12 /*efab*/, 11 /*efac*/, 12 /*efad*/, 12 /*efae*/, 13 /*efaf*/,
    10 /*efb0*/, 11 /*efb1*/, 11 /*efb2*/, 12 /*efb3*/, 11 /*efb4*/,
    12 /*efb5*/, 12 /*efb6*/, 13 /*efb7*/, 11 /*efb8*/, 12 /*efb9*/,
    12 /*efba*/, 13 /*efbb*/, 12 /*efbc*/, 13 /*efbd*/, 13 /*efbe*/,
    14 /*efbf*/, 9 /*efc0*/,  10 /*efc1*/, 10 /*efc2*/, 11 /*efc3*/,
    10 /*efc4*/, 11 /*efc5*/, 11 /*efc6*/, 12 /*efc7*/, 10 /*efc8*/,
    11 /*efc9*/, 11 /*efca*/, 12 /*efcb*/, 11 /*efcc*/, 12 /*efcd*/,
    12 /*efce*/, 13 /*efcf*/, 10 /*efd0*/, 11 /*efd1*/, 11 /*efd2*/,
    12 /*efd3*/, 11 /*efd4*/, 12 /*efd5*/, 12 /*efd6*/, 13 /*efd7*/,
    11 /*efd8*/, 12 /*efd9*/, 12 /*efda*/, 13 /*efdb*/, 12 /*efdc*/,
    13 /*efdd*/, 13 /*efde*/, 14 /*efdf*/, 10 /*efe0*/, 11 /*efe1*/,
    11 /*efe2*/, 12 /*efe3*/, 11 /*efe4*/, 12 /*efe5*/, 12 /*efe6*/,
    13 /*efe7*/, 11 /*efe8*/, 12 /*efe9*/, 12 /*efea*/, 13 /*efeb*/,
    12 /*efec*/, 13 /*efed*/, 13 /*efee*/, 14 /*efef*/, 11 /*eff0*/,
    12 /*eff1*/, 12 /*eff2*/, 13 /*eff3*/, 12 /*eff4*/, 13 /*eff5*/,
    13 /*eff6*/, 14 /*eff7*/, 12 /*eff8*/, 13 /*eff9*/, 13 /*effa*/,
    14 /*effb*/, 13 /*effc*/, 14 /*effd*/, 14 /*effe*/, 15 /*efff*/,
    4 /*f000*/,  5 /*f001*/,  5 /*f002*/,  6 /*f003*/,  5 /*f004*/,
    6 /*f005*/,  6 /*f006*/,  7 /*f007*/,  5 /*f008*/,  6 /*f009*/,
    6 /*f00a*/,  7 /*f00b*/,  6 /*f00c*/,  7 /*f00d*/,  7 /*f00e*/,
    8 /*f00f*/,  5 /*f010*/,  6 /*f011*/,  6 /*f012*/,  7 /*f013*/,
    6 /*f014*/,  7 /*f015*/,  7 /*f016*/,  8 /*f017*/,  6 /*f018*/,
    7 /*f019*/,  7 /*f01a*/,  8 /*f01b*/,  7 /*f01c*/,  8 /*f01d*/,
    8 /*f01e*/,  9 /*f01f*/,  5 /*f020*/,  6 /*f021*/,  6 /*f022*/,
    7 /*f023*/,  6 /*f024*/,  7 /*f025*/,  7 /*f026*/,  8 /*f027*/,
    6 /*f028*/,  7 /*f029*/,  7 /*f02a*/,  8 /*f02b*/,  7 /*f02c*/,
    8 /*f02d*/,  8 /*f02e*/,  9 /*f02f*/,  6 /*f030*/,  7 /*f031*/,
    7 /*f032*/,  8 /*f033*/,  7 /*f034*/,  8 /*f035*/,  8 /*f036*/,
    9 /*f037*/,  7 /*f038*/,  8 /*f039*/,  8 /*f03a*/,  9 /*f03b*/,
    8 /*f03c*/,  9 /*f03d*/,  9 /*f03e*/,  10 /*f03f*/, 5 /*f040*/,
    6 /*f041*/,  6 /*f042*/,  7 /*f043*/,  6 /*f044*/,  7 /*f045*/,
    7 /*f046*/,  8 /*f047*/,  6 /*f048*/,  7 /*f049*/,  7 /*f04a*/,
    8 /*f04b*/,  7 /*f04c*/,  8 /*f04d*/,  8 /*f04e*/,  9 /*f04f*/,
    6 /*f050*/,  7 /*f051*/,  7 /*f052*/,  8 /*f053*/,  7 /*f054*/,
    8 /*f055*/,  8 /*f056*/,  9 /*f057*/,  7 /*f058*/,  8 /*f059*/,
    8 /*f05a*/,  9 /*f05b*/,  8 /*f05c*/,  9 /*f05d*/,  9 /*f05e*/,
    10 /*f05f*/, 6 /*f060*/,  7 /*f061*/,  7 /*f062*/,  8 /*f063*/,
    7 /*f064*/,  8 /*f065*/,  8 /*f066*/,  9 /*f067*/,  7 /*f068*/,
    8 /*f069*/,  8 /*f06a*/,  9 /*f06b*/,  8 /*f06c*/,  9 /*f06d*/,
    9 /*f06e*/,  10 /*f06f*/, 7 /*f070*/,  8 /*f071*/,  8 /*f072*/,
    9 /*f073*/,  8 /*f074*/,  9 /*f075*/,  9 /*f076*/,  10 /*f077*/,
    8 /*f078*/,  9 /*f079*/,  9 /*f07a*/,  10 /*f07b*/, 9 /*f07c*/,
    10 /*f07d*/, 10 /*f07e*/, 11 /*f07f*/, 5 /*f080*/,  6 /*f081*/,
    6 /*f082*/,  7 /*f083*/,  6 /*f084*/,  7 /*f085*/,  7 /*f086*/,
    8 /*f087*/,  6 /*f088*/,  7 /*f089*/,  7 /*f08a*/,  8 /*f08b*/,
    7 /*f08c*/,  8 /*f08d*/,  8 /*f08e*/,  9 /*f08f*/,  6 /*f090*/,
    7 /*f091*/,  7 /*f092*/,  8 /*f093*/,  7 /*f094*/,  8 /*f095*/,
    8 /*f096*/,  9 /*f097*/,  7 /*f098*/,  8 /*f099*/,  8 /*f09a*/,
    9 /*f09b*/,  8 /*f09c*/,  9 /*f09d*/,  9 /*f09e*/,  10 /*f09f*/,
    6 /*f0a0*/,  7 /*f0a1*/,  7 /*f0a2*/,  8 /*f0a3*/,  7 /*f0a4*/,
    8 /*f0a5*/,  8 /*f0a6*/,  9 /*f0a7*/,  7 /*f0a8*/,  8 /*f0a9*/,
    8 /*f0aa*/,  9 /*f0ab*/,  8 /*f0ac*/,  9 /*f0ad*/,  9 /*f0ae*/,
    10 /*f0af*/, 7 /*f0b0*/,  8 /*f0b1*/,  8 /*f0b2*/,  9 /*f0b3*/,
    8 /*f0b4*/,  9 /*f0b5*/,  9 /*f0b6*/,  10 /*f0b7*/, 8 /*f0b8*/,
    9 /*f0b9*/,  9 /*f0ba*/,  10 /*f0bb*/, 9 /*f0bc*/,  10 /*f0bd*/,
    10 /*f0be*/, 11 /*f0bf*/, 6 /*f0c0*/,  7 /*f0c1*/,  7 /*f0c2*/,
    8 /*f0c3*/,  7 /*f0c4*/,  8 /*f0c5*/,  8 /*f0c6*/,  9 /*f0c7*/,
    7 /*f0c8*/,  8 /*f0c9*/,  8 /*f0ca*/,  9 /*f0cb*/,  8 /*f0cc*/,
    9 /*f0cd*/,  9 /*f0ce*/,  10 /*f0cf*/, 7 /*f0d0*/,  8 /*f0d1*/,
    8 /*f0d2*/,  9 /*f0d3*/,  8 /*f0d4*/,  9 /*f0d5*/,  9 /*f0d6*/,
    10 /*f0d7*/, 8 /*f0d8*/,  9 /*f0d9*/,  9 /*f0da*/,  10 /*f0db*/,
    9 /*f0dc*/,  10 /*f0dd*/, 10 /*f0de*/, 11 /*f0df*/, 7 /*f0e0*/,
    8 /*f0e1*/,  8 /*f0e2*/,  9 /*f0e3*/,  8 /*f0e4*/,  9 /*f0e5*/,
    9 /*f0e6*/,  10 /*f0e7*/, 8 /*f0e8*/,  9 /*f0e9*/,  9 /*f0ea*/,
    10 /*f0eb*/, 9 /*f0ec*/,  10 /*f0ed*/, 10 /*f0ee*/, 11 /*f0ef*/,
    8 /*f0f0*/,  9 /*f0f1*/,  9 /*f0f2*/,  10 /*f0f3*/, 9 /*f0f4*/,
    10 /*f0f5*/, 10 /*f0f6*/, 11 /*f0f7*/, 9 /*f0f8*/,  10 /*f0f9*/,
    10 /*f0fa*/, 11 /*f0fb*/, 10 /*f0fc*/, 11 /*f0fd*/, 11 /*f0fe*/,
    12 /*f0ff*/, 5 /*f100*/,  6 /*f101*/,  6 /*f102*/,  7 /*f103*/,
    6 /*f104*/,  7 /*f105*/,  7 /*f106*/,  8 /*f107*/,  6 /*f108*/,
    7 /*f109*/,  7 /*f10a*/,  8 /*f10b*/,  7 /*f10c*/,  8 /*f10d*/,
    8 /*f10e*/,  9 /*f10f*/,  6 /*f110*/,  7 /*f111*/,  7 /*f112*/,
    8 /*f113*/,  7 /*f114*/,  8 /*f115*/,  8 /*f116*/,  9 /*f117*/,
    7 /*f118*/,  8 /*f119*/,  8 /*f11a*/,  9 /*f11b*/,  8 /*f11c*/,
    9 /*f11d*/,  9 /*f11e*/,  10 /*f11f*/, 6 /*f120*/,  7 /*f121*/,
    7 /*f122*/,  8 /*f123*/,  7 /*f124*/,  8 /*f125*/,  8 /*f126*/,
    9 /*f127*/,  7 /*f128*/,  8 /*f129*/,  8 /*f12a*/,  9 /*f12b*/,
    8 /*f12c*/,  9 /*f12d*/,  9 /*f12e*/,  10 /*f12f*/, 7 /*f130*/,
    8 /*f131*/,  8 /*f132*/,  9 /*f133*/,  8 /*f134*/,  9 /*f135*/,
    9 /*f136*/,  10 /*f137*/, 8 /*f138*/,  9 /*f139*/,  9 /*f13a*/,
    10 /*f13b*/, 9 /*f13c*/,  10 /*f13d*/, 10 /*f13e*/, 11 /*f13f*/,
    6 /*f140*/,  7 /*f141*/,  7 /*f142*/,  8 /*f143*/,  7 /*f144*/,
    8 /*f145*/,  8 /*f146*/,  9 /*f147*/,  7 /*f148*/,  8 /*f149*/,
    8 /*f14a*/,  9 /*f14b*/,  8 /*f14c*/,  9 /*f14d*/,  9 /*f14e*/,
    10 /*f14f*/, 7 /*f150*/,  8 /*f151*/,  8 /*f152*/,  9 /*f153*/,
    8 /*f154*/,  9 /*f155*/,  9 /*f156*/,  10 /*f157*/, 8 /*f158*/,
    9 /*f159*/,  9 /*f15a*/,  10 /*f15b*/, 9 /*f15c*/,  10 /*f15d*/,
    10 /*f15e*/, 11 /*f15f*/, 7 /*f160*/,  8 /*f161*/,  8 /*f162*/,
    9 /*f163*/,  8 /*f164*/,  9 /*f165*/,  9 /*f166*/,  10 /*f167*/,
    8 /*f168*/,  9 /*f169*/,  9 /*f16a*/,  10 /*f16b*/, 9 /*f16c*/,
    10 /*f16d*/, 10 /*f16e*/, 11 /*f16f*/, 8 /*f170*/,  9 /*f171*/,
    9 /*f172*/,  10 /*f173*/, 9 /*f174*/,  10 /*f175*/, 10 /*f176*/,
    11 /*f177*/, 9 /*f178*/,  10 /*f179*/, 10 /*f17a*/, 11 /*f17b*/,
    10 /*f17c*/, 11 /*f17d*/, 11 /*f17e*/, 12 /*f17f*/, 6 /*f180*/,
    7 /*f181*/,  7 /*f182*/,  8 /*f183*/,  7 /*f184*/,  8 /*f185*/,
    8 /*f186*/,  9 /*f187*/,  7 /*f188*/,  8 /*f189*/,  8 /*f18a*/,
    9 /*f18b*/,  8 /*f18c*/,  9 /*f18d*/,  9 /*f18e*/,  10 /*f18f*/,
    7 /*f190*/,  8 /*f191*/,  8 /*f192*/,  9 /*f193*/,  8 /*f194*/,
    9 /*f195*/,  9 /*f196*/,  10 /*f197*/, 8 /*f198*/,  9 /*f199*/,
    9 /*f19a*/,  10 /*f19b*/, 9 /*f19c*/,  10 /*f19d*/, 10 /*f19e*/,
    11 /*f19f*/, 7 /*f1a0*/,  8 /*f1a1*/,  8 /*f1a2*/,  9 /*f1a3*/,
    8 /*f1a4*/,  9 /*f1a5*/,  9 /*f1a6*/,  10 /*f1a7*/, 8 /*f1a8*/,
    9 /*f1a9*/,  9 /*f1aa*/,  10 /*f1ab*/, 9 /*f1ac*/,  10 /*f1ad*/,
    10 /*f1ae*/, 11 /*f1af*/, 8 /*f1b0*/,  9 /*f1b1*/,  9 /*f1b2*/,
    10 /*f1b3*/, 9 /*f1b4*/,  10 /*f1b5*/, 10 /*f1b6*/, 11 /*f1b7*/,
    9 /*f1b8*/,  10 /*f1b9*/, 10 /*f1ba*/, 11 /*f1bb*/, 10 /*f1bc*/,
    11 /*f1bd*/, 11 /*f1be*/, 12 /*f1bf*/, 7 /*f1c0*/,  8 /*f1c1*/,
    8 /*f1c2*/,  9 /*f1c3*/,  8 /*f1c4*/,  9 /*f1c5*/,  9 /*f1c6*/,
    10 /*f1c7*/, 8 /*f1c8*/,  9 /*f1c9*/,  9 /*f1ca*/,  10 /*f1cb*/,
    9 /*f1cc*/,  10 /*f1cd*/, 10 /*f1ce*/, 11 /*f1cf*/, 8 /*f1d0*/,
    9 /*f1d1*/,  9 /*f1d2*/,  10 /*f1d3*/, 9 /*f1d4*/,  10 /*f1d5*/,
    10 /*f1d6*/, 11 /*f1d7*/, 9 /*f1d8*/,  10 /*f1d9*/, 10 /*f1da*/,
    11 /*f1db*/, 10 /*f1dc*/, 11 /*f1dd*/, 11 /*f1de*/, 12 /*f1df*/,
    8 /*f1e0*/,  9 /*f1e1*/,  9 /*f1e2*/,  10 /*f1e3*/, 9 /*f1e4*/,
    10 /*f1e5*/, 10 /*f1e6*/, 11 /*f1e7*/, 9 /*f1e8*/,  10 /*f1e9*/,
    10 /*f1ea*/, 11 /*f1eb*/, 10 /*f1ec*/, 11 /*f1ed*/, 11 /*f1ee*/,
    12 /*f1ef*/, 9 /*f1f0*/,  10 /*f1f1*/, 10 /*f1f2*/, 11 /*f1f3*/,
    10 /*f1f4*/, 11 /*f1f5*/, 11 /*f1f6*/, 12 /*f1f7*/, 10 /*f1f8*/,
    11 /*f1f9*/, 11 /*f1fa*/, 12 /*f1fb*/, 11 /*f1fc*/, 12 /*f1fd*/,
    12 /*f1fe*/, 13 /*f1ff*/, 5 /*f200*/,  6 /*f201*/,  6 /*f202*/,
    7 /*f203*/,  6 /*f204*/,  7 /*f205*/,  7 /*f206*/,  8 /*f207*/,
    6 /*f208*/,  7 /*f209*/,  7 /*f20a*/,  8 /*f20b*/,  7 /*f20c*/,
    8 /*f20d*/,  8 /*f20e*/,  9 /*f20f*/,  6 /*f210*/,  7 /*f211*/,
    7 /*f212*/,  8 /*f213*/,  7 /*f214*/,  8 /*f215*/,  8 /*f216*/,
    9 /*f217*/,  7 /*f218*/,  8 /*f219*/,  8 /*f21a*/,  9 /*f21b*/,
    8 /*f21c*/,  9 /*f21d*/,  9 /*f21e*/,  10 /*f21f*/, 6 /*f220*/,
    7 /*f221*/,  7 /*f222*/,  8 /*f223*/,  7 /*f224*/,  8 /*f225*/,
    8 /*f226*/,  9 /*f227*/,  7 /*f228*/,  8 /*f229*/,  8 /*f22a*/,
    9 /*f22b*/,  8 /*f22c*/,  9 /*f22d*/,  9 /*f22e*/,  10 /*f22f*/,
    7 /*f230*/,  8 /*f231*/,  8 /*f232*/,  9 /*f233*/,  8 /*f234*/,
    9 /*f235*/,  9 /*f236*/,  10 /*f237*/, 8 /*f238*/,  9 /*f239*/,
    9 /*f23a*/,  10 /*f23b*/, 9 /*f23c*/,  10 /*f23d*/, 10 /*f23e*/,
    11 /*f23f*/, 6 /*f240*/,  7 /*f241*/,  7 /*f242*/,  8 /*f243*/,
    7 /*f244*/,  8 /*f245*/,  8 /*f246*/,  9 /*f247*/,  7 /*f248*/,
    8 /*f249*/,  8 /*f24a*/,  9 /*f24b*/,  8 /*f24c*/,  9 /*f24d*/,
    9 /*f24e*/,  10 /*f24f*/, 7 /*f250*/,  8 /*f251*/,  8 /*f252*/,
    9 /*f253*/,  8 /*f254*/,  9 /*f255*/,  9 /*f256*/,  10 /*f257*/,
    8 /*f258*/,  9 /*f259*/,  9 /*f25a*/,  10 /*f25b*/, 9 /*f25c*/,
    10 /*f25d*/, 10 /*f25e*/, 11 /*f25f*/, 7 /*f260*/,  8 /*f261*/,
    8 /*f262*/,  9 /*f263*/,  8 /*f264*/,  9 /*f265*/,  9 /*f266*/,
    10 /*f267*/, 8 /*f268*/,  9 /*f269*/,  9 /*f26a*/,  10 /*f26b*/,
    9 /*f26c*/,  10 /*f26d*/, 10 /*f26e*/, 11 /*f26f*/, 8 /*f270*/,
    9 /*f271*/,  9 /*f272*/,  10 /*f273*/, 9 /*f274*/,  10 /*f275*/,
    10 /*f276*/, 11 /*f277*/, 9 /*f278*/,  10 /*f279*/, 10 /*f27a*/,
    11 /*f27b*/, 10 /*f27c*/, 11 /*f27d*/, 11 /*f27e*/, 12 /*f27f*/,
    6 /*f280*/,  7 /*f281*/,  7 /*f282*/,  8 /*f283*/,  7 /*f284*/,
    8 /*f285*/,  8 /*f286*/,  9 /*f287*/,  7 /*f288*/,  8 /*f289*/,
    8 /*f28a*/,  9 /*f28b*/,  8 /*f28c*/,  9 /*f28d*/,  9 /*f28e*/,
    10 /*f28f*/, 7 /*f290*/,  8 /*f291*/,  8 /*f292*/,  9 /*f293*/,
    8 /*f294*/,  9 /*f295*/,  9 /*f296*/,  10 /*f297*/, 8 /*f298*/,
    9 /*f299*/,  9 /*f29a*/,  10 /*f29b*/, 9 /*f29c*/,  10 /*f29d*/,
    10 /*f29e*/, 11 /*f29f*/, 7 /*f2a0*/,  8 /*f2a1*/,  8 /*f2a2*/,
    9 /*f2a3*/,  8 /*f2a4*/,  9 /*f2a5*/,  9 /*f2a6*/,  10 /*f2a7*/,
    8 /*f2a8*/,  9 /*f2a9*/,  9 /*f2aa*/,  10 /*f2ab*/, 9 /*f2ac*/,
    10 /*f2ad*/, 10 /*f2ae*/, 11 /*f2af*/, 8 /*f2b0*/,  9 /*f2b1*/,
    9 /*f2b2*/,  10 /*f2b3*/, 9 /*f2b4*/,  10 /*f2b5*/, 10 /*f2b6*/,
    11 /*f2b7*/, 9 /*f2b8*/,  10 /*f2b9*/, 10 /*f2ba*/, 11 /*f2bb*/,
    10 /*f2bc*/, 11 /*f2bd*/, 11 /*f2be*/, 12 /*f2bf*/, 7 /*f2c0*/,
    8 /*f2c1*/,  8 /*f2c2*/,  9 /*f2c3*/,  8 /*f2c4*/,  9 /*f2c5*/,
    9 /*f2c6*/,  10 /*f2c7*/, 8 /*f2c8*/,  9 /*f2c9*/,  9 /*f2ca*/,
    10 /*f2cb*/, 9 /*f2cc*/,  10 /*f2cd*/, 10 /*f2ce*/, 11 /*f2cf*/,
    8 /*f2d0*/,  9 /*f2d1*/,  9 /*f2d2*/,  10 /*f2d3*/, 9 /*f2d4*/,
    10 /*f2d5*/, 10 /*f2d6*/, 11 /*f2d7*/, 9 /*f2d8*/,  10 /*f2d9*/,
    10 /*f2da*/, 11 /*f2db*/, 10 /*f2dc*/, 11 /*f2dd*/, 11 /*f2de*/,
    12 /*f2df*/, 8 /*f2e0*/,  9 /*f2e1*/,  9 /*f2e2*/,  10 /*f2e3*/,
    9 /*f2e4*/,  10 /*f2e5*/, 10 /*f2e6*/, 11 /*f2e7*/, 9 /*f2e8*/,
    10 /*f2e9*/, 10 /*f2ea*/, 11 /*f2eb*/, 10 /*f2ec*/, 11 /*f2ed*/,
    11 /*f2ee*/, 12 /*f2ef*/, 9 /*f2f0*/,  10 /*f2f1*/, 10 /*f2f2*/,
    11 /*f2f3*/, 10 /*f2f4*/, 11 /*f2f5*/, 11 /*f2f6*/, 12 /*f2f7*/,
    10 /*f2f8*/, 11 /*f2f9*/, 11 /*f2fa*/, 12 /*f2fb*/, 11 /*f2fc*/,
    12 /*f2fd*/, 12 /*f2fe*/, 13 /*f2ff*/, 6 /*f300*/,  7 /*f301*/,
    7 /*f302*/,  8 /*f303*/,  7 /*f304*/,  8 /*f305*/,  8 /*f306*/,
    9 /*f307*/,  7 /*f308*/,  8 /*f309*/,  8 /*f30a*/,  9 /*f30b*/,
    8 /*f30c*/,  9 /*f30d*/,  9 /*f30e*/,  10 /*f30f*/, 7 /*f310*/,
    8 /*f311*/,  8 /*f312*/,  9 /*f313*/,  8 /*f314*/,  9 /*f315*/,
    9 /*f316*/,  10 /*f317*/, 8 /*f318*/,  9 /*f319*/,  9 /*f31a*/,
    10 /*f31b*/, 9 /*f31c*/,  10 /*f31d*/, 10 /*f31e*/, 11 /*f31f*/,
    7 /*f320*/,  8 /*f321*/,  8 /*f322*/,  9 /*f323*/,  8 /*f324*/,
    9 /*f325*/,  9 /*f326*/,  10 /*f327*/, 8 /*f328*/,  9 /*f329*/,
    9 /*f32a*/,  10 /*f32b*/, 9 /*f32c*/,  10 /*f32d*/, 10 /*f32e*/,
    11 /*f32f*/, 8 /*f330*/,  9 /*f331*/,  9 /*f332*/,  10 /*f333*/,
    9 /*f334*/,  10 /*f335*/, 10 /*f336*/, 11 /*f337*/, 9 /*f338*/,
    10 /*f339*/, 10 /*f33a*/, 11 /*f33b*/, 10 /*f33c*/, 11 /*f33d*/,
    11 /*f33e*/, 12 /*f33f*/, 7 /*f340*/,  8 /*f341*/,  8 /*f342*/,
    9 /*f343*/,  8 /*f344*/,  9 /*f345*/,  9 /*f346*/,  10 /*f347*/,
    8 /*f348*/,  9 /*f349*/,  9 /*f34a*/,  10 /*f34b*/, 9 /*f34c*/,
    10 /*f34d*/, 10 /*f34e*/, 11 /*f34f*/, 8 /*f350*/,  9 /*f351*/,
    9 /*f352*/,  10 /*f353*/, 9 /*f354*/,  10 /*f355*/, 10 /*f356*/,
    11 /*f357*/, 9 /*f358*/,  10 /*f359*/, 10 /*f35a*/, 11 /*f35b*/,
    10 /*f35c*/, 11 /*f35d*/, 11 /*f35e*/, 12 /*f35f*/, 8 /*f360*/,
    9 /*f361*/,  9 /*f362*/,  10 /*f363*/, 9 /*f364*/,  10 /*f365*/,
    10 /*f366*/, 11 /*f367*/, 9 /*f368*/,  10 /*f369*/, 10 /*f36a*/,
    11 /*f36b*/, 10 /*f36c*/, 11 /*f36d*/, 11 /*f36e*/, 12 /*f36f*/,
    9 /*f370*/,  10 /*f371*/, 10 /*f372*/, 11 /*f373*/, 10 /*f374*/,
    11 /*f375*/, 11 /*f376*/, 12 /*f377*/, 10 /*f378*/, 11 /*f379*/,
    11 /*f37a*/, 12 /*f37b*/, 11 /*f37c*/, 12 /*f37d*/, 12 /*f37e*/,
    13 /*f37f*/, 7 /*f380*/,  8 /*f381*/,  8 /*f382*/,  9 /*f383*/,
    8 /*f384*/,  9 /*f385*/,  9 /*f386*/,  10 /*f387*/, 8 /*f388*/,
    9 /*f389*/,  9 /*f38a*/,  10 /*f38b*/, 9 /*f38c*/,  10 /*f38d*/,
    10 /*f38e*/, 11 /*f38f*/, 8 /*f390*/,  9 /*f391*/,  9 /*f392*/,
    10 /*f393*/, 9 /*f394*/,  10 /*f395*/, 10 /*f396*/, 11 /*f397*/,
    9 /*f398*/,  10 /*f399*/, 10 /*f39a*/, 11 /*f39b*/, 10 /*f39c*/,
    11 /*f39d*/, 11 /*f39e*/, 12 /*f39f*/, 8 /*f3a0*/,  9 /*f3a1*/,
    9 /*f3a2*/,  10 /*f3a3*/, 9 /*f3a4*/,  10 /*f3a5*/, 10 /*f3a6*/,
    11 /*f3a7*/, 9 /*f3a8*/,  10 /*f3a9*/, 10 /*f3aa*/, 11 /*f3ab*/,
    10 /*f3ac*/, 11 /*f3ad*/, 11 /*f3ae*/, 12 /*f3af*/, 9 /*f3b0*/,
    10 /*f3b1*/, 10 /*f3b2*/, 11 /*f3b3*/, 10 /*f3b4*/, 11 /*f3b5*/,
    11 /*f3b6*/, 12 /*f3b7*/, 10 /*f3b8*/, 11 /*f3b9*/, 11 /*f3ba*/,
    12 /*f3bb*/, 11 /*f3bc*/, 12 /*f3bd*/, 12 /*f3be*/, 13 /*f3bf*/,
    8 /*f3c0*/,  9 /*f3c1*/,  9 /*f3c2*/,  10 /*f3c3*/, 9 /*f3c4*/,
    10 /*f3c5*/, 10 /*f3c6*/, 11 /*f3c7*/, 9 /*f3c8*/,  10 /*f3c9*/,
    10 /*f3ca*/, 11 /*f3cb*/, 10 /*f3cc*/, 11 /*f3cd*/, 11 /*f3ce*/,
    12 /*f3cf*/, 9 /*f3d0*/,  10 /*f3d1*/, 10 /*f3d2*/, 11 /*f3d3*/,
    10 /*f3d4*/, 11 /*f3d5*/, 11 /*f3d6*/, 12 /*f3d7*/, 10 /*f3d8*/,
    11 /*f3d9*/, 11 /*f3da*/, 12 /*f3db*/, 11 /*f3dc*/, 12 /*f3dd*/,
    12 /*f3de*/, 13 /*f3df*/, 9 /*f3e0*/,  10 /*f3e1*/, 10 /*f3e2*/,
    11 /*f3e3*/, 10 /*f3e4*/, 11 /*f3e5*/, 11 /*f3e6*/, 12 /*f3e7*/,
    10 /*f3e8*/, 11 /*f3e9*/, 11 /*f3ea*/, 12 /*f3eb*/, 11 /*f3ec*/,
    12 /*f3ed*/, 12 /*f3ee*/, 13 /*f3ef*/, 10 /*f3f0*/, 11 /*f3f1*/,
    11 /*f3f2*/, 12 /*f3f3*/, 11 /*f3f4*/, 12 /*f3f5*/, 12 /*f3f6*/,
    13 /*f3f7*/, 11 /*f3f8*/, 12 /*f3f9*/, 12 /*f3fa*/, 13 /*f3fb*/,
    12 /*f3fc*/, 13 /*f3fd*/, 13 /*f3fe*/, 14 /*f3ff*/, 5 /*f400*/,
    6 /*f401*/,  6 /*f402*/,  7 /*f403*/,  6 /*f404*/,  7 /*f405*/,
    7 /*f406*/,  8 /*f407*/,  6 /*f408*/,  7 /*f409*/,  7 /*f40a*/,
    8 /*f40b*/,  7 /*f40c*/,  8 /*f40d*/,  8 /*f40e*/,  9 /*f40f*/,
    6 /*f410*/,  7 /*f411*/,  7 /*f412*/,  8 /*f413*/,  7 /*f414*/,
    8 /*f415*/,  8 /*f416*/,  9 /*f417*/,  7 /*f418*/,  8 /*f419*/,
    8 /*f41a*/,  9 /*f41b*/,  8 /*f41c*/,  9 /*f41d*/,  9 /*f41e*/,
    10 /*f41f*/, 6 /*f420*/,  7 /*f421*/,  7 /*f422*/,  8 /*f423*/,
    7 /*f424*/,  8 /*f425*/,  8 /*f426*/,  9 /*f427*/,  7 /*f428*/,
    8 /*f429*/,  8 /*f42a*/,  9 /*f42b*/,  8 /*f42c*/,  9 /*f42d*/,
    9 /*f42e*/,  10 /*f42f*/, 7 /*f430*/,  8 /*f431*/,  8 /*f432*/,
    9 /*f433*/,  8 /*f434*/,  9 /*f435*/,  9 /*f436*/,  10 /*f437*/,
    8 /*f438*/,  9 /*f439*/,  9 /*f43a*/,  10 /*f43b*/, 9 /*f43c*/,
    10 /*f43d*/, 10 /*f43e*/, 11 /*f43f*/, 6 /*f440*/,  7 /*f441*/,
    7 /*f442*/,  8 /*f443*/,  7 /*f444*/,  8 /*f445*/,  8 /*f446*/,
    9 /*f447*/,  7 /*f448*/,  8 /*f449*/,  8 /*f44a*/,  9 /*f44b*/,
    8 /*f44c*/,  9 /*f44d*/,  9 /*f44e*/,  10 /*f44f*/, 7 /*f450*/,
    8 /*f451*/,  8 /*f452*/,  9 /*f453*/,  8 /*f454*/,  9 /*f455*/,
    9 /*f456*/,  10 /*f457*/, 8 /*f458*/,  9 /*f459*/,  9 /*f45a*/,
    10 /*f45b*/, 9 /*f45c*/,  10 /*f45d*/, 10 /*f45e*/, 11 /*f45f*/,
    7 /*f460*/,  8 /*f461*/,  8 /*f462*/,  9 /*f463*/,  8 /*f464*/,
    9 /*f465*/,  9 /*f466*/,  10 /*f467*/, 8 /*f468*/,  9 /*f469*/,
    9 /*f46a*/,  10 /*f46b*/, 9 /*f46c*/,  10 /*f46d*/, 10 /*f46e*/,
    11 /*f46f*/, 8 /*f470*/,  9 /*f471*/,  9 /*f472*/,  10 /*f473*/,
    9 /*f474*/,  10 /*f475*/, 10 /*f476*/, 11 /*f477*/, 9 /*f478*/,
    10 /*f479*/, 10 /*f47a*/, 11 /*f47b*/, 10 /*f47c*/, 11 /*f47d*/,
    11 /*f47e*/, 12 /*f47f*/, 6 /*f480*/,  7 /*f481*/,  7 /*f482*/,
    8 /*f483*/,  7 /*f484*/,  8 /*f485*/,  8 /*f486*/,  9 /*f487*/,
    7 /*f488*/,  8 /*f489*/,  8 /*f48a*/,  9 /*f48b*/,  8 /*f48c*/,
    9 /*f48d*/,  9 /*f48e*/,  10 /*f48f*/, 7 /*f490*/,  8 /*f491*/,
    8 /*f492*/,  9 /*f493*/,  8 /*f494*/,  9 /*f495*/,  9 /*f496*/,
    10 /*f497*/, 8 /*f498*/,  9 /*f499*/,  9 /*f49a*/,  10 /*f49b*/,
    9 /*f49c*/,  10 /*f49d*/, 10 /*f49e*/, 11 /*f49f*/, 7 /*f4a0*/,
    8 /*f4a1*/,  8 /*f4a2*/,  9 /*f4a3*/,  8 /*f4a4*/,  9 /*f4a5*/,
    9 /*f4a6*/,  10 /*f4a7*/, 8 /*f4a8*/,  9 /*f4a9*/,  9 /*f4aa*/,
    10 /*f4ab*/, 9 /*f4ac*/,  10 /*f4ad*/, 10 /*f4ae*/, 11 /*f4af*/,
    8 /*f4b0*/,  9 /*f4b1*/,  9 /*f4b2*/,  10 /*f4b3*/, 9 /*f4b4*/,
    10 /*f4b5*/, 10 /*f4b6*/, 11 /*f4b7*/, 9 /*f4b8*/,  10 /*f4b9*/,
    10 /*f4ba*/, 11 /*f4bb*/, 10 /*f4bc*/, 11 /*f4bd*/, 11 /*f4be*/,
    12 /*f4bf*/, 7 /*f4c0*/,  8 /*f4c1*/,  8 /*f4c2*/,  9 /*f4c3*/,
    8 /*f4c4*/,  9 /*f4c5*/,  9 /*f4c6*/,  10 /*f4c7*/, 8 /*f4c8*/,
    9 /*f4c9*/,  9 /*f4ca*/,  10 /*f4cb*/, 9 /*f4cc*/,  10 /*f4cd*/,
    10 /*f4ce*/, 11 /*f4cf*/, 8 /*f4d0*/,  9 /*f4d1*/,  9 /*f4d2*/,
    10 /*f4d3*/, 9 /*f4d4*/,  10 /*f4d5*/, 10 /*f4d6*/, 11 /*f4d7*/,
    9 /*f4d8*/,  10 /*f4d9*/, 10 /*f4da*/, 11 /*f4db*/, 10 /*f4dc*/,
    11 /*f4dd*/, 11 /*f4de*/, 12 /*f4df*/, 8 /*f4e0*/,  9 /*f4e1*/,
    9 /*f4e2*/,  10 /*f4e3*/, 9 /*f4e4*/,  10 /*f4e5*/, 10 /*f4e6*/,
    11 /*f4e7*/, 9 /*f4e8*/,  10 /*f4e9*/, 10 /*f4ea*/, 11 /*f4eb*/,
    10 /*f4ec*/, 11 /*f4ed*/, 11 /*f4ee*/, 12 /*f4ef*/, 9 /*f4f0*/,
    10 /*f4f1*/, 10 /*f4f2*/, 11 /*f4f3*/, 10 /*f4f4*/, 11 /*f4f5*/,
    11 /*f4f6*/, 12 /*f4f7*/, 10 /*f4f8*/, 11 /*f4f9*/, 11 /*f4fa*/,
    12 /*f4fb*/, 11 /*f4fc*/, 12 /*f4fd*/, 12 /*f4fe*/, 13 /*f4ff*/,
    6 /*f500*/,  7 /*f501*/,  7 /*f502*/,  8 /*f503*/,  7 /*f504*/,
    8 /*f505*/,  8 /*f506*/,  9 /*f507*/,  7 /*f508*/,  8 /*f509*/,
    8 /*f50a*/,  9 /*f50b*/,  8 /*f50c*/,  9 /*f50d*/,  9 /*f50e*/,
    10 /*f50f*/, 7 /*f510*/,  8 /*f511*/,  8 /*f512*/,  9 /*f513*/,
    8 /*f514*/,  9 /*f515*/,  9 /*f516*/,  10 /*f517*/, 8 /*f518*/,
    9 /*f519*/,  9 /*f51a*/,  10 /*f51b*/, 9 /*f51c*/,  10 /*f51d*/,
    10 /*f51e*/, 11 /*f51f*/, 7 /*f520*/,  8 /*f521*/,  8 /*f522*/,
    9 /*f523*/,  8 /*f524*/,  9 /*f525*/,  9 /*f526*/,  10 /*f527*/,
    8 /*f528*/,  9 /*f529*/,  9 /*f52a*/,  10 /*f52b*/, 9 /*f52c*/,
    10 /*f52d*/, 10 /*f52e*/, 11 /*f52f*/, 8 /*f530*/,  9 /*f531*/,
    9 /*f532*/,  10 /*f533*/, 9 /*f534*/,  10 /*f535*/, 10 /*f536*/,
    11 /*f537*/, 9 /*f538*/,  10 /*f539*/, 10 /*f53a*/, 11 /*f53b*/,
    10 /*f53c*/, 11 /*f53d*/, 11 /*f53e*/, 12 /*f53f*/, 7 /*f540*/,
    8 /*f541*/,  8 /*f542*/,  9 /*f543*/,  8 /*f544*/,  9 /*f545*/,
    9 /*f546*/,  10 /*f547*/, 8 /*f548*/,  9 /*f549*/,  9 /*f54a*/,
    10 /*f54b*/, 9 /*f54c*/,  10 /*f54d*/, 10 /*f54e*/, 11 /*f54f*/,
    8 /*f550*/,  9 /*f551*/,  9 /*f552*/,  10 /*f553*/, 9 /*f554*/,
    10 /*f555*/, 10 /*f556*/, 11 /*f557*/, 9 /*f558*/,  10 /*f559*/,
    10 /*f55a*/, 11 /*f55b*/, 10 /*f55c*/, 11 /*f55d*/, 11 /*f55e*/,
    12 /*f55f*/, 8 /*f560*/,  9 /*f561*/,  9 /*f562*/,  10 /*f563*/,
    9 /*f564*/,  10 /*f565*/, 10 /*f566*/, 11 /*f567*/, 9 /*f568*/,
    10 /*f569*/, 10 /*f56a*/, 11 /*f56b*/, 10 /*f56c*/, 11 /*f56d*/,
    11 /*f56e*/, 12 /*f56f*/, 9 /*f570*/,  10 /*f571*/, 10 /*f572*/,
    11 /*f573*/, 10 /*f574*/, 11 /*f575*/, 11 /*f576*/, 12 /*f577*/,
    10 /*f578*/, 11 /*f579*/, 11 /*f57a*/, 12 /*f57b*/, 11 /*f57c*/,
    12 /*f57d*/, 12 /*f57e*/, 13 /*f57f*/, 7 /*f580*/,  8 /*f581*/,
    8 /*f582*/,  9 /*f583*/,  8 /*f584*/,  9 /*f585*/,  9 /*f586*/,
    10 /*f587*/, 8 /*f588*/,  9 /*f589*/,  9 /*f58a*/,  10 /*f58b*/,
    9 /*f58c*/,  10 /*f58d*/, 10 /*f58e*/, 11 /*f58f*/, 8 /*f590*/,
    9 /*f591*/,  9 /*f592*/,  10 /*f593*/, 9 /*f594*/,  10 /*f595*/,
    10 /*f596*/, 11 /*f597*/, 9 /*f598*/,  10 /*f599*/, 10 /*f59a*/,
    11 /*f59b*/, 10 /*f59c*/, 11 /*f59d*/, 11 /*f59e*/, 12 /*f59f*/,
    8 /*f5a0*/,  9 /*f5a1*/,  9 /*f5a2*/,  10 /*f5a3*/, 9 /*f5a4*/,
    10 /*f5a5*/, 10 /*f5a6*/, 11 /*f5a7*/, 9 /*f5a8*/,  10 /*f5a9*/,
    10 /*f5aa*/, 11 /*f5ab*/, 10 /*f5ac*/, 11 /*f5ad*/, 11 /*f5ae*/,
    12 /*f5af*/, 9 /*f5b0*/,  10 /*f5b1*/, 10 /*f5b2*/, 11 /*f5b3*/,
    10 /*f5b4*/, 11 /*f5b5*/, 11 /*f5b6*/, 12 /*f5b7*/, 10 /*f5b8*/,
    11 /*f5b9*/, 11 /*f5ba*/, 12 /*f5bb*/, 11 /*f5bc*/, 12 /*f5bd*/,
    12 /*f5be*/, 13 /*f5bf*/, 8 /*f5c0*/,  9 /*f5c1*/,  9 /*f5c2*/,
    10 /*f5c3*/, 9 /*f5c4*/,  10 /*f5c5*/, 10 /*f5c6*/, 11 /*f5c7*/,
    9 /*f5c8*/,  10 /*f5c9*/, 10 /*f5ca*/, 11 /*f5cb*/, 10 /*f5cc*/,
    11 /*f5cd*/, 11 /*f5ce*/, 12 /*f5cf*/, 9 /*f5d0*/,  10 /*f5d1*/,
    10 /*f5d2*/, 11 /*f5d3*/, 10 /*f5d4*/, 11 /*f5d5*/, 11 /*f5d6*/,
    12 /*f5d7*/, 10 /*f5d8*/, 11 /*f5d9*/, 11 /*f5da*/, 12 /*f5db*/,
    11 /*f5dc*/, 12 /*f5dd*/, 12 /*f5de*/, 13 /*f5df*/, 9 /*f5e0*/,
    10 /*f5e1*/, 10 /*f5e2*/, 11 /*f5e3*/, 10 /*f5e4*/, 11 /*f5e5*/,
    11 /*f5e6*/, 12 /*f5e7*/, 10 /*f5e8*/, 11 /*f5e9*/, 11 /*f5ea*/,
    12 /*f5eb*/, 11 /*f5ec*/, 12 /*f5ed*/, 12 /*f5ee*/, 13 /*f5ef*/,
    10 /*f5f0*/, 11 /*f5f1*/, 11 /*f5f2*/, 12 /*f5f3*/, 11 /*f5f4*/,
    12 /*f5f5*/, 12 /*f5f6*/, 13 /*f5f7*/, 11 /*f5f8*/, 12 /*f5f9*/,
    12 /*f5fa*/, 13 /*f5fb*/, 12 /*f5fc*/, 13 /*f5fd*/, 13 /*f5fe*/,
    14 /*f5ff*/, 6 /*f600*/,  7 /*f601*/,  7 /*f602*/,  8 /*f603*/,
    7 /*f604*/,  8 /*f605*/,  8 /*f606*/,  9 /*f607*/,  7 /*f608*/,
    8 /*f609*/,  8 /*f60a*/,  9 /*f60b*/,  8 /*f60c*/,  9 /*f60d*/,
    9 /*f60e*/,  10 /*f60f*/, 7 /*f610*/,  8 /*f611*/,  8 /*f612*/,
    9 /*f613*/,  8 /*f614*/,  9 /*f615*/,  9 /*f616*/,  10 /*f617*/,
    8 /*f618*/,  9 /*f619*/,  9 /*f61a*/,  10 /*f61b*/, 9 /*f61c*/,
    10 /*f61d*/, 10 /*f61e*/, 11 /*f61f*/, 7 /*f620*/,  8 /*f621*/,
    8 /*f622*/,  9 /*f623*/,  8 /*f624*/,  9 /*f625*/,  9 /*f626*/,
    10 /*f627*/, 8 /*f628*/,  9 /*f629*/,  9 /*f62a*/,  10 /*f62b*/,
    9 /*f62c*/,  10 /*f62d*/, 10 /*f62e*/, 11 /*f62f*/, 8 /*f630*/,
    9 /*f631*/,  9 /*f632*/,  10 /*f633*/, 9 /*f634*/,  10 /*f635*/,
    10 /*f636*/, 11 /*f637*/, 9 /*f638*/,  10 /*f639*/, 10 /*f63a*/,
    11 /*f63b*/, 10 /*f63c*/, 11 /*f63d*/, 11 /*f63e*/, 12 /*f63f*/,
    7 /*f640*/,  8 /*f641*/,  8 /*f642*/,  9 /*f643*/,  8 /*f644*/,
    9 /*f645*/,  9 /*f646*/,  10 /*f647*/, 8 /*f648*/,  9 /*f649*/,
    9 /*f64a*/,  10 /*f64b*/, 9 /*f64c*/,  10 /*f64d*/, 10 /*f64e*/,
    11 /*f64f*/, 8 /*f650*/,  9 /*f651*/,  9 /*f652*/,  10 /*f653*/,
    9 /*f654*/,  10 /*f655*/, 10 /*f656*/, 11 /*f657*/, 9 /*f658*/,
    10 /*f659*/, 10 /*f65a*/, 11 /*f65b*/, 10 /*f65c*/, 11 /*f65d*/,
    11 /*f65e*/, 12 /*f65f*/, 8 /*f660*/,  9 /*f661*/,  9 /*f662*/,
    10 /*f663*/, 9 /*f664*/,  10 /*f665*/, 10 /*f666*/, 11 /*f667*/,
    9 /*f668*/,  10 /*f669*/, 10 /*f66a*/, 11 /*f66b*/, 10 /*f66c*/,
    11 /*f66d*/, 11 /*f66e*/, 12 /*f66f*/, 9 /*f670*/,  10 /*f671*/,
    10 /*f672*/, 11 /*f673*/, 10 /*f674*/, 11 /*f675*/, 11 /*f676*/,
    12 /*f677*/, 10 /*f678*/, 11 /*f679*/, 11 /*f67a*/, 12 /*f67b*/,
    11 /*f67c*/, 12 /*f67d*/, 12 /*f67e*/, 13 /*f67f*/, 7 /*f680*/,
    8 /*f681*/,  8 /*f682*/,  9 /*f683*/,  8 /*f684*/,  9 /*f685*/,
    9 /*f686*/,  10 /*f687*/, 8 /*f688*/,  9 /*f689*/,  9 /*f68a*/,
    10 /*f68b*/, 9 /*f68c*/,  10 /*f68d*/, 10 /*f68e*/, 11 /*f68f*/,
    8 /*f690*/,  9 /*f691*/,  9 /*f692*/,  10 /*f693*/, 9 /*f694*/,
    10 /*f695*/, 10 /*f696*/, 11 /*f697*/, 9 /*f698*/,  10 /*f699*/,
    10 /*f69a*/, 11 /*f69b*/, 10 /*f69c*/, 11 /*f69d*/, 11 /*f69e*/,
    12 /*f69f*/, 8 /*f6a0*/,  9 /*f6a1*/,  9 /*f6a2*/,  10 /*f6a3*/,
    9 /*f6a4*/,  10 /*f6a5*/, 10 /*f6a6*/, 11 /*f6a7*/, 9 /*f6a8*/,
    10 /*f6a9*/, 10 /*f6aa*/, 11 /*f6ab*/, 10 /*f6ac*/, 11 /*f6ad*/,
    11 /*f6ae*/, 12 /*f6af*/, 9 /*f6b0*/,  10 /*f6b1*/, 10 /*f6b2*/,
    11 /*f6b3*/, 10 /*f6b4*/, 11 /*f6b5*/, 11 /*f6b6*/, 12 /*f6b7*/,
    10 /*f6b8*/, 11 /*f6b9*/, 11 /*f6ba*/, 12 /*f6bb*/, 11 /*f6bc*/,
    12 /*f6bd*/, 12 /*f6be*/, 13 /*f6bf*/, 8 /*f6c0*/,  9 /*f6c1*/,
    9 /*f6c2*/,  10 /*f6c3*/, 9 /*f6c4*/,  10 /*f6c5*/, 10 /*f6c6*/,
    11 /*f6c7*/, 9 /*f6c8*/,  10 /*f6c9*/, 10 /*f6ca*/, 11 /*f6cb*/,
    10 /*f6cc*/, 11 /*f6cd*/, 11 /*f6ce*/, 12 /*f6cf*/, 9 /*f6d0*/,
    10 /*f6d1*/, 10 /*f6d2*/, 11 /*f6d3*/, 10 /*f6d4*/, 11 /*f6d5*/,
    11 /*f6d6*/, 12 /*f6d7*/, 10 /*f6d8*/, 11 /*f6d9*/, 11 /*f6da*/,
    12 /*f6db*/, 11 /*f6dc*/, 12 /*f6dd*/, 12 /*f6de*/, 13 /*f6df*/,
    9 /*f6e0*/,  10 /*f6e1*/, 10 /*f6e2*/, 11 /*f6e3*/, 10 /*f6e4*/,
    11 /*f6e5*/, 11 /*f6e6*/, 12 /*f6e7*/, 10 /*f6e8*/, 11 /*f6e9*/,
    11 /*f6ea*/, 12 /*f6eb*/, 11 /*f6ec*/, 12 /*f6ed*/, 12 /*f6ee*/,
    13 /*f6ef*/, 10 /*f6f0*/, 11 /*f6f1*/, 11 /*f6f2*/, 12 /*f6f3*/,
    11 /*f6f4*/, 12 /*f6f5*/, 12 /*f6f6*/, 13 /*f6f7*/, 11 /*f6f8*/,
    12 /*f6f9*/, 12 /*f6fa*/, 13 /*f6fb*/, 12 /*f6fc*/, 13 /*f6fd*/,
    13 /*f6fe*/, 14 /*f6ff*/, 7 /*f700*/,  8 /*f701*/,  8 /*f702*/,
    9 /*f703*/,  8 /*f704*/,  9 /*f705*/,  9 /*f706*/,  10 /*f707*/,
    8 /*f708*/,  9 /*f709*/,  9 /*f70a*/,  10 /*f70b*/, 9 /*f70c*/,
    10 /*f70d*/, 10 /*f70e*/, 11 /*f70f*/, 8 /*f710*/,  9 /*f711*/,
    9 /*f712*/,  10 /*f713*/, 9 /*f714*/,  10 /*f715*/, 10 /*f716*/,
    11 /*f717*/, 9 /*f718*/,  10 /*f719*/, 10 /*f71a*/, 11 /*f71b*/,
    10 /*f71c*/, 11 /*f71d*/, 11 /*f71e*/, 12 /*f71f*/, 8 /*f720*/,
    9 /*f721*/,  9 /*f722*/,  10 /*f723*/, 9 /*f724*/,  10 /*f725*/,
    10 /*f726*/, 11 /*f727*/, 9 /*f728*/,  10 /*f729*/, 10 /*f72a*/,
    11 /*f72b*/, 10 /*f72c*/, 11 /*f72d*/, 11 /*f72e*/, 12 /*f72f*/,
    9 /*f730*/,  10 /*f731*/, 10 /*f732*/, 11 /*f733*/, 10 /*f734*/,
    11 /*f735*/, 11 /*f736*/, 12 /*f737*/, 10 /*f738*/, 11 /*f739*/,
    11 /*f73a*/, 12 /*f73b*/, 11 /*f73c*/, 12 /*f73d*/, 12 /*f73e*/,
    13 /*f73f*/, 8 /*f740*/,  9 /*f741*/,  9 /*f742*/,  10 /*f743*/,
    9 /*f744*/,  10 /*f745*/, 10 /*f746*/, 11 /*f747*/, 9 /*f748*/,
    10 /*f749*/, 10 /*f74a*/, 11 /*f74b*/, 10 /*f74c*/, 11 /*f74d*/,
    11 /*f74e*/, 12 /*f74f*/, 9 /*f750*/,  10 /*f751*/, 10 /*f752*/,
    11 /*f753*/, 10 /*f754*/, 11 /*f755*/, 11 /*f756*/, 12 /*f757*/,
    10 /*f758*/, 11 /*f759*/, 11 /*f75a*/, 12 /*f75b*/, 11 /*f75c*/,
    12 /*f75d*/, 12 /*f75e*/, 13 /*f75f*/, 9 /*f760*/,  10 /*f761*/,
    10 /*f762*/, 11 /*f763*/, 10 /*f764*/, 11 /*f765*/, 11 /*f766*/,
    12 /*f767*/, 10 /*f768*/, 11 /*f769*/, 11 /*f76a*/, 12 /*f76b*/,
    11 /*f76c*/, 12 /*f76d*/, 12 /*f76e*/, 13 /*f76f*/, 10 /*f770*/,
    11 /*f771*/, 11 /*f772*/, 12 /*f773*/, 11 /*f774*/, 12 /*f775*/,
    12 /*f776*/, 13 /*f777*/, 11 /*f778*/, 12 /*f779*/, 12 /*f77a*/,
    13 /*f77b*/, 12 /*f77c*/, 13 /*f77d*/, 13 /*f77e*/, 14 /*f77f*/,
    8 /*f780*/,  9 /*f781*/,  9 /*f782*/,  10 /*f783*/, 9 /*f784*/,
    10 /*f785*/, 10 /*f786*/, 11 /*f787*/, 9 /*f788*/,  10 /*f789*/,
    10 /*f78a*/, 11 /*f78b*/, 10 /*f78c*/, 11 /*f78d*/, 11 /*f78e*/,
    12 /*f78f*/, 9 /*f790*/,  10 /*f791*/, 10 /*f792*/, 11 /*f793*/,
    10 /*f794*/, 11 /*f795*/, 11 /*f796*/, 12 /*f797*/, 10 /*f798*/,
    11 /*f799*/, 11 /*f79a*/, 12 /*f79b*/, 11 /*f79c*/, 12 /*f79d*/,
    12 /*f79e*/, 13 /*f79f*/, 9 /*f7a0*/,  10 /*f7a1*/, 10 /*f7a2*/,
    11 /*f7a3*/, 10 /*f7a4*/, 11 /*f7a5*/, 11 /*f7a6*/, 12 /*f7a7*/,
    10 /*f7a8*/, 11 /*f7a9*/, 11 /*f7aa*/, 12 /*f7ab*/, 11 /*f7ac*/,
    12 /*f7ad*/, 12 /*f7ae*/, 13 /*f7af*/, 10 /*f7b0*/, 11 /*f7b1*/,
    11 /*f7b2*/, 12 /*f7b3*/, 11 /*f7b4*/, 12 /*f7b5*/, 12 /*f7b6*/,
    13 /*f7b7*/, 11 /*f7b8*/, 12 /*f7b9*/, 12 /*f7ba*/, 13 /*f7bb*/,
    12 /*f7bc*/, 13 /*f7bd*/, 13 /*f7be*/, 14 /*f7bf*/, 9 /*f7c0*/,
    10 /*f7c1*/, 10 /*f7c2*/, 11 /*f7c3*/, 10 /*f7c4*/, 11 /*f7c5*/,
    11 /*f7c6*/, 12 /*f7c7*/, 10 /*f7c8*/, 11 /*f7c9*/, 11 /*f7ca*/,
    12 /*f7cb*/, 11 /*f7cc*/, 12 /*f7cd*/, 12 /*f7ce*/, 13 /*f7cf*/,
    10 /*f7d0*/, 11 /*f7d1*/, 11 /*f7d2*/, 12 /*f7d3*/, 11 /*f7d4*/,
    12 /*f7d5*/, 12 /*f7d6*/, 13 /*f7d7*/, 11 /*f7d8*/, 12 /*f7d9*/,
    12 /*f7da*/, 13 /*f7db*/, 12 /*f7dc*/, 13 /*f7dd*/, 13 /*f7de*/,
    14 /*f7df*/, 10 /*f7e0*/, 11 /*f7e1*/, 11 /*f7e2*/, 12 /*f7e3*/,
    11 /*f7e4*/, 12 /*f7e5*/, 12 /*f7e6*/, 13 /*f7e7*/, 11 /*f7e8*/,
    12 /*f7e9*/, 12 /*f7ea*/, 13 /*f7eb*/, 12 /*f7ec*/, 13 /*f7ed*/,
    13 /*f7ee*/, 14 /*f7ef*/, 11 /*f7f0*/, 12 /*f7f1*/, 12 /*f7f2*/,
    13 /*f7f3*/, 12 /*f7f4*/, 13 /*f7f5*/, 13 /*f7f6*/, 14 /*f7f7*/,
    12 /*f7f8*/, 13 /*f7f9*/, 13 /*f7fa*/, 14 /*f7fb*/, 13 /*f7fc*/,
    14 /*f7fd*/, 14 /*f7fe*/, 15 /*f7ff*/, 5 /*f800*/,  6 /*f801*/,
    6 /*f802*/,  7 /*f803*/,  6 /*f804*/,  7 /*f805*/,  7 /*f806*/,
    8 /*f807*/,  6 /*f808*/,  7 /*f809*/,  7 /*f80a*/,  8 /*f80b*/,
    7 /*f80c*/,  8 /*f80d*/,  8 /*f80e*/,  9 /*f80f*/,  6 /*f810*/,
    7 /*f811*/,  7 /*f812*/,  8 /*f813*/,  7 /*f814*/,  8 /*f815*/,
    8 /*f816*/,  9 /*f817*/,  7 /*f818*/,  8 /*f819*/,  8 /*f81a*/,
    9 /*f81b*/,  8 /*f81c*/,  9 /*f81d*/,  9 /*f81e*/,  10 /*f81f*/,
    6 /*f820*/,  7 /*f821*/,  7 /*f822*/,  8 /*f823*/,  7 /*f824*/,
    8 /*f825*/,  8 /*f826*/,  9 /*f827*/,  7 /*f828*/,  8 /*f829*/,
    8 /*f82a*/,  9 /*f82b*/,  8 /*f82c*/,  9 /*f82d*/,  9 /*f82e*/,
    10 /*f82f*/, 7 /*f830*/,  8 /*f831*/,  8 /*f832*/,  9 /*f833*/,
    8 /*f834*/,  9 /*f835*/,  9 /*f836*/,  10 /*f837*/, 8 /*f838*/,
    9 /*f839*/,  9 /*f83a*/,  10 /*f83b*/, 9 /*f83c*/,  10 /*f83d*/,
    10 /*f83e*/, 11 /*f83f*/, 6 /*f840*/,  7 /*f841*/,  7 /*f842*/,
    8 /*f843*/,  7 /*f844*/,  8 /*f845*/,  8 /*f846*/,  9 /*f847*/,
    7 /*f848*/,  8 /*f849*/,  8 /*f84a*/,  9 /*f84b*/,  8 /*f84c*/,
    9 /*f84d*/,  9 /*f84e*/,  10 /*f84f*/, 7 /*f850*/,  8 /*f851*/,
    8 /*f852*/,  9 /*f853*/,  8 /*f854*/,  9 /*f855*/,  9 /*f856*/,
    10 /*f857*/, 8 /*f858*/,  9 /*f859*/,  9 /*f85a*/,  10 /*f85b*/,
    9 /*f85c*/,  10 /*f85d*/, 10 /*f85e*/, 11 /*f85f*/, 7 /*f860*/,
    8 /*f861*/,  8 /*f862*/,  9 /*f863*/,  8 /*f864*/,  9 /*f865*/,
    9 /*f866*/,  10 /*f867*/, 8 /*f868*/,  9 /*f869*/,  9 /*f86a*/,
    10 /*f86b*/, 9 /*f86c*/,  10 /*f86d*/, 10 /*f86e*/, 11 /*f86f*/,
    8 /*f870*/,  9 /*f871*/,  9 /*f872*/,  10 /*f873*/, 9 /*f874*/,
    10 /*f875*/, 10 /*f876*/, 11 /*f877*/, 9 /*f878*/,  10 /*f879*/,
    10 /*f87a*/, 11 /*f87b*/, 10 /*f87c*/, 11 /*f87d*/, 11 /*f87e*/,
    12 /*f87f*/, 6 /*f880*/,  7 /*f881*/,  7 /*f882*/,  8 /*f883*/,
    7 /*f884*/,  8 /*f885*/,  8 /*f886*/,  9 /*f887*/,  7 /*f888*/,
    8 /*f889*/,  8 /*f88a*/,  9 /*f88b*/,  8 /*f88c*/,  9 /*f88d*/,
    9 /*f88e*/,  10 /*f88f*/, 7 /*f890*/,  8 /*f891*/,  8 /*f892*/,
    9 /*f893*/,  8 /*f894*/,  9 /*f895*/,  9 /*f896*/,  10 /*f897*/,
    8 /*f898*/,  9 /*f899*/,  9 /*f89a*/,  10 /*f89b*/, 9 /*f89c*/,
    10 /*f89d*/, 10 /*f89e*/, 11 /*f89f*/, 7 /*f8a0*/,  8 /*f8a1*/,
    8 /*f8a2*/,  9 /*f8a3*/,  8 /*f8a4*/,  9 /*f8a5*/,  9 /*f8a6*/,
    10 /*f8a7*/, 8 /*f8a8*/,  9 /*f8a9*/,  9 /*f8aa*/,  10 /*f8ab*/,
    9 /*f8ac*/,  10 /*f8ad*/, 10 /*f8ae*/, 11 /*f8af*/, 8 /*f8b0*/,
    9 /*f8b1*/,  9 /*f8b2*/,  10 /*f8b3*/, 9 /*f8b4*/,  10 /*f8b5*/,
    10 /*f8b6*/, 11 /*f8b7*/, 9 /*f8b8*/,  10 /*f8b9*/, 10 /*f8ba*/,
    11 /*f8bb*/, 10 /*f8bc*/, 11 /*f8bd*/, 11 /*f8be*/, 12 /*f8bf*/,
    7 /*f8c0*/,  8 /*f8c1*/,  8 /*f8c2*/,  9 /*f8c3*/,  8 /*f8c4*/,
    9 /*f8c5*/,  9 /*f8c6*/,  10 /*f8c7*/, 8 /*f8c8*/,  9 /*f8c9*/,
    9 /*f8ca*/,  10 /*f8cb*/, 9 /*f8cc*/,  10 /*f8cd*/, 10 /*f8ce*/,
    11 /*f8cf*/, 8 /*f8d0*/,  9 /*f8d1*/,  9 /*f8d2*/,  10 /*f8d3*/,
    9 /*f8d4*/,  10 /*f8d5*/, 10 /*f8d6*/, 11 /*f8d7*/, 9 /*f8d8*/,
    10 /*f8d9*/, 10 /*f8da*/, 11 /*f8db*/, 10 /*f8dc*/, 11 /*f8dd*/,
    11 /*f8de*/, 12 /*f8df*/, 8 /*f8e0*/,  9 /*f8e1*/,  9 /*f8e2*/,
    10 /*f8e3*/, 9 /*f8e4*/,  10 /*f8e5*/, 10 /*f8e6*/, 11 /*f8e7*/,
    9 /*f8e8*/,  10 /*f8e9*/, 10 /*f8ea*/, 11 /*f8eb*/, 10 /*f8ec*/,
    11 /*f8ed*/, 11 /*f8ee*/, 12 /*f8ef*/, 9 /*f8f0*/,  10 /*f8f1*/,
    10 /*f8f2*/, 11 /*f8f3*/, 10 /*f8f4*/, 11 /*f8f5*/, 11 /*f8f6*/,
    12 /*f8f7*/, 10 /*f8f8*/, 11 /*f8f9*/, 11 /*f8fa*/, 12 /*f8fb*/,
    11 /*f8fc*/, 12 /*f8fd*/, 12 /*f8fe*/, 13 /*f8ff*/, 6 /*f900*/,
    7 /*f901*/,  7 /*f902*/,  8 /*f903*/,  7 /*f904*/,  8 /*f905*/,
    8 /*f906*/,  9 /*f907*/,  7 /*f908*/,  8 /*f909*/,  8 /*f90a*/,
    9 /*f90b*/,  8 /*f90c*/,  9 /*f90d*/,  9 /*f90e*/,  10 /*f90f*/,
    7 /*f910*/,  8 /*f911*/,  8 /*f912*/,  9 /*f913*/,  8 /*f914*/,
    9 /*f915*/,  9 /*f916*/,  10 /*f917*/, 8 /*f918*/,  9 /*f919*/,
    9 /*f91a*/,  10 /*f91b*/, 9 /*f91c*/,  10 /*f91d*/, 10 /*f91e*/,
    11 /*f91f*/, 7 /*f920*/,  8 /*f921*/,  8 /*f922*/,  9 /*f923*/,
    8 /*f924*/,  9 /*f925*/,  9 /*f926*/,  10 /*f927*/, 8 /*f928*/,
    9 /*f929*/,  9 /*f92a*/,  10 /*f92b*/, 9 /*f92c*/,  10 /*f92d*/,
    10 /*f92e*/, 11 /*f92f*/, 8 /*f930*/,  9 /*f931*/,  9 /*f932*/,
    10 /*f933*/, 9 /*f934*/,  10 /*f935*/, 10 /*f936*/, 11 /*f937*/,
    9 /*f938*/,  10 /*f939*/, 10 /*f93a*/, 11 /*f93b*/, 10 /*f93c*/,
    11 /*f93d*/, 11 /*f93e*/, 12 /*f93f*/, 7 /*f940*/,  8 /*f941*/,
    8 /*f942*/,  9 /*f943*/,  8 /*f944*/,  9 /*f945*/,  9 /*f946*/,
    10 /*f947*/, 8 /*f948*/,  9 /*f949*/,  9 /*f94a*/,  10 /*f94b*/,
    9 /*f94c*/,  10 /*f94d*/, 10 /*f94e*/, 11 /*f94f*/, 8 /*f950*/,
    9 /*f951*/,  9 /*f952*/,  10 /*f953*/, 9 /*f954*/,  10 /*f955*/,
    10 /*f956*/, 11 /*f957*/, 9 /*f958*/,  10 /*f959*/, 10 /*f95a*/,
    11 /*f95b*/, 10 /*f95c*/, 11 /*f95d*/, 11 /*f95e*/, 12 /*f95f*/,
    8 /*f960*/,  9 /*f961*/,  9 /*f962*/,  10 /*f963*/, 9 /*f964*/,
    10 /*f965*/, 10 /*f966*/, 11 /*f967*/, 9 /*f968*/,  10 /*f969*/,
    10 /*f96a*/, 11 /*f96b*/, 10 /*f96c*/, 11 /*f96d*/, 11 /*f96e*/,
    12 /*f96f*/, 9 /*f970*/,  10 /*f971*/, 10 /*f972*/, 11 /*f973*/,
    10 /*f974*/, 11 /*f975*/, 11 /*f976*/, 12 /*f977*/, 10 /*f978*/,
    11 /*f979*/, 11 /*f97a*/, 12 /*f97b*/, 11 /*f97c*/, 12 /*f97d*/,
    12 /*f97e*/, 13 /*f97f*/, 7 /*f980*/,  8 /*f981*/,  8 /*f982*/,
    9 /*f983*/,  8 /*f984*/,  9 /*f985*/,  9 /*f986*/,  10 /*f987*/,
    8 /*f988*/,  9 /*f989*/,  9 /*f98a*/,  10 /*f98b*/, 9 /*f98c*/,
    10 /*f98d*/, 10 /*f98e*/, 11 /*f98f*/, 8 /*f990*/,  9 /*f991*/,
    9 /*f992*/,  10 /*f993*/, 9 /*f994*/,  10 /*f995*/, 10 /*f996*/,
    11 /*f997*/, 9 /*f998*/,  10 /*f999*/, 10 /*f99a*/, 11 /*f99b*/,
    10 /*f99c*/, 11 /*f99d*/, 11 /*f99e*/, 12 /*f99f*/, 8 /*f9a0*/,
    9 /*f9a1*/,  9 /*f9a2*/,  10 /*f9a3*/, 9 /*f9a4*/,  10 /*f9a5*/,
    10 /*f9a6*/, 11 /*f9a7*/, 9 /*f9a8*/,  10 /*f9a9*/, 10 /*f9aa*/,
    11 /*f9ab*/, 10 /*f9ac*/, 11 /*f9ad*/, 11 /*f9ae*/, 12 /*f9af*/,
    9 /*f9b0*/,  10 /*f9b1*/, 10 /*f9b2*/, 11 /*f9b3*/, 10 /*f9b4*/,
    11 /*f9b5*/, 11 /*f9b6*/, 12 /*f9b7*/, 10 /*f9b8*/, 11 /*f9b9*/,
    11 /*f9ba*/, 12 /*f9bb*/, 11 /*f9bc*/, 12 /*f9bd*/, 12 /*f9be*/,
    13 /*f9bf*/, 8 /*f9c0*/,  9 /*f9c1*/,  9 /*f9c2*/,  10 /*f9c3*/,
    9 /*f9c4*/,  10 /*f9c5*/, 10 /*f9c6*/, 11 /*f9c7*/, 9 /*f9c8*/,
    10 /*f9c9*/, 10 /*f9ca*/, 11 /*f9cb*/, 10 /*f9cc*/, 11 /*f9cd*/,
    11 /*f9ce*/, 12 /*f9cf*/, 9 /*f9d0*/,  10 /*f9d1*/, 10 /*f9d2*/,
    11 /*f9d3*/, 10 /*f9d4*/, 11 /*f9d5*/, 11 /*f9d6*/, 12 /*f9d7*/,
    10 /*f9d8*/, 11 /*f9d9*/, 11 /*f9da*/, 12 /*f9db*/, 11 /*f9dc*/,
    12 /*f9dd*/, 12 /*f9de*/, 13 /*f9df*/, 9 /*f9e0*/,  10 /*f9e1*/,
    10 /*f9e2*/, 11 /*f9e3*/, 10 /*f9e4*/, 11 /*f9e5*/, 11 /*f9e6*/,
    12 /*f9e7*/, 10 /*f9e8*/, 11 /*f9e9*/, 11 /*f9ea*/, 12 /*f9eb*/,
    11 /*f9ec*/, 12 /*f9ed*/, 12 /*f9ee*/, 13 /*f9ef*/, 10 /*f9f0*/,
    11 /*f9f1*/, 11 /*f9f2*/, 12 /*f9f3*/, 11 /*f9f4*/, 12 /*f9f5*/,
    12 /*f9f6*/, 13 /*f9f7*/, 11 /*f9f8*/, 12 /*f9f9*/, 12 /*f9fa*/,
    13 /*f9fb*/, 12 /*f9fc*/, 13 /*f9fd*/, 13 /*f9fe*/, 14 /*f9ff*/,
    6 /*fa00*/,  7 /*fa01*/,  7 /*fa02*/,  8 /*fa03*/,  7 /*fa04*/,
    8 /*fa05*/,  8 /*fa06*/,  9 /*fa07*/,  7 /*fa08*/,  8 /*fa09*/,
    8 /*fa0a*/,  9 /*fa0b*/,  8 /*fa0c*/,  9 /*fa0d*/,  9 /*fa0e*/,
    10 /*fa0f*/, 7 /*fa10*/,  8 /*fa11*/,  8 /*fa12*/,  9 /*fa13*/,
    8 /*fa14*/,  9 /*fa15*/,  9 /*fa16*/,  10 /*fa17*/, 8 /*fa18*/,
    9 /*fa19*/,  9 /*fa1a*/,  10 /*fa1b*/, 9 /*fa1c*/,  10 /*fa1d*/,
    10 /*fa1e*/, 11 /*fa1f*/, 7 /*fa20*/,  8 /*fa21*/,  8 /*fa22*/,
    9 /*fa23*/,  8 /*fa24*/,  9 /*fa25*/,  9 /*fa26*/,  10 /*fa27*/,
    8 /*fa28*/,  9 /*fa29*/,  9 /*fa2a*/,  10 /*fa2b*/, 9 /*fa2c*/,
    10 /*fa2d*/, 10 /*fa2e*/, 11 /*fa2f*/, 8 /*fa30*/,  9 /*fa31*/,
    9 /*fa32*/,  10 /*fa33*/, 9 /*fa34*/,  10 /*fa35*/, 10 /*fa36*/,
    11 /*fa37*/, 9 /*fa38*/,  10 /*fa39*/, 10 /*fa3a*/, 11 /*fa3b*/,
    10 /*fa3c*/, 11 /*fa3d*/, 11 /*fa3e*/, 12 /*fa3f*/, 7 /*fa40*/,
    8 /*fa41*/,  8 /*fa42*/,  9 /*fa43*/,  8 /*fa44*/,  9 /*fa45*/,
    9 /*fa46*/,  10 /*fa47*/, 8 /*fa48*/,  9 /*fa49*/,  9 /*fa4a*/,
    10 /*fa4b*/, 9 /*fa4c*/,  10 /*fa4d*/, 10 /*fa4e*/, 11 /*fa4f*/,
    8 /*fa50*/,  9 /*fa51*/,  9 /*fa52*/,  10 /*fa53*/, 9 /*fa54*/,
    10 /*fa55*/, 10 /*fa56*/, 11 /*fa57*/, 9 /*fa58*/,  10 /*fa59*/,
    10 /*fa5a*/, 11 /*fa5b*/, 10 /*fa5c*/, 11 /*fa5d*/, 11 /*fa5e*/,
    12 /*fa5f*/, 8 /*fa60*/,  9 /*fa61*/,  9 /*fa62*/,  10 /*fa63*/,
    9 /*fa64*/,  10 /*fa65*/, 10 /*fa66*/, 11 /*fa67*/, 9 /*fa68*/,
    10 /*fa69*/, 10 /*fa6a*/, 11 /*fa6b*/, 10 /*fa6c*/, 11 /*fa6d*/,
    11 /*fa6e*/, 12 /*fa6f*/, 9 /*fa70*/,  10 /*fa71*/, 10 /*fa72*/,
    11 /*fa73*/, 10 /*fa74*/, 11 /*fa75*/, 11 /*fa76*/, 12 /*fa77*/,
    10 /*fa78*/, 11 /*fa79*/, 11 /*fa7a*/, 12 /*fa7b*/, 11 /*fa7c*/,
    12 /*fa7d*/, 12 /*fa7e*/, 13 /*fa7f*/, 7 /*fa80*/,  8 /*fa81*/,
    8 /*fa82*/,  9 /*fa83*/,  8 /*fa84*/,  9 /*fa85*/,  9 /*fa86*/,
    10 /*fa87*/, 8 /*fa88*/,  9 /*fa89*/,  9 /*fa8a*/,  10 /*fa8b*/,
    9 /*fa8c*/,  10 /*fa8d*/, 10 /*fa8e*/, 11 /*fa8f*/, 8 /*fa90*/,
    9 /*fa91*/,  9 /*fa92*/,  10 /*fa93*/, 9 /*fa94*/,  10 /*fa95*/,
    10 /*fa96*/, 11 /*fa97*/, 9 /*fa98*/,  10 /*fa99*/, 10 /*fa9a*/,
    11 /*fa9b*/, 10 /*fa9c*/, 11 /*fa9d*/, 11 /*fa9e*/, 12 /*fa9f*/,
    8 /*faa0*/,  9 /*faa1*/,  9 /*faa2*/,  10 /*faa3*/, 9 /*faa4*/,
    10 /*faa5*/, 10 /*faa6*/, 11 /*faa7*/, 9 /*faa8*/,  10 /*faa9*/,
    10 /*faaa*/, 11 /*faab*/, 10 /*faac*/, 11 /*faad*/, 11 /*faae*/,
    12 /*faaf*/, 9 /*fab0*/,  10 /*fab1*/, 10 /*fab2*/, 11 /*fab3*/,
    10 /*fab4*/, 11 /*fab5*/, 11 /*fab6*/, 12 /*fab7*/, 10 /*fab8*/,
    11 /*fab9*/, 11 /*faba*/, 12 /*fabb*/, 11 /*fabc*/, 12 /*fabd*/,
    12 /*fabe*/, 13 /*fabf*/, 8 /*fac0*/,  9 /*fac1*/,  9 /*fac2*/,
    10 /*fac3*/, 9 /*fac4*/,  10 /*fac5*/, 10 /*fac6*/, 11 /*fac7*/,
    9 /*fac8*/,  10 /*fac9*/, 10 /*faca*/, 11 /*facb*/, 10 /*facc*/,
    11 /*facd*/, 11 /*face*/, 12 /*facf*/, 9 /*fad0*/,  10 /*fad1*/,
    10 /*fad2*/, 11 /*fad3*/, 10 /*fad4*/, 11 /*fad5*/, 11 /*fad6*/,
    12 /*fad7*/, 10 /*fad8*/, 11 /*fad9*/, 11 /*fada*/, 12 /*fadb*/,
    11 /*fadc*/, 12 /*fadd*/, 12 /*fade*/, 13 /*fadf*/, 9 /*fae0*/,
    10 /*fae1*/, 10 /*fae2*/, 11 /*fae3*/, 10 /*fae4*/, 11 /*fae5*/,
    11 /*fae6*/, 12 /*fae7*/, 10 /*fae8*/, 11 /*fae9*/, 11 /*faea*/,
    12 /*faeb*/, 11 /*faec*/, 12 /*faed*/, 12 /*faee*/, 13 /*faef*/,
    10 /*faf0*/, 11 /*faf1*/, 11 /*faf2*/, 12 /*faf3*/, 11 /*faf4*/,
    12 /*faf5*/, 12 /*faf6*/, 13 /*faf7*/, 11 /*faf8*/, 12 /*faf9*/,
    12 /*fafa*/, 13 /*fafb*/, 12 /*fafc*/, 13 /*fafd*/, 13 /*fafe*/,
    14 /*faff*/, 7 /*fb00*/,  8 /*fb01*/,  8 /*fb02*/,  9 /*fb03*/,
    8 /*fb04*/,  9 /*fb05*/,  9 /*fb06*/,  10 /*fb07*/, 8 /*fb08*/,
    9 /*fb09*/,  9 /*fb0a*/,  10 /*fb0b*/, 9 /*fb0c*/,  10 /*fb0d*/,
    10 /*fb0e*/, 11 /*fb0f*/, 8 /*fb10*/,  9 /*fb11*/,  9 /*fb12*/,
    10 /*fb13*/, 9 /*fb14*/,  10 /*fb15*/, 10 /*fb16*/, 11 /*fb17*/,
    9 /*fb18*/,  10 /*fb19*/, 10 /*fb1a*/, 11 /*fb1b*/, 10 /*fb1c*/,
    11 /*fb1d*/, 11 /*fb1e*/, 12 /*fb1f*/, 8 /*fb20*/,  9 /*fb21*/,
    9 /*fb22*/,  10 /*fb23*/, 9 /*fb24*/,  10 /*fb25*/, 10 /*fb26*/,
    11 /*fb27*/, 9 /*fb28*/,  10 /*fb29*/, 10 /*fb2a*/, 11 /*fb2b*/,
    10 /*fb2c*/, 11 /*fb2d*/, 11 /*fb2e*/, 12 /*fb2f*/, 9 /*fb30*/,
    10 /*fb31*/, 10 /*fb32*/, 11 /*fb33*/, 10 /*fb34*/, 11 /*fb35*/,
    11 /*fb36*/, 12 /*fb37*/, 10 /*fb38*/, 11 /*fb39*/, 11 /*fb3a*/,
    12 /*fb3b*/, 11 /*fb3c*/, 12 /*fb3d*/, 12 /*fb3e*/, 13 /*fb3f*/,
    8 /*fb40*/,  9 /*fb41*/,  9 /*fb42*/,  10 /*fb43*/, 9 /*fb44*/,
    10 /*fb45*/, 10 /*fb46*/, 11 /*fb47*/, 9 /*fb48*/,  10 /*fb49*/,
    10 /*fb4a*/, 11 /*fb4b*/, 10 /*fb4c*/, 11 /*fb4d*/, 11 /*fb4e*/,
    12 /*fb4f*/, 9 /*fb50*/,  10 /*fb51*/, 10 /*fb52*/, 11 /*fb53*/,
    10 /*fb54*/, 11 /*fb55*/, 11 /*fb56*/, 12 /*fb57*/, 10 /*fb58*/,
    11 /*fb59*/, 11 /*fb5a*/, 12 /*fb5b*/, 11 /*fb5c*/, 12 /*fb5d*/,
    12 /*fb5e*/, 13 /*fb5f*/, 9 /*fb60*/,  10 /*fb61*/, 10 /*fb62*/,
    11 /*fb63*/, 10 /*fb64*/, 11 /*fb65*/, 11 /*fb66*/, 12 /*fb67*/,
    10 /*fb68*/, 11 /*fb69*/, 11 /*fb6a*/, 12 /*fb6b*/, 11 /*fb6c*/,
    12 /*fb6d*/, 12 /*fb6e*/, 13 /*fb6f*/, 10 /*fb70*/, 11 /*fb71*/,
    11 /*fb72*/, 12 /*fb73*/, 11 /*fb74*/, 12 /*fb75*/, 12 /*fb76*/,
    13 /*fb77*/, 11 /*fb78*/, 12 /*fb79*/, 12 /*fb7a*/, 13 /*fb7b*/,
    12 /*fb7c*/, 13 /*fb7d*/, 13 /*fb7e*/, 14 /*fb7f*/, 8 /*fb80*/,
    9 /*fb81*/,  9 /*fb82*/,  10 /*fb83*/, 9 /*fb84*/,  10 /*fb85*/,
    10 /*fb86*/, 11 /*fb87*/, 9 /*fb88*/,  10 /*fb89*/, 10 /*fb8a*/,
    11 /*fb8b*/, 10 /*fb8c*/, 11 /*fb8d*/, 11 /*fb8e*/, 12 /*fb8f*/,
    9 /*fb90*/,  10 /*fb91*/, 10 /*fb92*/, 11 /*fb93*/, 10 /*fb94*/,
    11 /*fb95*/, 11 /*fb96*/, 12 /*fb97*/, 10 /*fb98*/, 11 /*fb99*/,
    11 /*fb9a*/, 12 /*fb9b*/, 11 /*fb9c*/, 12 /*fb9d*/, 12 /*fb9e*/,
    13 /*fb9f*/, 9 /*fba0*/,  10 /*fba1*/, 10 /*fba2*/, 11 /*fba3*/,
    10 /*fba4*/, 11 /*fba5*/, 11 /*fba6*/, 12 /*fba7*/, 10 /*fba8*/,
    11 /*fba9*/, 11 /*fbaa*/, 12 /*fbab*/, 11 /*fbac*/, 12 /*fbad*/,
    12 /*fbae*/, 13 /*fbaf*/, 10 /*fbb0*/, 11 /*fbb1*/, 11 /*fbb2*/,
    12 /*fbb3*/, 11 /*fbb4*/, 12 /*fbb5*/, 12 /*fbb6*/, 13 /*fbb7*/,
    11 /*fbb8*/, 12 /*fbb9*/, 12 /*fbba*/, 13 /*fbbb*/, 12 /*fbbc*/,
    13 /*fbbd*/, 13 /*fbbe*/, 14 /*fbbf*/, 9 /*fbc0*/,  10 /*fbc1*/,
    10 /*fbc2*/, 11 /*fbc3*/, 10 /*fbc4*/, 11 /*fbc5*/, 11 /*fbc6*/,
    12 /*fbc7*/, 10 /*fbc8*/, 11 /*fbc9*/, 11 /*fbca*/, 12 /*fbcb*/,
    11 /*fbcc*/, 12 /*fbcd*/, 12 /*fbce*/, 13 /*fbcf*/, 10 /*fbd0*/,
    11 /*fbd1*/, 11 /*fbd2*/, 12 /*fbd3*/, 11 /*fbd4*/, 12 /*fbd5*/,
    12 /*fbd6*/, 13 /*fbd7*/, 11 /*fbd8*/, 12 /*fbd9*/, 12 /*fbda*/,
    13 /*fbdb*/, 12 /*fbdc*/, 13 /*fbdd*/, 13 /*fbde*/, 14 /*fbdf*/,
    10 /*fbe0*/, 11 /*fbe1*/, 11 /*fbe2*/, 12 /*fbe3*/, 11 /*fbe4*/,
    12 /*fbe5*/, 12 /*fbe6*/, 13 /*fbe7*/, 11 /*fbe8*/, 12 /*fbe9*/,
    12 /*fbea*/, 13 /*fbeb*/, 12 /*fbec*/, 13 /*fbed*/, 13 /*fbee*/,
    14 /*fbef*/, 11 /*fbf0*/, 12 /*fbf1*/, 12 /*fbf2*/, 13 /*fbf3*/,
    12 /*fbf4*/, 13 /*fbf5*/, 13 /*fbf6*/, 14 /*fbf7*/, 12 /*fbf8*/,
    13 /*fbf9*/, 13 /*fbfa*/, 14 /*fbfb*/, 13 /*fbfc*/, 14 /*fbfd*/,
    14 /*fbfe*/, 15 /*fbff*/, 6 /*fc00*/,  7 /*fc01*/,  7 /*fc02*/,
    8 /*fc03*/,  7 /*fc04*/,  8 /*fc05*/,  8 /*fc06*/,  9 /*fc07*/,
    7 /*fc08*/,  8 /*fc09*/,  8 /*fc0a*/,  9 /*fc0b*/,  8 /*fc0c*/,
    9 /*fc0d*/,  9 /*fc0e*/,  10 /*fc0f*/, 7 /*fc10*/,  8 /*fc11*/,
    8 /*fc12*/,  9 /*fc13*/,  8 /*fc14*/,  9 /*fc15*/,  9 /*fc16*/,
    10 /*fc17*/, 8 /*fc18*/,  9 /*fc19*/,  9 /*fc1a*/,  10 /*fc1b*/,
    9 /*fc1c*/,  10 /*fc1d*/, 10 /*fc1e*/, 11 /*fc1f*/, 7 /*fc20*/,
    8 /*fc21*/,  8 /*fc22*/,  9 /*fc23*/,  8 /*fc24*/,  9 /*fc25*/,
    9 /*fc26*/,  10 /*fc27*/, 8 /*fc28*/,  9 /*fc29*/,  9 /*fc2a*/,
    10 /*fc2b*/, 9 /*fc2c*/,  10 /*fc2d*/, 10 /*fc2e*/, 11 /*fc2f*/,
    8 /*fc30*/,  9 /*fc31*/,  9 /*fc32*/,  10 /*fc33*/, 9 /*fc34*/,
    10 /*fc35*/, 10 /*fc36*/, 11 /*fc37*/, 9 /*fc38*/,  10 /*fc39*/,
    10 /*fc3a*/, 11 /*fc3b*/, 10 /*fc3c*/, 11 /*fc3d*/, 11 /*fc3e*/,
    12 /*fc3f*/, 7 /*fc40*/,  8 /*fc41*/,  8 /*fc42*/,  9 /*fc43*/,
    8 /*fc44*/,  9 /*fc45*/,  9 /*fc46*/,  10 /*fc47*/, 8 /*fc48*/,
    9 /*fc49*/,  9 /*fc4a*/,  10 /*fc4b*/, 9 /*fc4c*/,  10 /*fc4d*/,
    10 /*fc4e*/, 11 /*fc4f*/, 8 /*fc50*/,  9 /*fc51*/,  9 /*fc52*/,
    10 /*fc53*/, 9 /*fc54*/,  10 /*fc55*/, 10 /*fc56*/, 11 /*fc57*/,
    9 /*fc58*/,  10 /*fc59*/, 10 /*fc5a*/, 11 /*fc5b*/, 10 /*fc5c*/,
    11 /*fc5d*/, 11 /*fc5e*/, 12 /*fc5f*/, 8 /*fc60*/,  9 /*fc61*/,
    9 /*fc62*/,  10 /*fc63*/, 9 /*fc64*/,  10 /*fc65*/, 10 /*fc66*/,
    11 /*fc67*/, 9 /*fc68*/,  10 /*fc69*/, 10 /*fc6a*/, 11 /*fc6b*/,
    10 /*fc6c*/, 11 /*fc6d*/, 11 /*fc6e*/, 12 /*fc6f*/, 9 /*fc70*/,
    10 /*fc71*/, 10 /*fc72*/, 11 /*fc73*/, 10 /*fc74*/, 11 /*fc75*/,
    11 /*fc76*/, 12 /*fc77*/, 10 /*fc78*/, 11 /*fc79*/, 11 /*fc7a*/,
    12 /*fc7b*/, 11 /*fc7c*/, 12 /*fc7d*/, 12 /*fc7e*/, 13 /*fc7f*/,
    7 /*fc80*/,  8 /*fc81*/,  8 /*fc82*/,  9 /*fc83*/,  8 /*fc84*/,
    9 /*fc85*/,  9 /*fc86*/,  10 /*fc87*/, 8 /*fc88*/,  9 /*fc89*/,
    9 /*fc8a*/,  10 /*fc8b*/, 9 /*fc8c*/,  10 /*fc8d*/, 10 /*fc8e*/,
    11 /*fc8f*/, 8 /*fc90*/,  9 /*fc91*/,  9 /*fc92*/,  10 /*fc93*/,
    9 /*fc94*/,  10 /*fc95*/, 10 /*fc96*/, 11 /*fc97*/, 9 /*fc98*/,
    10 /*fc99*/, 10 /*fc9a*/, 11 /*fc9b*/, 10 /*fc9c*/, 11 /*fc9d*/,
    11 /*fc9e*/, 12 /*fc9f*/, 8 /*fca0*/,  9 /*fca1*/,  9 /*fca2*/,
    10 /*fca3*/, 9 /*fca4*/,  10 /*fca5*/, 10 /*fca6*/, 11 /*fca7*/,
    9 /*fca8*/,  10 /*fca9*/, 10 /*fcaa*/, 11 /*fcab*/, 10 /*fcac*/,
    11 /*fcad*/, 11 /*fcae*/, 12 /*fcaf*/, 9 /*fcb0*/,  10 /*fcb1*/,
    10 /*fcb2*/, 11 /*fcb3*/, 10 /*fcb4*/, 11 /*fcb5*/, 11 /*fcb6*/,
    12 /*fcb7*/, 10 /*fcb8*/, 11 /*fcb9*/, 11 /*fcba*/, 12 /*fcbb*/,
    11 /*fcbc*/, 12 /*fcbd*/, 12 /*fcbe*/, 13 /*fcbf*/, 8 /*fcc0*/,
    9 /*fcc1*/,  9 /*fcc2*/,  10 /*fcc3*/, 9 /*fcc4*/,  10 /*fcc5*/,
    10 /*fcc6*/, 11 /*fcc7*/, 9 /*fcc8*/,  10 /*fcc9*/, 10 /*fcca*/,
    11 /*fccb*/, 10 /*fccc*/, 11 /*fccd*/, 11 /*fcce*/, 12 /*fccf*/,
    9 /*fcd0*/,  10 /*fcd1*/, 10 /*fcd2*/, 11 /*fcd3*/, 10 /*fcd4*/,
    11 /*fcd5*/, 11 /*fcd6*/, 12 /*fcd7*/, 10 /*fcd8*/, 11 /*fcd9*/,
    11 /*fcda*/, 12 /*fcdb*/, 11 /*fcdc*/, 12 /*fcdd*/, 12 /*fcde*/,
    13 /*fcdf*/, 9 /*fce0*/,  10 /*fce1*/, 10 /*fce2*/, 11 /*fce3*/,
    10 /*fce4*/, 11 /*fce5*/, 11 /*fce6*/, 12 /*fce7*/, 10 /*fce8*/,
    11 /*fce9*/, 11 /*fcea*/, 12 /*fceb*/, 11 /*fcec*/, 12 /*fced*/,
    12 /*fcee*/, 13 /*fcef*/, 10 /*fcf0*/, 11 /*fcf1*/, 11 /*fcf2*/,
    12 /*fcf3*/, 11 /*fcf4*/, 12 /*fcf5*/, 12 /*fcf6*/, 13 /*fcf7*/,
    11 /*fcf8*/, 12 /*fcf9*/, 12 /*fcfa*/, 13 /*fcfb*/, 12 /*fcfc*/,
    13 /*fcfd*/, 13 /*fcfe*/, 14 /*fcff*/, 7 /*fd00*/,  8 /*fd01*/,
    8 /*fd02*/,  9 /*fd03*/,  8 /*fd04*/,  9 /*fd05*/,  9 /*fd06*/,
    10 /*fd07*/, 8 /*fd08*/,  9 /*fd09*/,  9 /*fd0a*/,  10 /*fd0b*/,
    9 /*fd0c*/,  10 /*fd0d*/, 10 /*fd0e*/, 11 /*fd0f*/, 8 /*fd10*/,
    9 /*fd11*/,  9 /*fd12*/,  10 /*fd13*/, 9 /*fd14*/,  10 /*fd15*/,
    10 /*fd16*/, 11 /*fd17*/, 9 /*fd18*/,  10 /*fd19*/, 10 /*fd1a*/,
    11 /*fd1b*/, 10 /*fd1c*/, 11 /*fd1d*/, 11 /*fd1e*/, 12 /*fd1f*/,
    8 /*fd20*/,  9 /*fd21*/,  9 /*fd22*/,  10 /*fd23*/, 9 /*fd24*/,
    10 /*fd25*/, 10 /*fd26*/, 11 /*fd27*/, 9 /*fd28*/,  10 /*fd29*/,
    10 /*fd2a*/, 11 /*fd2b*/, 10 /*fd2c*/, 11 /*fd2d*/, 11 /*fd2e*/,
    12 /*fd2f*/, 9 /*fd30*/,  10 /*fd31*/, 10 /*fd32*/, 11 /*fd33*/,
    10 /*fd34*/, 11 /*fd35*/, 11 /*fd36*/, 12 /*fd37*/, 10 /*fd38*/,
    11 /*fd39*/, 11 /*fd3a*/, 12 /*fd3b*/, 11 /*fd3c*/, 12 /*fd3d*/,
    12 /*fd3e*/, 13 /*fd3f*/, 8 /*fd40*/,  9 /*fd41*/,  9 /*fd42*/,
    10 /*fd43*/, 9 /*fd44*/,  10 /*fd45*/, 10 /*fd46*/, 11 /*fd47*/,
    9 /*fd48*/,  10 /*fd49*/, 10 /*fd4a*/, 11 /*fd4b*/, 10 /*fd4c*/,
    11 /*fd4d*/, 11 /*fd4e*/, 12 /*fd4f*/, 9 /*fd50*/,  10 /*fd51*/,
    10 /*fd52*/, 11 /*fd53*/, 10 /*fd54*/, 11 /*fd55*/, 11 /*fd56*/,
    12 /*fd57*/, 10 /*fd58*/, 11 /*fd59*/, 11 /*fd5a*/, 12 /*fd5b*/,
    11 /*fd5c*/, 12 /*fd5d*/, 12 /*fd5e*/, 13 /*fd5f*/, 9 /*fd60*/,
    10 /*fd61*/, 10 /*fd62*/, 11 /*fd63*/, 10 /*fd64*/, 11 /*fd65*/,
    11 /*fd66*/, 12 /*fd67*/, 10 /*fd68*/, 11 /*fd69*/, 11 /*fd6a*/,
    12 /*fd6b*/, 11 /*fd6c*/, 12 /*fd6d*/, 12 /*fd6e*/, 13 /*fd6f*/,
    10 /*fd70*/, 11 /*fd71*/, 11 /*fd72*/, 12 /*fd73*/, 11 /*fd74*/,
    12 /*fd75*/, 12 /*fd76*/, 13 /*fd77*/, 11 /*fd78*/, 12 /*fd79*/,
    12 /*fd7a*/, 13 /*fd7b*/, 12 /*fd7c*/, 13 /*fd7d*/, 13 /*fd7e*/,
    14 /*fd7f*/, 8 /*fd80*/,  9 /*fd81*/,  9 /*fd82*/,  10 /*fd83*/,
    9 /*fd84*/,  10 /*fd85*/, 10 /*fd86*/, 11 /*fd87*/, 9 /*fd88*/,
    10 /*fd89*/, 10 /*fd8a*/, 11 /*fd8b*/, 10 /*fd8c*/, 11 /*fd8d*/,
    11 /*fd8e*/, 12 /*fd8f*/, 9 /*fd90*/,  10 /*fd91*/, 10 /*fd92*/,
    11 /*fd93*/, 10 /*fd94*/, 11 /*fd95*/, 11 /*fd96*/, 12 /*fd97*/,
    10 /*fd98*/, 11 /*fd99*/, 11 /*fd9a*/, 12 /*fd9b*/, 11 /*fd9c*/,
    12 /*fd9d*/, 12 /*fd9e*/, 13 /*fd9f*/, 9 /*fda0*/,  10 /*fda1*/,
    10 /*fda2*/, 11 /*fda3*/, 10 /*fda4*/, 11 /*fda5*/, 11 /*fda6*/,
    12 /*fda7*/, 10 /*fda8*/, 11 /*fda9*/, 11 /*fdaa*/, 12 /*fdab*/,
    11 /*fdac*/, 12 /*fdad*/, 12 /*fdae*/, 13 /*fdaf*/, 10 /*fdb0*/,
    11 /*fdb1*/, 11 /*fdb2*/, 12 /*fdb3*/, 11 /*fdb4*/, 12 /*fdb5*/,
    12 /*fdb6*/, 13 /*fdb7*/, 11 /*fdb8*/, 12 /*fdb9*/, 12 /*fdba*/,
    13 /*fdbb*/, 12 /*fdbc*/, 13 /*fdbd*/, 13 /*fdbe*/, 14 /*fdbf*/,
    9 /*fdc0*/,  10 /*fdc1*/, 10 /*fdc2*/, 11 /*fdc3*/, 10 /*fdc4*/,
    11 /*fdc5*/, 11 /*fdc6*/, 12 /*fdc7*/, 10 /*fdc8*/, 11 /*fdc9*/,
    11 /*fdca*/, 12 /*fdcb*/, 11 /*fdcc*/, 12 /*fdcd*/, 12 /*fdce*/,
    13 /*fdcf*/, 10 /*fdd0*/, 11 /*fdd1*/, 11 /*fdd2*/, 12 /*fdd3*/,
    11 /*fdd4*/, 12 /*fdd5*/, 12 /*fdd6*/, 13 /*fdd7*/, 11 /*fdd8*/,
    12 /*fdd9*/, 12 /*fdda*/, 13 /*fddb*/, 12 /*fddc*/, 13 /*fddd*/,
    13 /*fdde*/, 14 /*fddf*/, 10 /*fde0*/, 11 /*fde1*/, 11 /*fde2*/,
    12 /*fde3*/, 11 /*fde4*/, 12 /*fde5*/, 12 /*fde6*/, 13 /*fde7*/,
    11 /*fde8*/, 12 /*fde9*/, 12 /*fdea*/, 13 /*fdeb*/, 12 /*fdec*/,
    13 /*fded*/, 13 /*fdee*/, 14 /*fdef*/, 11 /*fdf0*/, 12 /*fdf1*/,
    12 /*fdf2*/, 13 /*fdf3*/, 12 /*fdf4*/, 13 /*fdf5*/, 13 /*fdf6*/,
    14 /*fdf7*/, 12 /*fdf8*/, 13 /*fdf9*/, 13 /*fdfa*/, 14 /*fdfb*/,
    13 /*fdfc*/, 14 /*fdfd*/, 14 /*fdfe*/, 15 /*fdff*/, 7 /*fe00*/,
    8 /*fe01*/,  8 /*fe02*/,  9 /*fe03*/,  8 /*fe04*/,  9 /*fe05*/,
    9 /*fe06*/,  10 /*fe07*/, 8 /*fe08*/,  9 /*fe09*/,  9 /*fe0a*/,
    10 /*fe0b*/, 9 /*fe0c*/,  10 /*fe0d*/, 10 /*fe0e*/, 11 /*fe0f*/,
    8 /*fe10*/,  9 /*fe11*/,  9 /*fe12*/,  10 /*fe13*/, 9 /*fe14*/,
    10 /*fe15*/, 10 /*fe16*/, 11 /*fe17*/, 9 /*fe18*/,  10 /*fe19*/,
    10 /*fe1a*/, 11 /*fe1b*/, 10 /*fe1c*/, 11 /*fe1d*/, 11 /*fe1e*/,
    12 /*fe1f*/, 8 /*fe20*/,  9 /*fe21*/,  9 /*fe22*/,  10 /*fe23*/,
    9 /*fe24*/,  10 /*fe25*/, 10 /*fe26*/, 11 /*fe27*/, 9 /*fe28*/,
    10 /*fe29*/, 10 /*fe2a*/, 11 /*fe2b*/, 10 /*fe2c*/, 11 /*fe2d*/,
    11 /*fe2e*/, 12 /*fe2f*/, 9 /*fe30*/,  10 /*fe31*/, 10 /*fe32*/,
    11 /*fe33*/, 10 /*fe34*/, 11 /*fe35*/, 11 /*fe36*/, 12 /*fe37*/,
    10 /*fe38*/, 11 /*fe39*/, 11 /*fe3a*/, 12 /*fe3b*/, 11 /*fe3c*/,
    12 /*fe3d*/, 12 /*fe3e*/, 13 /*fe3f*/, 8 /*fe40*/,  9 /*fe41*/,
    9 /*fe42*/,  10 /*fe43*/, 9 /*fe44*/,  10 /*fe45*/, 10 /*fe46*/,
    11 /*fe47*/, 9 /*fe48*/,  10 /*fe49*/, 10 /*fe4a*/, 11 /*fe4b*/,
    10 /*fe4c*/, 11 /*fe4d*/, 11 /*fe4e*/, 12 /*fe4f*/, 9 /*fe50*/,
    10 /*fe51*/, 10 /*fe52*/, 11 /*fe53*/, 10 /*fe54*/, 11 /*fe55*/,
    11 /*fe56*/, 12 /*fe57*/, 10 /*fe58*/, 11 /*fe59*/, 11 /*fe5a*/,
    12 /*fe5b*/, 11 /*fe5c*/, 12 /*fe5d*/, 12 /*fe5e*/, 13 /*fe5f*/,
    9 /*fe60*/,  10 /*fe61*/, 10 /*fe62*/, 11 /*fe63*/, 10 /*fe64*/,
    11 /*fe65*/, 11 /*fe66*/, 12 /*fe67*/, 10 /*fe68*/, 11 /*fe69*/,
    11 /*fe6a*/, 12 /*fe6b*/, 11 /*fe6c*/, 12 /*fe6d*/, 12 /*fe6e*/,
    13 /*fe6f*/, 10 /*fe70*/, 11 /*fe71*/, 11 /*fe72*/, 12 /*fe73*/,
    11 /*fe74*/, 12 /*fe75*/, 12 /*fe76*/, 13 /*fe77*/, 11 /*fe78*/,
    12 /*fe79*/, 12 /*fe7a*/, 13 /*fe7b*/, 12 /*fe7c*/, 13 /*fe7d*/,
    13 /*fe7e*/, 14 /*fe7f*/, 8 /*fe80*/,  9 /*fe81*/,  9 /*fe82*/,
    10 /*fe83*/, 9 /*fe84*/,  10 /*fe85*/, 10 /*fe86*/, 11 /*fe87*/,
    9 /*fe88*/,  10 /*fe89*/, 10 /*fe8a*/, 11 /*fe8b*/, 10 /*fe8c*/,
    11 /*fe8d*/, 11 /*fe8e*/, 12 /*fe8f*/, 9 /*fe90*/,  10 /*fe91*/,
    10 /*fe92*/, 11 /*fe93*/, 10 /*fe94*/, 11 /*fe95*/, 11 /*fe96*/,
    12 /*fe97*/, 10 /*fe98*/, 11 /*fe99*/, 11 /*fe9a*/, 12 /*fe9b*/,
    11 /*fe9c*/, 12 /*fe9d*/, 12 /*fe9e*/, 13 /*fe9f*/, 9 /*fea0*/,
    10 /*fea1*/, 10 /*fea2*/, 11 /*fea3*/, 10 /*fea4*/, 11 /*fea5*/,
    11 /*fea6*/, 12 /*fea7*/, 10 /*fea8*/, 11 /*fea9*/, 11 /*feaa*/,
    12 /*feab*/, 11 /*feac*/, 12 /*fead*/, 12 /*feae*/, 13 /*feaf*/,
    10 /*feb0*/, 11 /*feb1*/, 11 /*feb2*/, 12 /*feb3*/, 11 /*feb4*/,
    12 /*feb5*/, 12 /*feb6*/, 13 /*feb7*/, 11 /*feb8*/, 12 /*feb9*/,
    12 /*feba*/, 13 /*febb*/, 12 /*febc*/, 13 /*febd*/, 13 /*febe*/,
    14 /*febf*/, 9 /*fec0*/,  10 /*fec1*/, 10 /*fec2*/, 11 /*fec3*/,
    10 /*fec4*/, 11 /*fec5*/, 11 /*fec6*/, 12 /*fec7*/, 10 /*fec8*/,
    11 /*fec9*/, 11 /*feca*/, 12 /*fecb*/, 11 /*fecc*/, 12 /*fecd*/,
    12 /*fece*/, 13 /*fecf*/, 10 /*fed0*/, 11 /*fed1*/, 11 /*fed2*/,
    12 /*fed3*/, 11 /*fed4*/, 12 /*fed5*/, 12 /*fed6*/, 13 /*fed7*/,
    11 /*fed8*/, 12 /*fed9*/, 12 /*feda*/, 13 /*fedb*/, 12 /*fedc*/,
    13 /*fedd*/, 13 /*fede*/, 14 /*fedf*/, 10 /*fee0*/, 11 /*fee1*/,
    11 /*fee2*/, 12 /*fee3*/, 11 /*fee4*/, 12 /*fee5*/, 12 /*fee6*/,
    13 /*fee7*/, 11 /*fee8*/, 12 /*fee9*/, 12 /*feea*/, 13 /*feeb*/,
    12 /*feec*/, 13 /*feed*/, 13 /*feee*/, 14 /*feef*/, 11 /*fef0*/,
    12 /*fef1*/, 12 /*fef2*/, 13 /*fef3*/, 12 /*fef4*/, 13 /*fef5*/,
    13 /*fef6*/, 14 /*fef7*/, 12 /*fef8*/, 13 /*fef9*/, 13 /*fefa*/,
    14 /*fefb*/, 13 /*fefc*/, 14 /*fefd*/, 14 /*fefe*/, 15 /*feff*/,
    8 /*ff00*/,  9 /*ff01*/,  9 /*ff02*/,  10 /*ff03*/, 9 /*ff04*/,
    10 /*ff05*/, 10 /*ff06*/, 11 /*ff07*/, 9 /*ff08*/,  10 /*ff09*/,
    10 /*ff0a*/, 11 /*ff0b*/, 10 /*ff0c*/, 11 /*ff0d*/, 11 /*ff0e*/,
    12 /*ff0f*/, 9 /*ff10*/,  10 /*ff11*/, 10 /*ff12*/, 11 /*ff13*/,
    10 /*ff14*/, 11 /*ff15*/, 11 /*ff16*/, 12 /*ff17*/, 10 /*ff18*/,
    11 /*ff19*/, 11 /*ff1a*/, 12 /*ff1b*/, 11 /*ff1c*/, 12 /*ff1d*/,
    12 /*ff1e*/, 13 /*ff1f*/, 9 /*ff20*/,  10 /*ff21*/, 10 /*ff22*/,
    11 /*ff23*/, 10 /*ff24*/, 11 /*ff25*/, 11 /*ff26*/, 12 /*ff27*/,
    10 /*ff28*/, 11 /*ff29*/, 11 /*ff2a*/, 12 /*ff2b*/, 11 /*ff2c*/,
    12 /*ff2d*/, 12 /*ff2e*/, 13 /*ff2f*/, 10 /*ff30*/, 11 /*ff31*/,
    11 /*ff32*/, 12 /*ff33*/, 11 /*ff34*/, 12 /*ff35*/, 12 /*ff36*/,
    13 /*ff37*/, 11 /*ff38*/, 12 /*ff39*/, 12 /*ff3a*/, 13 /*ff3b*/,
    12 /*ff3c*/, 13 /*ff3d*/, 13 /*ff3e*/, 14 /*ff3f*/, 9 /*ff40*/,
    10 /*ff41*/, 10 /*ff42*/, 11 /*ff43*/, 10 /*ff44*/, 11 /*ff45*/,
    11 /*ff46*/, 12 /*ff47*/, 10 /*ff48*/, 11 /*ff49*/, 11 /*ff4a*/,
    12 /*ff4b*/, 11 /*ff4c*/, 12 /*ff4d*/, 12 /*ff4e*/, 13 /*ff4f*/,
    10 /*ff50*/, 11 /*ff51*/, 11 /*ff52*/, 12 /*ff53*/, 11 /*ff54*/,
    12 /*ff55*/, 12 /*ff56*/, 13 /*ff57*/, 11 /*ff58*/, 12 /*ff59*/,
    12 /*ff5a*/, 13 /*ff5b*/, 12 /*ff5c*/, 13 /*ff5d*/, 13 /*ff5e*/,
    14 /*ff5f*/, 10 /*ff60*/, 11 /*ff61*/, 11 /*ff62*/, 12 /*ff63*/,
    11 /*ff64*/, 12 /*ff65*/, 12 /*ff66*/, 13 /*ff67*/, 11 /*ff68*/,
    12 /*ff69*/, 12 /*ff6a*/, 13 /*ff6b*/, 12 /*ff6c*/, 13 /*ff6d*/,
    13 /*ff6e*/, 14 /*ff6f*/, 11 /*ff70*/, 12 /*ff71*/, 12 /*ff72*/,
    13 /*ff73*/, 12 /*ff74*/, 13 /*ff75*/, 13 /*ff76*/, 14 /*ff77*/,
    12 /*ff78*/, 13 /*ff79*/, 13 /*ff7a*/, 14 /*ff7b*/, 13 /*ff7c*/,
    14 /*ff7d*/, 14 /*ff7e*/, 15 /*ff7f*/, 9 /*ff80*/,  10 /*ff81*/,
    10 /*ff82*/, 11 /*ff83*/, 10 /*ff84*/, 11 /*ff85*/, 11 /*ff86*/,
    12 /*ff87*/, 10 /*ff88*/, 11 /*ff89*/, 11 /*ff8a*/, 12 /*ff8b*/,
    11 /*ff8c*/, 12 /*ff8d*/, 12 /*ff8e*/, 13 /*ff8f*/, 10 /*ff90*/,
    11 /*ff91*/, 11 /*ff92*/, 12 /*ff93*/, 11 /*ff94*/, 12 /*ff95*/,
    12 /*ff96*/, 13 /*ff97*/, 11 /*ff98*/, 12 /*ff99*/, 12 /*ff9a*/,
    13 /*ff9b*/, 12 /*ff9c*/, 13 /*ff9d*/, 13 /*ff9e*/, 14 /*ff9f*/,
    10 /*ffa0*/, 11 /*ffa1*/, 11 /*ffa2*/, 12 /*ffa3*/, 11 /*ffa4*/,
    12 /*ffa5*/, 12 /*ffa6*/, 13 /*ffa7*/, 11 /*ffa8*/, 12 /*ffa9*/,
    12 /*ffaa*/, 13 /*ffab*/, 12 /*ffac*/, 13 /*ffad*/, 13 /*ffae*/,
    14 /*ffaf*/, 11 /*ffb0*/, 12 /*ffb1*/, 12 /*ffb2*/, 13 /*ffb3*/,
    12 /*ffb4*/, 13 /*ffb5*/, 13 /*ffb6*/, 14 /*ffb7*/, 12 /*ffb8*/,
    13 /*ffb9*/, 13 /*ffba*/, 14 /*ffbb*/, 13 /*ffbc*/, 14 /*ffbd*/,
    14 /*ffbe*/, 15 /*ffbf*/, 10 /*ffc0*/, 11 /*ffc1*/, 11 /*ffc2*/,
    12 /*ffc3*/, 11 /*ffc4*/, 12 /*ffc5*/, 12 /*ffc6*/, 13 /*ffc7*/,
    11 /*ffc8*/, 12 /*ffc9*/, 12 /*ffca*/, 13 /*ffcb*/, 12 /*ffcc*/,
    13 /*ffcd*/, 13 /*ffce*/, 14 /*ffcf*/, 11 /*ffd0*/, 12 /*ffd1*/,
    12 /*ffd2*/, 13 /*ffd3*/, 12 /*ffd4*/, 13 /*ffd5*/, 13 /*ffd6*/,
    14 /*ffd7*/, 12 /*ffd8*/, 13 /*ffd9*/, 13 /*ffda*/, 14 /*ffdb*/,
    13 /*ffdc*/, 14 /*ffdd*/, 14 /*ffde*/, 15 /*ffdf*/, 11 /*ffe0*/,
    12 /*ffe1*/, 12 /*ffe2*/, 13 /*ffe3*/, 12 /*ffe4*/, 13 /*ffe5*/,
    13 /*ffe6*/, 14 /*ffe7*/, 12 /*ffe8*/, 13 /*ffe9*/, 13 /*ffea*/,
    14 /*ffeb*/, 13 /*ffec*/, 14 /*ffed*/, 14 /*ffee*/, 15 /*ffef*/,
    12 /*fff0*/, 13 /*fff1*/, 13 /*fff2*/, 14 /*fff3*/, 13 /*fff4*/,
    14 /*fff5*/, 14 /*fff6*/, 15 /*fff7*/, 13 /*fff8*/, 14 /*fff9*/,
    14 /*fffa*/, 15 /*fffb*/, 14 /*fffc*/, 15 /*fffd*/, 15 /*fffe*/,
    16 /*ffff*/
};

// ----------------------------------------------------------------
int hammingNorm8(Hash8 h) {
  return hash8_norm_lookup_table[h];
}

// ----------------------------------------------------------------
int hammingNorm16(Hash16 h) {
  // return
  // hash8_norm_lookup_table[(h>> 8) & 0xff] +
  // hash8_norm_lookup_table[h & 0xff];
  return hash16_norm_lookup_table[h];
}

// ----------------------------------------------------------------
int hammingDistance8(Hash8 a, Hash8 b) {
  return hammingNorm8(a ^ b);
}

// ----------------------------------------------------------------
int hammingDistance16(Hash16 a, Hash16 b) {
  return hammingNorm16(a ^ b);
}

#endif

} // namespace hashing
} // namespace pdq
} // namespace facebook
